@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2021 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -138,6 +138,9 @@ import org.eclipse.jdt.internal.ui.util.ASTHelper;
 public class ASTView extends ViewPart implements IShowInSource, IShowInTargetList {
 
 	static final int JLS_LATEST= AST.getJLSLatest();
+	private static final int JLS19= ASTHelper.JLS19;
+	private static final int JLS18= ASTHelper.JLS18;
+	private static final int JLS17= ASTHelper.JLS17;
 	private static final int JLS16= ASTHelper.JLS16;
 	private static final int JLS15= ASTHelper.JLS15;
 	private static final int JLS14= ASTHelper.JLS14;
@@ -509,6 +512,9 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 				case JLS14:
 				case JLS15:
 				case JLS16:
+				case JLS17:
+				case JLS18:
+				case JLS19:
 					fCurrentASTLevel= level;
 			}
 		} catch (NumberFormatException e) {
@@ -1131,6 +1137,9 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 				new ASTLevelToggle("AST Level 1&4 (14)", JLS14), //$NON-NLS-1$
 				new ASTLevelToggle("AST Level 1&5 (15)", JLS15), //$NON-NLS-1$
 				new ASTLevelToggle("AST Level 1&6 (16)", JLS16), //$NON-NLS-1$
+				new ASTLevelToggle("AST Level 1&7 (17)", JLS17), //$NON-NLS-1$
+				new ASTLevelToggle("AST Level 1&8 (18)", JLS18), //$NON-NLS-1$
+				new ASTLevelToggle("AST Level 1&9 (19)", JLS19), //$NON-NLS-1$
 		};
 
 		fAddToTrayAction= new Action() {
