@@ -19,6 +19,8 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 
+import org.eclipse.core.runtime.Platform;
+
 import org.eclipse.jface.text.BadLocationException;
 import org.eclipse.jface.text.BadPositionCategoryException;
 import org.eclipse.jface.text.DocumentEvent;
@@ -65,9 +67,9 @@ public class SemanticHighlightingPresenterCore {
 			try {
 				Position[] positions= event.getDocument().getPositions(fCategory);
 
-				for (int i= 0; i != positions.length; i++) {
+				for (Position position2 : positions) {
 
-					HighlightedPositionCore position= (HighlightedPositionCore) positions[i];
+					HighlightedPositionCore position= (HighlightedPositionCore) position2;
 
 					// Also update deleted positions because they get deleted by the background thread and removed/invalidated only in the UI runnable
 //					if (position.isDeleted())
@@ -260,7 +262,7 @@ public class SemanticHighlightingPresenterCore {
 		try {
 			event.fDocument.addPosition(category, highlightedPosition);
 		} catch (BadLocationException | BadPositionCategoryException e) {
-			JavaManipulationPlugin.logException("Error when adding new highlighting position to the document", e); //$NON-NLS-1$
+			Platform.getLog(this.getClass()).error("Error when adding new highlighting position to the document", e); //$NON-NLS-1$
 		}
 
 	}
@@ -299,12 +301,7 @@ public class SemanticHighlightingPresenterCore {
 		if (isCanceled())
 			return null;
 
-		Runnable runnable= new Runnable() {
-			@Override
-			public void run() {
-				updatePresentationCore(document, added, removed);
-			}
-		};
+		Runnable runnable= () -> updatePresentationCore(document, added, removed);
 		return runnable;
 	}
 
@@ -386,10 +383,7 @@ public class SemanticHighlightingPresenterCore {
 				}
 				fPositions= newPositions;
 			}
-		} catch (BadPositionCategoryException e) {
-			// Should not happen
-			JavaManipulationPlugin.log(e);
-		} catch (BadLocationException e) {
+		} catch (BadPositionCategoryException | BadLocationException e) {
 			// Should not happen
 			JavaManipulationPlugin.log(e);
 		}
