@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2018, 2019 IBM Corporation and others.
+ * Copyright (c) 2018, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -161,18 +161,13 @@ public class SemanticHighlightingsCore {
 	public static final String INHERITED_FIELD="inheritedField"; //$NON-NLS-1$
 
 	/**
-	 * A named preference part that controls the highlighting of 'var' keywords.
+	 * A named preference part that controls the highlighting of 'sealed' and 'non-sealed' keywords.
 	 */
-	public static final String VAR_KEYWORD= "varKeyword"; //$NON-NLS-1$
-
-	/**
-	 * A named preference part that controls the highlighting of 'yield' keywords.
-	 */
-	public static final String YIELD_KEYWORD= "yieldKeyword"; //$NON-NLS-1$
+	public static final String RESTRICTED_KEYWORDS= "restrictedKeywords"; //$NON-NLS-1$
 
 	/**
 	 * Do not instantiate
 	 */
-	protected SemanticHighlightingsCore() {
+	private SemanticHighlightingsCore() {
 	}
 }
