@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Microsoft Corporation - add helper methods to read formatting options from the compilation unit
  *******************************************************************************/
 package org.eclipse.jdt.internal.core.manipulation.util;
 
@@ -22,6 +23,7 @@ import org.eclipse.jface.text.DefaultLineTracker;
 import org.eclipse.jface.text.ILineTracker;
 import org.eclipse.jface.text.IRegion;
 
+import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.formatter.IndentManipulation;
 
@@ -54,7 +56,7 @@ public class Strings {
 
 	/**
 	 * Adds special marks so that that the given string is readable in a BiDi environment.
-	 * 
+	 *
 	 * @param string the string
 	 * @return the processed styled string
 	 * @since 3.4
@@ -68,7 +70,7 @@ public class Strings {
 
 	/**
 	 * Adds special marks so that that the given string is readable in a BiDi environment.
-	 * 
+	 *
 	 * @param string the string
 	 * @param delimiters the delimiters
 	 * @return the processed styled string
@@ -84,7 +86,7 @@ public class Strings {
 	/**
 	 * Adds special marks so that that the given Java element label is readable in a BiDi
 	 * environment.
-	 * 
+	 *
 	 * @param string the string
 	 * @return the processed styled string
 	 * @since 3.6
@@ -118,7 +120,7 @@ public class Strings {
 	}
 
 	public static String removeNewLine(String message) {
-		StringBuffer result= new StringBuffer();
+		StringBuilder result= new StringBuilder();
 		int current= 0;
 		int index= message.indexOf('\n', 0);
 		while (index != -1) {
@@ -235,6 +237,18 @@ public class Strings {
 		return IndentManipulation.measureIndentUnits(line, CodeFormatterUtil.getTabWidth(project), CodeFormatterUtil.getIndentWidth(project));
 	}
 
+	/**
+	 * Returns the indent of the given string in indentation units. Odd spaces
+	 * are not counted.
+	 *
+	 * @param line the text line
+	 * @param cu the compilation unit from which to get the formatter preferences
+	 * @return the number of indent units
+	 */
+	public static int computeIndentUnits(String line, ICompilationUnit cu) {
+		return IndentManipulation.measureIndentUnits(line, CodeFormatterUtil.getTabWidth(cu), CodeFormatterUtil.getIndentWidth(cu));
+	}
+
 	/**
 	 * Returns the indent of the given string in indentation units. Odd spaces
 	 * are not counted.
@@ -281,6 +295,20 @@ public class Strings {
 		return IndentManipulation.trimIndent(line, indentsToRemove, CodeFormatterUtil.getTabWidth(project), CodeFormatterUtil.getIndentWidth(project));
 	}
 
+	/**
+	 * Removes the given number of indents from the line. Asserts that the given line
+	 * has the requested number of indents. If <code>indentsToRemove <= 0</code>
+	 * the line is returned.
+	 *
+	 * @param line the line
+	 * @param indentsToRemove the indents to remove
+	 * @param cu the compilation unit from which to get the formatter preferences
+	 * @return the trimmed line
+	 */
+	public static String trimIndent(String line, int indentsToRemove, ICompilationUnit cu) {
+		return IndentManipulation.trimIndent(line, indentsToRemove, CodeFormatterUtil.getTabWidth(cu), CodeFormatterUtil.getIndentWidth(cu));
+	}
+
 	/**
 	 * Removes the given number of indents from the line. Asserts that the given line
 	 * has the requested number of indents. If <code>indentsToRemove <= 0</code>
@@ -309,6 +337,7 @@ public class Strings {
 	public static void trimIndentation(String[] lines, IJavaProject project) {
 		trimIndentation(lines, CodeFormatterUtil.getTabWidth(project), CodeFormatterUtil.getIndentWidth(project), true);
 	}
+
 	/**
 	 * Removes the common number of indents from all lines. If a line
 	 * only consists out of white space it is ignored.
@@ -337,6 +366,19 @@ public class Strings {
 		trimIndentation(lines, CodeFormatterUtil.getTabWidth(project), CodeFormatterUtil.getIndentWidth(project), considerFirstLine);
 	}
 
+	/**
+	 * Removes the common number of indents from all lines. If a line
+	 * only consists out of white space it is ignored. If <code>
+	 * considerFirstLine</code> is false the first line will be ignored.
+	 *
+	 * @param lines the lines
+	 * @param cu the compilation unit from which to get the formatter preferences
+	 * @param considerFirstLine  If <code>considerFirstLine</code> is false the first line will be ignored.
+	 */
+	public static void trimIndentation(String[] lines, ICompilationUnit cu, boolean considerFirstLine) {
+		trimIndentation(lines, CodeFormatterUtil.getTabWidth(cu), CodeFormatterUtil.getIndentWidth(cu), considerFirstLine);
+	}
+
 	/**
 	 * Removes the common number of indents from all lines. If a line
 	 * only consists out of white space it is ignored. If <code>
@@ -394,6 +436,18 @@ public class Strings {
 		return IndentManipulation.extractIndentString(line, CodeFormatterUtil.getTabWidth(project), CodeFormatterUtil.getIndentWidth(project));
 	}
 
+	/**
+	 * Returns that part of the indentation of <code>line</code> that makes up
+	 * a multiple of indentation units.
+	 *
+	 * @param line the line to scan
+	 * @param cu the compilation unit from which to get the formatter preferences
+	 * @return the indent part of <code>line</code>, but no odd spaces
+	 */
+	public static String getIndentString(String line, ICompilationUnit cu) {
+		return IndentManipulation.extractIndentString(line, CodeFormatterUtil.getTabWidth(cu), CodeFormatterUtil.getIndentWidth(cu));
+	}
+
 	/**
 	 * Returns that part of the indentation of <code>line</code> that makes up
 	 * a multiple of indentation units.
@@ -411,15 +465,13 @@ public class Strings {
 	public static String[] removeTrailingEmptyLines(String[] sourceLines) {
 		int lastNonEmpty= findLastNonEmptyLineIndex(sourceLines);
 		String[] result= new String[lastNonEmpty + 1];
-		for (int i= 0; i < result.length; i++) {
-			result[i]= sourceLines[i];
-		}
+		System.arraycopy(sourceLines, 0, result, 0, result.length);
 		return result;
 	}
 
 	private static int findLastNonEmptyLineIndex(String[] sourceLines) {
 		for (int i= sourceLines.length - 1; i >= 0; i--) {
-			if (! sourceLines[i].trim().equals(""))//$NON-NLS-1$
+			if (! sourceLines[i].trim().isEmpty())
 				return i;
 		}
 		return -1;
@@ -443,6 +495,22 @@ public class Strings {
 		return IndentManipulation.changeIndent(code, codeIndentLevel, CodeFormatterUtil.getTabWidth(project), CodeFormatterUtil.getIndentWidth(project), newIndent, lineDelim);
 	}
 
+	/**
+	 * Change the indent of, possible multi-line, code range. The current indent is removed, a new indent added.
+	 * The first line of the code will not be changed. (It is considered to have no indent as it might start in
+	 * the middle of a line)
+	 *
+	 * @param code the code
+	 * @param codeIndentLevel level of indentation
+	 * @param cu the compilation unit from which to get the formatter preferences
+	 * @param newIndent new indent
+	 * @param lineDelim line delimiter
+	 * @return the changed code
+	 */
+	public static String changeIndent(String code, int codeIndentLevel, ICompilationUnit cu, String newIndent, String lineDelim) {
+		return IndentManipulation.changeIndent(code, codeIndentLevel, CodeFormatterUtil.getTabWidth(cu), CodeFormatterUtil.getIndentWidth(cu), newIndent, lineDelim);
+	}
+
 	/**
 	 * Change the indent of, possible muti-line, code range. The current indent is removed, a new indent added.
 	 * The first line of the code will not be changed. (It is considered to have no indent as it might start in
@@ -464,6 +532,10 @@ public class Strings {
 		return trimIndentation(source, CodeFormatterUtil.getTabWidth(project), CodeFormatterUtil.getIndentWidth(project), considerFirstLine);
 	}
 
+	public static String trimIndentation(String source, ICompilationUnit cu, boolean considerFirstLine) {
+		return trimIndentation(source, CodeFormatterUtil.getTabWidth(cu), CodeFormatterUtil.getIndentWidth(cu), considerFirstLine);
+	}
+
 	public static String trimIndentation(String source, int tabWidth, int indentWidth, boolean considerFirstLine) {
 		try {
 			ILineTracker tracker= new DefaultLineTracker();
@@ -478,7 +550,7 @@ public class Strings {
 				lines[i]= source.substring(offset, offset + region.getLength());
 			}
 			Strings.trimIndentation(lines, tabWidth, indentWidth, considerFirstLine);
-			StringBuffer result= new StringBuffer();
+			StringBuilder result= new StringBuilder();
 			int last= size - 1;
 			for (int i= 0; i < size; i++) {
 				result.append(lines[i]);
@@ -501,7 +573,7 @@ public class Strings {
 	 * @return the concatenated lines
 	 */
 	public static String concatenate(String[] lines, String delimiter) {
-		StringBuffer buffer= new StringBuffer();
+		StringBuilder buffer= new StringBuilder();
 		for (int i= 0; i < lines.length; i++) {
 			if (i > 0)
 				buffer.append(delimiter);
