@@ -17,7 +17,6 @@ package org.eclipse.jdt.internal.corext.codemanipulation.tostringgeneration;
 
 import java.util.ArrayList;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 
@@ -66,8 +65,8 @@ import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
 import org.eclipse.jdt.core.dom.VariableDeclarationStatement;
 import org.eclipse.jdt.core.manipulation.CodeGeneration;
 
-import org.eclipse.jdt.internal.corext.codemanipulation.StubUtility2Core;
 import org.eclipse.jdt.internal.core.manipulation.StubUtility;
+import org.eclipse.jdt.internal.corext.codemanipulation.StubUtility2Core;
 import org.eclipse.jdt.internal.corext.dom.ASTNodeFactory;
 
 /**
@@ -137,16 +136,12 @@ import org.eclipse.jdt.internal.corext.dom.ASTNodeFactory;
  * @since 3.5
  */
 public abstract class AbstractToStringGenerator {
-
 	protected static final String METHODNAME_TO_STRING= "toString"; //$NON-NLS-1$
-
 	protected static final String TYPENAME_STRING= "String"; //$NON-NLS-1$
 
-	final protected String HELPER_TOSTRING_METHOD_NAME= "toString"; //$NON-NLS-1$
+	private static final String HELPER_ARRAYTOSTRING_METHOD_NAME= "arrayToString"; //$NON-NLS-1$
+	private static final String MAX_LEN_VARIABLE_NAME= "maxLen"; //$NON-NLS-1$
 
-	final private String HELPER_ARRAYTOSTRING_METHOD_NAME= "arrayToString"; //$NON-NLS-1$
-
-	final private String MAX_LEN_VARIABLE_NAME= "maxLen"; //$NON-NLS-1$
 	protected String fMaxLenVariableName= MAX_LEN_VARIABLE_NAME;
 
 	/**
@@ -154,7 +149,7 @@ public abstract class AbstractToStringGenerator {
 	* This property determines whether the method should be overwritten if already exists. The data
 	* of this property is a Boolean.
 	*/
-	protected final static String OVERWRITE_METHOD_PROPERTY= "override_method"; //$NON-NLS-1$
+	protected static final String OVERWRITE_METHOD_PROPERTY= "override_method"; //$NON-NLS-1$
 
 	public ToStringTemplateParser getTemplateParser() {
 		return new ToStringTemplateParser();
@@ -191,7 +186,6 @@ public abstract class AbstractToStringGenerator {
 			addElement(processElement(element, null));
 		}
 
-		fContext.getTemplateParser().getBody();
 		Object[] members= fContext.getSelectedMembers();
 		for (int i= 0; i < members.length; i++) {
 			if (!fContext.isSkipNulls() || getMemberType(members[i]).isPrimitive())
@@ -230,7 +224,7 @@ public abstract class AbstractToStringGenerator {
 		ITypeBinding object= fAst.resolveWellKnownType("java.lang.Object"); //$NON-NLS-1$
 		IMethodBinding objectMethod= null;
 		for (IMethodBinding objm : object.getDeclaredMethods()) {
-			if (objm.getName().equals(METHODNAME_TO_STRING) && objm.getParameterTypes().length == 0) {
+			if (METHODNAME_TO_STRING.equals(objm.getName()) && objm.getParameterTypes().length == 0) {
 				objectMethod= objm;
 			}
 		}
@@ -274,7 +268,7 @@ public abstract class AbstractToStringGenerator {
 
 		//private arrayToString() {
 		MethodDeclaration arrayToStringMethod= fAst.newMethodDeclaration();
-		arrayToStringMethod.setName(fAst.newSimpleName(array ? HELPER_ARRAYTOSTRING_METHOD_NAME : HELPER_TOSTRING_METHOD_NAME));
+		arrayToStringMethod.setName(fAst.newSimpleName(array ? HELPER_ARRAYTOSTRING_METHOD_NAME : METHODNAME_TO_STRING));
 		arrayToStringMethod.modifiers().add(fAst.newModifier(Modifier.ModifierKeyword.PRIVATE_KEYWORD));
 		arrayToStringMethod.setReturnType2(fAst.newSimpleType(fAst.newName(TYPENAME_STRING)));
 
@@ -372,20 +366,19 @@ public abstract class AbstractToStringGenerator {
 			// i < length;
 			forStatement.setExpression(createInfixExpression(fAst.newSimpleName(indexName), Operator.LESS, fAst.newSimpleName(lengthParamName)));
 
-			for (Iterator<ITypeBinding> iterator= typesThatNeedArrayToStringMethod.iterator(); iterator.hasNext();) {
-				ITypeBinding typeBinding= iterator.next();
+			for (ITypeBinding typeBinding : typesThatNeedArrayToStringMethod) {
 				//if (array instanceof int[]) {
 				String typeName= typeBinding.getName();
 				PrimitiveType.Code code= null;
-				if (typeName.equals("byte")) code= PrimitiveType.BYTE; //$NON-NLS-1$
-				if (typeName.equals("short")) code= PrimitiveType.SHORT; //$NON-NLS-1$
-				if (typeName.equals("char")) code= PrimitiveType.CHAR; //$NON-NLS-1$
-				if (typeName.equals("int")) code= PrimitiveType.INT; //$NON-NLS-1$
-				if (typeName.equals("long")) code= PrimitiveType.LONG; //$NON-NLS-1$
-				if (typeName.equals("float")) code= PrimitiveType.FLOAT; //$NON-NLS-1$
-				if (typeName.equals("double")) code= PrimitiveType.DOUBLE; //$NON-NLS-1$
-				if (typeName.equals("boolean")) code= PrimitiveType.BOOLEAN; //$NON-NLS-1$
-				if (code == null && !typeName.equals("Object"))continue; //$NON-NLS-1$
+				if ("byte".equals(typeName)) code= PrimitiveType.BYTE; //$NON-NLS-1$
+				if ("short".equals(typeName)) code= PrimitiveType.SHORT; //$NON-NLS-1$
+				if ("char".equals(typeName)) code= PrimitiveType.CHAR; //$NON-NLS-1$
+				if ("int".equals(typeName)) code= PrimitiveType.INT; //$NON-NLS-1$
+				if ("long".equals(typeName)) code= PrimitiveType.LONG; //$NON-NLS-1$
+				if ("float".equals(typeName)) code= PrimitiveType.FLOAT; //$NON-NLS-1$
+				if ("double".equals(typeName)) code= PrimitiveType.DOUBLE; //$NON-NLS-1$
+				if ("boolean".equals(typeName)) code= PrimitiveType.BOOLEAN; //$NON-NLS-1$
+				if (code == null && !"Object".equals(typeName))continue; //$NON-NLS-1$
 				InstanceofExpression instanceOf= fAst.newInstanceofExpression();
 				instanceOf.setLeftOperand(fAst.newSimpleName(paramName));
 				instanceOf.setRightOperand(fAst.newArrayType(code != null ? (Type)fAst.newPrimitiveType(code) : fAst.newSimpleType(addImport("java.lang.Object")))); //$NON-NLS-1$
@@ -444,7 +437,7 @@ public abstract class AbstractToStringGenerator {
 
 		//return stringBuilder.toString();
 		ReturnStatement returnStatement= fAst.newReturnStatement();
-		returnStatement.setExpression(createMethodInvocation(stringBuilderName, "toString", null)); //$NON-NLS-1$
+		returnStatement.setExpression(createMethodInvocation(stringBuilderName, METHODNAME_TO_STRING, null));
 		body.statements().add(returnStatement);
 
 		arrayToStringMethod.setProperty(OVERWRITE_METHOD_PROPERTY, Boolean.valueOf(array));
@@ -528,10 +521,10 @@ public abstract class AbstractToStringGenerator {
 	 */
 	protected Object processElement(String templateElement, Object member) {
 		Object result= templateElement;
-		if (templateElement == ToStringTemplateParser.OBJECT_NAME_VARIABLE) {
+		if (ToStringTemplateParser.OBJECT_NAME_VARIABLE.equals(templateElement)) {
 			result= fContext.getTypeBinding().getName();
 		}
-		if (templateElement == ToStringTemplateParser.OBJECT_GET_NAME_VARIABLE) {
+		if (ToStringTemplateParser.OBJECT_GET_NAME_VARIABLE.equals(templateElement)) {
 			//this.getClass().getName()
 			MethodInvocation getClassInvocation= fAst.newMethodInvocation();
 			if (fContext.isKeywordThis())
@@ -542,13 +535,13 @@ public abstract class AbstractToStringGenerator {
 			getNameInvocation.setName(fAst.newSimpleName("getName")); //$NON-NLS-1$
 			result= getNameInvocation;
 		}
-		if (templateElement == ToStringTemplateParser.OBJECT_SUPER_TOSTRING_VARIABLE) {
+		if (ToStringTemplateParser.OBJECT_SUPER_TOSTRING_VARIABLE.equals(templateElement)) {
 			//super.toString()
 			SuperMethodInvocation superToStringInvocation= fAst.newSuperMethodInvocation();
 			superToStringInvocation.setName(fAst.newSimpleName(METHODNAME_TO_STRING));
 			result= superToStringInvocation;
 		}
-		if (templateElement == ToStringTemplateParser.OBJECT_HASHCODE_VARIABLE) {
+		if (ToStringTemplateParser.OBJECT_HASHCODE_VARIABLE.equals(templateElement)) {
 			//this.hashCode()
 			MethodInvocation hashCodeInvocation= fAst.newMethodInvocation();
 			if (fContext.isKeywordThis())
@@ -556,14 +549,14 @@ public abstract class AbstractToStringGenerator {
 			hashCodeInvocation.setName(fAst.newSimpleName("hashCode")); //$NON-NLS-1$
 			result= hashCodeInvocation;
 		}
-		if (templateElement == ToStringTemplateParser.OBJECT_SYSTEM_HASHCODE_VARIABLE) {
+		if (ToStringTemplateParser.OBJECT_SYSTEM_HASHCODE_VARIABLE.equals(templateElement)) {
 			//system.identityHashCode(this)
 			result= createMethodInvocation(addImport("java.lang.System"), "identityHashCode", fAst.newThisExpression()); //$NON-NLS-1$ //$NON-NLS-2$
 		}
-		if (templateElement == ToStringTemplateParser.MEMBER_NAME_VARIABLE || templateElement == ToStringTemplateParser.MEMBER_NAME_PARENTHESIS_VARIABLE) {
+		if (ToStringTemplateParser.MEMBER_NAME_VARIABLE.equals(templateElement) || ToStringTemplateParser.MEMBER_NAME_PARENTHESIS_VARIABLE.equals(templateElement)) {
 			result= getMemberName(member, templateElement);
 		}
-		if (templateElement == ToStringTemplateParser.MEMBER_VALUE_VARIABLE) {
+		if (ToStringTemplateParser.MEMBER_VALUE_VARIABLE.equals(templateElement)) {
 			result= createMemberAccessExpression(member, false, fContext.isSkipNulls());
 		}
 		if (result instanceof StringLiteral)
@@ -724,7 +717,7 @@ public abstract class AbstractToStringGenerator {
 							MethodInvocation toStringInvocation= fAst.newMethodInvocation();
 							if (fContext.isKeywordThis())
 								toStringInvocation.setExpression(fAst.newThisExpression());
-							toStringInvocation.setName(fAst.newSimpleName(HELPER_TOSTRING_METHOD_NAME));
+							toStringInvocation.setName(fAst.newSimpleName(METHODNAME_TO_STRING));
 							toStringInvocation.arguments().add(memberAccess);
 							toStringInvocation.arguments().add(fAst.newSimpleName(fMaxLenVariableName));
 							needMaxLenVariable= true;
@@ -748,7 +741,7 @@ public abstract class AbstractToStringGenerator {
 									MethodInvocation copyOfInvocation= createMethodInvocation(arraysImport, "copyOf", createMemberAccessExpression(member, true, true)); //$NON-NLS-1$
 									copyOfInvocation.arguments().add(minInvocation);
 									Name arraysImportCopy= (Name)ASTNode.copySubtree(fAst, arraysImport);
-									accessExpression= createMethodInvocation(arraysImportCopy, "toString", copyOfInvocation); //$NON-NLS-1$
+									accessExpression= createMethodInvocation(arraysImportCopy, METHODNAME_TO_STRING, copyOfInvocation);
 								} else {
 									// arrayToString(member, member.length, maxLen)
 									MethodInvocation arrayToStringInvocation= fAst.newMethodInvocation();
@@ -768,7 +761,7 @@ public abstract class AbstractToStringGenerator {
 					if (isArray && fContext.isCustomArray()) {
 						if (fContext.is50orHigher()) {
 							// Arrays.toString(member)
-							return createMethodInvocation(addImport("java.util.Arrays"), "toString", createMemberAccessExpression(member, true, true)); //$NON-NLS-1$ //$NON-NLS-2$
+							return createMethodInvocation(addImport("java.util.Arrays"), METHODNAME_TO_STRING, createMemberAccessExpression(member, true, true)); //$NON-NLS-1$
 						} else {
 							ITypeBinding arrayComponentType= memberType.getComponentType();
 							if (!arrayComponentType.isPrimitive() && typesThatNeedArrayToStringMethod.isEmpty()) {
@@ -812,7 +805,7 @@ public abstract class AbstractToStringGenerator {
 			return fAst.newSimpleName(((IVariableBinding)member).getName());
 		}
 		if (member instanceof IMethodBinding) {
-			if (((IMethodBinding)member).getName().equals(METHODNAME_TO_STRING)) {
+			if (METHODNAME_TO_STRING.equals(((IMethodBinding)member).getName())) {
 				SuperMethodInvocation invocation= fAst.newSuperMethodInvocation();
 				invocation.setName(fAst.newSimpleName(((IMethodBinding)member).getName()));
 				return invocation;
@@ -921,7 +914,7 @@ public abstract class AbstractToStringGenerator {
 		}
 		if (member instanceof IMethodBinding) {
 			String result= ((IMethodBinding)member).getName();
-			if (templateElement == ToStringTemplateParser.MEMBER_NAME_PARENTHESIS_VARIABLE)
+			if (ToStringTemplateParser.MEMBER_NAME_PARENTHESIS_VARIABLE.equals(templateElement))
 				result+= "()"; //$NON-NLS-1$
 			return result;
 		}
