@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2021 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -379,6 +379,16 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 		endVisit((Expression)node);
 	}
 
+	@Override
+	public boolean visit(CaseDefaultExpression node) {
+		return visit((Expression)node);
+	}
+
+	@Override
+	public void endVisit(CaseDefaultExpression node) {
+		endVisit((Expression)node);
+	}
+
 	@Override
 	public boolean visit(CastExpression node) {
 		return visit((Expression)node);
@@ -601,6 +611,26 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 
 	//---- End Name Hierarchy ------------------------------------
 
+	@Override
+	public boolean visit(RecordPattern node) {
+		return visit((Pattern)node);
+	}
+
+	@Override
+	public void endVisit(RecordPattern node) {
+		endVisit((Pattern)node);
+	}
+
+	@Override
+	public boolean visit(GuardedPattern node) {
+		return visit((Pattern)node);
+	}
+
+	@Override
+	public void endVisit(GuardedPattern node) {
+		endVisit((Pattern)node);
+	}
+
 	@Override
 	public boolean visit(NullLiteral node) {
 		return visit((Expression)node);
@@ -611,6 +641,16 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 		endVisit((Expression)node);
 	}
 
+	@Override
+	public boolean visit(NullPattern node) {
+		return visit((Pattern)node);
+	}
+
+	@Override
+	public void endVisit(NullPattern node) {
+		endVisit((Pattern)node);
+	}
+
 	@Override
 	public boolean visit(NumberLiteral node) {
 		return visit((Expression)node);
@@ -621,6 +661,14 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 		endVisit((Expression)node);
 	}
 
+	public boolean visit(Pattern node) {
+		return visit((Expression)node);
+	}
+
+	public void endVisit(Pattern node) {
+		endVisit((Expression)node);
+	}
+
 	@Override
 	public boolean visit(ParenthesizedExpression node) {
 		return visit((Expression)node);
@@ -711,6 +759,16 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 		endVisit((Expression)node);
 	}
 
+	@Override
+	public boolean visit(TypePattern node) {
+		return visit((Pattern)node);
+	}
+
+	@Override
+	public void endVisit(TypePattern node) {
+		endVisit((Pattern)node);
+	}
+
 	@Override
 	public boolean visit(VariableDeclarationExpression node) {
 		return visit((Expression)node);
@@ -1119,26 +1177,71 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 
 //---- End Statement Hierarchy ----------------------------------
 
+	public boolean visit(AbstractTagElement node) {
+		return visit((ASTNode)node);
+	}
+
+	public void endVisit(AbstractTagElement node) {
+		endVisit((ASTNode)node);
+	}
+
 	@Override
 	public boolean visit(TagElement node) {
-		return visit((ASTNode)node);
+		return visit((AbstractTagElement)node);
 	}
 
 	@Override
 	public void endVisit(TagElement node) {
+		endVisit((AbstractTagElement)node);
+	}
+
+	public boolean visit(AbstractTextElement node) {
+		return visit((ASTNode)node);
+	}
+
+	public void endVisit(AbstractTextElement node) {
 		endVisit((ASTNode)node);
 	}
 
 	@Override
 	public boolean visit(TextElement node) {
-		return visit((ASTNode)node);
+		return visit((AbstractTextElement)node);
 	}
 
 	@Override
 	public void endVisit(TextElement node) {
+		endVisit((AbstractTextElement)node);
+	}
+
+	@Override
+	public boolean visit(JavaDocTextElement node) {
+		return visit((AbstractTextElement)node);
+	}
+
+	@Override
+	public void endVisit(JavaDocTextElement node) {
+		endVisit((AbstractTextElement)node);
+	}
+
+	@Override
+	public boolean visit(TagProperty node) {
+		return visit((ASTNode)node);
+	}
+
+	@Override
+	public void endVisit(TagProperty node) {
 		endVisit((ASTNode)node);
 	}
 
+	@Override
+	public boolean visit(JavaDocRegion node) {
+		return visit((AbstractTagElement)node);
+	}
+
+	@Override
+	public void endVisit(JavaDocRegion node) {
+		endVisit((AbstractTagElement)node);
+	}
 
 //---- Begin Type Hierarchy --------------------------------------
 	public boolean visit(Type node) {
