@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2013, 2020 IBM Corporation and others.
+ * Copyright (c) 2013, 2021 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,6 +12,7 @@
  *     Jerome Cambon <jerome.cambon@oracle.com> - [1.8][clean up][quick assist] Convert lambda to anonymous must qualify references to 'this'/'super' - https://bugs.eclipse.org/430573
  *     Stephan Herrmann - Contribution for Bug 463360 - [override method][null] generating method override should not create redundant null annotations
  *     Red Hat Inc. - modified to create core class in jdt.core.manipulation
+ *     Microsoft Corporation - read preferences from the compilation unit
  *******************************************************************************/
 package org.eclipse.jdt.internal.corext.fix;
 
@@ -19,8 +20,9 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
+import java.util.Objects;
+import java.util.Set;
 
 import org.eclipse.core.runtime.CoreException;
 
@@ -54,6 +56,7 @@ import org.eclipse.jdt.core.dom.Modifier;
 import org.eclipse.jdt.core.dom.Name;
 import org.eclipse.jdt.core.dom.NormalAnnotation;
 import org.eclipse.jdt.core.dom.QualifiedName;
+import org.eclipse.jdt.core.dom.QualifiedType;
 import org.eclipse.jdt.core.dom.ReturnStatement;
 import org.eclipse.jdt.core.dom.SimpleName;
 import org.eclipse.jdt.core.dom.SingleMemberAnnotation;
@@ -63,6 +66,7 @@ import org.eclipse.jdt.core.dom.SuperFieldAccess;
 import org.eclipse.jdt.core.dom.SuperMethodInvocation;
 import org.eclipse.jdt.core.dom.ThisExpression;
 import org.eclipse.jdt.core.dom.Type;
+import org.eclipse.jdt.core.dom.TypeDeclaration;
 import org.eclipse.jdt.core.dom.VariableDeclaration;
 import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
 import org.eclipse.jdt.core.dom.rewrite.ASTRewrite;
@@ -78,6 +82,7 @@ import org.eclipse.jdt.internal.corext.codemanipulation.ContextSensitiveImportRe
 import org.eclipse.jdt.internal.corext.codemanipulation.StubUtility2Core;
 import org.eclipse.jdt.internal.corext.dom.ASTNodeFactory;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
+import org.eclipse.jdt.internal.corext.dom.AbortSearchException;
 import org.eclipse.jdt.internal.corext.dom.Bindings;
 import org.eclipse.jdt.internal.corext.dom.HierarchicalASTVisitor;
 import org.eclipse.jdt.internal.corext.dom.LinkedNodeFinder;
@@ -89,9 +94,7 @@ import org.eclipse.jdt.internal.corext.util.JdtFlags;
 import org.eclipse.jdt.internal.ui.preferences.JavaPreferencesSettings;
 
 public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFixCore {
-
 	public static final class FunctionalAnonymousClassesFinder extends ASTVisitor {
-
 		private final ArrayList<ClassInstanceCreation> fNodes= new ArrayList<>();
 
 		public static ArrayList<ClassInstanceCreation> perform(ASTNode node) {
@@ -110,7 +113,6 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 	}
 
 	public static final class LambdaExpressionsFinder extends ASTVisitor {
-
 		private final ArrayList<LambdaExpression> fNodes= new ArrayList<>();
 
 		public static ArrayList<LambdaExpression> perform(ASTNode node) {
@@ -129,12 +131,7 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 		}
 	}
 
-	public static class AbortSearchException extends RuntimeException {
-		private static final long serialVersionUID= 1L;
-	}
-
 	public static final class SuperThisReferenceFinder extends HierarchicalASTVisitor {
-
 		private ITypeBinding fFunctionalInterface;
 		private MethodDeclaration fMethodDeclaration;
 
@@ -206,14 +203,11 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 	}
 
 	public static final class FinalFieldAccessInFieldDeclarationFinder extends HierarchicalASTVisitor {
-
 		private MethodDeclaration fMethodDeclaration;
 		private ASTNode fFieldDeclaration;
 		static boolean hasReference(MethodDeclaration node) {
 			try {
 				FinalFieldAccessInFieldDeclarationFinder finder= new FinalFieldAccessInFieldDeclarationFinder();
-				ClassInstanceCreation cic= (ClassInstanceCreation) node.getParent().getParent();
-				cic.getType().resolveBinding();
 				finder.fMethodDeclaration= node;
 				finder.fFieldDeclaration= finder.findFieldDeclaration(node);
 				if (finder.fFieldDeclaration == null) {
@@ -281,7 +275,6 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 
 		@Override
 		public boolean visit(SimpleName node) {
-			node.getParent();
 			IBinding binding= node.resolveBinding();
 			checkForUninitializedFinalReference(binding);
 			return true;
@@ -289,7 +282,6 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 
 		@Override
 		public boolean visit(QualifiedName node) {
-			node.getParent();
 			IBinding binding= node.resolveBinding();
 			checkForUninitializedFinalReference(binding);
 			return true;
@@ -309,7 +301,6 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 	}
 
 	public static final class SuperThisQualifier extends HierarchicalASTVisitor {
-
 		private ITypeBinding fQualifierTypeBinding;
 		private ImportRewrite fImportRewrite;
 		private ASTRewrite fASTRewrite;
@@ -391,8 +382,61 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 		}
 	}
 
-	public static class CreateLambdaOperation extends CompilationUnitRewriteOperation {
+	private static final class MethodRecursionFinder extends HierarchicalASTVisitor {
+		private MethodDeclaration fMethodDeclaration;
+		private IMethodBinding fMethodBinding;
+		private ASTNode fFieldDeclaration;
 
+		private static boolean isRecursiveLocal(MethodDeclaration node) {
+			try {
+				MethodRecursionFinder finder= new MethodRecursionFinder();
+				finder.fMethodDeclaration= node;
+				finder.fFieldDeclaration= finder.findFieldDeclaration(node);
+				if (finder.fFieldDeclaration != null) {
+					return false;
+				}
+				finder.fMethodBinding= finder.fMethodDeclaration.resolveBinding();
+				if (finder.fMethodBinding == null) {
+					return false;
+				}
+				node.accept(finder);
+			} catch (AbortSearchException e) {
+				return true;
+			}
+
+			return false;
+		}
+
+		private ASTNode findFieldDeclaration(ASTNode node) {
+			ASTNode originalNode= node;
+			while (node != null) {
+				if (node instanceof FieldDeclaration) {
+					return node;
+				}
+				if (node instanceof AbstractTypeDeclaration) {
+					return null;
+				}
+				if (node instanceof MethodDeclaration && node != originalNode) {
+					return null;
+				}
+				node= node.getParent();
+			}
+			return null;
+		}
+
+		@Override
+		public boolean visit(MethodInvocation node) {
+			if (node.getExpression() == null) {
+				IMethodBinding binding= node.resolveMethodBinding();
+				if (binding != null && binding.isEqualTo(fMethodBinding)) {
+					throw new AbortSearchException();
+				}
+			}
+			return true;
+		}
+	}
+
+	public static class CreateLambdaOperation extends CompilationUnitRewriteOperation {
 		private final List<ClassInstanceCreation> fExpressions;
 
 		public CreateLambdaOperation(List<ClassInstanceCreation> expressions) {
@@ -402,23 +446,23 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 		@Override
 		public void rewriteAST(CompilationUnitRewrite cuRewrite, LinkedProposalModelCore model) throws CoreException {
 
-			ASTRewrite rewrite= cuRewrite.getASTRewrite();
+			final ASTRewrite rewrite= cuRewrite.getASTRewrite();
 			ImportRemover importRemover= cuRewrite.getImportRemover();
-			AST ast= rewrite.getAST();
+			final AST ast= rewrite.getAST();
 
 			HashMap<ClassInstanceCreation, HashSet<String>> cicToNewNames= new HashMap<>();
 			for (int i= 0; i < fExpressions.size(); i++) {
 				ClassInstanceCreation classInstanceCreation= fExpressions.get(i);
-				TextEditGroup group= createTextEditGroup(FixMessages.LambdaExpressionsFix_convert_to_lambda_expression, cuRewrite);
 
 				AnonymousClassDeclaration anonymTypeDecl= classInstanceCreation.getAnonymousClassDeclaration();
 				List<BodyDeclaration> bodyDeclarations= anonymTypeDecl.bodyDeclarations();
 
 				Object object= bodyDeclarations.get(0);
+
 				if (!(object instanceof MethodDeclaration)) {
 					continue;
 				}
-				MethodDeclaration methodDeclaration= (MethodDeclaration) object;
+
 				HashSet<String> excludedNames= new HashSet<>();
 				if (i != 0) {
 					for (ClassInstanceCreation convertedCic : fExpressions.subList(0, i)) {
@@ -427,6 +471,9 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 						}
 					}
 				}
+
+				final MethodDeclaration methodDeclaration= (MethodDeclaration) object;
+				TextEditGroup group= createTextEditGroup(FixMessages.LambdaExpressionsFix_convert_to_lambda_expression, cuRewrite);
 				HashSet<String> newNames= makeNamesUnique(excludedNames, methodDeclaration, rewrite, group);
 				cicToNewNames.put(classInstanceCreation, new HashSet<>(newNames));
 				List<SingleVariableDeclaration> methodParameters= methodDeclaration.parameters();
@@ -439,6 +486,7 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 						break;
 					}
 				}
+
 				LambdaExpression lambdaExpression= ast.newLambdaExpression();
 				List<VariableDeclaration> lambdaParameters= lambdaExpression.parameters();
 				lambdaExpression.setParentheses(createExplicitlyTypedParameters || methodParameters.size() != 1);
@@ -468,10 +516,143 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 						}
 					}
 				}
+
+				final Set<ITypeBinding> inheritedTypes= new HashSet<>();
+				collectInheritedTypes(anonymTypeDecl.resolveBinding(), inheritedTypes);
+
+				ASTVisitor inheritedFieldsVisitor= new ASTVisitor() {
+					@Override
+					public boolean visit(final SimpleName node) {
+						if ((!(node.getParent() instanceof QualifiedName) || node.getLocationInParent() != QualifiedName.NAME_PROPERTY)
+								&& (!(node.getParent() instanceof FieldAccess) || node.getLocationInParent() != FieldAccess.NAME_PROPERTY)
+								&& (!(node.getParent() instanceof SuperFieldAccess) || node.getLocationInParent() != SuperFieldAccess.NAME_PROPERTY)
+								&& node.resolveBinding() != null
+								&& node.resolveBinding().getKind() == IBinding.VARIABLE) {
+							IVariableBinding variableBinding= (IVariableBinding) node.resolveBinding();
+
+							if (variableBinding != null
+									&& (variableBinding.getModifiers() & Modifier.STATIC) != 0
+									&& variableBinding.isField()
+									&& inheritedTypes.contains(variableBinding.getDeclaringClass())) {
+								Type copyOfClassName= (Type) rewrite.createCopyTarget(classInstanceCreation.getType());
+								QualifiedType replacement= ast.newQualifiedType(copyOfClassName, ASTNodes.createMoveTarget(rewrite, node));
+								rewrite.replace(node, replacement, group);
+								return false;
+							}
+						}
+
+						return true;
+					}
+				};
+				lambdaBody.accept(inheritedFieldsVisitor);
+
+				ASTNode fragment= ASTNodes.getFirstAncestorOrNull(classInstanceCreation, VariableDeclarationFragment.class, BodyDeclaration.class);
+
+				if (fragment instanceof VariableDeclarationFragment) {
+					final VariableDeclarationFragment actualFragment= (VariableDeclarationFragment) fragment;
+
+					if (actualFragment.getParent() instanceof FieldDeclaration) {
+						FieldDeclaration fieldDeclaration= (FieldDeclaration) actualFragment.getParent();
+
+						TypeDeclaration declarationClass= ASTNodes.getFirstAncestorOrNull(fieldDeclaration, TypeDeclaration.class);
+
+						if (declarationClass != null) {
+							TypeDeclaration typeDeclaration= declarationClass;
+
+							final List<FieldDeclaration> nextFields= new ArrayList<>(typeDeclaration.getFields().length);
+							boolean isBefore= true;
+
+							for (FieldDeclaration oneField : typeDeclaration.getFields()) {
+								if (oneField == fieldDeclaration) {
+									isBefore= false;
+								}
+
+								if (!isBefore) {
+									nextFields.add(oneField);
+								}
+							}
+
+							ASTVisitor visitor= new ASTVisitor() {
+								@Override
+								public boolean visit(final MethodInvocation node) {
+									ITypeBinding fieldType= fieldDeclaration.getType().resolveBinding();
+									ASTNode declaration= ASTNodes.findDeclaration(node.resolveMethodBinding(), declarationClass);
+
+									if (node.getExpression() == null && fieldType != null && methodDeclaration == declaration) {
+										ASTNode replacement;
+
+										if ((fieldDeclaration.getModifiers() & Modifier.STATIC) != 0) {
+											SimpleName copyOfClassName= (SimpleName) rewrite.createCopyTarget(typeDeclaration.getName());
+											replacement= ast.newQualifiedName(copyOfClassName, (SimpleName) rewrite.createCopyTarget(actualFragment.getName()));
+										} else {
+											FieldAccess newFieldAccess= ast.newFieldAccess();
+											newFieldAccess.setExpression(ast.newThisExpression());
+											newFieldAccess.setName((SimpleName) rewrite.createCopyTarget(actualFragment.getName()));
+											replacement= newFieldAccess;
+										}
+
+										rewrite.set(node, MethodInvocation.EXPRESSION_PROPERTY, replacement, group);
+
+										return false;
+									}
+
+									return true;
+								}
+
+								@Override
+								public boolean visit(final SimpleName node) {
+									if ((!(node.getParent() instanceof QualifiedName) || node.getLocationInParent() != QualifiedName.NAME_PROPERTY)
+											&& (!(node.getParent() instanceof FieldAccess) || node.getLocationInParent() != FieldAccess.NAME_PROPERTY)
+											&& (!(node.getParent() instanceof SuperFieldAccess) || node.getLocationInParent() != SuperFieldAccess.NAME_PROPERTY)) {
+										ASTNode declaration= ASTNodes.findDeclaration(node.resolveBinding(), declarationClass);
+
+										if (declaration instanceof VariableDeclarationFragment && declaration.getParent() instanceof FieldDeclaration) {
+											FieldDeclaration currentField= (FieldDeclaration) declaration.getParent();
+
+											if (nextFields.contains(currentField)) {
+												if ((currentField.getModifiers() & Modifier.STATIC) != 0) {
+													SimpleName copyOfClassName= (SimpleName) rewrite.createCopyTarget(typeDeclaration.getName());
+													QualifiedName replacement= ast.newQualifiedName(copyOfClassName, ASTNodes.createMoveTarget(rewrite, node));
+													rewrite.replace(node, replacement, group);
+												} else {
+													FieldAccess newFieldAccess= ast.newFieldAccess();
+													newFieldAccess.setExpression(ast.newThisExpression());
+													newFieldAccess.setName(ASTNodes.createMoveTarget(rewrite, node));
+													rewrite.replace(node, newFieldAccess, group);
+												}
+
+												return false;
+											}
+										}
+									}
+
+									return true;
+								}
+
+								@Override
+								public boolean visit(final ThisExpression node) {
+									Name qualifier= node.getQualifier();
+
+									if (qualifier != null
+											&& qualifier.resolveBinding() != null
+											&& qualifier.resolveBinding().getKind() == IBinding.TYPE
+											&& Objects.equals(qualifier.resolveBinding(), typeDeclaration.resolveBinding())) {
+										rewrite.remove(qualifier, group);
+									}
+
+									return true;
+								}
+							};
+							lambdaBody.accept(visitor);
+						}
+					}
+				}
+
 				//TODO: Bug 421479: [1.8][clean up][quick assist] convert anonymous to lambda must consider lost scope of interface
 				//				lambdaBody.accept(new InterfaceAccessQualifier(rewrite, classInstanceCreation.getType().resolveBinding())); //TODO: maybe need a separate ASTRewrite and string placeholder
 
 				lambdaExpression.setBody(ASTNodes.getCopyOrReplacement(rewrite, lambdaBody, group));
+
 				Expression replacement= lambdaExpression;
 				ITypeBinding targetTypeBinding= ASTNodes.getTargetType(classInstanceCreation);
 				if (ASTNodes.isTargetAmbiguous(classInstanceCreation, ASTNodes.isExplicitlyTypedLambda(lambdaExpression)) || targetTypeBinding.getFunctionalInterfaceMethod() == null) {
@@ -491,9 +672,30 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 			}
 		}
 
-		private HashSet<String> makeNamesUnique(HashSet<String> excludedNames, MethodDeclaration methodDeclaration, ASTRewrite rewrite, TextEditGroup group) {
+		private static void collectInheritedTypes(final ITypeBinding anonymType, final Set<ITypeBinding> inheritedTypes) {
+			if (anonymType != null) {
+				ITypeBinding motherType= anonymType.getSuperclass();
+
+				if (motherType != null) {
+					inheritedTypes.add(motherType);
+					collectInheritedTypes(motherType, inheritedTypes);
+				}
+
+				ITypeBinding[] interfaces= anonymType.getInterfaces();
+
+				if (interfaces != null && interfaces.length > 0) {
+					Collections.addAll(inheritedTypes, interfaces);
+
+					for (ITypeBinding iTypeBinding : interfaces) {
+						collectInheritedTypes(iTypeBinding, inheritedTypes);
+					}
+				}
+			}
+		}
+
+		private HashSet<String> makeNamesUnique(HashSet<String> namesFromUpperScope, MethodDeclaration methodDeclaration, ASTRewrite rewrite, TextEditGroup group) {
 			HashSet<String> newNames= new HashSet<>();
-			excludedNames.addAll(ASTNodes.getVisibleLocalVariablesInScope(methodDeclaration));
+			namesFromUpperScope.addAll(ASTNodes.getVisibleLocalVariablesInScope(methodDeclaration));
 			List<SimpleName> simpleNamesInMethod= getNamesInMethod(methodDeclaration);
 			List<String> namesInMethod= new ArrayList<>();
 			for (SimpleName name : simpleNamesInMethod) {
@@ -503,10 +705,9 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 			for (int i= 0; i < simpleNamesInMethod.size(); i++) {
 				SimpleName name= simpleNamesInMethod.get(i);
 				String identifier= namesInMethod.get(i);
-				HashSet<String> allNamesToExclude= getNamesToExclude(excludedNames, namesInMethod, i);
-				if (allNamesToExclude.contains(identifier)) {
-					String newIdentifier= createName(identifier, allNamesToExclude);
-					excludedNames.add(newIdentifier);
+				if (namesFromUpperScope.contains(identifier)) {
+					String newIdentifier= createName(identifier, namesFromUpperScope, namesInMethod, newNames);
+					namesFromUpperScope.add(newIdentifier);
 					newNames.add(newIdentifier);
 					SimpleName[] references= LinkedNodeFinder.findByNode(name.getRoot(), name);
 					for (SimpleName ref : references) {
@@ -518,13 +719,6 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 			return newNames;
 		}
 
-		private HashSet<String> getNamesToExclude(HashSet<String> excludedNames, List<String> namesInMethod, int i) {
-			HashSet<String> allNamesToExclude= new HashSet<>(excludedNames);
-			allNamesToExclude.addAll(namesInMethod.subList(0, i));
-			allNamesToExclude.addAll(namesInMethod.subList(i + 1, namesInMethod.size()));
-			return allNamesToExclude;
-		}
-
 		private List<SimpleName> getNamesInMethod(MethodDeclaration methodDeclaration) {
 			class NamesCollector extends HierarchicalASTVisitor {
 				private int fTypeCounter;
@@ -569,19 +763,19 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 			return namesCollector.fNames;
 		}
 
-		private String createName(String candidate, HashSet<String> excludedNames) {
+		private String createName(String candidate, HashSet<String> excludedNames, List<String> namesInMethod, HashSet<String> newNames) {
 			int i= 1;
 			String result= candidate;
-			while (excludedNames.contains(result)) {
+			while (excludedNames.contains(result) || newNames.contains(result) || namesInMethod.contains(result)) {
 				result= candidate + i++;
 			}
 			return result;
 		}
 	}
 
-	public static interface IAnonymousClassCreationOperation {
+	public interface IAnonymousClassCreationOperation {
 
-		public MethodDeclaration getMethodDeclaration(ICompilationUnit cu, ASTRewrite rewrite, ImportRewrite rewrites,
+		MethodDeclaration getMethodDeclaration(ICompilationUnit cu, ASTRewrite rewrite, ImportRewrite rewrites,
 				ImportRewriteContext context, IMethodBinding binding, String[] parameterNames, ITypeBinding targetType,
 				boolean inInterface, ASTNode astNode) throws CoreException;
 
@@ -599,7 +793,7 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 		public MethodDeclaration getMethodDeclaration(ICompilationUnit cu, ASTRewrite rewrite, ImportRewrite rewrites,
 				ImportRewriteContext context, IMethodBinding binding, String[] parameterNames, ITypeBinding targetType,
 				boolean inInterface, ASTNode astNode) throws CoreException {
-			final CodeGenerationSettings settings= JavaPreferencesSettings.getCodeGenerationSettings(cu.getJavaProject());
+			final CodeGenerationSettings settings= JavaPreferencesSettings.getCodeGenerationSettings(cu);
 			MethodDeclaration methodDeclaration= StubUtility2Core.createImplementationStubCore(cu, rewrite, rewrites, context, binding, parameterNames, targetType, settings, inInterface,
 					astNode,
 					false);
@@ -616,8 +810,7 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 			ASTRewrite rewrite= cuRewrite.getASTRewrite();
 			AST ast= rewrite.getAST();
 
-			for (Iterator<LambdaExpression> iterator= fExpressions.iterator(); iterator.hasNext();) {
-				LambdaExpression lambdaExpression= iterator.next();
+			for (LambdaExpression lambdaExpression : fExpressions) {
 				TextEditGroup group= createTextEditGroup(FixMessages.LambdaExpressionsFix_convert_to_anonymous_class_creation, cuRewrite);
 
 				ITypeBinding lambdaTypeBinding= lambdaExpression.resolveTypeBinding();
@@ -693,7 +886,7 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 
 	public static LambdaExpressionsFixCore createConvertToLambdaFix(ClassInstanceCreation cic) {
 		CompilationUnit root= (CompilationUnit) cic.getRoot();
-		if (!JavaModelUtil.is18OrHigher(root.getJavaElement().getJavaProject())) {
+		if (!JavaModelUtil.is1d8OrHigher(root.getJavaElement().getJavaProject())) {
 			return null;
 		}
 
@@ -724,7 +917,7 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 	}
 
 	public static ICleanUpFixCore createCleanUp(CompilationUnit compilationUnit, boolean useLambda, boolean useAnonymous) {
-		if (!JavaModelUtil.is18OrHigher(compilationUnit.getJavaElement().getJavaProject())) {
+		if (!JavaModelUtil.is1d8OrHigher(compilationUnit.getJavaElement().getJavaProject())) {
 			return null;
 		}
 
@@ -816,6 +1009,11 @@ public class LambdaExpressionsFixCore extends CompilationUnitRewriteOperationsFi
 			return false;
 		}
 
+		// Cannot handle recursive calls in a locally declared anonymous class
+		if (MethodRecursionFinder.isRecursiveLocal(methodDecl)) {
+			return false;
+		}
+
 		// Check if annotations other than @Override and @Deprecated will be removed
 		checkAnnotationsRemoval(methodBinding);
 
