@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -323,7 +323,7 @@ public class PromoteTempToFieldRefactoring extends Refactoring {
 	public RefactoringStatus checkInitialConditions(IProgressMonitor pm) throws CoreException {
 		RefactoringStatus result= Checks.validateModifiesFiles(
 			ResourceUtil.getFiles(new ICompilationUnit[]{fCu}),
-			getValidationContext());
+			getValidationContext(), pm);
 		if (result.hasFatalError())
 			return result;
 
@@ -395,8 +395,8 @@ public class PromoteTempToFieldRefactoring extends Refactoring {
 		if (type instanceof TypeDeclaration) {
 			FieldDeclaration[] fields= ((TypeDeclaration) type).getFields();
 			List<String> result= new ArrayList<>(fields.length);
-			for (int i= 0; i < fields.length; i++) {
-				for (Iterator<VariableDeclarationFragment> iter= fields[i].fragments().iterator(); iter.hasNext();) {
+			for (FieldDeclaration field2 : fields) {
+				for (Iterator<VariableDeclarationFragment> iter= field2.fragments().iterator(); iter.hasNext();) {
 					VariableDeclarationFragment field= iter.next();
 					result.add(field.getName().getIdentifier());
 				}
@@ -482,9 +482,7 @@ public class PromoteTempToFieldRefactoring extends Refactoring {
 		Assert.isTrue(!isDeclaredInAnonymousClass());
 		final AbstractTypeDeclaration declaration= (AbstractTypeDeclaration) getMethodDeclaration().getParent();
 		if (declaration instanceof TypeDeclaration) {
-			MethodDeclaration[] methods= ((TypeDeclaration) declaration).getMethods();
-			for (int i= 0; i < methods.length; i++) {
-				MethodDeclaration method= methods[i];
+			for (MethodDeclaration method : ((TypeDeclaration) declaration).getMethods()) {
 				if (!method.isConstructor())
 					continue;
 				NameCollector nameCollector= new NameCollector(method) {
@@ -506,12 +504,9 @@ public class PromoteTempToFieldRefactoring extends Refactoring {
 	}
 
     private RefactoringStatus checkClashesWithExistingFields(){
-        FieldDeclaration[] existingFields= getFieldDeclarations();
-        for (int i= 0; i < existingFields.length; i++) {
-            FieldDeclaration declaration= existingFields[i];
-			VariableDeclarationFragment[] fragments= (VariableDeclarationFragment[]) declaration.fragments().toArray(new VariableDeclarationFragment[declaration.fragments().size()]);
-			for (int j= 0; j < fragments.length; j++) {
-                VariableDeclarationFragment fragment= fragments[j];
+        for (FieldDeclaration declaration : getFieldDeclarations()) {
+            VariableDeclarationFragment[] fragments= (VariableDeclarationFragment[]) declaration.fragments().toArray(new VariableDeclarationFragment[declaration.fragments().size()]);
+			for (VariableDeclarationFragment fragment : fragments) {
                 if (fFieldName.equals(fragment.getName().getIdentifier())){
                 	//cannot conflict with more than 1 name
                 	RefactoringStatusContext context= JavaStatusContext.create(fCu, fragment);
@@ -525,8 +520,8 @@ public class PromoteTempToFieldRefactoring extends Refactoring {
     private FieldDeclaration[] getFieldDeclarations() {
     	List<BodyDeclaration> bodyDeclarations= ASTNodes.getBodyDeclarations(getMethodDeclaration().getParent());
     	List<FieldDeclaration> fields= new ArrayList<>(1);
-    	for (Iterator<BodyDeclaration> iter= bodyDeclarations.iterator(); iter.hasNext();) {
-	        Object each= iter.next();
+    	for (BodyDeclaration bodyDeclaration : bodyDeclarations) {
+	        Object each= bodyDeclaration;
 	        if (each instanceof FieldDeclaration)
 	        	fields.add((FieldDeclaration) each);
         }
@@ -578,11 +573,9 @@ public class PromoteTempToFieldRefactoring extends Refactoring {
 		}
     	TempOccurrenceAnalyzer analyzer= new TempOccurrenceAnalyzer(fTempDeclarationNode, false);
 		analyzer.perform();
-    	SimpleName[] tempRefs= analyzer.getReferenceNodes(); // no javadocs (refactoring not for parameters)
 
-
-		for (int j= 0; j < tempRefs.length; j++) {
-			SimpleName occurence= tempRefs[j];
+		// no javadocs (refactoring not for parameters)
+		for (SimpleName occurence : analyzer.getReferenceNodes()) {
 			if (noNameChange) {
 				addLinkedName(rewrite, occurence, false);
 			} else {
@@ -611,9 +604,9 @@ public class PromoteTempToFieldRefactoring extends Refactoring {
     		int insertionIndex= computeInsertIndexForNewConstructor(declaration);
 			rewrite.getListRewrite(declaration, declaration.getBodyDeclarationsProperty()).insertAt(newConstructor, insertionIndex, null);
     	} else {
-    		for (int index= 0; index < constructors.length; index++) {
-                if (shouldInsertTempInitialization(constructors[index]))
-                    addFieldInitializationToConstructor(rewrite, constructors[index]);
+    		for (MethodDeclaration constructor : constructors) {
+                if (shouldInsertTempInitialization(constructor))
+                    addFieldInitializationToConstructor(rewrite, constructor);
             }
     	}
     }
@@ -678,8 +671,7 @@ public class PromoteTempToFieldRefactoring extends Refactoring {
 		if (typeDeclaration instanceof TypeDeclaration) {
 			MethodDeclaration[] allMethods= ((TypeDeclaration) typeDeclaration).getMethods();
 			List<MethodDeclaration> result= new ArrayList<>(Math.min(allMethods.length, 1));
-			for (int i= 0; i < allMethods.length; i++) {
-				MethodDeclaration declaration= allMethods[i];
+			for (MethodDeclaration declaration : allMethods) {
 				if (declaration.isConstructor())
 					result.add(declaration);
 			}
@@ -725,11 +717,11 @@ public class PromoteTempToFieldRefactoring extends Refactoring {
 		final ConvertLocalVariableDescriptor descriptor= RefactoringSignatureDescriptorFactory.createConvertLocalVariableDescriptor(project, description, comment.asString(), arguments, RefactoringDescriptor.STRUCTURAL_CHANGE);
 		arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_INPUT, JavaRefactoringDescriptorUtil.elementToHandle(project, fCu));
 		arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_NAME, fFieldName);
-		arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_SELECTION, Integer.valueOf(fSelectionStart).toString() + " " + Integer.valueOf(fSelectionLength).toString()); //$NON-NLS-1$
-		arguments.put(ATTRIBUTE_STATIC, Boolean.valueOf(fDeclareStatic).toString());
-		arguments.put(ATTRIBUTE_FINAL, Boolean.valueOf(fDeclareFinal).toString());
-		arguments.put(ATTRIBUTE_VISIBILITY, Integer.valueOf(fVisibility).toString());
-		arguments.put(ATTRIBUTE_INITIALIZE, Integer.valueOf(fInitializeIn).toString());
+		arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_SELECTION, Integer.toString(fSelectionStart) + " " + Integer.toString(fSelectionLength)); //$NON-NLS-1$
+		arguments.put(ATTRIBUTE_STATIC, Boolean.toString(fDeclareStatic));
+		arguments.put(ATTRIBUTE_FINAL, Boolean.toString(fDeclareFinal));
+		arguments.put(ATTRIBUTE_VISIBILITY, Integer.toString(fVisibility));
+		arguments.put(ATTRIBUTE_INITIALIZE, Integer.toString(fInitializeIn));
 		return descriptor;
 	}
 
@@ -947,9 +939,9 @@ public class PromoteTempToFieldRefactoring extends Refactoring {
 			int length= -1;
 			final StringTokenizer tokenizer= new StringTokenizer(selection);
 			if (tokenizer.hasMoreTokens())
-				offset= Integer.valueOf(tokenizer.nextToken()).intValue();
+				offset= Integer.parseInt(tokenizer.nextToken());
 			if (tokenizer.hasMoreTokens())
-				length= Integer.valueOf(tokenizer.nextToken()).intValue();
+				length= Integer.parseInt(tokenizer.nextToken());
 			if (offset >= 0 && length >= 0) {
 				fSelectionStart= offset;
 				fSelectionLength= length;
@@ -993,12 +985,12 @@ public class PromoteTempToFieldRefactoring extends Refactoring {
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, JavaRefactoringDescriptorUtil.ATTRIBUTE_NAME));
 		final String declareStatic= arguments.getAttribute(ATTRIBUTE_STATIC);
 		if (declareStatic != null) {
-			fDeclareStatic= Boolean.valueOf(declareStatic).booleanValue();
+			fDeclareStatic= Boolean.parseBoolean(declareStatic);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_STATIC));
 		final String declareFinal= arguments.getAttribute(ATTRIBUTE_FINAL);
 		if (declareFinal != null) {
-			fDeclareFinal= Boolean.valueOf(declareFinal).booleanValue();
+			fDeclareFinal= Boolean.parseBoolean(declareFinal);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_FINAL));
 		return new RefactoringStatus();
