@@ -16,5 +16,5 @@ package org.eclipse.jdt.internal.corext.refactoring.reorg;
 import org.eclipse.core.runtime.OperationCanceledException;
 
 public interface INewNameQuery {
-	public	String getNewName() throws OperationCanceledException;
+	String getNewName() throws OperationCanceledException;
 }
