@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -12,13 +12,13 @@
  *     IBM Corporation - initial API and implementation
  *     Jerome Cambon <jerome.cambon@oracle.com> - [code style] don't generate redundant modifiers "public static final abstract" for interface members - https://bugs.eclipse.org/71627
  *     Microsoft Corporation - copied to jdt.core.manipulation
+ *     Microsoft Corporation - read formatting options from the compilation unit
  *******************************************************************************/
 package org.eclipse.jdt.internal.corext.refactoring.structure;
 
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
-import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -233,10 +233,9 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 		List<MoveParticipant> result= new ArrayList<>();
 		MoveArguments args= new MoveArguments(fDestinationType, true);
 		String[] natures= JavaProcessors.computeAffectedNaturs(fMembersToMove);
-		for (int i= 0; i < fMembersToMove.length; i++) {
-			IMember member= fMembersToMove[i];
+		for (IMember memberToMove : fMembersToMove) {
 			result.addAll(Arrays.asList(ParticipantManager.loadMoveParticipants(
-				status, this, member, args, natures, sharedParticipants)));
+				status, this, memberToMove, args, natures, sharedParticipants)));
 		}
 		return result.toArray(new RefactoringParticipant[result.size()]);
 	}
@@ -246,8 +245,8 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 	@Override
 	public boolean canEnableDelegateUpdating() {
 		try {
-			for (int i= 0; i < fMembersToMove.length; i++) {
-				if (isDelegateCreationAvailable(fMembersToMove[i]))
+			for (IMember memberToMove : fMembersToMove) {
+				if (isDelegateCreationAvailable(memberToMove))
 					return true;
 			}
 		} catch (JavaModelException e) {
@@ -344,8 +343,8 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 	}
 
 	private boolean hasUnresolvedMemberBinding() {
-		for (int i= 0; i < fMemberBindings.length; i++) {
-			if (fMemberBindings[i] == null)
+		for (IBinding memberBinding : fMemberBindings) {
+			if (memberBinding == null)
 				return true;
 		}
 		return false;
@@ -354,7 +353,7 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 	private RefactoringStatus checkDeclaringType(){
 		IType declaringType= getDeclaringType();
 
-		if (declaringType.getFullyQualifiedName('.').equals("java.lang.Object")) //$NON-NLS-1$
+		if ("java.lang.Object".equals(declaringType.getFullyQualifiedName('.'))) //$NON-NLS-1$
 			return RefactoringStatus.createFatalErrorStatus(RefactoringCoreMessages.MoveMembersRefactoring_Object);
 
 		if (declaringType.isBinary())
@@ -397,10 +396,9 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 
 			List<ICompilationUnit> modifiedCus= new ArrayList<>();
 			createChange(modifiedCus, result, new SubProgressMonitor(pm, 7));
-			IFile[] changedFiles= getAllFilesToModify(modifiedCus);
 			ResourceChangeChecker checker= context.getChecker(ResourceChangeChecker.class);
-			for (int i= 0; i < changedFiles.length; i++) {
-				checker.getDeltaFactory().change(changedFiles[i]);
+			for (IFile changedFile : getAllFilesToModify(modifiedCus)) {
+				checker.getDeltaFactory().change(changedFile);
 			}
 
 			return result;
@@ -413,13 +411,12 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 		Set<IResource> result= new HashSet<>();
 		IResource resource= fDestinationType.getCompilationUnit().getResource();
 		result.add(resource);
-		for (int i= 0; i < fMembersToMove.length; i++) {
-			resource= fMembersToMove[i].getCompilationUnit().getResource();
+		for (IMember memberToMove : fMembersToMove) {
+			resource= memberToMove.getCompilationUnit().getResource();
 			if (resource != null)
 				result.add(resource);
 		}
-		for (Iterator<ICompilationUnit> iter= modifiedCus.iterator(); iter.hasNext();) {
-			ICompilationUnit unit= iter.next();
+		for (ICompilationUnit unit : modifiedCus) {
 			if (unit.getResource() != null)
 				result.add(unit.getResource());
 		}
@@ -459,7 +456,7 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 
 		// no checking required for moving interface fields to classes
 
-		if (! (JdtFlags.isStatic(fDestinationType) || fDestinationType.getDeclaringType() == null)){
+		if (!JdtFlags.isStatic(fDestinationType) && fDestinationType.getDeclaringType() != null) {
 			String message= RefactoringCoreMessages.MoveMembersRefactoring_static_declaration;
 			result.addError(message);
 		}
@@ -469,10 +466,10 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 
 	private RefactoringStatus checkDestinationInsideTypeToMove() throws JavaModelException {
 		RefactoringStatus result= new RefactoringStatus();
-		for (int i= 0; i < fMembersToMove.length; i++) {
-			if (! (fMembersToMove[i] instanceof IType))
+		for (IMember memberToMove : fMembersToMove) {
+			if (! (memberToMove instanceof IType))
 				continue;
-			IType type= (IType) fMembersToMove[i];
+			IType type= (IType) memberToMove;
 			if (fDestinationType.equals(type) || JavaElementUtil.isAncestorOf(type, fDestinationType)) {
 				String message= Messages.format(RefactoringCoreMessages.MoveMembersRefactoring_inside,
 						new String[] { getQualifiedTypeLabel(type), getQualifiedTypeLabel(fDestinationType)});
@@ -486,19 +483,19 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 
 	private RefactoringStatus checkMoveToInterface() throws JavaModelException {
 		//could be more clever and make field final if it is only written once...
-		boolean is18OrHigher= JavaModelUtil.is18OrHigher(fDestinationType.getJavaProject());
+		boolean is18OrHigher= JavaModelUtil.is1d8OrHigher(fDestinationType.getJavaProject());
 		RefactoringStatus result= new RefactoringStatus();
 		boolean declaringIsInterface= getDeclaringType().isInterface();
 		if (declaringIsInterface && is18OrHigher)
 			return result;
 		String moveMembersMsg= is18OrHigher ? RefactoringCoreMessages.MoveMembersRefactoring_only_public_static_18 : RefactoringCoreMessages.MoveMembersRefactoring_only_public_static;
-		for (int i= 0; i < fMembersToMove.length; i++) {
-			if (declaringIsInterface && !(fMembersToMove[i] instanceof IMethod) && !is18OrHigher) {
+		for (IMember memberToMove : fMembersToMove) {
+			if (declaringIsInterface && !(memberToMove instanceof IMethod) && !is18OrHigher) {
 				// moving from interface to interface is OK, unless method is moved to pre-18
-			} else if (!canMoveToInterface(fMembersToMove[i], is18OrHigher)) {
-				result.addError(moveMembersMsg, JavaStatusContext.create(fMembersToMove[i]));
-			} else if (!Flags.isPublic(fMembersToMove[i].getFlags()) && !declaringIsInterface) {
-				result.addWarning(RefactoringCoreMessages.MoveMembersRefactoring_member_will_be_public, JavaStatusContext.create(fMembersToMove[i]));
+			} else if (!canMoveToInterface(memberToMove, is18OrHigher)) {
+				result.addError(moveMembersMsg, JavaStatusContext.create(memberToMove));
+			} else if (!Flags.isPublic(memberToMove.getFlags()) && !declaringIsInterface) {
+				result.addWarning(RefactoringCoreMessages.MoveMembersRefactoring_member_will_be_public, JavaStatusContext.create(memberToMove));
 			}
 		}
 		return result;
@@ -508,7 +505,7 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 		int flags= member.getFlags();
 		switch (member.getElementType()) {
 			case IJavaElement.FIELD:
-				if (!(Flags.isStatic(flags) && Flags.isFinal(flags)))
+				if (!Flags.isStatic(flags) || !Flags.isFinal(flags))
 					return false;
 				if (Flags.isEnum(flags))
 					return false;
@@ -535,19 +532,18 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 		if (memberToMove instanceof IType) { // recursively check accessibility of member type's members
 			IJavaElement[] typeMembers= ((IType) memberToMove).getChildren();
 			pm.beginTask(RefactoringCoreMessages.MoveMembersRefactoring_checking, typeMembers.length + 1);
-			for (int i= 0; i < typeMembers.length; i++) {
-				if (typeMembers[i] instanceof IInitializer)
+			for (IJavaElement typeMember : typeMembers) {
+				if (typeMember instanceof IInitializer)
 					pm.worked(1);
 				else
-					result.merge(checkMovedMemberAvailability((IMember) typeMembers[i], new SubProgressMonitor(pm, 1)));
+					result.merge(checkMovedMemberAvailability((IMember) typeMember, new SubProgressMonitor(pm, 1)));
 			}
 		} else {
 			pm.beginTask(RefactoringCoreMessages.MoveMembersRefactoring_checking, 1);
 		}
 
-		IType[] blindAccessorTypes= getTypesNotSeeingMovedMember(memberToMove, new SubProgressMonitor(pm, 1), result);
-		for (int k= 0; k < blindAccessorTypes.length; k++) {
-			String message= createNonAccessibleMemberMessage(memberToMove, blindAccessorTypes[k],/*moved*/true);
+		for (IType blindAccessorType : getTypesNotSeeingMovedMember(memberToMove, new SubProgressMonitor(pm, 1), result)) {
+			String message= createNonAccessibleMemberMessage(memberToMove, blindAccessorType,/*moved*/true);
 			result.addError(message, JavaStatusContext.create(memberToMove));
 		}
 		pm.done();
@@ -559,11 +555,8 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 			return new IType[0];
 
 		HashSet<IType> blindAccessorTypes= new HashSet<>(); // referencing, but access to destination type illegal
-		SearchResultGroup[] references= getReferences(member, new SubProgressMonitor(pm, 1), status);
-		for (int i = 0; i < references.length; i++) {
-			SearchMatch[] searchResults= references[i].getSearchResults();
-			for (int k= 0; k < searchResults.length; k++) {
-				SearchMatch searchResult= searchResults[k];
+		for (SearchResultGroup reference : getReferences(member, new SubProgressMonitor(pm, 1), status)) {
+			for (SearchMatch searchResult : reference.getSearchResults()) {
 				IJavaElement element= SearchUtils.getEnclosingJavaElement(searchResult);
 				IType type= (IType) element.getAncestor(IJavaElement.TYPE);
 				if (type != null //reference can e.g. be an import declaration
@@ -638,7 +631,11 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 	}
 
 	private static SearchResultGroup[] getReferences(IMember member, IProgressMonitor monitor, RefactoringStatus status) throws JavaModelException {
-		final RefactoringSearchEngine2 engine= new RefactoringSearchEngine2(SearchPattern.createPattern(member, IJavaSearchConstants.REFERENCES, SearchUtils.GENERICS_AGNOSTIC_MATCH_RULE));
+		SearchPattern pattern= SearchPattern.createPattern(member, IJavaSearchConstants.REFERENCES, SearchUtils.GENERICS_AGNOSTIC_MATCH_RULE);
+		if (pattern == null) {
+			return new SearchResultGroup[0];
+		}
+		final RefactoringSearchEngine2 engine= new RefactoringSearchEngine2(pattern);
 		engine.setFiltering(true, true);
 		engine.setScope(RefactoringScopeFactory.create(member));
 		engine.setStatus(status);
@@ -691,8 +688,8 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 		if (! referenceCU.equals(fSource.getCu()))
 			return false;
 		int referenceStart= result.getOffset();
-		for (int i= 0; i < fMembersToMove.length; i++) {
-			ISourceRange range= fMembersToMove[i].getSourceRange();
+		for (IMember memberToMove : fMembersToMove) {
+			ISourceRange range= memberToMove.getSourceRange();
 			if (range.getOffset() <= referenceStart && range.getOffset() + range.getLength() >= referenceStart)
 				return true;
 		}
@@ -702,14 +699,14 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 	private RefactoringStatus checkNativeMovedMethods(IProgressMonitor pm) throws JavaModelException{
 		pm.beginTask(RefactoringCoreMessages.MoveMembersRefactoring_checking, fMembersToMove.length);
 		RefactoringStatus result= new RefactoringStatus();
-		for (int i= 0; i < fMembersToMove.length; i++) {
-			if (fMembersToMove[i].getElementType() != IJavaElement.METHOD)
+		for (IMember memberToMove : fMembersToMove) {
+			if (memberToMove.getElementType() != IJavaElement.METHOD)
 				continue;
-			if (! JdtFlags.isNative(fMembersToMove[i]))
+			if (! JdtFlags.isNative(memberToMove))
 				continue;
 			String message= Messages.format(RefactoringCoreMessages.MoveMembersRefactoring_native,
-				JavaElementUtil.createMethodSignature((IMethod)fMembersToMove[i]));
-			result.addWarning(message, JavaStatusContext.create(fMembersToMove[i]));
+				JavaElementUtil.createMethodSignature((IMethod) memberToMove));
+			result.addWarning(message, JavaStatusContext.create(memberToMove));
 			pm.worked(1);
 		}
 		pm.done();
@@ -735,12 +732,10 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 
 		try {
 			Map<IMember, IncomingMemberVisibilityAdjustment> adjustments= new HashMap<>();
-			IMember member= null;
 			SubProgressMonitor sub= new SubProgressMonitor(monitor, 1, SubProgressMonitor.SUPPRESS_SUBTASK_LABEL);
 			sub.beginTask(RefactoringCoreMessages.MoveMembersRefactoring_creating, fMembersToMove.length);
 			Set<IMember> rewritten= new HashSet<>();
-			for (int index= 0; index < fMembersToMove.length; index++) {
-				member= fMembersToMove[index];
+			for (IMember member : fMembersToMove) {
 				final MemberVisibilityAdjustor adjustor= new MemberVisibilityAdjustor(fDestinationType, member);
 				adjustor.setAdjustments(adjustments);
 				adjustor.setStatus(status);
@@ -764,8 +759,8 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 				// error message if not (for example, when moving into a private type)
 				status.merge(checkMovedMemberAvailability(member, new SubProgressMonitor(sub, 1)));
 				// Put rewrite info into code and into status
-				for (final Iterator<IMember> iterator= rewritten.iterator(); iterator.hasNext();) {
-					adjustments.remove(iterator.next());
+				for (IMember iMember : rewritten) {
+					adjustments.remove(iMember);
 				}
 				rewritten.addAll(adjustments.keySet());
 				adjustor.rewriteVisibility(new NullProgressMonitor());
@@ -806,8 +801,7 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 			final MemberVisibilityAdjustor adjustor= new MemberVisibilityAdjustor(fDestinationType, fDestinationType);
 			sub= new SubProgressMonitor(monitor, 1);
 			sub.beginTask(RefactoringCoreMessages.MoveMembersRefactoring_creating, units.length);
-			for (int index= 0; index < units.length; index++) {
-				ICompilationUnit unit= units[index];
+			for (ICompilationUnit unit : units) {
 				CompilationUnitRewrite rewrite= getCuRewrite(unit);
 				adjustor.setRewrites(Collections.singletonMap(unit, rewrite));
 				adjustor.setAdjustments(adjustments);
@@ -819,7 +813,7 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 					fChange= null;
 					return;
 				}
-				if (!(fSource.getCu().equals(unit) || fTarget.getCu().equals(unit)))
+				if (!fSource.getCu().equals(unit) && !fTarget.getCu().equals(unit))
 					fChange.add(rewrite.createChange(true));
 			}
 			status.merge(moveMembers(fMemberDeclarations, memberSources));
@@ -909,8 +903,7 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 		boolean targetNeedsSourceImport= false;
 		boolean isSourceNotTarget= fSource != fTarget;
 		Set<IBinding> exclude= new HashSet<>();
-		for (int i= 0; i < members.length; i++) {
-			BodyDeclaration declaration= members[i];
+		for (BodyDeclaration declaration : members) {
 			if (declaration instanceof AbstractTypeDeclaration) {
 				AbstractTypeDeclaration type= (AbstractTypeDeclaration) declaration;
 				ITypeBinding binding= type.resolveBinding();
@@ -932,8 +925,7 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 			}
 		}
 		ImportRewriteContext context= new ContextSensitiveImportRewriteContext(getDestinationNode(), fTarget.getImportRewrite());
-		for (int i= 0; i < members.length; i++) {
-			BodyDeclaration declaration= members[i];
+		for (BodyDeclaration declaration : members) {
 			if (isSourceNotTarget)
 				typeRefs.addAll(TypeReferenceFinder.perform(declaration));
 			MovedMemberAnalyzer analyzer= new MovedMemberAnalyzer(fSource, fMemberBindings, fSourceBinding, target);
@@ -979,15 +971,15 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 			fTarget.getImportRewrite().addImport(fSourceBinding, context);
 		}
 		if (isSourceNotTarget) {
-			for (Iterator<IBinding> iter= typeRefs.iterator(); iter.hasNext();) {
-				ITypeBinding binding= (ITypeBinding) iter.next();
+			for (IBinding iBinding : typeRefs) {
+				ITypeBinding binding= (ITypeBinding) iBinding;
 				fTarget.getImportRewrite().addImport(binding, context);
 			}
 		}
 		// extract updated members
 		String[] updatedMemberSources= new String[members.length];
 		IDocument document= new Document(fSource.getCu().getBuffer().getContents());
-		TextEdit edit= fSource.getASTRewrite().rewriteAST(document, fSource.getCu().getJavaProject().getOptions(true));
+		TextEdit edit= fSource.getASTRewrite().rewriteAST(document, fSource.getCu().getOptions(true));
 		edit.apply(document, TextEdit.UPDATE_REGIONS);
 		for (int i= 0; i < members.length; i++) {
 			updatedMemberSources[i]= getUpdatedMember(document, members[i]);
@@ -1093,12 +1085,7 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 		}
 
 		//Sorting members is important for field declarations referring to previous fields.
-		Arrays.sort(result, new Comparator<BodyDeclaration>() {
-			@Override
-			public int compare(BodyDeclaration o1, BodyDeclaration o2) {
-				return o1.getStartPosition() - o2.getStartPosition();
-			}
-		});
+		Arrays.sort(result, (o1, o2) -> o1.getStartPosition() - o2.getStartPosition());
 		return result;
 	}
 
@@ -1116,12 +1103,12 @@ public final class MoveStaticMembersProcessor extends MoveProcessor implements I
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, JavaRefactoringDescriptorUtil.ATTRIBUTE_INPUT));
 		final String delegate= extended.getAttribute(ATTRIBUTE_DELEGATE);
 		if (delegate != null) {
-			fDelegateUpdating= Boolean.valueOf(delegate).booleanValue();
+			fDelegateUpdating= Boolean.parseBoolean(delegate);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_DELEGATE));
 		final String deprecate= extended.getAttribute(ATTRIBUTE_DEPRECATE);
 		if (deprecate != null) {
-			fDelegateDeprecation= Boolean.valueOf(deprecate).booleanValue();
+			fDelegateDeprecation= Boolean.parseBoolean(deprecate);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_DEPRECATE));
 		int count= 1;
