@@ -60,7 +60,6 @@ import org.eclipse.core.resources.IWorkspaceRoot;
 
 import org.eclipse.jface.action.Action;
 import org.eclipse.jface.action.IAction;
-import org.eclipse.jface.action.IMenuListener;
 import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.action.MenuManager;
@@ -70,8 +69,6 @@ import org.eclipse.jface.dialogs.IInputValidator;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.jface.resource.ImageDescriptor;
-import org.eclipse.jface.viewers.DoubleClickEvent;
-import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.ISelectionProvider;
@@ -111,8 +108,6 @@ import org.eclipse.ui.part.IShowInTarget;
 import org.eclipse.ui.part.ShowInContext;
 import org.eclipse.ui.part.ViewPart;
 import org.eclipse.ui.views.properties.IPropertySheetPage;
-import org.eclipse.ui.views.properties.IPropertySource;
-import org.eclipse.ui.views.properties.IPropertySourceProvider;
 import org.eclipse.ui.views.properties.PropertySheetPage;
 
 import org.eclipse.ui.texteditor.ITextEditor;
@@ -182,12 +177,7 @@ public class JavaElementView extends ViewPart implements IShowInSource, IShowInT
 
 		public JEViewSelectionProvider(TreeViewer viewer) {
 			fViewer= viewer;
-			fViewer.addSelectionChangedListener(new ISelectionChangedListener() {
-				@Override
-				public void selectionChanged(SelectionChangedEvent event) {
-					fireSelectionChanged();
-				}
-			});
+			fViewer.addSelectionChangedListener(event -> fireSelectionChanged());
 		}
 
 		void fireSelectionChanged() {
@@ -290,12 +280,7 @@ public class JavaElementView extends ViewPart implements IShowInSource, IShowInT
 		hookContextMenu();
 		hookDoubleClickAction();
 		getSite().setSelectionProvider(new JEViewSelectionProvider(fViewer));
-		fViewer.addSelectionChangedListener(new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				fCopyAction.setEnabled(! event.getSelection().isEmpty());
-			}
-		});
+		fViewer.addSelectionChangedListener(event -> fCopyAction.setEnabled(! event.getSelection().isEmpty()));
 		contributeToActionBars();
 	}
 
@@ -332,12 +317,7 @@ public class JavaElementView extends ViewPart implements IShowInSource, IShowInT
 	private void hookContextMenu() {
 		MenuManager menuMgr = new MenuManager("#PopupMenu");
 		menuMgr.setRemoveAllWhenShown(true);
-		menuMgr.addMenuListener(new IMenuListener() {
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				JavaElementView.this.fillContextMenu(manager);
-			}
-		});
+		menuMgr.addMenuListener(this::fillContextMenu);
 		Menu menu = menuMgr.createContextMenu(fViewer.getControl());
 		fViewer.getControl().setMenu(menu);
 		getSite().registerContextMenu(menuMgr, fViewer);
@@ -619,9 +599,7 @@ public class JavaElementView extends ViewPart implements IShowInSource, IShowInT
 				Runner runner= new Runner();
 				try {
 					PlatformUI.getWorkbench().getProgressService().busyCursorWhile(runner);
-				} catch (InvocationTargetException e) {
-					JEViewPlugin.log(e);
-				} catch (InterruptedException e) {
+				} catch (InvocationTargetException | InterruptedException e) {
 					JEViewPlugin.log(e);
 				}
 				JavaElement element= new JavaElement(fInput, fullyQualifiedName, runner.type);
@@ -709,9 +687,7 @@ public class JavaElementView extends ViewPart implements IShowInSource, IShowInT
 				Runner runner= new Runner();
 				try {
 					PlatformUI.getWorkbench().getProgressService().busyCursorWhile(runner);
-				} catch (InvocationTargetException e) {
-					JEViewPlugin.log(e);
-				} catch (InterruptedException e) {
+				} catch (InvocationTargetException | InterruptedException e) {
 					JEViewPlugin.log(e);
 				}
 				JavaElement element= new JavaElement(fInput, bindingKey, runner.element);
@@ -729,12 +705,7 @@ public class JavaElementView extends ViewPart implements IShowInSource, IShowInT
 
 		fRefreshAction= new Action("Re&fresh", JEPluginImages.IMG_REFRESH) {
 			@Override public void run() {
-				BusyIndicator.showWhile(getSite().getShell().getDisplay(), new Runnable() {
-					@Override
-					public void run() {
-						fViewer.refresh();
-					}
-				});
+				BusyIndicator.showWhile(getSite().getShell().getDisplay(), () -> fViewer.refresh());
 			}
 		};
 		fRefreshAction.setToolTipText("Refresh");
@@ -785,13 +756,7 @@ public class JavaElementView extends ViewPart implements IShowInSource, IShowInT
 								try {
 									Object context= getSite().getService(IHandlerService.class).getCurrentState();
 									showInCommand.executeWithChecks(new ExecutionEvent(null, params, null, context));
-								} catch (ExecutionException e1) {
-									showAndLogError("Could not show element", e1);
-								} catch (NotDefinedException e1) {
-									showAndLogError("Could not show element", e1);
-								} catch (NotEnabledException e1) {
-									showAndLogError("Could not show element", e1);
-								} catch (NotHandledException e1) {
+								} catch (ExecutionException | NotDefinedException | NotEnabledException | NotHandledException e1) {
 									showAndLogError("Could not show element", e1);
 								}
 								break;
@@ -807,9 +772,7 @@ public class JavaElementView extends ViewPart implements IShowInSource, IShowInT
 											JavaUI.revealInEditor(editorPart, javaElement);
 										}
 									}
-								} catch (PartInitException e) {
-									showAndLogError("Could not open editor.", e); //$NON-NLS-1$
-								} catch (JavaModelException e) {
+								} catch (PartInitException | JavaModelException e) {
 									showAndLogError("Could not open editor.", e); //$NON-NLS-1$
 								}
 						}
@@ -853,22 +816,22 @@ public class JavaElementView extends ViewPart implements IShowInSource, IShowInT
 				@Override
 				@SuppressWarnings("deprecation")
 				public void elementChanged(ElementChangedEvent event) {
-					String type= "\nEvent type: ";
+					StringBuilder type= new StringBuilder("\nEvent type: ");
 					switch (event.getType()) {
 					case ElementChangedEvent.POST_CHANGE:
-						type+= "POST_CHANGE";
+						type.append("POST_CHANGE");
 						break;
 					case ElementChangedEvent.POST_RECONCILE:
-						type+= "POST_RECONCILE";
+						type.append("POST_RECONCILE");
 						break;
 					case ElementChangedEvent.PRE_AUTO_BUILD:
-						type+= "PRE_AUTO_BUILD";
+						type.append("PRE_AUTO_BUILD");
 						break;
 					default:
-						type+= event.getType();
+						type.append(event.getType());
 						break;
 					}
-					JEViewPlugin.logMessage(event.getDelta().toString() + type);
+					JEViewPlugin.logMessage(event.getDelta().toString() + type.toString());
 				}
 			};
 
@@ -939,12 +902,7 @@ public class JavaElementView extends ViewPart implements IShowInSource, IShowInT
 	}
 
 	private void hookDoubleClickAction() {
-		fViewer.addDoubleClickListener(new IDoubleClickListener() {
-			@Override
-			public void doubleClick(DoubleClickEvent event) {
-				fDoubleClickAction.run();
-			}
-		});
+		fViewer.addDoubleClickListener(event -> fDoubleClickAction.run());
 	}
 
 	void showAndLogError(String message, CoreException e) {
@@ -1046,24 +1004,21 @@ public class JavaElementView extends ViewPart implements IShowInSource, IShowInT
 	private PropertySheetPage getPropertySheetPage() {
 		if (fPropertySheetPage == null) {
 			final PropertySheetPage propertySheetPage= new PropertySheetPage();
-			propertySheetPage.setPropertySourceProvider(new IPropertySourceProvider() {
-				@Override
-				public IPropertySource getPropertySource(Object object) {
-					if (object instanceof IJavaElement)
-						return new JavaElementProperties((IJavaElement) object);
-					else if (object instanceof IResource)
-						return new ResourceProperties((IResource) object);
-					else if (object instanceof IMarker)
-						return new MarkerProperties((IMarker) object);
-					else if (object instanceof IJarEntryResource)
-						return new JarEntryResourceProperties((IJarEntryResource) object);
-					else if (object instanceof IMemberValuePair)
-						return new MemberValuePairProperties((IMemberValuePair) object);
-					else if (object instanceof IClasspathEntry)
-						return new ClasspathEntryProperties((IClasspathEntry) object);
-					else
-						return null;
-				}
+			propertySheetPage.setPropertySourceProvider(object -> {
+				if (object instanceof IJavaElement)
+					return new JavaElementProperties((IJavaElement) object);
+				else if (object instanceof IResource)
+					return new ResourceProperties((IResource) object);
+				else if (object instanceof IMarker)
+					return new MarkerProperties((IMarker) object);
+				else if (object instanceof IJarEntryResource)
+					return new JarEntryResourceProperties((IJarEntryResource) object);
+				else if (object instanceof IMemberValuePair)
+					return new MemberValuePairProperties((IMemberValuePair) object);
+				else if (object instanceof IClasspathEntry)
+					return new ClasspathEntryProperties((IClasspathEntry) object);
+				else
+					return null;
 			});
 			fPropertySheetPage= propertySheetPage;
 		}
