@@ -17,8 +17,6 @@ package org.eclipse.jdt.internal.junit.launcher;
 
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Comparator;
-import java.util.Iterator;
 
 import org.eclipse.core.runtime.IConfigurationElement;
 import org.eclipse.core.runtime.IExtension;
@@ -70,20 +68,16 @@ public class TestKindRegistry {
 			return;
 
 		ArrayList<TestKind> items= new ArrayList<>();
-		for (Iterator<IConfigurationElement> iter= getConfigurationElements().iterator(); iter.hasNext();) {
-			IConfigurationElement element= iter.next();
-			items.add(new TestKind(element));
+		for (IConfigurationElement configurationElement : getConfigurationElements()) {
+			items.add(new TestKind(configurationElement));
 		}
 
-		Collections.sort(items, new Comparator<TestKind>() {
-			@Override
-			public int compare(TestKind kind0, TestKind kind1) {
-				if (kind0.precedes(kind1))
-					return -1;
-				if (kind1.precedes(kind0))
-					return 1;
-				return 0;
-			}
+		Collections.sort(items, (kind0, kind1) -> {
+			if (kind0.precedes(kind1))
+				return -1;
+			if (kind1.precedes(kind0))
+				return 1;
+			return 0;
 		});
 		fTestKinds= items;
 	}
@@ -150,7 +144,7 @@ public class TestKindRegistry {
 				if (runWithAnnotation.exists()) {
 					IMemberValuePair[] memberValuePairs= runWithAnnotation.getMemberValuePairs();
 					for (IMemberValuePair memberValuePair : memberValuePairs) {
-						if (memberValuePair.getMemberName().equals("value") && memberValuePair.getValue().equals("JUnitPlatform")) { //$NON-NLS-1$ //$NON-NLS-2$
+						if ("value".equals(memberValuePair.getMemberName()) && "JUnitPlatform".equals(memberValuePair.getValue())) { //$NON-NLS-1$ //$NON-NLS-2$
 							return true;
 						}
 					}
@@ -168,22 +162,18 @@ public class TestKindRegistry {
 
 	private ArrayList<IConfigurationElement> getConfigurationElements() {
 		ArrayList<IConfigurationElement> items= new ArrayList<>();
-		IExtension[] extensions= fPoint.getExtensions();
-		for (IExtension extension : extensions) {
-			IConfigurationElement[] elements= extension.getConfigurationElements();
-			for (IConfigurationElement element : elements) {
-				items.add(element);
-			}
+		for (IExtension extension : fPoint.getExtensions()) {
+			Collections.addAll(items, extension.getConfigurationElements());
 		}
 		return items;
 	}
 
 	public String getAllKindIds() {
 		ArrayList<TestKind> allKinds= getAllKinds();
-		String returnThis= ""; //$NON-NLS-1$
+		StringBuilder returnThis= new StringBuilder();
 		for (ITestKind kind : allKinds) {
-			returnThis+= "(" + kind.getId() + ")"; //$NON-NLS-1$ //$NON-NLS-2$
+			returnThis.append("(").append(kind.getId()).append(")"); //$NON-NLS-1$ //$NON-NLS-2$
 		}
-		return returnThis;
+		return returnThis.toString();
 	}
 }
