@@ -18,18 +18,18 @@ public interface IJUnitStatusConstants {
 	// JUnit UI status constants start at 10000 to make sure that we don't
 	// collide with resource and java model constants.
 
-	public static final int INTERNAL_ERROR= 10001;
+	int INTERNAL_ERROR= 10001;
 
 	/**
 	 * Status constant indicating that an validateEdit call has changed the
 	 * content of a file on disk.
 	 */
-	public static final int VALIDATE_EDIT_CHANGED_CONTENT= 10003;
+	int VALIDATE_EDIT_CHANGED_CONTENT= 10003;
 
 	/**
 	 * Status constant indicating that junit.framework.TestCase
 	 * is not on the project's path.
 	 */
-	public static final int ERR_JUNIT_NOT_ON_PATH = 10004;
+	int ERR_JUNIT_NOT_ON_PATH = 10004;
 
 }
