@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2010 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -22,6 +22,8 @@ import org.eclipse.swt.dnd.Transfer;
 import org.eclipse.jface.action.Action;
 import org.eclipse.jface.dialogs.MessageDialog;
 
+import org.eclipse.ui.ISharedImages;
+import org.eclipse.ui.IWorkbench;
 import org.eclipse.ui.PlatformUI;
 
 import org.eclipse.jdt.internal.junit.model.TestElement;
@@ -40,7 +42,9 @@ public class CopyFailureListAction extends Action {
 		super(JUnitMessages.CopyFailureList_action_label);
 		fRunner= runner;
 		fClipboard= clipboard;
-		PlatformUI.getWorkbench().getHelpSystem().setHelp(this, IJUnitHelpContextIds.COPYFAILURELIST_ACTION);
+		IWorkbench workbench= PlatformUI.getWorkbench();
+		workbench.getHelpSystem().setHelp(this, IJUnitHelpContextIds.COPYFAILURELIST_ACTION);
+		setImageDescriptor(workbench.getSharedImages().getImageDescriptor(ISharedImages.IMG_TOOL_COPY));
 	}
 
 	/*
@@ -66,26 +70,16 @@ public class CopyFailureListAction extends Action {
 		StringBuilder buf= new StringBuilder();
 		TestElement[] failures= fRunner.getAllFailures();
 
-		String lineDelim= System.getProperty("line.separator", "\n");  //$NON-NLS-1$//$NON-NLS-2$
+		String lineDelim= System.lineSeparator();
 		for (TestElement failure : failures) {
 			buf.append(failure.getTestName()).append(lineDelim);
 			String failureTrace= failure.getTrace();
 			if (failureTrace != null) {
-				int start= 0;
-				while (start < failureTrace.length()) {
-					int idx= failureTrace.indexOf('\n', start);
-					if (idx != -1) {
-						String line= failureTrace.substring(start, idx);
-						buf.append(line).append(lineDelim);
-						start= idx + 1;
-					} else {
-						start= Integer.MAX_VALUE;
-					}
-				}
+				failureTrace = failureTrace.replaceAll("\\r\\n|\\r|\\n", lineDelim); //$NON-NLS-1$
+				buf.append(failureTrace);
 			}
 		}
 		return buf.toString();
 	}
 
-
 }
