@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -78,8 +78,6 @@ public class JUnitPlugin extends AbstractUIPlugin {
 
 	private BundleContext fBundleContext;
 
-	private static boolean fIsStopped= false;
-
 
 	public JUnitPlugin() {
 		fgPlugin= this;
@@ -217,6 +215,9 @@ public class JUnitPlugin extends AbstractUIPlugin {
 		favoritesToAdd.add("org.junit.jupiter.api.Assumptions.*"); //$NON-NLS-1$
 		favoritesToAdd.add("org.junit.jupiter.api.DynamicContainer.*"); //$NON-NLS-1$
 		favoritesToAdd.add("org.junit.jupiter.api.DynamicTest.*"); //$NON-NLS-1$
+		favoritesToAdd.add("org.mockito.ArgumentMatchers.*"); //$NON-NLS-1$
+		favoritesToAdd.add("org.mockito.Mockito.*"); //$NON-NLS-1$
+		favoritesToAdd.add("org.assertj.core.api.Assertions.*"); //$NON-NLS-1$
 
 		// default value
 		Set<String> defaultFavorites= new LinkedHashSet<>();
@@ -249,7 +250,6 @@ public class JUnitPlugin extends AbstractUIPlugin {
 
 	@Override
 	public void stop(BundleContext context) throws Exception {
-		fIsStopped= true;
 		super.stop(context);
 		fBundleContext= null;
 	}
@@ -331,10 +331,6 @@ public class JUnitPlugin extends AbstractUIPlugin {
 		return null;
 	}
 
-	public static boolean isStopped() {
-		return fIsStopped;
-	}
-
 	public IDialogSettings getDialogSettingsSection(String name) {
 		IDialogSettings dialogSettings= getDialogSettings();
 		IDialogSettings section= dialogSettings.getSection(name);
@@ -345,12 +341,7 @@ public class JUnitPlugin extends AbstractUIPlugin {
 	}
 
 	public static void asyncShowTestRunnerViewPart() {
-		getDisplay().asyncExec(new Runnable() {
-			@Override
-			public void run() {
-				showTestRunnerViewPartInActivePage();
-			}
-		});
+		getDisplay().asyncExec(JUnitPlugin::showTestRunnerViewPartInActivePage);
 	}
 
 	public static TestRunnerViewPart showTestRunnerViewPartInActivePage() {
