@@ -23,12 +23,10 @@ import java.util.regex.Pattern;
 import java.util.stream.Collectors;
 
 import org.eclipse.core.runtime.CoreException;
-import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.OperationCanceledException;
 
 import org.eclipse.jface.dialogs.MessageDialog;
-import org.eclipse.jface.operation.IRunnableWithProgress;
 
 import org.eclipse.jface.text.BadLocationException;
 import org.eclipse.jface.text.IDocument;
@@ -106,11 +104,12 @@ public class OpenTestAction extends OpenEditorAction {
 		PlatformUI.getWorkbench().getHelpSystem().setHelp(this, IJUnitHelpContextIds.OPENTEST_ACTION);
 		fMethodName= method;
 		fMethodParamTypes= methodParamTypes;
+		setImageDescriptor(JUnitPlugin.getImageDescriptor("elcl16/goto_input.png")); //$NON-NLS-1$
 	}
 
 	private static String extractRealMethodName(TestCaseElement testCase) {
 		//workaround for https://bugs.eclipse.org/bugs/show_bug.cgi?id=334864 :
-		if (testCase.isIgnored() && JavaConventions.validateJavaTypeName(testCase.getTestName(), JavaCore.VERSION_1_5, JavaCore.VERSION_1_5).getSeverity() != IStatus.ERROR) {
+		if (testCase.isIgnored() && JavaConventions.validateJavaTypeName(testCase.getTestName(), JavaCore.VERSION_1_5, JavaCore.VERSION_1_5, null).getSeverity() != IStatus.ERROR) {
 			return null;
 		}
 
@@ -170,44 +169,41 @@ public class OpenTestAction extends OpenEditorAction {
 
 		List<IMethod> foundMethods= new ArrayList<>();
 		try {
-			PlatformUI.getWorkbench().getProgressService().busyCursorWhile(new IRunnableWithProgress() {
-				@Override
-				public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
-					String methodPattern= type.getFullyQualifiedName('.') + '.' + fMethodName;
-					if (fMethodParamTypes != null && fMethodParamTypes.length > 0) {
-						String paramTypes= Arrays.stream(fMethodParamTypes).map(paramType -> {
-							try {
-								return paramType= Signature.toString(paramType);
-							} catch (IllegalArgumentException e) {
-								// return the paramType as it is
-							}
-							return paramType.replace('$', '.'); // for nested classes... See OpenEditorAction#findType also.
-						}).collect(Collectors.joining(", ", "(", ")")); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
-						methodPattern+= paramTypes;
-					} else {
-						methodPattern+= "()"; //$NON-NLS-1$
-					}
-					int matchRule= SearchPattern.R_ERASURE_MATCH | SearchPattern.R_EXACT_MATCH | SearchPattern.R_CASE_SENSITIVE;
-					SearchPattern searchPattern= SearchPattern.createPattern(methodPattern, IJavaSearchConstants.METHOD, IJavaSearchConstants.DECLARATIONS, matchRule);
-					if (searchPattern == null) {
-						return;
-					}
-					SearchRequestor requestor= new SearchRequestor() {
-						@Override
-						public void acceptSearchMatch(SearchMatch match) throws CoreException {
-							Object element= match.getElement();
-							if (element instanceof IMethod) {
-								foundMethods.add((IMethod) element);
-							}
+			PlatformUI.getWorkbench().getProgressService().busyCursorWhile(monitor -> {
+				StringBuilder methodPattern= new StringBuilder(type.getFullyQualifiedName('.')).append('.').append(fMethodName);
+				if (fMethodParamTypes != null && fMethodParamTypes.length > 0) {
+					String paramTypes= Arrays.stream(fMethodParamTypes).map(paramType -> {
+						try {
+							return paramType= Signature.toString(paramType);
+						} catch (IllegalArgumentException e1) {
+							// return the paramType as it is
+						}
+						return paramType.replace('$', '.'); // for nested classes... See OpenEditorAction#findType also.
+					}).collect(Collectors.joining(", ", "(", ")")); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+					methodPattern.append(paramTypes);
+				} else {
+					methodPattern.append("()"); //$NON-NLS-1$
+				}
+				int matchRule= SearchPattern.R_ERASURE_MATCH | SearchPattern.R_EXACT_MATCH | SearchPattern.R_CASE_SENSITIVE;
+				SearchPattern searchPattern= SearchPattern.createPattern(methodPattern.toString(), IJavaSearchConstants.METHOD, IJavaSearchConstants.DECLARATIONS, matchRule);
+				if (searchPattern == null) {
+					return;
+				}
+				SearchRequestor requestor= new SearchRequestor() {
+					@Override
+					public void acceptSearchMatch(SearchMatch match) throws CoreException {
+						Object element= match.getElement();
+						if (element instanceof IMethod) {
+							foundMethods.add((IMethod) element);
 						}
-					};
-					SearchParticipant[] participants= new SearchParticipant[] { SearchEngine.getDefaultSearchParticipant() };
-					IJavaSearchScope scope= SearchEngine.createJavaSearchScope(new IJavaElement[] { type });
-					try {
-						new SearchEngine().search(searchPattern, participants, scope, requestor, monitor);
-					} catch (CoreException e) {
-						JUnitPlugin.log(e);
 					}
+				};
+				SearchParticipant[] participants= new SearchParticipant[] { SearchEngine.getDefaultSearchParticipant() };
+				IJavaSearchScope scope= SearchEngine.createJavaSearchScope(new IJavaElement[] { type });
+				try {
+					new SearchEngine().search(searchPattern, participants, scope, requestor, monitor);
+				} catch (CoreException e2) {
+					JUnitPlugin.log(e2);
 				}
 			});
 		} catch (InvocationTargetException e) {
