@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2014 Moritz Eysholdt and others.
+ * Copyright (c) 2014, 2021 Moritz Eysholdt and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -40,7 +40,7 @@ public class SubForestFilter extends Filter {
 	@Override
 	public void apply(Object child) throws NoTestsRemainException {
 		if (child instanceof Runner && fIncluded == null) {
-			fIncluded= new HashSet<Description>();
+			fIncluded= new HashSet<>();
 			collectIncludedDescriptions(((Runner)child).getDescription());
 			if (fIncluded.isEmpty())
 				throw new NoTestsRemainException();
