@@ -13,11 +13,16 @@
  *******************************************************************************/
 package org.eclipse.jdt.text.tests;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+
 import java.util.Hashtable;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Ignore;
+import org.junit.Test;
 
 import org.eclipse.jface.text.Document;
 import org.eclipse.jface.text.IDocument;
@@ -36,23 +41,14 @@ import org.eclipse.jdt.internal.ui.text.JavaIndenter;
  * SmartSemicolonAutoEditStrategyTest
  * @since 3.0
  */
-public class JavaHeuristicScannerTest extends TestCase {
-
-	private static final boolean BUG_65463= true;
+public class JavaHeuristicScannerTest {
 	private FastPartitioner fPartitioner;
 	private Document fDocument;
 	private JavaIndenter fScanner;
 	private JavaHeuristicScanner fHeuristicScanner;
 
-	public static Test suite() {
-		return new TestSuite(JavaHeuristicScannerTest.class);
-	}
-
-	/*
-	 * @see junit.framework.TestCase#setUp()
-	 */
-	@Override
-	protected void setUp() {
+	@Before
+	public void setUp() {
 		if (JavaCore.getPlugin() != null) {
 			Hashtable<String, String> options= JavaCore.getDefaultOptions();
 			options.put(DefaultCodeFormatterConstants.FORMATTER_TAB_CHAR, JavaCore.TAB);
@@ -82,11 +78,8 @@ public class JavaHeuristicScannerTest extends TestCase {
 		fScanner= new JavaIndenter(fDocument, fHeuristicScanner);
 	}
 
-	/*
-	 * @see junit.framework.TestCase#tearDown()
-	 */
-	@Override
-	protected void tearDown() throws Exception {
+	@After
+	public void tearDown() throws Exception {
 		fDocument.setDocumentPartitioner(IJavaPartitions.JAVA_PARTITIONING, null);
 		fPartitioner.disconnect();
 		fPartitioner= null;
@@ -95,8 +88,9 @@ public class JavaHeuristicScannerTest extends TestCase {
 		if (JavaCore.getPlugin() != null) {
 			JavaCore.setOptions(JavaCore.getDefaultOptions());
 		}
-}
+	}
 
+	@Test
 	public void testPrevIndentationUnit1() {
 		fDocument.set("\tint a;\n" +
 			"\tif (true)\n" +
@@ -106,6 +100,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals(9, pos);
 	}
 
+	@Test
 	public void testPrevIndentationUnit2() {
 		fDocument.set("\tint a;\n" +
 			"\tif (true)\n" +
@@ -116,6 +111,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 	}
 
 
+	@Test
 	public void testPrevIndentationUnit5() {
 		fDocument.set("\tint a;\n" +
 			"\tif (true)\n" +
@@ -126,6 +122,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals(9, pos);
 	}
 
+	@Test
 	public void testPrevIndentationUnit6() {
 		// method definition
 		fDocument.set("\tvoid proc (int par1, int par2\n");
@@ -134,6 +131,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals(12, pos);
 	}
 
+	@Test
 	public void testPrevIndentationUnit7() {
 		// for with semis
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -145,15 +143,17 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals(39, pos);
 	}
 
+	@Test
 	public void testPrevIndentationUnit8() {
 		// TODO this is mean - comment at indentation spot
 		fDocument.set("\t/* package */ void proc (int par1, int par2) {\n");
 
 		int pos= fScanner.findReferencePosition(fDocument.getLength());
-//		Assert.assertEquals(1, pos);
+//		assertEquals(1, pos);
 		assertEquals(15, pos);
 	}
 
+	@Test
 	public void testPrevIndentationUnit9() {
 		// block
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -167,6 +167,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals(fDocument.getLength() - 7, pos);
 	}
 
+	@Test
 	public void testPrevIndentationUnit10() {
 		// if else
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -182,6 +183,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals(39, pos);
 	}
 
+	@Test
 	public void testPrevIndentationUnit11() {
 		// inside else block
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -197,6 +199,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals(83, pos);
 	}
 
+	@Test
 	public void testPrevIndentation1() {
 		fDocument.set("\tint a;\n" +
 			"\tif (true)\n" +
@@ -206,6 +209,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testPrevIndentation2() {
 		fDocument.set("\tint a;\n" +
 			"\tif (true)\n" +
@@ -215,6 +219,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testPrevIndentation3() {
 		fDocument.set("\tint a;\n" +
 			"\tif (true)\n" +
@@ -224,6 +229,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testPrevIndentation4() {
 		fDocument.set("\tint a;\n" +
 			"\tif (true)\n" +
@@ -234,6 +240,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testPrevIndentation5() {
 		fDocument.set("\tint a;\n" +
 			"\tif (true)\n" +
@@ -244,6 +251,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testPrevIndentation6() {
 		fDocument.set("\tvoid proc (int par1, int par2\n");
 
@@ -251,6 +259,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testPrevIndentation7() {
 		// for with semis
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -262,6 +271,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testPrevIndentation8() {
 		fDocument.set("\t/* package */ void proc (int par1, int par2) {\n");
 
@@ -269,6 +279,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testPrevIndentation9() {
 		// block
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -282,6 +293,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testPrevIndentation10() {
 		// else
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -297,6 +309,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testPrevIndentation11() {
 		// else
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -312,6 +325,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation1() {
 		fDocument.set("\tint a;\n" +
 			"\tif (true)\n" +
@@ -321,6 +335,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation5() {
 		fDocument.set("\tint a;\n" +
 			"\tif (true)\n" +
@@ -331,6 +346,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testIndentation6() {
 		// parameter declaration - alignment with parenthesis
 		fDocument.set("\tvoid proc (int par1, int par2\n");
@@ -339,6 +355,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t           ", indent);
 	}
 
+	@Test
 	public void testIndentation6a() {
 		// parameter declaration - alignment with parenthesis
 		fDocument.set("\tvoid proc (  int par1, int par2\n");
@@ -347,6 +364,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t             ", indent);
 	}
 
+	@Test
 	public void testIndentation7() {
 		// for with semis
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -358,6 +376,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation8() {
 		// method definition
 		fDocument.set("\t/* package */ void proc (int par1, int par2) {\n");
@@ -366,6 +385,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation9() {
 		// block
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -379,6 +399,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation10() {
 		// else
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -394,6 +415,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation11() {
 		// else
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -409,6 +431,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation12() {
 		// multi-line condition
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -420,6 +443,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation13() {
 		// multi-line call
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -431,6 +455,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation14() {
 		// multi-line array initializer
 		fDocument.set("\tvoid proc (int par1, int par2) {\n" +
@@ -442,6 +467,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("		                             ", indent);
 	}
 
+	@Test
 	public void testIndentation15() {
 		// for
 		fDocument.set("\tfor (int i= 0; i < 10; i++) {\n" +
@@ -452,6 +478,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testIndentation16() {
 		// if
 		fDocument.set("\tif (true)\n" +
@@ -461,6 +488,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation17() {
 		// if
 		fDocument.set("\tif (true)\n" +
@@ -470,6 +498,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation18() {
 		// if
 		fDocument.set("\tif (true)\n" +
@@ -479,6 +508,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation19() {
 		// if w/ brace right after }
 		fDocument.set("\tif (true) {\n" +
@@ -488,6 +518,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testIndentation20() {
 		// if w/ brace right before }
 		fDocument.set("\tif (true) {\n" +
@@ -497,6 +528,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testIndentation21() {
 		// double if w/ brace
 		fDocument.set("\tif (true)\n" +
@@ -507,6 +539,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation22() {
 		// after double if w/ brace
 		fDocument.set("\tif (true)\n" +
@@ -519,6 +552,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent); // because of possible dangling else
 	}
 
+	@Test
 	public void testIndentation22a() {
 		// after double if w/ brace
 		fDocument.set("\tif (true)\n" +
@@ -531,6 +565,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation22b() {
 		// after double if w/ brace
 		fDocument.set("\tif (true)\n" +
@@ -543,6 +578,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent); // no dangling else possible
 	}
 
+	@Test
 	public void testIndentation23() {
 		// do
 		fDocument.set("\tdo\n" +
@@ -552,6 +588,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation24() {
 		// braceless else
 		fDocument.set("\tif (true) {\n" +
@@ -563,6 +600,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation25() {
 		// braceless else
 		fDocument.set("\tif (true) {\r\n" +
@@ -574,6 +612,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testIndentation26() {
 		// do while
 		fDocument.set("\tdo\n" +
@@ -585,6 +624,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testIndentation27() {
 		// do while
 		fDocument.set("\tdo\n" +
@@ -598,6 +638,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testIndentation28() {
 		// TODO do while - how to we distinguish from while {} loop?
 		fDocument.set("\tdo\n" +
@@ -611,6 +652,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testIndentation29() {
 		fDocument.set("\t\twhile (condition)\n" +
 				"\t\t\twhile (condition)\n" +
@@ -622,6 +664,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation30() {
 		// braceless else
 		fDocument.set("\tif (true)\n" +
@@ -631,6 +674,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testIndentation31() {
 		// braceless else
 		fDocument.set("\tif (true)\n" +
@@ -643,6 +687,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testIndentation32() {
 		// braceless else
 		fDocument.set("\tswitch(ch) {\n" +
@@ -652,6 +697,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("			", indent);
 	}
 
+	@Test
 	public void testAnonymousIndentation1() {
 		fDocument.set(	"		MenuItem mi= new MenuItem(\"About...\");\n" +
 						"		mi.addActionListener(\n" +
@@ -662,6 +708,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("				", indent);
 	}
 
+	@Test
 	public void testAnonymousIndentation2() {
 		fDocument.set(	"		MenuItem mi= new MenuItem(\"About...\");\n" +
 						"		mi.addActionListener(\n" +
@@ -678,6 +725,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("			", indent);
 	}
 
+	@Test
 	public void testExceptionIndentation1() {
 		fDocument.set("public void processChildren(CompositeExpression result, IConfigurationElement element) throws CoreException {\n" +
 				"			IConfigurationElement[] children= element.getChildren();\n" +
@@ -691,6 +739,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("							", indent);
 	}
 
+	@Test
 	public void testExceptionIndentation2() {
 		fDocument.set("public void processChildren(CompositeExpression result, IConfigurationElement element) throws CoreException {\n" +
 				"			IConfigurationElement[] children= element.getChildren();\n" +
@@ -704,6 +753,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("							", indent);
 	}
 
+	@Test
 	public void testExceptionIndentation3() {
 		fDocument.set("public void processChildren(CompositeExpression result, IConfigurationElement element) throws CoreException {\n" +
 				"			IConfigurationElement[] children= element.getChildren();\n" +
@@ -717,6 +767,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("							", indent);
 	}
 
+	@Test
 	public void testListAlignmentMethodDeclaration() {
 		// parameter declaration - alignment with parenthesis
 		fDocument.set(	"\tvoid proc (  int par1, int par2,\n" +
@@ -726,6 +777,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("	   ", indent);
 	}
 
+	@Test
 	public void testListAlignmentMethodCall() {
 		// parameter declaration - alignment with parenthesis
 		fDocument.set(	"\this.proc (par1, par2,\n" +
@@ -735,6 +787,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("	   ", indent);
 	}
 
+	@Test
 	public void testListAlignmentArray() {
 		// parameter declaration - alignment with parenthesis
 		fDocument.set(	"\tint[]= new int[] { 1, two,\n" +
@@ -744,6 +797,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("	   ", indent);
 	}
 
+	@Test
 	public void testListAlignmentArray2() {
 		// no prior art - probe system settings.
 		fDocument.set(	"\tint[]= new int[] { 1, two,\n");
@@ -753,6 +807,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 
 	}
 
+	@Test
 	public void testBraceAlignmentOfMultilineDeclaration() {
 		fDocument.set(	"	protected int foobar(int one, int two,\n" +
 						"						 int three, int four,\n" +
@@ -765,6 +820,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("	", indent);
 	}
 
+	@Test
 	public void testBlocksInCaseStatements() {
 		fDocument.set(
 				"		switch (i) {\n" +
@@ -776,6 +832,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("					", indent);
 	}
 
+	@Test
 	public void testAnonymousTypeBraceNextLine() throws Exception {
 		fDocument.set(
 				"		MenuItem mi= new MenuItem(\"About...\");\n" +
@@ -791,6 +848,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 	/*
 	 * @since 3.2
 	 */
+	@Test
 	public void testClassInstanceCreationHeuristic() throws Exception {
 	    fDocument.set("   method(new java.util.ArrayList<String>(10), foo, new int[])");
 
@@ -814,9 +872,9 @@ public class JavaHeuristicScannerTest extends TestCase {
 	    	assertFalse(fHeuristicScanner.looksLikeClassInstanceCreationBackward(offset, JavaHeuristicScanner.UNBOUND));
     }
 
+	@Ignore("enable when https://bugs.eclipse.org/bugs/show_bug.cgi?id=65463 is fixed")
+	@Test
 	public void testConditional1() throws Exception {
-		if (BUG_65463) // XXX enable when https://bugs.eclipse.org/bugs/show_bug.cgi?id=65463 is fixed
-			return;
     	fDocument.set(
     			"		public boolean isPrime() {\n" +
     			"			return fPrime == true ? true\n" +
@@ -827,9 +885,9 @@ public class JavaHeuristicScannerTest extends TestCase {
     	assertEquals("			                      ", indent);
     }
 
+	@Ignore("enable when https://bugs.eclipse.org/bugs/show_bug.cgi?id=65463 is fixed")
+	@Test
 	public void testConditional2() throws Exception {
-		if (BUG_65463) // XXX enable when https://bugs.eclipse.org/bugs/show_bug.cgi?id=65463 is fixed
-			return;
     	fDocument.set(
     			"		public boolean isPrime() {\n" +
     			"			return fPrime == true" +
@@ -842,6 +900,17 @@ public class JavaHeuristicScannerTest extends TestCase {
 
     }
 
+	@Test
+	public void testTernaryAfterConditional() throws Exception {
+		fDocument.set(
+		"		if (true)\n" +
+		"			ret = true ? \"\".substring(0) : \"\";\n");
+
+		String indent= fScanner.computeIndentation(fDocument.getLength() - 1).toString();
+		assertEquals("		", indent);
+	}
+
+	@Test
 	public void testContinuationIndentationOfForStatement() throws Exception {
 		fDocument.set("\tfor (int i = (2 * 2); i < array.length; i++) {\n" +
 				"\tint i= 25;\n" +
@@ -863,6 +932,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentationOfForEachStatement() throws Exception {
 		// Bug 331028 and Bug 331734
 		fDocument.set("\tfor (int value : values) {\n" +
@@ -874,6 +944,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentationOfForEachStatement2() throws Exception {
 		// Bug 348198
 		fDocument.set("\tfor (int value : values)\n" +
@@ -885,6 +956,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentationOfBooleanExpression() throws Exception {
 		fDocument.set("\tboolean a = true || false;\n" +
 				"\tboolean b = a || false;\n");
@@ -895,6 +967,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentationOfReturnStatement() throws Exception {
 		fDocument.set("\t\treturn \"I'm such a long string that you have to split me to see the whole line without scrolling around\"\n");
 
@@ -906,6 +979,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentationOfAssignmentStatement() throws Exception {
 		fDocument.set("\tint i= 5+");
 
@@ -915,6 +989,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentationOfThrowsClause() throws Exception {
 		fDocument.set("\tprivate void thrower() throws java.sql.SQLException, java.io.IOException {");
 
@@ -924,6 +999,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentationOfParentheses() throws Exception {
 		fDocument.set("\tint foo() {\n\treturn \"\".length(\n\t\t);\n\t}");
 
@@ -931,6 +1007,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentationOfAnnotation() throws Exception {
 		fDocument.set("\t@MyAnnotation(\n\t\tvalue=\"hello\")\n\t\tpublic class ArrayAnnotationBug {\n\t\t}");
 		String indent= fScanner.computeIndentation(33).toString();
@@ -941,6 +1018,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t", indent);
 	}
 
+	@Test
 	public void testIndentationAfterIfTryCatch() throws Exception {
 		fDocument.set("\tpublic class Bug237081 {\n" +
 				"\t\tpublic void foo() {\n" +
@@ -969,6 +1047,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentationOfBrackets() throws Exception {
 		fDocument.set("\tprivate void helper2(boolean[] booleans) {\n\t}");
 
@@ -990,6 +1069,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentationOfStrings1() throws Exception {
 		fDocument.set(
 				"	String[] i = new String[] {\n" + //0-28
@@ -1014,6 +1094,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentationOfStrings2() throws Exception {
 		//Bug 338229
 		fDocument.set(
@@ -1025,6 +1106,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentationOfStrings3() throws Exception {
 		fDocument.set(
 				"	String test =\n" + //0-14
@@ -1035,6 +1117,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentation1() throws Exception {
 		fDocument.set("\treturn (thisIsAVeryLongName == 1 && anotherVeryLongName == 1)\n" +
 				"\t\t|| thisIsAVeryLongName == 2;");
@@ -1045,6 +1128,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentation2() {
 		fDocument.set("\tint a;\n" +
 				"\tif (true)\n" +
@@ -1055,6 +1139,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals(21, pos);
 	}
 
+	@Test
 	public void testContinuationIndentation3() {
 		fDocument.set("\tint a;\n" +
 				"\tif (true)\n" +
@@ -1064,6 +1149,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentation4() {
 		fDocument.set("\tint a;\n" +
 				"\tif (true)\n" +
@@ -1073,6 +1159,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testContinuationIndentation5() {
 		fDocument.set("\tint a;\n" +
 				"\tif (true)\n" +
@@ -1083,6 +1170,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testIndentationTryWithResources() throws Exception {
 		String s= "class A {\n" +
 				"	void foo() throws Throwable {\n" +
@@ -1109,6 +1197,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t\t", indent);
 	}
 
+	@Test
 	public void testDefaultMethod1() {
 		StringBuilder buf= new StringBuilder();
 		buf.append("interface I {\n");
@@ -1132,6 +1221,7 @@ public class JavaHeuristicScannerTest extends TestCase {
 		assertEquals("\t\t", indent);
 	}
 
+	@Test
 	public void testDefaultMethod2() {
 		StringBuilder buf= new StringBuilder();
 		buf.append("interface I {\n");
