@@ -13,14 +13,15 @@
  *******************************************************************************/
 package org.eclipse.jdt.text.tests;
 
+import static org.junit.Assert.assertEquals;
+
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+import org.junit.Before;
+import org.junit.Test;
 
 import org.eclipse.jface.text.BadLocationException;
 import org.eclipse.jface.text.Document;
@@ -35,18 +36,13 @@ import org.eclipse.jdt.internal.ui.text.JavaPartitionScanner;
 /**
  * Compares two <code>IParitionTokenScanner</code>s for conformance and performance.
  */
-public class PartitionTokenScannerTest extends TestCase {
-
+public class PartitionTokenScannerTest {
 	private static final boolean DEBUG= false;
 	private IPartitionTokenScanner fReference;
 	private IPartitionTokenScanner fTestee;
 
-	public PartitionTokenScannerTest(String name) {
-		super(name);
-	}
-
-	@Override
-	protected void setUp() {
+	@Before
+	public void setUp() {
 		fReference= new JavaPartitionScanner();
 		fTestee= new FastJavaPartitionScanner(true);
 	}
@@ -76,7 +72,7 @@ public class PartitionTokenScannerTest extends TestCase {
 
 	public static IDocument getRandomDocument(int size) {
 		final char[] characters= {'/', '*', '\'', '"', '\r', '\n', '\\'};
-		final StringBuffer buffer= new StringBuffer();
+		final StringBuilder buffer= new StringBuilder();
 
 		for (int i= 0; i < size; i++) {
 			final int randomIndex= (int) (Math.random() * characters.length);
@@ -86,30 +82,32 @@ public class PartitionTokenScannerTest extends TestCase {
 		return new Document(buffer.toString());
 	}
 
-	public static Test suite() {
-		return new TestSuite(PartitionTokenScannerTest.class);
-	}
-
+	@Test
 	public void testTestCaseLF() {
 		testConformance(getDocument("TestCase.txt", "\n"));
 	}
 
+	@Test
 	public void testTestCaseCRLF() {
 		testConformance(getDocument("TestCase.txt", "\r\n"));
 	}
 
+	@Test
 	public void testTestCaseCR() {
 		testConformance(getDocument("TestCase.txt", "\r"));
 	}
 
+	@Test
 	public void testTestCase2LF() {
 		testConformance(getDocument("TestCase2.txt", "\n"));
 	}
 
+	@Test
 	public void testTestCase2CRLF() {
 		testConformance(getDocument("TestCase2.txt", "\r\n"));
 	}
 
+	@Test
 	public void testTestCase2CR() {
 		testConformance(getDocument("TestCase2.txt", "\r"));
 	}
@@ -122,6 +120,7 @@ public class PartitionTokenScannerTest extends TestCase {
 	/**
 	 * Tests performance of the testee against the reference IPartitionTokenScanner.
 	 */
+	@Test
 	public void testPerformance() {
 		final int COUNT= 5000;
 		final IDocument document= getDocument("TestCase.txt", "\n");
@@ -139,6 +138,7 @@ public class PartitionTokenScannerTest extends TestCase {
 		// assertTrue(testeeTime <= referenceTime);
 	}
 
+	@Test
 	public void test_bug57903() {
 		final Document document= new Document("<%/**f%>");
 		fReference.setRange(document, 2, 4);
@@ -165,7 +165,7 @@ public class PartitionTokenScannerTest extends TestCase {
 
 	private void testConformance(final IDocument document) {
 
-		final StringBuffer message= new StringBuffer();
+		final StringBuilder message= new StringBuilder();
 
 		fReference.setRange(document, 0, document.getLength());
 		fTestee.setRange(document, 0, document.getLength());
@@ -215,7 +215,7 @@ public class PartitionTokenScannerTest extends TestCase {
 	}
 
 	private static String extractString(IDocument document, int offset) {
-		final StringBuffer buffer= new StringBuffer();
+		final StringBuilder buffer= new StringBuilder();
 
 		try {
 			IRegion region= document.getLineInformationOfOffset(offset);
@@ -246,7 +246,7 @@ public class PartitionTokenScannerTest extends TestCase {
 	 * @return the escaped string
 	 */
 	public static String escape(String string) {
-		final StringBuffer buffer= new StringBuffer();
+		final StringBuilder buffer= new StringBuilder();
 
 		final int length= string.length();
 		for (int i= 0; i < length; i++) {
@@ -272,5 +272,4 @@ public class PartitionTokenScannerTest extends TestCase {
 
 		return buffer.toString();
 	}
-
 }
