@@ -12,9 +12,18 @@
  *******************************************************************************/
 package org.eclipse.jdt.text.tests.contentassist;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+
 import java.util.Arrays;
+import java.util.Hashtable;
 import java.util.List;
 
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
+
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 
 import org.eclipse.swt.SWT;
@@ -30,50 +39,50 @@ import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.IPackageFragment;
 import org.eclipse.jdt.core.IPackageFragmentRoot;
+import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
+import org.eclipse.jdt.core.formatter.DefaultCodeFormatterConstants;
 
-import org.eclipse.jdt.ui.tests.core.ProjectTestSetup;
+import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
 import org.eclipse.jdt.ui.text.java.JavaContentAssistInvocationContext;
 
 import org.eclipse.jdt.internal.ui.javaeditor.EditorUtility;
 import org.eclipse.jdt.internal.ui.text.java.PostfixCompletionProposalComputer;
 import org.eclipse.jdt.internal.ui.text.template.contentassist.PostfixTemplateProposal;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
-public class PostFixCompletionTest extends TestCase {
-
-	private static final Class<PostFixCompletionTest> THIS= PostFixCompletionTest.class;
-
+public class PostFixCompletionTest {
 	private IJavaProject fJProject;
 
 	private IPackageFragmentRoot javaSrc;
 
 	private IPackageFragment pkg;
 
-	public static Test suite() {
-		return setUpTest(new TestSuite(THIS));
-	}
+	private Hashtable<String, String> savedOptions;
 
-	public static Test setUpTest(Test test) {
-		return new ProjectTestSetup(test);
-	}
+	@Rule
+	public ProjectTestSetup cts= new ProjectTestSetup();
+
+	@Before
+	public void setUp() throws Exception {
+		Hashtable<String, String> options= JavaCore.getDefaultOptions();
+		savedOptions= new Hashtable<>(options);
+		options.put(DefaultCodeFormatterConstants.FORMATTER_TAB_CHAR, JavaCore.SPACE);
+		options.put(DefaultCodeFormatterConstants.FORMATTER_TAB_SIZE, "2");
+		JavaCore.setOptions(options);
 
-	@Override
-	protected void setUp() throws Exception {
 		fJProject= JavaProjectHelper.createJavaProject("TestProject", "bin");
 		JavaProjectHelper.addRTJar18(fJProject);
 		javaSrc= JavaProjectHelper.addSourceContainer(fJProject, "src");
 		pkg= javaSrc.createPackageFragment("test", false, null);
 	}
 
-	@Override
-	protected void tearDown() throws Exception {
+	@After
+	public void tearDown() throws Exception {
 		JavaProjectHelper.delete(fJProject);
+		JavaCore.setOptions(savedOptions);
 	}
 
+	@Test
 	public void testStringVar() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -96,13 +105,14 @@ public class PostFixCompletionTest extends TestCase {
 		expected.append("package test;\n" +
 				"public class StringVar {\n" +
 				"  public void test () {\n" +
-				"    String name = \"Some String Value\";\n" +
+				"    String string = \"Some String Value\";\n" +
 				"  }\n" +
 				"}");
 
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testStringVar2() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -128,7 +138,7 @@ public class PostFixCompletionTest extends TestCase {
 				"\n" +
 				"public class StringVar2 {\n" +
 				"  public void test () {\n" +
-				"    String name = \"foo\";\n" +
+				"    String string = \"foo\";\n" +
 				"    if (true);\n" +
 				"  }\n" +
 				"}");
@@ -136,6 +146,7 @@ public class PostFixCompletionTest extends TestCase {
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testIntegerVar() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -158,13 +169,14 @@ public class PostFixCompletionTest extends TestCase {
 		expected.append("package test;\n" +
 				"public class IntegerVar {\n" +
 				"  public void test () {\n" +
-				"    Integer name = new Integer(0);\n" +
+				"    Integer integer = new Integer(0);\n" +
 				"  }\n" +
 				"}");
 
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testBooleanVar() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -187,13 +199,14 @@ public class PostFixCompletionTest extends TestCase {
 		expected.append("package test;\n" +
 				"public class BooleanVar {\n" +
 				"  public void test () {\n" +
-				"    boolean false1 = false;\n" +
+				"    boolean b = false;\n" +
 				"  }\n" +
 				"}");
 
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testIntVar() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -223,6 +236,7 @@ public class PostFixCompletionTest extends TestCase {
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testStringConcatVar() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -245,13 +259,14 @@ public class PostFixCompletionTest extends TestCase {
 		expected.append("package test;\n" +
 				"public class StringConcatVar {\n" +
 				"  public void test () {\n" +
-				"    String name = (\"two\" + 2);\n" +
+				"    String string = (\"two\" + 2);\n" +
 				"  }\n" +
 				"}");
 
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testStringConcatVar2() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -274,19 +289,20 @@ public class PostFixCompletionTest extends TestCase {
 		expected.append("package test;\n" +
 				"public class testStringConcatVar2 {\n" +
 				"  public void test () {\n" +
-				"    String name = ((((\"two\" + 2))));\n" +
+				"    String string = ((((\"two\" + 2))));\n" +
 				"  }\n" +
 				"}");
 
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testArrayVar() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
 				"public class ArrayVar {\n" +
 				"  public void test () {\n" +
-				"    new byte[]{0, 1, 3}.var$\n" +
+				"    new byte[] { 0, 1, 3 }.var$\n" +
 				"  }\n" +
 				"}");
 
@@ -303,13 +319,46 @@ public class PostFixCompletionTest extends TestCase {
 		expected.append("package test;\n" +
 				"public class ArrayVar {\n" +
 				"  public void test () {\n" +
-				"    byte[] name = new byte[]{0, 1, 3};\n" +
+				"    byte[] name = new byte[] { 0, 1, 3 };\n" +
 				"  }\n" +
 				"}");
 
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
+	public void testArrayAccessVar() throws Exception {
+		StringBuffer buf= new StringBuffer();
+		buf.append("package test;\n" +
+				"public class ArrayAccessVar {\n" +
+				"  public void test () {\n" +
+				"    String [] args = new String [] { \"one\", \"two\" };\n" +
+				"    args[0].var$\n" +
+				"  }\n" +
+				"}");
+
+		int completionIndex= getCompletionIndex(buf);
+		ICompilationUnit cu= getCompilationUnit(pkg, buf, "ArrayAccessVar.java");
+		List<ICompletionProposal> proposals= computeCompletionProposals(cu, completionIndex);
+
+		assertProposalsExist(Arrays.asList("var - Creates a new variable"), proposals);
+
+		ITextViewer viewer= initializeViewer(cu);
+		applyProposal(viewer, proposals, "var", completionIndex);
+
+		StringBuffer expected= new StringBuffer();
+		expected.append("package test;\n" +
+				"public class ArrayAccessVar {\n" +
+				"  public void test () {\n" +
+				"    String [] args = new String [] { \"one\", \"two\" };\n" +
+				"    String string = args[0];\n" +
+				"  }\n" +
+				"}");
+
+		assertEquals(expected.toString(), viewer.getDocument().get());
+	}
+
+	@Test
 	public void testBoundedExtendsTypeParameterVar() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -336,13 +385,14 @@ public class PostFixCompletionTest extends TestCase {
 				"public class BoundedExtendsTypeParameterVar {\n" +
 				"  public void test () {\n" +
 				"    List<? extends Number> x = null;\n" +
-				"    Number name = x.get(0);\n" +
+				"    Number number = x.get(0);\n" +
 				"  }\n" +
 				"}");
 
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testBoundedSuperTypeParameterVar() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -369,13 +419,14 @@ public class PostFixCompletionTest extends TestCase {
 				"public class testBoundedSuperTypeParameterVar {\n" +
 				"  public void test () {\n" +
 				"    List<? super Number> x = null;\n" +
-				"    Object name = x.get(0);\n" +
+				"    Object number = x.get(0);\n" +
 				"  }\n" +
 				"}");
 
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testVarForMethodInvocation() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -404,13 +455,14 @@ public class PostFixCompletionTest extends TestCase {
 				"public class VarForMethodInvocation {\n" +
 				"  public void test () {\n" +
 				"    List<String> res = Arrays.asList(\"a\", \"b\");\n" +
-				"    boolean name = res.get(0).isEmpty();\n" +
+				"    boolean empty = res.get(0).isEmpty();\n" +
 				"  }\n" +
 				"}");
 
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testVarForMethodInvocation2() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -435,13 +487,155 @@ public class PostFixCompletionTest extends TestCase {
 				"public class VarForMethodInvocation2 {\n" +
 				"  public void test () {\n" +
 				"    String s = \"5\";\n" +
-				"    Integer name = Integer.valueOf(s);\n" +
+				"    Integer valueOf = Integer.valueOf(s);\n" +
 				"  }\n" +
 				"}");
 
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
+	public void testVarForMethodInvocation3() throws Exception {
+		StringBuffer buf= new StringBuffer();
+		buf.append("package test;\n" +
+				"public class VarForMethodInvocation3 {\n" +
+				"  public <T> T getAdapter(Class<T> required) {\n" +
+				"    return null;\n" +
+				"  } \n" +
+				"  public class Child extends VarForMethodInvocation3 {\n" +
+				"    public void test() {\n" +
+				"      super.getAdapter(VarForMethodInvocation3.class).var$\n" +
+				"    }\n" +
+				"  } \n" +
+				"}");
+
+		int completionIndex= getCompletionIndex(buf);
+		ICompilationUnit cu= getCompilationUnit(pkg, buf, "VarForMethodInvocation3.java");
+		List<ICompletionProposal> proposals= computeCompletionProposals(cu, completionIndex);
+
+		assertProposalsExist(Arrays.asList("var - Creates a new variable"), proposals);
+
+		ITextViewer viewer= initializeViewer(cu);
+		applyProposal(viewer, proposals, "var", completionIndex);
+
+		StringBuffer expected= new StringBuffer();
+		expected.append("package test;\n" +
+				"public class VarForMethodInvocation3 {\n" +
+				"  public <T> T getAdapter(Class<T> required) {\n" +
+				"    return null;\n" +
+				"  } \n" +
+				"  public class Child extends VarForMethodInvocation3 {\n" +
+				"    public void test() {\n" +
+				"      VarForMethodInvocation3 adapter = super.getAdapter(VarForMethodInvocation3.class);\n" +
+				"    }\n" +
+				"  } \n" +
+				"}");
+
+		assertEquals(expected.toString(), viewer.getDocument().get());
+	}
+
+	@Test
+	public void testVarForClassCreation() throws Exception {
+		StringBuffer buf= new StringBuffer();
+		buf.append("package test;\n" +
+				"public class VarForClassCreation {\n" +
+				"  public static final int STYLE = 7;\n" +
+				"  public void test () {\n" +
+				"    new Integer(VarForClassCreation.STYLE).var$\n" +
+				"  }\n" +
+				"}");
+
+		int completionIndex= getCompletionIndex(buf);
+		ICompilationUnit cu= getCompilationUnit(pkg, buf, "VarForClassCreation.java");
+		List<ICompletionProposal> proposals= computeCompletionProposals(cu, completionIndex);
+
+		assertProposalsExist(Arrays.asList("var - Creates a new variable"), proposals);
+
+		ITextViewer viewer= initializeViewer(cu);
+		applyProposal(viewer, proposals, "var", completionIndex);
+
+		StringBuffer expected= new StringBuffer();
+		expected.append("package test;\n" +
+				"public class VarForClassCreation {\n" +
+				"  public static final int STYLE = 7;\n" +
+				"  public void test () {\n" +
+				"    Integer integer = new Integer(VarForClassCreation.STYLE);\n" +
+				"  }\n" +
+				"}");
+
+		assertEquals(expected.toString(), viewer.getDocument().get());
+	}
+
+	@Test
+	public void testBegForVoidMethodInvocation() throws Exception {
+		StringBuffer buf= new StringBuffer();
+		buf.append("package test;\n" +
+				"public class BegForVoidMethodInvocation {\n" +
+				"  public void test() {\n" +
+				"    getFoo(String.class).beg$\n" +
+				"  } \n" +
+				"  public <T> void getFoo (Class <T> foo) {\n" +
+				"  } \n" +
+				"}");
+
+		int completionIndex= getCompletionIndex(buf);
+		ICompilationUnit cu= getCompilationUnit(pkg, buf, "BegForVoidMethodInvocation.java");
+		List<ICompletionProposal> proposals= computeCompletionProposals(cu, completionIndex);
+
+		assertProposalsExist(Arrays.asList("beg - Sets the cursor to the begin of the expression"), proposals);
+
+		ITextViewer viewer= initializeViewer(cu);
+		applyProposal(viewer, proposals, "beg", completionIndex);
+
+		int expectedBeg = buf.toString().indexOf("getFoo(String.class)");
+		assertEquals(expectedBeg, viewer.getSelectedRange().x);
+	}
+
+	@Test
+	public void testVarForAnonymousClass() throws Exception {
+		StringBuffer buf= new StringBuffer();
+		buf.append("package test;\n" +
+				"import java.io.File;\n" +
+				"import java.io.FileFilter;\n" +
+				"public class Test {\n" +
+				"  public void test() {\n" +
+				"    new File(\"\").listFiles(new FileFilter() {\n" +
+				"      @Override\n" +
+				"      public boolean accept(File pathname) {\n" +
+				"        return false;\n" +
+				"      }\n" +
+				"    }).var$\n" +
+				"  } \n" +
+				"}");
+
+		int completionIndex= getCompletionIndex(buf);
+		ICompilationUnit cu= getCompilationUnit(pkg, buf, "VarForAnonymousClass.java");
+		List<ICompletionProposal> proposals= computeCompletionProposals(cu, completionIndex);
+
+		assertProposalsExist(Arrays.asList("var - Creates a new variable"), proposals);
+
+		ITextViewer viewer= initializeViewer(cu);
+		applyProposal(viewer, proposals, "var", completionIndex);
+
+		StringBuffer expected= new StringBuffer();
+		expected.append("package test;\n" +
+				"import java.io.File;\n" +
+				"import java.io.FileFilter;\n" +
+				"public class Test {\n" +
+				"  public void test() {\n" +
+				"    File[] listFiles = new File(\"\").listFiles(new FileFilter() {\n" +
+				"      @Override\n" +
+				"      public boolean accept(File pathname) {\n" +
+				"        return false;\n" +
+				"      }\n" +
+				"    });\n" +
+				"  } \n" +
+				"}");
+
+		assertEquals(expected.toString(), viewer.getDocument().get());
+	}
+
+	@Test
 	public void testNestedQualifiedNames() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -474,7 +668,7 @@ public class PostFixCompletionTest extends TestCase {
 				"public Foo foo; \n" +
 				"public void foo () {\n" +
 				"  Foo foo = new Foo ();\n" +
-				"  String name = foo.bar.res;\n" +
+				"  String res = foo.bar.res;\n" +
 				"}\n" +
 				"public class Foo {\n" +
 				"  public Bar bar;\n" +
@@ -487,6 +681,7 @@ public class PostFixCompletionTest extends TestCase {
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testFieldAccess() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -514,7 +709,7 @@ public class PostFixCompletionTest extends TestCase {
 				"  public class Foo {\n" +
 				"    public String res;\n" +
 				"    public void foo () {\n" +
-				"      String name = this.res;\n" +
+				"      String res = this.res;\n" +
 				"    }\n" +
 				"  }" +
 				"}");
@@ -522,6 +717,7 @@ public class PostFixCompletionTest extends TestCase {
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testForStatement() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -549,23 +745,24 @@ public class PostFixCompletionTest extends TestCase {
 				"  public void test () {\n" +
 				"    List<String> a;\n" +
 				"    for (String a2 : a) {\n" +
-				"		\n" +
-				"	}\n" +
+				"      \n" +
+				"    }\n" +
 				"  }\n" +
 				"}");
 
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testForStatement2() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
 				"import java.util.List;\n" +
 				"public class ForStatement2 {\n" +
-				"	public int test (String [] inp) {\n" +
-				"		inp.fo$\n" +
-				"		return 0;\n" +
-				"	}\n" +
+				"  public int test (String [] inp) {\n" +
+				"    inp.fo$\n" +
+				"    return 0;\n" +
+				"  }\n" +
 				"}");
 
 		int completionIndex= getCompletionIndex(buf);
@@ -581,17 +778,18 @@ public class PostFixCompletionTest extends TestCase {
 		expected.append("package test;\n" +
 				"import java.util.List;\n" +
 				"public class ForStatement2 {\n" +
-				"	public int test (String [] inp) {\n" +
-				"		for (String inp2 : inp) {\n" +
-				"			\n" +
-				"		}\n" +
-				"		return 0;\n" +
-				"	}\n" +
+				"  public int test (String [] inp) {\n" +
+				"    for (String inp2 : inp) {\n" +
+				"      \n" +
+				"    }\n" +
+				"    return 0;\n" +
+				"  }\n" +
 				"}");
 
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testShorthandIfStatement() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -621,6 +819,7 @@ public class PostFixCompletionTest extends TestCase {
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testConcatenatedShorthandIfStatement() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -650,6 +849,7 @@ public class PostFixCompletionTest extends TestCase {
 		assertEquals(expected.toString(), viewer.getDocument().get());
 	}
 
+	@Test
 	public void testNoThrownExceptions() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package test;\n" +
@@ -664,6 +864,37 @@ public class PostFixCompletionTest extends TestCase {
 		computeCompletionProposals(cu, completionIndex);
 	}
 
+	@Test
+	public void testStreamOf() throws Exception {
+		StringBuffer buf= new StringBuffer();
+		buf.append("package test;\n" +
+				"public class StreamOf {\n" +
+				"  public void test (String[] args) {\n" +
+				"    args.stream$\n" +
+				"  }\n" +
+				"}");
+
+		int completionIndex= getCompletionIndex(buf);
+		ICompilationUnit cu= getCompilationUnit(pkg, buf, "StreamOf.java");
+		List<ICompletionProposal> proposals= computeCompletionProposals(cu, completionIndex);
+
+		assertProposalsExist(Arrays.asList("stream - Creates a new stream using Stream.of"), proposals);
+
+		ITextViewer viewer= initializeViewer(cu);
+		applyProposal(viewer, proposals, "stream", completionIndex);
+
+		StringBuffer expected= new StringBuffer();
+		expected.append("package test;\n" +
+				"public class StreamOf {\n" +
+				"  public void test (String[] args) {\n" +
+				"    Stream.of(args)\n" +
+				"  }\n" +
+				"}");
+
+		assertEquals(expected.toString(), viewer.getDocument().get());
+	}
+
+
 	private ITextViewer initializeViewer(ICompilationUnit cu) throws Exception {
 		IEditorPart editor= EditorUtility.openInEditor(cu);
 		ITextViewer viewer= new TextViewer(editor.getSite().getShell(), SWT.NONE);
@@ -700,5 +931,4 @@ public class PostFixCompletionTest extends TestCase {
 		PostfixTemplateProposal proposal= (PostfixTemplateProposal) proposals.stream().filter(p -> ((PostfixTemplateProposal) p).getTemplate().getName().equals(name)).findFirst().get();
 		proposal.apply(viewer, '0', -1, offset);
 	}
-
 }
