@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2015 IBM Corporation and others.
+ * Copyright (c) 2007, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,8 +13,12 @@
  *******************************************************************************/
 package org.eclipse.jdt.text.tests.templates;
 
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import java.util.Iterator;
 
+import org.junit.Test;
+
 import org.eclipse.jface.text.templates.ContextTypeRegistry;
 import org.eclipse.jface.text.templates.Template;
 import org.eclipse.jface.text.templates.TemplateContextType;
@@ -22,27 +26,19 @@ import org.eclipse.jface.text.templates.TemplateException;
 import org.eclipse.jface.text.templates.TemplateTranslator;
 import org.eclipse.jface.text.templates.TemplateVariable;
 import org.eclipse.jface.text.templates.TemplateVariableResolver;
+
 import org.eclipse.jdt.internal.corext.template.java.JavaContextType;
 import org.eclipse.jdt.internal.corext.template.java.JavaDocContextType;
 import org.eclipse.jdt.internal.corext.template.java.SWTContextType;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
-
 /**
  * Template contribution tests.
  *
  * @since 3.4
  */
-public class TemplateContributionTest extends TestCase {
-
-	public static Test suite() {
-		return new TestSuite(TemplateContributionTest.class);
-	}
+public class TemplateContributionTest {
 
 	private void checkContribution(String resolverContextTypeId, String contextTypeId) throws TemplateException {
 		ContextTypeRegistry registry= JavaPlugin.getDefault().getTemplateContextRegistry();
@@ -52,12 +48,13 @@ public class TemplateContributionTest extends TestCase {
 			TemplateTranslator translator= new TemplateTranslator();
 			for (TemplateVariable variable : translator.translate(template).getVariables()) {
 				if (!variable.getType().equals(variable.getName())) {
-					assertTrue("No resolver found for variable '" + variable.getType() + "' in template '" + template.getName() + "'\n\n" + template.getPattern(), canHandle(context, variable));
+					assertTrue(canHandle(context, variable),"No resolver found for variable '" + variable.getType() + "' in template '" + template.getName() + "'\n\n" + template.getPattern());
 				}
 			}
 		}
 	}
 
+	@Test
 	public void testJavaContribution() throws Exception {
 		checkContribution(JavaContextType.ID_ALL, JavaContextType.ID_ALL);
 		checkContribution(JavaContextType.ID_ALL, JavaContextType.ID_MEMBERS);
@@ -66,10 +63,12 @@ public class TemplateContributionTest extends TestCase {
 		checkContribution(JavaContextType.ID_STATEMENTS, JavaContextType.ID_STATEMENTS);
 	}
 
+	@Test
 	public void testJavaDocContribution() throws Exception {
 		checkContribution(JavaDocContextType.ID, JavaDocContextType.ID);
 	}
 
+	@Test
 	public void testSWTContributionAll() throws Exception {
 		checkContribution(SWTContextType.ID_ALL, SWTContextType.ID_ALL);
 		checkContribution(SWTContextType.ID_ALL, SWTContextType.ID_MEMBERS);
