@@ -4,7 +4,7 @@ import p2.B;
 
 public interface A {
 	public int fInt= 10;
-	public B fB= new B();
+	public B fB= new B() {};
 	public String fString= "something";
 	public boolean fBool= true;
 	
