@@ -6,15 +6,11 @@ import java.io.IOException;
 
 class TestWithThrows3 {
 	public FileInputStream foo(int a) throws FileNotFoundException {
-		try {
-			try (/*[*/ FileInputStream f = new FileInputStream("a.b")) {
-				return f;/*]*/
-			} catch (FileNotFoundException e) {
-				throw e;
-			} catch (IOException e) {
-			}
+		try (/*[*/ FileInputStream f = new FileInputStream("a.b")) {
+			return f;/*]*/
 		} catch (FileNotFoundException e) {
 			// do nothing
+		} catch (IOException e) {
 		}
 		return null;
 	}
