@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2017 IBM Corporation and others.
+ * Copyright (c) 2007, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -15,12 +15,17 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.refactoring;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
 import java.io.IOException;
 import java.util.HashMap;
 import java.util.Map;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
 
 import org.eclipse.core.runtime.NullProgressMonitor;
 
@@ -41,25 +46,21 @@ import org.eclipse.jdt.core.refactoring.descriptors.ExtractClassDescriptor.Field
 import org.eclipse.jdt.internal.core.refactoring.descriptors.RefactoringSignatureDescriptorFactory;
 
 import org.eclipse.jdt.ui.PreferenceConstants;
+import org.eclipse.jdt.ui.tests.refactoring.rules.RefactoringTestSetup;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 
-public class ExtractClassTests extends RefactoringTest {
-
+public class ExtractClassTests extends GenericRefactoringTest {
 	private static final String REFACTORING_PATH= "ExtractClass/";
 	protected IPackageFragment fPack;
 	protected ExtractClassDescriptor fDescriptor;
 
-	public ExtractClassTests(String name) {
-		super(name);
+	public ExtractClassTests() {
+		this.rts= new RefactoringTestSetup();
 	}
 
-	public static Test suite() {
-		return new RefactoringTestSetup(new TestSuite(ExtractClassTests.class));
-	}
-
-	public static Test setUpTest(Test someTest) {
-		return new RefactoringTestSetup(someTest);
+	protected ExtractClassTests(RefactoringTestSetup rts) {
+		super(rts);
 	}
 
 	protected IType setupType() throws Exception {
@@ -162,9 +163,8 @@ public class ExtractClassTests extends RefactoringTest {
 		return status;
 	}
 
-	@Override
-	protected void setUp() throws Exception {
-		super.setUp();
+	@Before
+	public void before() throws Exception {
 		IPreferenceStore store= JavaPlugin.getDefault().getPreferenceStore();
 		store.setValue(PreferenceConstants.CODEGEN_ADD_COMMENTS, false);
 		fDescriptor= RefactoringSignatureDescriptorFactory.createExtractClassDescriptor();
@@ -172,33 +172,36 @@ public class ExtractClassTests extends RefactoringTest {
 		fPack= getPackageP();
 	}
 
-	@Override
-	protected void tearDown() throws Exception {
-		super.tearDown();
+	@After
+	public void after() throws Exception {
 		fDescriptor= null;
 		fPack= null;
 		IPreferenceStore store= JavaPlugin.getDefault().getPreferenceStore();
 		store.setToDefault(PreferenceConstants.CODEGEN_ADD_COMMENTS);
 	}
 
+	@Test
 	public void testComplexExtract() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setClassName("ComplexExtractParameter");
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testInitializerProblem() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setClassName("InitializerProblemParameter");
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testMethodUpdate() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setClassName("MethodUpdateParameter");
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testInheritanceUpdate() throws Exception {
 		createAdditionalFile("InheritanceUpdateImpl");
 		fDescriptor.setType(setupType());
@@ -207,6 +210,7 @@ public class ExtractClassTests extends RefactoringTest {
 		checkAdditionalFile("InheritanceUpdateImpl");
 	}
 
+	@Test
 	public void testInheritanceUpdateGetterSetter() throws Exception {
 		createAdditionalFile("InheritanceUpdateImplGetterSetter");
 		fDescriptor.setType(setupType());
@@ -216,6 +220,7 @@ public class ExtractClassTests extends RefactoringTest {
 		checkAdditionalFile("InheritanceUpdateImplGetterSetter");
 	}
 
+	@Test
 	public void testComplexExtractGetterSetter() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setCreateGetterSetter(true);
@@ -223,6 +228,7 @@ public class ExtractClassTests extends RefactoringTest {
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testComplexExtractNested() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setCreateTopLevel(false);
@@ -230,6 +236,7 @@ public class ExtractClassTests extends RefactoringTest {
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testStaticInstanceFields() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setClassName("StaticInstanceFieldsParameter");
@@ -238,16 +245,18 @@ public class ExtractClassTests extends RefactoringTest {
 		//Warning for no IFields moved
 		assertEquals(1, entries.length);
 		for (RefactoringStatusEntry refactoringStatusEntry : entries) {
-			assertEquals("Status was:" + refactoringStatusEntry, true, refactoringStatusEntry.isFatalError());
+			assertTrue("Status was:" + refactoringStatusEntry, refactoringStatusEntry.isFatalError());
 		}
 	}
 
+	@Test
 	public void testImportRemove() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setClassName("ImportRemoveParameter");
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testSwitchCase() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setClassName("SwitchCaseParameter");
@@ -256,10 +265,11 @@ public class ExtractClassTests extends RefactoringTest {
 		//Error for usage in Switch case
 		assertEquals(1, entries.length);
 		for (RefactoringStatusEntry refactoringStatusEntry : entries) {
-			assertEquals(true, refactoringStatusEntry.isError());
+			assertTrue(refactoringStatusEntry.isError());
 		}
 	}
 
+	@Test
 	public void testCopyModifierAnnotations() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setClassName("CopyModifierAnnotationsParameter");
@@ -269,10 +279,11 @@ public class ExtractClassTests extends RefactoringTest {
 		//Warning for volatile
 		assertEquals(2, entries.length);
 		for (RefactoringStatusEntry refactoringStatusEntry : entries) {
-			assertEquals(true, refactoringStatusEntry.isWarning());
+			assertTrue(refactoringStatusEntry.isWarning());
 		}
 	}
 
+	@Test
 	public void testUFOGetter() throws Exception {
 		fDescriptor.setType(setupType());
 		Field[] fields= ExtractClassDescriptor.getFields(fDescriptor.getType());
@@ -287,6 +298,7 @@ public class ExtractClassTests extends RefactoringTest {
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testControlBodyUpdates() throws Exception {
 		IJavaProject javaProject= getRoot().getJavaProject();
 		Map<String, String> originalOptions= javaProject.getOptions(true);
@@ -303,6 +315,7 @@ public class ExtractClassTests extends RefactoringTest {
 		}
 	}
 
+	@Test
 	public void testArrayInitializer() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setCreateGetterSetter(true);
@@ -310,6 +323,7 @@ public class ExtractClassTests extends RefactoringTest {
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testVariableDeclarationInitializer() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setCreateGetterSetter(true);
@@ -317,6 +331,7 @@ public class ExtractClassTests extends RefactoringTest {
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testUpdateSimpleName() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setCreateGetterSetter(true);
@@ -324,6 +339,7 @@ public class ExtractClassTests extends RefactoringTest {
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testArrayLengthAccess() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setCreateGetterSetter(true);
@@ -331,6 +347,7 @@ public class ExtractClassTests extends RefactoringTest {
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testInnerDocumentedClass() throws Exception {
 		IType outer= setupType();
 		IType inner= outer.getType("InnerClass");
@@ -341,6 +358,7 @@ public class ExtractClassTests extends RefactoringTest {
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testPackageReferences() throws Exception {
 		createAdditionalFile("subPack","PackEx");
 		fDescriptor.setType(setupType());
@@ -352,10 +370,11 @@ public class ExtractClassTests extends RefactoringTest {
 		//Error for OtherPackageProteced reference
 		assertEquals(2, entries.length);
 		for (RefactoringStatusEntry refactoringStatusEntry : entries) {
-			assertEquals(true, refactoringStatusEntry.isError());
+			assertTrue(refactoringStatusEntry.isError());
 		}
 	}
 
+	@Test
 	public void testDuplicateParamName() throws Exception {
 		IJavaProject javaProject= getRoot().getJavaProject();
 		Map<String, String> originalOptions= javaProject.getOptions(true);
@@ -372,6 +391,7 @@ public class ExtractClassTests extends RefactoringTest {
 		}
 	}
 
+	@Test
 	public void testLowestVisibility() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setCreateGetterSetter(true);
@@ -379,6 +399,7 @@ public class ExtractClassTests extends RefactoringTest {
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testSwitchCaseUpdates() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setCreateGetterSetter(true);
@@ -386,6 +407,7 @@ public class ExtractClassTests extends RefactoringTest {
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testFieldsWithJavadoc() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setFieldName("data");
@@ -393,6 +415,7 @@ public class ExtractClassTests extends RefactoringTest {
 		runRefactoring(false);
 	}
 
+	@Test
 	public void testQualifiedIncrements() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setCreateGetterSetter(true);
@@ -402,10 +425,11 @@ public class ExtractClassTests extends RefactoringTest {
 		//3*Warning for semantic change
 		assertEquals(3, entries.length);
 		for (RefactoringStatusEntry refactoringStatusEntry : entries) {
-			assertEquals(true, refactoringStatusEntry.isWarning());
+			assertTrue(refactoringStatusEntry.isWarning());
 		}
 	}
 
+	@Test
 	public void testComment() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setCreateTopLevel(false);
@@ -413,6 +437,7 @@ public class ExtractClassTests extends RefactoringTest {
 	}
 
 	// see bug 394547
+	@Test
 	public void testNested1() throws Exception {
 		IType outer= setupType();
 		IType inner= outer.getType("Inner");
@@ -424,6 +449,7 @@ public class ExtractClassTests extends RefactoringTest {
 	}
 
 	// see bug 394547
+	@Test
 	public void testNested2() throws Exception {
 		IType outer= setupType();
 		IType inner= outer.getType("Inner");
@@ -434,6 +460,7 @@ public class ExtractClassTests extends RefactoringTest {
 		runRefactoring(false);
 	}
 	// see bug 394548
+	@Test
 	public void testTypeParameter() throws Exception {
 		fDescriptor.setType(setupType());
 		fDescriptor.setCreateTopLevel(false);
