@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2017 IBM Corporation and others.
+ * Copyright (c) 2017, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -18,7 +18,7 @@ import org.eclipse.ltk.core.refactoring.RefactoringCore;
 import org.eclipse.jdt.core.IPackageFragment;
 import org.eclipse.jdt.core.IPackageFragmentRoot;
 
-import junit.framework.Test;
+import org.eclipse.jdt.ui.tests.refactoring.rules.Java9Setup;
 
 public class ExtractMethodTestSetup9 extends Java9Setup {
 
@@ -26,13 +26,9 @@ public class ExtractMethodTestSetup9 extends Java9Setup {
 
 	private IPackageFragment fInvalidSelectionPackage;
 
-	public ExtractMethodTestSetup9(Test test) {
-		super(test);
-	}
-
 	@Override
-	protected void setUp() throws Exception {
-		super.setUp();
+	public void before() throws Exception {
+		super.before();
 
 		RefactoringCore.getUndoManager().flush();
 
