@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2012 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,11 +13,13 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.refactoring;
 
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+
 import java.util.Arrays;
 import java.util.List;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.Test;
 
 import org.eclipse.core.runtime.NullProgressMonitor;
 
@@ -26,6 +28,7 @@ import org.eclipse.ltk.core.refactoring.RefactoringStatus;
 import org.eclipse.ltk.core.refactoring.participants.ProcessorBasedRefactoring;
 
 import org.eclipse.jdt.core.ICompilationUnit;
+import org.eclipse.jdt.core.IField;
 import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.IMember;
@@ -39,6 +42,8 @@ import org.eclipse.jdt.internal.corext.refactoring.RefactoringAvailabilityTester
 import org.eclipse.jdt.internal.corext.refactoring.structure.ExtractSupertypeProcessor;
 import org.eclipse.jdt.internal.corext.refactoring.util.JavaElementUtil;
 
+import org.eclipse.jdt.ui.tests.refactoring.rules.Java1d5Setup;
+
 import org.eclipse.jdt.internal.ui.preferences.JavaPreferencesSettings;
 
 /**
@@ -46,9 +51,11 @@ import org.eclipse.jdt.internal.ui.preferences.JavaPreferencesSettings;
  *
  * Note: Extract Supertype heavily relies on PullUpRefactoring and its tests
  */
-public final class ExtractSupertypeTests extends RefactoringTest {
+public final class ExtractSupertypeTests extends GenericRefactoringTest {
 
-	private static final Class<ExtractSupertypeTests> clazz= ExtractSupertypeTests.class;
+	public ExtractSupertypeTests() {
+		rts= new Java1d5Setup();
+	}
 
 	private static final String REFACTORING_PATH= "ExtractSupertype/";
 
@@ -71,86 +78,99 @@ public final class ExtractSupertypeTests extends RefactoringTest {
 		return l.toArray(new IMethod[l.size()]);
 	}
 
-	public static Test setUpTest(Test someTest) {
-		return new Java15Setup(someTest);
-	}
-
-	public static Test suite() {
-		return new Java15Setup(new TestSuite(clazz));
-	}
-
-	public ExtractSupertypeTests(String name) {
-		super(name);
-	}
-
 	@Override
 	protected String getRefactoringPath() {
 		return REFACTORING_PATH;
 	}
 
-	private void helper1(String[] methodNames, String[][] signatures, boolean deleteAllInSourceType, boolean deleteAllMatchingMethods, boolean replaceOccurences) throws Exception {
+	private void helper1(String[] methodNames, String[][] signatures, String[] fieldNames, boolean deleteAllInSourceType, boolean deleteAllMatchingMethods, boolean replaceOccurences) throws Exception {
 		ICompilationUnit cu= createCUfromTestFile(getPackageP(), "A");
 		IType type= getType(cu, "B");
 		IMethod[] methods= getMethods(type, methodNames, signatures);
 
-		ExtractSupertypeProcessor processor= createRefactoringProcessor(methods);
+		IField[] fields= getFields(type, fieldNames);
+
+		IMember[] members= merge(methods, fields);
+		ExtractSupertypeProcessor processor= createRefactoringProcessor(members);
 		Refactoring refactoring= processor.getRefactoring();
-		processor.setMembersToMove(methods);
 
 		assertTrue("activation", refactoring.checkInitialConditions(new NullProgressMonitor()).isOK());
 
+		processor.setMembersToMove(members);
 		processor.setTypesToExtract(new IType[] { type});
 		processor.setTypeName("Z");
-		processor.setCreateMethodStubs(true);
+		processor.setCreateMethodStubs(false);
 		processor.setInstanceOf(false);
 		processor.setReplace(replaceOccurences);
 		if (deleteAllInSourceType)
-			processor.setDeletedMethods(methods);
+			processor.setDeletedMethods(getMethods(members));
 		if (deleteAllMatchingMethods)
 			processor.setDeletedMethods(getMethods(processor.getMatchingElements(new NullProgressMonitor(), false)));
 
 		RefactoringStatus status= refactoring.checkFinalConditions(new NullProgressMonitor());
-		assertTrue("precondition was supposed to pass", !status.hasError());
+		assertFalse("precondition was supposed to pass", status.hasError());
 		performChange(refactoring, false);
 
 		String expected= getFileContents(getOutputTestFileName("A"));
-		String actual= cu.getSource();
+		ICompilationUnit unit= getPackageP().getCompilationUnit("A.java");
+		String actual= unit.getBuffer().getContents();
 		assertEqualLines(expected, actual);
 
 		expected= getFileContents(getOutputTestFileName("Z"));
-		ICompilationUnit unit= getPackageP().getCompilationUnit("Z.java");
-		if (!unit.exists())
-			assertTrue("extracted compilation unit does not exist", false);
+		unit= getPackageP().getCompilationUnit("Z.java");
+		assertTrue("extracted compilation unit does not exist", unit.exists());
 		actual= unit.getBuffer().getContents();
 		assertEqualLines(expected, actual);
-
 	}
 
+	@Test
 	public void test0() throws Exception {
-		helper1(new String[] { "m"}, new String[][] { new String[0]}, true, false, true);
+		helper1(new String[] { "m"}, new String[][] { new String[0]}, null, true, false, true);
 	}
 
+	@Test
 	public void test1() throws Exception {
-		helper1(new String[] { "m"}, new String[][] { new String[0]}, true, false, true);
+		helper1(new String[] { "m"}, new String[][] { new String[0]}, null, true, false, true);
 	}
 
+	@Test
 	public void test2() throws Exception {
-		helper1(new String[] { "m", "n"}, new String[][] { new String[0], new String[0]}, true, false, true);
+		helper1(new String[] { "m", "n"}, new String[][] { new String[0], new String[0]}, null, true, false, true);
 	}
 
+	@Test
 	public void test3() throws Exception {
-		helper1(new String[] { "m", "n"}, new String[][] { new String[0], new String[0]}, true, false, true);
+		helper1(new String[] { "m", "n"}, new String[][] { new String[0], new String[0]}, null, true, false, true);
 	}
 
+	@Test
 	public void test4() throws Exception {
-		helper1(new String[] { "m"}, new String[][] { new String[0]}, true, false, true);
+		helper1(new String[] { "m"}, new String[][] { new String[0]}, null, true, false, true);
 	}
 
+	@Test
 	public void testBug151683() throws Exception {
-		helper1(new String[] { "m" }, new String[][] { new String[0] }, true, false, false);
+		helper1(new String[] { "m" }, new String[][] { new String[0] }, null, true, false, false);
 	}
 
+	@Test
 	public void testBug240353() throws Exception {
-		helper1(new String[] { "foo" }, new String[][] { new String[] { Signature.createTypeSignature("T", false) } }, true, false, false);
+		helper1(new String[] { "foo" }, new String[][] { new String[] { Signature.createTypeSignature("T", false) } },
+				null, true, false, false);
+	}
+
+	@Test
+	public void testBug573884_1() throws Exception {
+		helper1(new String[] { "geta", "getb" }, new String[][] { new String[0], new String[0] }, new String[] { "a", "b" }, true, false, true);
+	}
+
+	@Test
+	public void testBug573884_2() throws Exception {
+		helper1(new String[] { "geta", "getb" }, new String[][] { new String[0], new String[0] }, new String[] { "a", "b" }, true, false, true);
+	}
+
+	@Test
+	public void testBug573884_3() throws Exception {
+		helper1(new String[] { "geta", "getb" }, new String[][] { new String[0], new String[0] }, new String[] { "a", "b" }, true, false, true);
 	}
 }
