@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,21 +13,20 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.refactoring;
 
+import static org.junit.Assert.assertEquals;
+
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Iterator;
-import java.util.Set;
+
+import org.junit.Test;
 
 import org.eclipse.jdt.internal.corext.refactoring.rename.RefactoringScanner;
 import org.eclipse.jdt.internal.corext.refactoring.rename.RefactoringScanner.TextMatch;
 
 import org.eclipse.jdt.ui.tests.refactoring.infra.TextRangeUtil;
+import org.eclipse.jdt.ui.tests.refactoring.rules.RefactoringTestSetup;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
-public class RefactoringScannerTests extends RefactoringTest{
-
+public class RefactoringScannerTests extends GenericRefactoringTest {
 	private static class Position {
 		private final int fLine;
 		private final int fColumn;
@@ -37,32 +36,26 @@ public class RefactoringScannerTests extends RefactoringTest{
 		}
 	}
 
-
-	public RefactoringScannerTests(String name){
-		super(name);
+	public RefactoringScannerTests() {
+		rts= new RefactoringTestSetup();
 	}
 
 	private RefactoringScanner fScanner;
-	private static Class<RefactoringScannerTests> clazz= RefactoringScannerTests.class;
 
 	@Override
 	protected String getRefactoringPath() {
 		return "RefactoringScanner/";
 	}
 
-	public static Test suite() {
-		return new RefactoringTestSetup(new TestSuite(clazz));
-	}
-
 	@Override
-	protected void setUp() throws Exception {
-		//no need to call super.setUp();
+	public void genericbefore() throws Exception {
+		//no need to call super.genericbefore();
 		fScanner= new RefactoringScanner("TestPattern", "org.eclipse");
 	}
 
 	@Override
-	protected void tearDown() throws Exception {
-		//no need to call super.tearDown();
+	public void genericafter() throws Exception {
+		//no need to call super.genericafter();
 	}
 
 	private void helper(String fileName, int expectedMatchCount)	throws Exception{
@@ -77,33 +70,35 @@ public class RefactoringScannerTests extends RefactoringTest{
 
 		ArrayList<Integer> expectedMatchesList= new ArrayList<>(expectedMatches.length);
 		for (Position expectedMatch : expectedMatches) {
-			expectedMatchesList.add(Integer.valueOf(TextRangeUtil.getOffset(text, expectedMatch.fLine, expectedMatch.fColumn)));
+			expectedMatchesList.add(TextRangeUtil.getOffset(text, expectedMatch.fLine, expectedMatch.fColumn));
 		}
 		ArrayList<Integer> matchesList= new ArrayList<>();
-		Set<TextMatch> matches= fScanner.getMatches();
-		for (Iterator<TextMatch> iter= matches.iterator(); iter.hasNext();) {
-			TextMatch element= iter.next();
-			matchesList.add(Integer.valueOf(element.getStartPosition()));
+		for (TextMatch element : fScanner.getMatches()) {
+			matchesList.add(element.getStartPosition());
 		}
 		Collections.sort(matchesList);
 		assertEquals("results", expectedMatchesList.toString(), matchesList.toString());
 	}
 
 	//-- tests
+	@Test
 	public void test0() throws Exception{
 		String text= "";
 		fScanner.scan(text);
 		assertEquals("results.length", 0, fScanner.getMatches().size());
 	}
 
+	@Test
 	public void test1() throws Exception{
 		helper("A.java", 8);
 	}
 
+	@Test
 	public void testWord1() throws Exception{
 		helper("B.java", 6);
 	}
 
+	@Test
 	public void testQualifier() throws Exception{
 		helper2("C.java", new Position[] {
 				new Position(4, 21),
@@ -119,4 +114,3 @@ public class RefactoringScannerTests extends RefactoringTest{
 		});
 	}
 }
-
