@@ -27,7 +27,6 @@ import org.eclipse.core.runtime.IStatus;
 
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.resources.IResourceDelta;
-import org.eclipse.core.resources.IResourceDeltaVisitor;
 import org.eclipse.core.resources.mapping.ModelProvider;
 
 public class TestModelProvider extends ModelProvider {
@@ -185,7 +184,7 @@ public class TestModelProvider extends ModelProvider {
 			Assert.assertEquals("Same path length", expectedPath.segmentCount(), actualPath.segmentCount());
 			for(int i= 0; i < expectedPath.segmentCount(); i++) {
 				String expectedSegment= expectedPath.segment(i);
-				if (expectedSegment.startsWith("UnusedName") || expectedSegment.equals("unusedName"))
+				if (expectedSegment.startsWith("UnusedName") || "unusedName".equals(expectedSegment))
 					continue;
 				Assert.assertEquals("Different path segment", expectedSegment, actualPath.segment(i));
 			}
@@ -260,7 +259,7 @@ public class TestModelProvider extends ModelProvider {
 			return false;
 		for(int i= 0; i < expectedPath.segmentCount(); i++) {
 			String expectedSegment= expectedPath.segment(i);
-			if (expectedSegment.startsWith("UnusedName") || expectedSegment.equals("unusedName"))
+			if (expectedSegment.startsWith("UnusedName") || "unusedName".equals(expectedSegment))
 				continue;
 			if (!expectedSegment.equals(actualPath.segment(i)))
 				return false;
@@ -270,15 +269,12 @@ public class TestModelProvider extends ModelProvider {
 
 	private static void assertCopySource(IResourceDelta delta) {
 		try {
-			delta.accept(new IResourceDeltaVisitor() {
-				@Override
-				public boolean visit(IResourceDelta d) throws CoreException {
-					Assert.assertTrue("Not a copy delta", (d.getKind() & ~IResourceDelta.CHANGED) == 0);
-					return true;
-				}
+			delta.accept(d -> {
+				Assert.assertEquals("Not a copy delta", 0, (d.getKind() & ~IResourceDelta.CHANGED));
+				return true;
 			});
 		} catch (CoreException e) {
-			Assert.assertTrue("Shouldn't happen", false);
+			Assert.fail("Shouldn't happen");
 		}
 	}
 }
