@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2009 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,74 +14,68 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.refactoring.nls;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+import org.junit.Test;
 
 import org.eclipse.jdt.internal.corext.refactoring.nls.NLSElement;
 import org.eclipse.jdt.internal.corext.refactoring.nls.NLSLine;
 import org.eclipse.jdt.internal.corext.refactoring.nls.NLSScanner;
 
-
-public class NLSScannerTester extends TestCase {
-
-
-	public NLSScannerTester(String name) {
-		super(name);
-	}
-
-	public static void main (String[] args) {
-		junit.textui.TestRunner.run (suite());
-	}
-
-	public static Test suite() {
-		return new TestSuite(NLSScannerTester.class);
-	}
-
+public class NLSScannerTester {
+	@Test
 	public void test0() throws Exception{
 		String text= "fred"; //$NON-NLS-1$
 		NLSLine[] l= NLSScanner.scan(text);
-		assertEquals("empty", true, l.length == 0); //$NON-NLS-1$
+		assertEquals("empty", 0, l.length); //$NON-NLS-1$
 	}
 
+	@Test
 	public void test1() throws Exception{
 		String text= "fred\"x\"";
 		NLSLine[] l= NLSScanner.scan(text);
 		assertEquals("1 line", 1, l.length);
 	}
 
+	@Test
 	public void test1a() throws Exception{
 		String text= "fred\n\"x\""; //$NON-NLS-1$
 		NLSLine[] l= NLSScanner.scan(text);
-		assertEquals("1 line", 1,l.length); //$NON-NLS-1$
+		assertEquals("1 line", 1, l.length); //$NON-NLS-1$
 	}
 
+	@Test
 	public void test2() throws Exception{
 		String text= "fred\"x\"\n\"xx\"";
 		NLSLine[] l= NLSScanner.scan(text);
-		assertEquals("2 line", 2,l.length);
+		assertEquals("2 line", 2, l.length);
 	}
 
+	@Test
 	public void test2a() throws Exception{
 		String text= "fred\n\"x\" \"xx\""; //$NON-NLS-1$
 		NLSLine[] l= NLSScanner.scan(text);
-		assertEquals("1 lines", 1,l.length); //$NON-NLS-1$
+		assertEquals("1 lines", 1, l.length); //$NON-NLS-1$
 	}
 
+	@Test
 	public void test3() throws Exception{
 		String text= "fred\"x\"\n \"xx\"";
 		NLSLine[] l= NLSScanner.scan(text);
-		assertEquals("2 lines", 2,l.length);
+		assertEquals("2 lines", 2, l.length);
 	}
 
 
+	@Test
 	public void test4() throws Exception{
 		String text= "fred\n \"xx\""; //$NON-NLS-1$
 		NLSLine[] l= NLSScanner.scan(text);
-		assertEquals("1 line", 1,l.length); //$NON-NLS-1$
+		assertEquals("1 line", 1, l.length); //$NON-NLS-1$
 	}
 
+	@Test
 	public void test5() throws Exception{
 		String text= "\n \"xx\""; //$NON-NLS-1$
 		NLSLine[] l= NLSScanner.scan(text);
@@ -89,6 +83,7 @@ public class NLSScannerTester extends TestCase {
 		assertEquals("1 string", 1, line.size()); //$NON-NLS-1$
 	}
 
+	@Test
 	public void test6() throws Exception{
 		String text= "\n \"xx\" \"dff\""; //$NON-NLS-1$
 		NLSLine[] l= NLSScanner.scan(text);
@@ -96,6 +91,7 @@ public class NLSScannerTester extends TestCase {
 		assertEquals("2 string", 2, line.size()); //$NON-NLS-1$
 	}
 
+	@Test
 	public void test7() throws Exception{
 		String text= "\n \"xx\" \n\"dff\""; //$NON-NLS-1$
 		NLSLine[] l= NLSScanner.scan(text);
@@ -107,6 +103,7 @@ public class NLSScannerTester extends TestCase {
 	}
 
 
+	@Test
 	public void test8() throws Exception{
 		String text= "\n \"xx\" \n\"dff\" \"ccc\""; //$NON-NLS-1$
 		NLSLine[] l= NLSScanner.scan(text);
@@ -117,23 +114,26 @@ public class NLSScannerTester extends TestCase {
 		assertEquals("2 strings B", 2, line.size()); //$NON-NLS-1$
 	}
 
+	@Test
 	public void test9() throws Exception{
 		String text= "fred\n \"xx\"" + NLSElement.createTagText(1) + "\n"; //$NON-NLS-1$ //$NON-NLS-2$
 		NLSLine[] l= NLSScanner.scan(text);
 		NLSLine line=l[0];
 		NLSElement el= line.get(0);
-		assertEquals("has tag", true, el.hasTag()); //$NON-NLS-1$
+		assertTrue("has tag", el.hasTag()); //$NON-NLS-1$
 	}
 
 
+	@Test
 	public void test10() throws Exception{
 		String text= "fred\n \"xx\"\n"; //$NON-NLS-1$
 		NLSLine[] l= NLSScanner.scan(text);
 		NLSLine line=l[0];
 		NLSElement el= line.get(0);
-		assertEquals("has tag", false, el.hasTag()); //$NON-NLS-1$
+		assertFalse("has tag", el.hasTag()); //$NON-NLS-1$
 	}
 
+	@Test
 	public void test11() throws Exception{
 		String text=
 				"\n\"x\" \"y\"" //$NON-NLS-1$
@@ -145,12 +145,13 @@ public class NLSScannerTester extends TestCase {
 		assertEquals("2 strings", 2, line.size()); //$NON-NLS-1$
 
 		NLSElement el= line.get(0);
-		assertEquals("0 has tag", true, el.hasTag()); //$NON-NLS-1$
+		assertTrue("0 has tag", el.hasTag()); //$NON-NLS-1$
 
 		el= line.get(1);
-		assertEquals("1 has tag", true, el.hasTag()); //$NON-NLS-1$
+		assertTrue("1 has tag", el.hasTag()); //$NON-NLS-1$
 	}
 
+	@Test
 	public void test12() throws Exception{
 		String text=
 				"\n\"x\" \"y\"" //$NON-NLS-1$
@@ -162,12 +163,13 @@ public class NLSScannerTester extends TestCase {
 		assertEquals("2 strings", 2, line.size()); //$NON-NLS-1$
 
 		NLSElement el= line.get(0);
-		assertEquals("0 has tag", true, el.hasTag()); //$NON-NLS-1$
+		assertTrue("0 has tag", el.hasTag()); //$NON-NLS-1$
 
 		el= line.get(1);
-		assertEquals("1 has tag", true, el.hasTag()); //$NON-NLS-1$
+		assertTrue("1 has tag", el.hasTag()); //$NON-NLS-1$
 	}
 
+	@Test
 	public void test13() throws Exception{
 		String text=
 				"\n\"x\" \"y\"" //$NON-NLS-1$
@@ -178,12 +180,13 @@ public class NLSScannerTester extends TestCase {
 		assertEquals("2 strings", 2, line.size()); //$NON-NLS-1$
 
 		NLSElement el= line.get(0);
-		assertEquals("0 has tag", true, el.hasTag()); //$NON-NLS-1$
+		assertTrue("0 has tag", el.hasTag()); //$NON-NLS-1$
 
 		el= line.get(1);
-		assertEquals("1 has no tag", false, el.hasTag()); //$NON-NLS-1$
+		assertFalse("1 has no tag", el.hasTag()); //$NON-NLS-1$
 	}
 
+	@Test
 	public void test14() throws Exception{
 		String text=
 				"\n\"x\" \"y\"" //$NON-NLS-1$
@@ -194,13 +197,14 @@ public class NLSScannerTester extends TestCase {
 		assertEquals("2 strings", 2, line.size()); //$NON-NLS-1$
 
 		NLSElement el= line.get(0);
-		assertEquals("0 has no tag", false, el.hasTag()); //$NON-NLS-1$
+		assertFalse("0 has no tag", el.hasTag()); //$NON-NLS-1$
 
 		el= line.get(1);
-		assertEquals("1 has tag", true, el.hasTag()); //$NON-NLS-1$
+		assertTrue("1 has tag", el.hasTag()); //$NON-NLS-1$
 	}
 
 	// test for bug 102132
+	@Test
 	public void test15() throws Exception {
 		String text= "\nfoo\n@Annotation(\"bar\")\n\"baz\"";
 		NLSLine[] l= NLSScanner.scan(text);
@@ -213,6 +217,7 @@ public class NLSScannerTester extends TestCase {
 	}
 
 	// test for bug 102132
+	@Test
 	public void test16() throws Exception {
 		String text = "\nfoo\n@Annotation(\n{\"bar\",\n\"baz\"})\n\"baz\"";
 		NLSLine[] l= NLSScanner.scan(text);
@@ -225,6 +230,7 @@ public class NLSScannerTester extends TestCase {
 	}
 
 	// test for bug 102132
+	@Test
 	public void test17() throws Exception {
 		String text= "\n@Annotation(a= @Nested(\"Hello\"), b= \"World\")\n@Annotation2(a= (1 + 2) * 3, b= \"xx\")";
 		NLSLine[] l= NLSScanner.scan(text);
@@ -232,6 +238,7 @@ public class NLSScannerTester extends TestCase {
 	}
 
 	// test for bug 102132
+	@Test
 	public void test18() throws Exception {
 		String text= "@interface Annotation { String a= \"translate me\"; }";
 		NLSLine[] l= NLSScanner.scan(text);
@@ -244,6 +251,7 @@ public class NLSScannerTester extends TestCase {
 	}
 
 	// test for bug 102132
+	@Test
 	public void test19() throws Exception {
 		String text=
 				"@interface Annotation {\r\n" +
@@ -256,6 +264,7 @@ public class NLSScannerTester extends TestCase {
 	}
 
 	// test for bug 102132
+	@Test
 	public void test20() throws Exception {
 		String text=
 			"class C {\r\n" +
@@ -283,6 +292,7 @@ public class NLSScannerTester extends TestCase {
 	}
 
 	// test for https://bugs.eclipse.org/bugs/show_bug.cgi?id=227482
+	@Test
 	public void test21() throws Exception {
 		String text=
 			"class C {\r\n" +
@@ -306,6 +316,7 @@ public class NLSScannerTester extends TestCase {
 	}
 
 	// test for https://bugs.eclipse.org/bugs/show_bug.cgi?id=227482
+	@Test
 	public void test22() throws Exception {
 		String text=
 			"class C {\r\n" +
@@ -329,6 +340,7 @@ public class NLSScannerTester extends TestCase {
 	}
 
 	// test for https://bugs.eclipse.org/bugs/show_bug.cgi?id=227482
+	@Test
 	public void test23() throws Exception {
 		String text=
 			"class C {\r\n" +
@@ -350,6 +362,7 @@ public class NLSScannerTester extends TestCase {
 	}
 
 	// test for https://bugs.eclipse.org/bugs/show_bug.cgi?id=227482
+	@Test
 	public void test24() throws Exception {
 		String text=
 			"class C {\r\n" +
@@ -366,6 +379,7 @@ public class NLSScannerTester extends TestCase {
 	}
 
 	// test for bug https://bugs.eclipse.org/bugs/show_bug.cgi?id=233905
+	@Test
 	public void test25() throws Exception {
 		String text=
 				"@SuppressWarnings(\"unchecked\") //$NON-NLS-1$\r\n" +
@@ -376,6 +390,7 @@ public class NLSScannerTester extends TestCase {
 	}
 
 	// test for https://bugs.eclipse.org/bugs/show_bug.cgi?id=xxx
+	@Test
 	public void test26() throws Exception {
 		String text=
 				"@interface Ann {\n" +
@@ -400,6 +415,7 @@ public class NLSScannerTester extends TestCase {
 	}
 
 	//regression test for bug 12600
+	@Test
 	public void test54() throws Exception{
 		String text=
 				"\n\"x\"" //$NON-NLS-1$
@@ -410,9 +426,6 @@ public class NLSScannerTester extends TestCase {
 		assertEquals("1 strings", 1, line.size()); //$NON-NLS-1$
 
 		NLSElement el= line.get(0);
-		assertEquals("0 has no tag", false, el.hasTag()); //$NON-NLS-1$
+		assertFalse("0 has no tag", el.hasTag()); //$NON-NLS-1$
 	}
-
 }
-
-
