@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,15 +13,18 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.refactoring.nls;
 
+import static org.junit.Assert.assertEquals;
+
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
 import java.util.Properties;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 
@@ -41,52 +44,41 @@ import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.internal.corext.refactoring.nls.NLSRefactoring;
 import org.eclipse.jdt.internal.corext.refactoring.nls.NLSSubstitution;
 
-import org.eclipse.jdt.ui.tests.core.ProjectTestSetup;
-import org.eclipse.jdt.ui.tests.refactoring.RefactoringTest;
+import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
+import org.eclipse.jdt.ui.tests.refactoring.GenericRefactoringTest;
 
-public class NlsRefactoringCreateChangeTest extends TestCase {
-
-	private static final Class<NlsRefactoringCreateChangeTest> THIS= NlsRefactoringCreateChangeTest.class;
+public class NlsRefactoringCreateChangeTest {
+	@Rule
+	public ProjectTestSetup pts= new ProjectTestSetup();
 
 	private NlsRefactoringTestHelper fHelper;
 	private IJavaProject fJavaProject;
 	private IPackageFragmentRoot fSourceFolder;
 
-	public NlsRefactoringCreateChangeTest(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return setUpTest(new TestSuite(THIS));
-	}
-
-	public static Test setUpTest(Test test) {
-		return new ProjectTestSetup(test);
-	}
-
-	@Override
-	protected void setUp() throws Exception {
-		fJavaProject= ProjectTestSetup.getProject();
+	@Before
+	public void setUp() throws Exception {
+		fJavaProject= pts.getProject();
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJavaProject, "src");
 		fHelper= new NlsRefactoringTestHelper(fJavaProject);
 	}
 
-	@Override
-	protected void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJavaProject, ProjectTestSetup.getDefaultClasspath());
+	@After
+	public void tearDown() throws Exception {
+		JavaProjectHelper.clear(fJavaProject, pts.getDefaultClasspath());
 	}
 
-	public void testWithoutPreviousNlsing() throws Exception {
+	@Test
+	public void withoutPreviousNlsing() throws Exception {
 
 		fHelper.createPackageFragment("p2", "/TestSetupProject/src2"); //$NON-NLS-1$//$NON-NLS-2$
 
 		// class to NLS
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\r\n");
 		buf.append("class Test {\n");
 		buf.append("	String hello=\"helloworld\";\n");
 		buf.append("}");
-		ICompilationUnit cu= RefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/p"), "Test.java", //$NON-NLS-1$//$NON-NLS-2$
+		ICompilationUnit cu= GenericRefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/p"), "Test.java", //$NON-NLS-1$//$NON-NLS-2$
 				buf.toString());
 
 		NLSRefactoring nls= createDefaultNls(cu);
@@ -94,7 +86,7 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 
 		performChange(nls);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\r\n\r\n");
 		buf.append("import p2.Messages;\r\n\r\n");
 		buf.append("class Test {\n");
@@ -102,27 +94,28 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		buf.append("}");
 		checkContentOfCu("manipulated class", cu, buf.toString()); //$NON-NLS-1$
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("test0=helloworld\n");
 		checkContentOfFile("properties", fHelper.getFile("/TestSetupProject/src2/p/test.properties"), buf.toString()); //$NON-NLS-1$ //$NON-NLS-2$
 	}
 
 
-	public void testCreateChangeWithCollidingImport() throws Exception {
+	@Test
+	public void createChangeWithCollidingImport() throws Exception {
 		//class to NLS
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import p.another.Messages;\n");
 		buf.append("class Test {");
 		buf.append("	String hello=\"helloworld\";\r\n");
 		buf.append("}");
-		ICompilationUnit cu= RefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/p"), "Test.java", buf.toString()); //$NON-NLS-1$ //$NON-NLS-2$
+		ICompilationUnit cu= GenericRefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/p"), "Test.java", buf.toString()); //$NON-NLS-1$ //$NON-NLS-2$
 
 		NLSRefactoring nls= createDefaultNls(cu);
 
 		performChange(nls);
 
-		buf=new StringBuffer();
+		buf=new StringBuilder();
 		buf.append("package p;\n" );
 		buf.append("import p.another.Messages;\n");
 		buf.append("class Test {" );
@@ -130,16 +123,17 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		buf.append("}");
 		checkContentOfCu("manipulated class", cu, buf.toString());
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("test0=helloworld\n");
 		checkContentOfFile("properties", fHelper.getFile("/TestSetupProject/src2/p/test.properties"), buf.toString()); //$NON-NLS-1$ //$NON-NLS-2$
 	}
 
 
 	// BUG 59156
-	public void testCreateChangeWithExistingAccessorclassInDifferentPackage() throws Exception {
+	@Test
+	public void createChangeWithExistingAccessorclassInDifferentPackage() throws Exception {
 		//Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("public class Accessor {\n");
 		buf.append("		 private static final String BUNDLE_NAME = \"test.test\";//$NON-NLS-1$\n");
@@ -147,17 +141,17 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		buf.append("		 		 return \"\";\n");
 		buf.append("		 }\n");
 		buf.append("}\n");
-		RefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/p"), "Accessor.java", buf.toString());
+		GenericRefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/p"), "Accessor.java", buf.toString());
 
 		//class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("class Test {\n");
 		buf.append("  String hello=\"hello\";\n");
 		buf.append("  String world=\"world\";\n");
 		buf.append("}\n");
 		fHelper.createPackageFragment("test", "/TestSetupProject/src1");
-		ICompilationUnit testClass= RefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/test"), "AClass.java", buf.toString());
+		ICompilationUnit testClass= GenericRefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/test"), "AClass.java", buf.toString());
 
 		NLSRefactoring nls= NLSRefactoring.create(testClass);
 
@@ -177,7 +171,7 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		performChange(nls);
 
 		//class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n\n");
 		buf.append("import p.Accessor;\n\n");
 		buf.append("class Test {\n");
@@ -188,9 +182,10 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 	}
 
 	// BUG 202566
-	public void testCreateChangeWithExistingAccessorclassInDifferentPackage_1() throws Exception {
+	@Test
+	public void createChangeWithExistingAccessorclassInDifferentPackage_1() throws Exception {
 		//Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("public class Accessor {\n");
 		buf.append("		 private static final String BUNDLE_NAME = \"test.test\";//$NON-NLS-1$\n");
@@ -198,16 +193,16 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		buf.append("		 		 return \"\";\n");
 		buf.append("		 }\n");
 		buf.append("}\n");
-		RefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/p"), "Accessor.java", buf.toString());
+		GenericRefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/p"), "Accessor.java", buf.toString());
 
 		//class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("class Test {\n");
 		buf.append("  String hello=\"helloworld\";\n");
 		buf.append("}\n");
 		fHelper.createPackageFragment("test", "/TestSetupProject/src1");
-		ICompilationUnit testClass= RefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/test"), "AClass.java", buf.toString());
+		ICompilationUnit testClass= GenericRefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/test"), "AClass.java", buf.toString());
 
 		NLSRefactoring nls= NLSRefactoring.create(testClass);
 
@@ -223,22 +218,23 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		performChange(nls);
 
 		//class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("class Test {\n");
 		buf.append("  String hello=\"helloworld\"; //$NON-NLS-1$\n");
 		buf.append("}\n");
 		checkContentOfCu("manipulated class", testClass, buf.toString());
 	}
-	public void testCreateChangeWithNonDefaultSubstitution() throws Exception {
+	@Test
+	public void createChangeWithNonDefaultSubstitution() throws Exception {
 		//class to NLS
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import p.another.Messages;\n");
 		buf.append("class Test {\n");
 		buf.append("	String hello=\"helloworld\";\n");
 		buf.append("}");
-		ICompilationUnit cu= RefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/p"), "Test.java", //$NON-NLS-1$ //$NON-NLS-2$
+		ICompilationUnit cu= GenericRefactoringTest.createCU(fHelper.getPackageFragment("/TestSetupProject/src1/p"), "Test.java", //$NON-NLS-1$ //$NON-NLS-2$
 				buf.toString());
 		NLSRefactoring nls= createDefaultNls(cu);
 
@@ -246,7 +242,7 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		nls.setSubstitutionPattern(string);
 
 		performChange(nls);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import p.another.Messages;\n");
 		buf.append("class Test {\n");
@@ -255,7 +251,7 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		checkContentOfCu("manipulated class", //$NON-NLS-1$
 				cu, buf.toString());
 
-		buf=new StringBuffer();
+		buf=new StringBuilder();
 		buf.append("test0=helloworld\n");
 		checkContentOfFile("properties", fHelper.getFile("/TestSetupProject/src2/p/test.properties"), buf.toString()); //$NON-NLS-1$ //$NON-NLS-2$
 	}
@@ -272,21 +268,22 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 	}
 
-	public void testExternalizedToIgnore() throws Exception {
+	@Test
+	public void externalizedToIgnore() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
 		createDefaultAccessor(pack1);
 
 		// property file
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("A.1=Hello1\n");
 		buf.append("A.2=Hello2\n");
 		buf.append("A.3=Hello3\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"A.1\"); //$NON-NLS-1$\n");
@@ -303,13 +300,13 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 
 		performChange(nls);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("A.2=Hello2\n");
 		buf.append("A.3=Hello3\n");
 		checkContentOfFile("property file", file, buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= \"Hello1\"; //$NON-NLS-1$\n");
@@ -319,20 +316,21 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		checkContentOfCu("nls file", cu, buf.toString());
 	}
 
-	public void testInsertToDuplicate() throws Exception {
+	@Test
+	public void insertToDuplicate() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
 		createDefaultAccessor(pack1);
 
 		// property file
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -352,13 +350,13 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 
 		performChange(nls);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		checkContentOfFile("property file", file, buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -368,21 +366,22 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		checkContentOfCu("nls file", cu, buf.toString());
 	}
 
-	public void testRenameToDuplicate() throws Exception {
+	@Test
+	public void renameToDuplicate() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
 		createDefaultAccessor(pack1);
 
 		// property file
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		buf.append("Test.3=Hello3\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -401,13 +400,13 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 
 		performChange(nls);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		checkContentOfFile("property file", file, buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -417,20 +416,21 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		checkContentOfCu("nls file", cu, buf.toString());
 	}
 
-	public void testRenameDuplicate() throws Exception {
+	@Test
+	public void renameDuplicate() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
 		createDefaultAccessor(pack1);
 
 		// property file
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -449,14 +449,14 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 
 		performChange(nls);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		buf.append("Test.3=Hello3\n");
 		checkContentOfFile("property file", file, buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -466,20 +466,21 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		checkContentOfCu("nls file", cu, buf.toString());
 	}
 
-	public void testInternalizeDuplicate() throws Exception {
+	@Test
+	public void internalizeDuplicate() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
 		createDefaultAccessor(pack1);
 
 		// property file
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -497,13 +498,13 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 
 		performChange(nls);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		checkContentOfFile("property file", file, buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -513,20 +514,21 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		checkContentOfCu("nls file", cu, buf.toString());
 	}
 
-	public void testInternalizeAndInsert() throws Exception {
+	@Test
+	public void internalizeAndInsert() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
 		createDefaultAccessor(pack1);
 
 		// property file
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -548,13 +550,13 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 
 		performChange(nls);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		checkContentOfFile("property file", file, buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= \"Hello1\"; \n");
@@ -565,20 +567,21 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 	}
 
 
-	public void testAddMissing1() throws Exception {
+	@Test
+	public void addMissing1() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
 		createDefaultAccessor(pack1);
 
 		// property file
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -596,14 +599,14 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 
 		performChange(nls);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		buf.append("Test.3=Hello3\n");
 		checkContentOfFile("property file", file, buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -613,20 +616,21 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		checkContentOfCu("nls file", cu, buf.toString());
 	}
 
-	public void testAddMissing2() throws Exception {
+	@Test
+	public void addMissing2() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
 		createDefaultAccessor(pack1);
 
 		// property file
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -647,14 +651,14 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 
 		performChange(nls);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello22\n");
 		buf.append("Test.3=Hello3\n");
 		checkContentOfFile("property file", file, buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -664,19 +668,20 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		checkContentOfCu("nls file", cu, buf.toString());
 	}
 
-	public void testNoNewLineAtEnd() throws Exception {
+	@Test
+	public void noNewLineAtEnd() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
 		createDefaultAccessor(pack1);
 
 		// property file
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("Test.1=Hello1");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -694,13 +699,13 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 
 		performChange(nls);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		checkContentOfFile("property file", file, buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -709,19 +714,20 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 		checkContentOfCu("nls file", cu, buf.toString());
 	}
 
-	public void testTwoInsertsNoNewLineAtEnd() throws Exception {
+	@Test
+	public void twoInsertsNoNewLineAtEnd() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
 		createDefaultAccessor(pack1);
 
 		// property file
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("Test.1=Hello1");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -744,14 +750,14 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 
 		performChange(nls);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test.1=Hello1\n");
 		buf.append("Test.2=Hello2\n");
 		buf.append("Test.3=Hello3\n");
 		checkContentOfFile("property file", file, buf.toString());
 
 		// class to NLS
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Test {\n");
 		buf.append("    String hello1= Accessor.getString(\"Test.1\"); //$NON-NLS-1$\n");
@@ -769,13 +775,13 @@ public class NlsRefactoringCreateChangeTest extends TestCase {
 	}
 
 	private void checkContentOfCu(String message, ICompilationUnit cu, String content) throws Exception {
-		RefactoringTest.assertEqualLines(message, content, cu.getBuffer().getContents());
+		GenericRefactoringTest.assertEqualLines(message, content, cu.getBuffer().getContents());
 	}
 
 	private void checkContentOfFile(String message, IFile file, String content) throws Exception {
 		try (InputStream in= file.getContents()) {
 			String realContent= copyToString(in);
-			RefactoringTest.assertEqualLines(message, content, realContent);
+			GenericRefactoringTest.assertEqualLines(message, content, realContent);
 		}
 	}
 
