@@ -16,9 +16,9 @@ package org.eclipse.jdt.ui.tests.refactoring.type;
 import java.util.ArrayList;
 import java.util.List;
 
-import junit.framework.Test;
+import org.junit.Rule;
+import org.junit.Test;
 
-import org.eclipse.test.OrderedTestSuite;
 import org.eclipse.test.performance.Dimension;
 
 import org.eclipse.ltk.core.refactoring.Refactoring;
@@ -32,34 +32,21 @@ import org.eclipse.jdt.core.IType;
 import org.eclipse.jdt.internal.corext.refactoring.structure.ExtractInterfaceProcessor;
 
 import org.eclipse.jdt.ui.tests.performance.SWTTestProject;
-import org.eclipse.jdt.ui.tests.refactoring.infra.RefactoringPerformanceTestCase;
-import org.eclipse.jdt.ui.tests.refactoring.infra.RefactoringPerformanceTestSetup;
+import org.eclipse.jdt.ui.tests.refactoring.infra.RefactoringPerformanceTestCaseCommon;
+import org.eclipse.jdt.ui.tests.refactoring.rules.RefactoringPerformanceTestSetup;
 
 import org.eclipse.jdt.internal.ui.preferences.JavaPreferencesSettings;
 
-public class ExtractInterfacePerfAcceptanceTests extends RefactoringPerformanceTestCase {
+public class ExtractInterfacePerfAcceptanceTests extends RefactoringPerformanceTestCaseCommon {
 
 	private SWTTestProject fProject;
 	private Refactoring fRefactoring;
 
-	public static Test suite() {
-		// we must make sure that cold is executed before warm
-		OrderedTestSuite suite= new OrderedTestSuite(ExtractInterfacePerfAcceptanceTests.class, new String[] {
-			"testExtractControl",
-		});
-        return new RefactoringPerformanceTestSetup(suite);
-	}
-
-	public static Test setUpTest(Test someTest) {
-		return new RefactoringPerformanceTestSetup(someTest);
-	}
-
-	public ExtractInterfacePerfAcceptanceTests(String test) {
-		super(test);
-	}
+	@Rule
+	public RefactoringPerformanceTestSetup rpts= new RefactoringPerformanceTestSetup();
 
 	@Override
-	protected void setUp() throws Exception {
+	public void setUp() throws Exception {
 		super.setUp();
 		fProject= new SWTTestProject();
 		IType control= fProject.getProject().findType("org.eclipse.swt.widgets.Control");
@@ -80,11 +67,12 @@ public class ExtractInterfacePerfAcceptanceTests extends RefactoringPerformanceT
 	}
 
 	@Override
-	protected void tearDown() throws Exception {
+	public void tearDown() throws Exception {
 		fProject.delete();
 		super.tearDown();
 	}
 
+	@Test
 	public void testExtractControl() throws Exception {
 		tagAsSummary("Extract Interface - Elapsed Process", Dimension.ELAPSED_PROCESS);
 		executeRefactoring(fRefactoring, true);
