@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,6 +13,8 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.chkpii;
 
+import static org.junit.Assert.assertTrue;
+
 import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileInputStream;
@@ -25,17 +27,21 @@ import java.net.URL;
 import java.nio.charset.Charset;
 import java.util.StringTokenizer;
 
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TestName;
+
 import org.eclipse.osgi.service.environment.Constants;
 
 import org.eclipse.core.runtime.FileLocator;
 import org.eclipse.core.runtime.Path;
 import org.eclipse.core.runtime.Platform;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
-public class ChkpiiTests extends TestCase {
+public class ChkpiiTests {
+	@Rule
+	public TestName tn= new TestName();
 
 	private String fLogDirectoryName;
 
@@ -59,6 +65,7 @@ public class ChkpiiTests extends TestCase {
 			return fName.toUpperCase();
 		}
 	}
+
 	private static class StreamConsumer extends Thread {
 		StringBuffer fStrBuffer;
 		BufferedReader fReader;
@@ -114,18 +121,17 @@ public class ChkpiiTests extends TestCase {
 	private final FileCategory PROPERTIES= new FileCategory("PROPERTIES");
 	private final FileCategory XML= new FileCategory("XML");
 
-	public static Test suite() {
-		return new TestSuite(ChkpiiTests.class);
-	}
-
+	@Test
 	public void testHTMLFiles() {
 		assertChkpii(HTML);
 	}
 
+	@Test
 	public void testXMLFiles() {
 		assertChkpii(XML);
 	}
 
+	@Test
 	public void testPropertiesFiles() {
 		assertChkpii(PROPERTIES);
 	}
@@ -177,7 +183,7 @@ public class ChkpiiTests extends TestCase {
 			}
 		}
  		int res= process.exitValue();
- 		System.out.println("ChkpiiTests#" + getName() + "() exit value: " + res);
+ 		System.out.println("ChkpiiTests#" + tn.getMethodName() + "() exit value: " + res);
 		return true;
 	}
 
@@ -198,7 +204,7 @@ public class ChkpiiTests extends TestCase {
 
 		while (tokenizer.hasMoreTokens()) {
 			String token= tokenizer.nextToken();
-			if (token.equals("org.eclipse.jdt.ui.tests"))
+			if ("org.eclipse.jdt.ui.tests".equals(token))
 				break;
 
 			path= path + File.separator + token;
@@ -248,7 +254,7 @@ public class ChkpiiTests extends TestCase {
 
 		String fileName;
 
-		if (Platform.getOS().equals(Constants.OS_WIN32))
+		if (Constants.OS_WIN32.equals(Platform.getOS()))
 			fileName= "ignoreErrorsWindows.txt"; //$NON-NLS-1$
 		else
 			fileName= "ignoreErrorsUnix.txt"; //$NON-NLS-1$
@@ -350,10 +356,8 @@ public class ChkpiiTests extends TestCase {
 	/**
 	 * Constructor for EmptyDirectoriesTest.
 	 *
-	 * @param name the test name
 	 */
-	public ChkpiiTests(String name) {
-		super(name);
+	public ChkpiiTests() {
 		fLogDirectoryName= getPluginDirectory() + "chkpiiResults" + File.separator; //$NON-NLS-1$
 		new File(PROPERTIES.getOutputFile()).delete();
 		new File(HTML.getOutputFile()).delete();
@@ -363,18 +367,16 @@ public class ChkpiiTests extends TestCase {
 	/*
 	 * @see TestCase#setUp()
 	 */
-	@Override
-	protected void setUp() throws Exception {
-		super.setUp();
+	@Before
+	public void setUp() throws Exception {
 		new File(fLogDirectoryName).mkdirs();
 	}
 
 	/*
 	 * @see TestCase#tearDown()
 	 */
-	@Override
-	protected void tearDown() throws Exception {
-		super.tearDown();
+	@After
+	public void tearDown() throws Exception {
 		fLogDirectoryName= null;
 	}
 }
