@@ -14,14 +14,13 @@
 package org.eclipse.jdt.ui.tests.leaks;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.widgets.Shell;
@@ -45,11 +44,10 @@ import org.eclipse.jdt.ui.tests.core.rules.LeakTestSetup;
  *
  * @since 3.2
  */
-@RunWith(JUnit4.class)
 public class TextViewerUndoManagerLeakTest extends LeakTestCase {
 
 	@Rule
-	public LeakTestSetup projectsetup = new LeakTestSetup();
+	public LeakTestSetup projectSetup = new LeakTestSetup();
 
 	/** The maximum undo level. */
 	private static final int MAX_UNDO_LEVEL= 256;
@@ -140,7 +138,7 @@ public class TextViewerUndoManagerLeakTest extends LeakTestCase {
 			document.replace(1, 2, "\n");
 			document.replace(3, 2, "\n");
 		} catch (BadLocationException e) {
-			assertTrue(false);
+			fail();
 		}
 
 		assertTrue(fUndoManager.undoable());
@@ -186,7 +184,7 @@ public class TextViewerUndoManagerLeakTest extends LeakTestCase {
 				document.replace(position.getOffset(), position.getLength(), string);
 			}
 		} catch (BadLocationException e) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
@@ -208,7 +206,7 @@ public class TextViewerUndoManagerLeakTest extends LeakTestCase {
 		assertTrue(fUndoManager.undoable());
 		while (fUndoManager.undoable())
 			fUndoManager.undo();
-		assertTrue(!fUndoManager.undoable());
+		assertFalse(fUndoManager.undoable());
 
 		final String reverted= document.get();
 
@@ -216,7 +214,7 @@ public class TextViewerUndoManagerLeakTest extends LeakTestCase {
 	}
 
 	private static String createRandomString(int length) {
-		final StringBuffer buffer= new StringBuffer();
+		final StringBuilder buffer= new StringBuilder();
 
 		for (int i= 0; i < length; i++)
 			buffer.append(getRandomCharacter());
