@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2013 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,15 +14,14 @@
 
 package org.eclipse.jdt.ui.tests.performance;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
 import org.eclipse.jdt.ui.tests.performance.views.TypeHierarchyPerfTest;
 
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+	TypeHierarchyPerfTest.class
+})
 public class PerformanceTestSuite {
-	public static Test suite() {
-		TestSuite suite= new TestSuite(PerformanceTestSuite.class.getName());
-		suite.addTest(TypeHierarchyPerfTest.suite());
-		return suite;
-	}
 }
