@@ -13,6 +13,13 @@
  *******************************************************************************/
 package org.eclipse.jdt.testplugin.test;
 
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.fail;
+
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 
 import org.eclipse.core.runtime.Path;
@@ -22,46 +29,29 @@ import org.eclipse.jdt.core.IMethod;
 import org.eclipse.jdt.core.IOrdinaryClassFile;
 import org.eclipse.jdt.core.IType;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
-
-public class HelloWorld extends TestCase {
-
+public class HelloWorld {
 	private IJavaProject fJProject;
 
-
-	public static Test suite() {
-		TestSuite suite= new TestSuite();
-		suite.addTest(new HelloWorld("test1"));
-		return suite;
-	}
-
-	public HelloWorld(String name) {
-		super(name);
-	}
-
-	@Override
-	protected void setUp() throws Exception {
+	@BeforeEach
+	public void setUp() throws Exception {
 			fJProject= JavaProjectHelper.createJavaProject("TestProject1", "bin");
 	}
 
-
-	@Override
-	protected void tearDown() throws Exception {
+	@AfterEach
+	public void tearDown() throws Exception {
 		JavaProjectHelper.delete(fJProject);
 	}
 
+	@Test
 	public void test1() throws Exception {
 		if (JavaProjectHelper.addRTJar(fJProject) == null) {
-			assertTrue("jdk not found", false);
+			fail("jdk not found");
 			return;
 		}
 
 		String name= "java/util/Vector.java";
 		IOrdinaryClassFile classfile= (IOrdinaryClassFile) fJProject.findElement(new Path(name));
-		assertTrue("classfile not found", classfile != null);
+		assertNotNull(classfile, "classfile not found");
 
 		IType type= classfile.getType();
 		System.out.println("methods of Vector");
@@ -69,5 +59,4 @@ public class HelloWorld extends TestCase {
 			System.out.println(method.getElementName());
 		}
 	}
-
 }
