@@ -13,10 +13,13 @@
  *******************************************************************************/
 package org.eclipse.jdt.junit.tests;
 
-import java.util.HashSet;
-import java.util.Iterator;
+import static org.junit.Assert.assertEquals;
 
-import junit.framework.TestCase;
+import java.util.HashSet;
+
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
 
 import org.eclipse.jdt.junit.JUnitCore;
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
@@ -37,15 +40,12 @@ import org.eclipse.jdt.internal.junit.launcher.ITestKind;
 import org.eclipse.jdt.internal.junit.launcher.TestKindRegistry;
 
 
-public class JUnit3TestFinderTest extends TestCase {
+public class JUnit3TestFinderTest {
 	private IJavaProject fProject;
 	private IPackageFragmentRoot fRoot;
 
-	private static final boolean BUG_559685= true;
-
-	@Override
-	protected void setUp() throws Exception {
-		super.setUp();
+	@Before
+	public void setUp() throws Exception {
 		fProject= JavaProjectHelper.createJavaProject("TestProject", "bin");
 		JavaProjectHelper.addRTJar(fProject);
 		IClasspathEntry cpe= JavaCore.newContainerEntry(JUnitCore.JUNIT3_CONTAINER_PATH);
@@ -54,18 +54,15 @@ public class JUnit3TestFinderTest extends TestCase {
 		fRoot= JavaProjectHelper.addSourceContainer(fProject, "src");
 	}
 
-	@Override
-	protected void tearDown() throws Exception {
+	@After
+	public void tearDown() throws Exception {
 		JavaProjectHelper.delete(fProject);
-		super.tearDown();
 	}
 
+	@Test
 	public void testTestCase() throws Exception {
-		if (BUG_559685) {
-			return;
-		}
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestCase;\n");
 		buf.append("\n");
@@ -78,7 +75,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(validTest1, new String[] { "p.MyTest" });
 		assertTestFound(validTest1.getCompilationUnit(), new String[] { "p.MyTest" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestCase;\n");
 		buf.append("\n");
@@ -91,7 +88,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(validTest2, new String[] { "p.MySuperTest" });
 		assertTestFound(validTest2.getCompilationUnit(), new String[] { "p.MySuperTest" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestCase;\n");
 		buf.append("\n");
@@ -105,7 +102,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(validTest3, new String[] { "p.InvisibleTest" });
 		assertTestFound(validTest3.getCompilationUnit(), new String[] { "p.InvisibleTest" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestCase;\n");
 		buf.append("\n");
@@ -120,7 +117,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(validTest4, new String[] { "p.Outer.InnerTest" });
 		assertTestFound(validTest4.getCompilationUnit(), new String[] { "p.Outer.InnerTest" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestCase;\n");
 		buf.append("\n");
@@ -145,7 +142,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(invalidTests[0].getCompilationUnit(), new String[] {});
 
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestCase;\n");
 		buf.append("\n");
@@ -158,7 +155,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(invalidTest1, new String[] {});
 		assertTestFound(invalidTest1.getCompilationUnit(), new String[] {});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("\n");
@@ -178,12 +175,10 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(fProject, validTests);
 	}
 
+	@Test
 	public void testSuite() throws Exception {
-		if (BUG_559685) {
-			return;
-		}
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.Test;\n");
 		buf.append("\n");
@@ -197,7 +192,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(validTest1, new String[] { "p.SuiteClass" });
 		assertTestFound(validTest1.getCompilationUnit(), new String[] { "p.SuiteClass" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.Test;\n");
 		buf.append("\n");
@@ -211,7 +206,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(validTest2, new String[] { "p.AbstractSuiteClass" });
 		assertTestFound(validTest2.getCompilationUnit(), new String[] { "p.AbstractSuiteClass" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.Test;\n");
 		buf.append("\n");
@@ -225,7 +220,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(validTest3, new String[] { "p.InvisibleSuiteClass" });
 		assertTestFound(validTest3.getCompilationUnit(), new String[] { "p.InvisibleSuiteClass" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.Test;\n");
 		buf.append("\n");
@@ -241,7 +236,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(validTest4, new String[] { "p.SuiteOuter.InnerSuite" });
 		assertTestFound(validTest4.getCompilationUnit(), new String[] { "p.SuiteOuter.InnerSuite" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestCase;\n");
 		buf.append("\n");
@@ -266,7 +261,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		}
 		assertTestFound(invalidTests[0].getCompilationUnit(), new String[] {});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.Test;\n");
 		buf.append("\n");
@@ -280,7 +275,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(invalidTest1, new String[] {});
 		assertTestFound(invalidTest1.getCompilationUnit(), new String[] {});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.Test;\n");
 		buf.append("\n");
@@ -294,7 +289,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(invalidTest2, new String[] {});
 		assertTestFound(invalidTest2.getCompilationUnit(), new String[] {});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.Test;\n");
 		buf.append("\n");
@@ -315,12 +310,10 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(fProject, validTests);
 	}
 
+	@Test
 	public void testTestInterface() throws Exception {
-		if (BUG_559685) {
-			return;
-		}
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.Test;\n");
 		buf.append("import junit.framework.TestResult;\n");
@@ -337,7 +330,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(validTest1, new String[] { "p.MyITest" });
 		assertTestFound(validTest1.getCompilationUnit(), new String[] { "p.MyITest" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("public class MySuperITest extends MyITest {\n");
@@ -349,7 +342,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(validTest2, new String[] { "p.MySuperITest" });
 		assertTestFound(validTest2.getCompilationUnit(), new String[] { "p.MySuperITest" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.Test;\n");
 		buf.append("\n");
@@ -360,7 +353,7 @@ public class JUnit3TestFinderTest extends TestCase {
 		assertTestFound(invalidTest1, new String[] {});
 		assertTestFound(invalidTest1.getCompilationUnit(), new String[] {});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestResult;\n");
 		buf.append("\n");
@@ -401,8 +394,8 @@ public class JUnit3TestFinderTest extends TestCase {
 		finder.findTestsInContainer(container, set, null);
 
 		HashSet<String> namesFound= new HashSet<>();
-		for (Iterator<IType> iterator= set.iterator(); iterator.hasNext();) {
-			namesFound.add(iterator.next().getFullyQualifiedName('.'));
+		for (IType iType : set) {
+			namesFound.add(iType.getFullyQualifiedName('.'));
 		}
 		String[] actuals= namesFound.toArray(new String[namesFound.size()]);
 		StringAsserts.assertEqualStringsIgnoreOrder(actuals, expectedValidTests);
