@@ -13,12 +13,15 @@
  *******************************************************************************/
 package org.eclipse.jdt.junit.tests;
 
+import static org.junit.Assert.assertEquals;
+
 import java.io.File;
 import java.util.Arrays;
 import java.util.HashSet;
-import java.util.Iterator;
 
-import junit.framework.TestCase;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
 
 import org.eclipse.jdt.junit.JUnitCore;
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
@@ -41,16 +44,13 @@ import org.eclipse.jdt.internal.junit.launcher.ITestKind;
 import org.eclipse.jdt.internal.junit.launcher.TestKindRegistry;
 
 
-public class JUnit4TestFinderTest extends TestCase {
+public class JUnit4TestFinderTest {
 
 	private IJavaProject fProject;
 	private IPackageFragmentRoot fRoot;
 
-	private static final boolean BUG_559685= true;
-
-	@Override
-	protected void setUp() throws Exception {
-		super.setUp();
+	@Before
+	public void setUp() throws Exception {
 		fProject= JavaProjectHelper.createJavaProject("TestProject", "bin");
 		JavaProjectHelper.addRTJar(fProject);
 		IClasspathEntry cpe= JavaCore.newContainerEntry(JUnitCore.JUNIT4_CONTAINER_PATH);
@@ -60,22 +60,19 @@ public class JUnit4TestFinderTest extends TestCase {
 		fRoot= JavaProjectHelper.addSourceContainer(fProject, "src");
 	}
 
-	@Override
-	protected void tearDown() throws Exception {
+	@After
+	public void tearDown() throws Exception {
 		JavaProjectHelper.delete(fProject);
-		super.tearDown();
 	}
 
 	/**
 	 * Copy from {@link JUnit3TestFinderTest}: All tests must work in Junit 4 as well
 	 * @throws Exception if it fails
 	 */
+	@Test
 	public void testTestCase() throws Exception {
-		if (BUG_559685) {
-			return;
-		}
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestCase;\n");
 		buf.append("\n");
@@ -88,7 +85,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(validTest1, new String[] { "p.MyTest" });
 		assertTestFound(validTest1.getCompilationUnit(), new String[] { "p.MyTest" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestCase;\n");
 		buf.append("\n");
@@ -101,7 +98,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(validTest2, new String[] { "p.MySuperTest" });
 		assertTestFound(validTest2.getCompilationUnit(), new String[] { "p.MySuperTest" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestCase;\n");
 		buf.append("\n");
@@ -115,7 +112,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(validTest3, new String[] { "p.InvisibleTest" });
 		assertTestFound(validTest3.getCompilationUnit(), new String[] { "p.InvisibleTest" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestCase;\n");
 		buf.append("\n");
@@ -130,7 +127,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(validTest4, new String[] { "p.Outer.InnerTest" });
 		assertTestFound(validTest4.getCompilationUnit(), new String[] { "p.Outer.InnerTest" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestCase;\n");
 		buf.append("\n");
@@ -155,7 +152,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(invalidTests[0].getCompilationUnit(), new String[] {});
 
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import junit.framework.TestCase;\n");
 		buf.append("\n");
@@ -168,7 +165,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(invalidTest1, new String[] {});
 		assertTestFound(invalidTest1.getCompilationUnit(), new String[] {});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("\n");
@@ -188,10 +185,8 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(fProject, validTests);
 	}
 
+	@Test
 	public void testSuiteFinder() throws Exception {
-		if (BUG_559685) {
-			return;
-		}
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
 		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
@@ -213,12 +208,10 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(fProject, validTests);
 	}
 
+	@Test
 	public void testRunWith() throws Exception {
-		if (BUG_559685) {
-			return;
-		}
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("import org.junit.Test;\n");
@@ -229,7 +222,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		buf.append("}\n");
 		p.createCompilationUnit("Test1.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("import org.junit.runner.RunWith;\n");
@@ -246,7 +239,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(validTest1, new String[] { "p.Test2" });
 		assertTestFound(validTest1.getCompilationUnit(), new String[] { "p.Test2" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("public class Test3 extends Test2 {\n");
@@ -257,7 +250,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(validTest2, new String[] { "p.Test3" });
 		assertTestFound(validTest2.getCompilationUnit(), new String[] { "p.Test3" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("import org.junit.runner.RunWith;\n");
@@ -274,7 +267,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(invalidTest1, new String[] {});
 		assertTestFound(invalidTest1.getCompilationUnit(), new String[] {});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("import org.junit.runner.RunWith;\n");
@@ -291,7 +284,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(validTest3, new String[] { "p.Test5"});
 		assertTestFound(validTest3.getCompilationUnit(), new String[] { "p.Test5" });
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("import org.junit.runner.RunWith;\n");
@@ -305,7 +298,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(invalidTest2, new String[] {});
 		assertTestFound(invalidTest2.getCompilationUnit(), new String[] {});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("import java.util.Arrays;\n");
 		buf.append("import java.util.Collection;\n");
 		buf.append("\n");
@@ -342,12 +335,10 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(fProject, validTests);
 	}
 
+	@Test
 	public void testTestAnnotation() throws Exception {
-		if (BUG_559685) {
-			return;
-		}
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("import org.junit.Test;\n");
@@ -362,7 +353,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(validTest1.getCompilationUnit(), new String[] { "p.Test1" });
 
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("public class Test2 extends Test1 {\n");
@@ -375,7 +366,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(validTest2.getCompilationUnit(), new String[] { "p.Test2" });
 
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("import org.junit.Test;\n");
@@ -390,7 +381,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(validTest3.getCompilationUnit(), new String[] { "p.Test3" });
 
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("import org.junit.Test;\n");
@@ -411,6 +402,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(fProject, validTests);
 	}
 
+	@Test
 	public void testTestAnnotation_bug204682() throws Exception {
 
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
@@ -433,6 +425,7 @@ public class JUnit4TestFinderTest extends TestCase {
 		assertTestFound(validTest1.getCompilationUnit(), new String[] { });
 	}
 
+	@Test
 	public void testTestAnnotation2() throws Exception {
 
 		IPackageFragment p= fRoot.createPackageFragment("p", true, null);
@@ -467,13 +460,9 @@ public class JUnit4TestFinderTest extends TestCase {
 			assertEquals(type.getFullyQualifiedName(), isTest, finder.isTest(type));
 		}
 
-		HashSet<IType> set= new HashSet<>();
-//		finder.findTestsInContainer(container, set, null);
-		set.addAll(Arrays.asList(JUnitCore.findTestTypes(container, null)));
-
+		HashSet<IType> set= new HashSet<>(Arrays.asList(JUnitCore.findTestTypes(container, null)));
 		HashSet<String> namesFound= new HashSet<>();
-		for (Iterator<IType> iterator= set.iterator(); iterator.hasNext();) {
-			IType curr= iterator.next();
+		for (IType curr : set) {
 			namesFound.add(curr.getFullyQualifiedName('.'));
 		}
 		String[] actuals= namesFound.toArray(new String[namesFound.size()]);
