@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2006, 2016 IBM Corporation and others.
+ * Copyright (c) 2006, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,6 +14,9 @@
 
 package org.eclipse.jdt.junit.tests;
 
+import org.junit.Before;
+import org.junit.Test;
+
 import org.eclipse.jdt.junit.JUnitCore;
 import org.eclipse.jdt.junit.TestRunListener;
 import org.eclipse.jdt.junit.model.ITestElement.FailureTrace;
@@ -51,12 +54,14 @@ public class TestRunListenerTest4 extends AbstractTestRunListenerTest {
 	}
 
 	@Override
-	protected void setUp() throws Exception {
+	@Before
+	public void setUp() throws Exception {
 		fProject= JavaProjectHelper.createJavaProject("TestRunListenerTest", "bin");
 		JavaProjectHelper.addToClasspath(fProject, JavaCore.newContainerEntry(JUnitCore.JUNIT4_CONTAINER_PATH));
 		JavaProjectHelper.addRTJar15(fProject);
 	}
 
+	@Test
 	public void testOK() throws Exception {
 		String source=
 				"package pack;\n" +
@@ -75,7 +80,7 @@ public class TestRunListenerTest4 extends AbstractTestRunListenerTest {
 		String[] actual= runSequenceTest(aTestCase);
 		assertEqualLog(expectedSequence, actual);
 	}
-
+	@Test
 	public void testTreeOK() throws Exception {
 		String source=
 				"package pack;\n"+
@@ -119,6 +124,7 @@ public class TestRunListenerTest4 extends AbstractTestRunListenerTest {
 		assertEqualLog(expectedSequence, actual);
 	}
 
+	@Test
 	public void testFail() throws Exception {
 		String source=
 			"package pack;\n" +
@@ -139,6 +145,7 @@ public class TestRunListenerTest4 extends AbstractTestRunListenerTest {
 		assertEqualLog(expectedSequence, actual);
 	}
 
+	@Test
 	public void testSimpleTest() throws Exception {
 		String source=
 			"package pack;\n" +
@@ -190,6 +197,7 @@ public class TestRunListenerTest4 extends AbstractTestRunListenerTest {
 	}
 
 
+	@Test
 	public void testTreeOnSessionStarted() throws Exception {
 		String source=
 				"package pack;\n" +
@@ -208,6 +216,7 @@ public class TestRunListenerTest4 extends AbstractTestRunListenerTest {
 		assertEqualLog(expectedTree, actual);
 	}
 
+	@Test
 	public void testTreeOnSessionEnded() throws Exception {
 		String source=
 				"package pack;\n" +
@@ -227,6 +236,7 @@ public class TestRunListenerTest4 extends AbstractTestRunListenerTest {
 		assertEqualLog(expectedTree, actual);
 	}
 
+	@Test
 	public void testTreeOnSecondTestStarted() throws Exception {
 		String source=
 				"package pack;\n" +
@@ -252,6 +262,7 @@ public class TestRunListenerTest4 extends AbstractTestRunListenerTest {
 		assertEqualLog(expectedTree, actual);
 	}
 
+	@Test
 	public void testTreeOnSecondTestStarted2() throws Exception {
 		String source=
 				"package pack;\n" +
@@ -278,6 +289,7 @@ public class TestRunListenerTest4 extends AbstractTestRunListenerTest {
 		assertEqualLog(expectedTree, actual);
 	}
 
+	@Test
 	public void testParametrizedWithEvilChars() throws Exception {
 		String source=
 				"package pack;\n"+
