@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,9 +13,18 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.buildpath;
 
-import java.util.Iterator;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotEquals;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import java.util.List;
 
+import org.junit.After;
+import org.junit.Test;
+
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 
 import org.eclipse.core.runtime.CoreException;
@@ -38,31 +47,15 @@ import org.eclipse.jdt.internal.corext.buildpath.ClasspathModifier;
 
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.CPListElement;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
-public class BuildpathModifierActionTest extends TestCase {
+public class BuildpathModifierActionTest {
 
     private static final String DEFAULT_OUTPUT_FOLDER_NAME= "bin";
 	private static final String PROJECT_NAME= "P01";
 
 	private IJavaProject fJavaProject;
 
-	public BuildpathModifierActionTest(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return new TestSuite(BuildpathModifierActionTest.class);
-	}
-
-	@Override
-	protected void setUp() throws Exception {
-	}
-
-	@Override
-	protected void tearDown() throws Exception {
+	@After
+	public void tearDown() throws Exception {
 		if (fJavaProject != null) {
 			JavaProjectHelper.delete(fJavaProject);
 			fJavaProject= null;
@@ -82,7 +75,7 @@ public class BuildpathModifierActionTest extends TestCase {
 				return;
 			}
 		}
-		assertTrue("Element with location " + path + " is not on buildpath", false);
+		fail("Element with location " + path + " is not on buildpath");
     }
 
     private static void assertDeltaResources(BuildpathDelta delta, IPath[] createdFolders, IPath[] removedFolders, IPath[] createdFiles, IPath[] removedFiles) {
@@ -99,7 +92,7 @@ public class BuildpathModifierActionTest extends TestCase {
 	        } else if (createdResources[i] instanceof IFolder) {
 	        	assertTrue("Folder " + createdResources[i] + " is unexpected created", contains(createdFolders, path));
 	        } else {
-	        	assertTrue("Resource " + createdResources[i] + " is nor file nor folder.", false);
+	        	fail("Resource " + createdResources[i] + " is nor file nor folder.");
 	        }
         }
 		for (IPath createdFolder : createdFolders) {
@@ -122,7 +115,7 @@ public class BuildpathModifierActionTest extends TestCase {
 	        } else if (deletedResources[i] instanceof IFolder) {
 	        	assertTrue("Folder " + deletedResources[i] + " is unexpected removed", contains(removedFolders, path));
 	        } else {
-	        	assertTrue("Resource " + deletedResources[i] + " is nor file nor folder.", false);
+	        	fail("Resource " + deletedResources[i] + " is nor file nor folder.");
 	        }
         }
 		for (IPath removedFolder : removedFolders) {
@@ -135,11 +128,10 @@ public class BuildpathModifierActionTest extends TestCase {
 
     private static void assertDeltaRemovedEntries(BuildpathDelta delta, IPath[] paths) {
     	List<CPListElement> removedEntries= delta.getRemovedEntries();
-    	assertTrue("Expected " + paths.length + " is " + removedEntries.size(), removedEntries.size() == paths.length);
+    	assertEquals("Expected " + paths.length + " is " + removedEntries.size(), removedEntries.size(), paths.length);
     	IPath[] removed= new IPath[removedEntries.size()];
     	int i= 0;
-    	for (Iterator<CPListElement> iterator= removedEntries.iterator(); iterator.hasNext();) {
-	        CPListElement element= iterator.next();
+    	for (CPListElement element : removedEntries) {
 	        removed[i]= element.getPath();
 	        i++;
         }
@@ -153,11 +145,10 @@ public class BuildpathModifierActionTest extends TestCase {
 
     private static void assertDeltaAddedEntries(BuildpathDelta delta, IPath[] paths) {
     	List<CPListElement> addedEntries= delta.getAddedEntries();
-    	assertTrue("Expected " + paths.length + " is " + addedEntries.size(), addedEntries.size() == paths.length);
+    	assertEquals("Expected " + paths.length + " is " + addedEntries.size(), addedEntries.size(), paths.length);
     	IPath[] added= new IPath[addedEntries.size()];
     	int i= 0;
-    	for (Iterator<CPListElement> iterator= addedEntries.iterator(); iterator.hasNext();) {
-	        CPListElement element= iterator.next();
+    	for (CPListElement element : addedEntries) {
 	        added[i]= element.getPath();
 	        i++;
         }
@@ -184,9 +175,10 @@ public class BuildpathModifierActionTest extends TestCase {
     }
 
     private static void assertNumberOfEntries(IClasspathEntry[] entries, int expected) {
-    	assertTrue("Expected count was " + expected + " is " + entries.length, expected == entries.length);
+    	assertEquals("Expected count was " + expected + " is " + entries.length, expected, entries.length);
     }
 
+    @Test
 	public void testAddExternalJar01AddMyLib() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 
@@ -209,6 +201,7 @@ public class BuildpathModifierActionTest extends TestCase {
 		assertIsOnBuildpath(classpathEntries, JavaProjectHelper.MYLIB.makeAbsolute());
 	}
 
+    @Test
 	public void testAddExternalJar02AddMuiltiLibs() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 
@@ -235,6 +228,7 @@ public class BuildpathModifierActionTest extends TestCase {
 		assertIsOnBuildpath(classpathEntries, JavaProjectHelper.NLS_LIB.makeAbsolute());
 	}
 
+    @Test
 	public void testAddExternalJar02AddMuiltiLibsTwice() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 
@@ -251,7 +245,7 @@ public class BuildpathModifierActionTest extends TestCase {
 
 		cpProject= CPJavaProject.createFromExisting(fJavaProject);
 		IStatus status= ClasspathModifier.checkAddExternalJarsPrecondition(jarPaths, cpProject);
-		assertTrue(status.getMessage(), status.getSeverity() == IStatus.INFO);
+		assertEquals(status.getMessage(), IStatus.INFO, status.getSeverity());
 
 		BuildpathDelta delta= ClasspathModifier.addExternalJars(jarPaths, cpProject);
 		assertDeltaResources(delta, new IPath[0], new IPath[0], new IPath[0], new IPath[0]);
@@ -267,6 +261,7 @@ public class BuildpathModifierActionTest extends TestCase {
 		assertIsOnBuildpath(classpathEntries, JavaProjectHelper.NLS_LIB.makeAbsolute());
 	}
 
+    @Test
 	public void testAddExternalJarBug132827() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 
@@ -278,7 +273,7 @@ public class BuildpathModifierActionTest extends TestCase {
 
 		cpProject= CPJavaProject.createFromExisting(fJavaProject);
 		IStatus status= ClasspathModifier.checkAddExternalJarsPrecondition(jarPaths, cpProject);
-		assertTrue(status.getSeverity() == IStatus.INFO);
+		assertEquals(IStatus.INFO, status.getSeverity());
 
 		BuildpathDelta delta= ClasspathModifier.addExternalJars(jarPaths, cpProject);
 		assertDeltaResources(delta, new IPath[0], new IPath[0], new IPath[0], new IPath[0]);
@@ -293,6 +288,7 @@ public class BuildpathModifierActionTest extends TestCase {
 		assertIsOnBuildpath(classpathEntries, JavaProjectHelper.MYLIB.makeAbsolute());
 	}
 
+    @Test
 	public void testEditOutputFolder01SetOutputFolderForSourceFolder() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 		IPackageFragmentRoot src= JavaProjectHelper.addSourceContainer(fJavaProject, "src");
@@ -303,7 +299,7 @@ public class BuildpathModifierActionTest extends TestCase {
 		CPJavaProject cpProject= CPJavaProject.createFromExisting(fJavaProject);
 		CPListElement element= cpProject.getCPElement(CPListElement.createFromExisting(src.getRawClasspathEntry(), fJavaProject));
 		IStatus status= ClasspathModifier.checkSetOutputLocationPrecondition(element, outputPath, false, cpProject);
-		assertTrue(status.getMessage(), status.getSeverity() != IStatus.ERROR);
+		assertNotEquals(status.getMessage(), IStatus.ERROR, status.getSeverity());
 
 		BuildpathDelta delta= ClasspathModifier.setOutputLocation(element, outputPath, false, cpProject);
 		assertDeltaResources(delta, new IPath[] {outputPath}, new IPath[0], new IPath[0], new IPath[0]);
@@ -316,11 +312,12 @@ public class BuildpathModifierActionTest extends TestCase {
 		IClasspathEntry[] classpathEntries= fJavaProject.getRawClasspath();
 		assertNumberOfEntries(classpathEntries, 2);
 		IClasspathEntry entry= classpathEntries[1];
-		assertTrue(src.getRawClasspathEntry() == entry);
+		assertSame(src.getRawClasspathEntry(), entry);
 		IPath location= entry.getOutputLocation();
 		assertTrue("Output path is " + location + " expected was " + outputPath, outputPath.equals(location));
 	}
 
+    @Test
 	public void testEditOutputFolder02RemoveProjectAsSourceFolder() throws Exception {
 		fJavaProject= createProject(null);
 
@@ -336,7 +333,7 @@ public class BuildpathModifierActionTest extends TestCase {
 		CPJavaProject cpProject= CPJavaProject.createFromExisting(fJavaProject);
 		CPListElement element= cpProject.getCPElement(CPListElement.createFromExisting(src.getRawClasspathEntry(), fJavaProject));
 		IStatus status= ClasspathModifier.checkSetOutputLocationPrecondition(element, outputPath, false, cpProject);
-		assertTrue(status.getMessage(), status.getSeverity() == IStatus.INFO);
+		assertEquals(status.getMessage(), IStatus.INFO, status.getSeverity());
 
 		BuildpathDelta delta= ClasspathModifier.setOutputLocation(element, outputPath, false, cpProject);
 		assertDeltaResources(delta, new IPath[] {outputPath}, new IPath[0], new IPath[0], new IPath[0]);
@@ -351,11 +348,12 @@ public class BuildpathModifierActionTest extends TestCase {
 		IClasspathEntry[] classpathEntries= fJavaProject.getRawClasspath();
 		assertNumberOfEntries(classpathEntries, 2);
 		IClasspathEntry entry= classpathEntries[1];
-		assertTrue(src.getRawClasspathEntry() == entry);
+		assertSame(src.getRawClasspathEntry(), entry);
 		IPath location= entry.getOutputLocation();
 		assertTrue("Output path is " + location + " expected was " + outputPath, outputPath.equals(location));
 	}
 
+    @Test
 	public void testEditOutputFolder03ExcludeOutputFolderSelf() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 		IPackageFragmentRoot src1= JavaProjectHelper.addSourceContainer(fJavaProject, "src1");
@@ -366,7 +364,7 @@ public class BuildpathModifierActionTest extends TestCase {
 		CPJavaProject cpProject= CPJavaProject.createFromExisting(fJavaProject);
 		CPListElement element= cpProject.getCPElement(CPListElement.createFromExisting(src1.getRawClasspathEntry(), fJavaProject));
 		IStatus status= ClasspathModifier.checkSetOutputLocationPrecondition(element, outputPath, false, cpProject);
-		assertTrue(status.getMessage(), status.getSeverity() != IStatus.ERROR);
+		assertNotEquals(status.getMessage(), IStatus.ERROR, status.getSeverity());
 
 		BuildpathDelta delta= ClasspathModifier.setOutputLocation(element, outputPath, false, cpProject);
 		assertDeltaResources(delta, new IPath[] {outputPath}, new IPath[0], new IPath[0], new IPath[0]);
@@ -379,14 +377,15 @@ public class BuildpathModifierActionTest extends TestCase {
 		IClasspathEntry[] classpathEntries= fJavaProject.getRawClasspath();
 		assertNumberOfEntries(classpathEntries, 2);
 		IClasspathEntry entry= classpathEntries[1];
-		assertTrue(src1.getRawClasspathEntry() == entry);
+		assertSame(src1.getRawClasspathEntry(), entry);
 		IPath location= entry.getOutputLocation();
 		assertTrue("Output path is " + location + " expected was " + outputPath, outputPath.equals(location));
 		IPath[] exclusionPatterns= entry.getExclusionPatterns();
-		assertTrue(exclusionPatterns.length == 1);
-		assertTrue(exclusionPatterns[0].toString().equals("bin/"));
+		assertEquals(1, exclusionPatterns.length);
+		assertEquals("bin/", exclusionPatterns[0].toString());
 	}
 
+    @Test
 	public void testEditOutputFolder03ExcludeOutputFolderOther() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 		IPackageFragmentRoot src1= JavaProjectHelper.addSourceContainer(fJavaProject, "src1");
@@ -398,7 +397,7 @@ public class BuildpathModifierActionTest extends TestCase {
 		CPJavaProject cpProject= CPJavaProject.createFromExisting(fJavaProject);
 		CPListElement element= cpProject.getCPElement(CPListElement.createFromExisting(src1.getRawClasspathEntry(), fJavaProject));
 		IStatus status= ClasspathModifier.checkSetOutputLocationPrecondition(element, outputPath, false, cpProject);
-		assertTrue(status.getMessage(), status.getSeverity() != IStatus.ERROR);
+		assertNotEquals(status.getMessage(), IStatus.ERROR, status.getSeverity());
 
 		BuildpathDelta delta= ClasspathModifier.setOutputLocation(element, outputPath, false, cpProject);
 		assertDeltaResources(delta, new IPath[] {outputPath}, new IPath[0], new IPath[0], new IPath[0]);
@@ -411,17 +410,18 @@ public class BuildpathModifierActionTest extends TestCase {
 		IClasspathEntry[] classpathEntries= fJavaProject.getRawClasspath();
 		assertNumberOfEntries(classpathEntries, 3);
 		IClasspathEntry entry= classpathEntries[1];
-		assertTrue(src1.getRawClasspathEntry() == entry);
+		assertSame(src1.getRawClasspathEntry(), entry);
 		IPath location= entry.getOutputLocation();
 		assertTrue("Output path is " + location + " expected was " + outputPath, outputPath.equals(location));
 
 		entry= classpathEntries[2];
-		assertTrue(src2.getRawClasspathEntry() == entry);
+		assertSame(src2.getRawClasspathEntry(), entry);
 		IPath[] exclusionPatterns= entry.getExclusionPatterns();
-		assertTrue(exclusionPatterns.length == 1);
-		assertTrue(exclusionPatterns[0].toString().equals("bin/"));
+		assertEquals(1, exclusionPatterns.length);
+		assertEquals("bin/", exclusionPatterns[0].toString());
 	}
 
+    @Test
 	public void testEditOutputFolder04RemoveProjectAndExcludeOutput() throws Exception {
 		fJavaProject= createProject(null);
 
@@ -438,7 +438,7 @@ public class BuildpathModifierActionTest extends TestCase {
 		CPJavaProject cpProject= CPJavaProject.createFromExisting(fJavaProject);
 		CPListElement element= cpProject.getCPElement(CPListElement.createFromExisting(src1.getRawClasspathEntry(), fJavaProject));
 		IStatus status= ClasspathModifier.checkSetOutputLocationPrecondition(element, outputPath, false, cpProject);
-		assertTrue(status.getMessage(), status.getSeverity() == IStatus.INFO);
+		assertEquals(status.getMessage(), IStatus.INFO, status.getSeverity());
 
 		BuildpathDelta delta= ClasspathModifier.setOutputLocation(element, outputPath, false, cpProject);
 		assertDeltaResources(delta, new IPath[] {outputPath}, new IPath[0], new IPath[0], new IPath[0]);
@@ -453,17 +453,18 @@ public class BuildpathModifierActionTest extends TestCase {
 		IClasspathEntry[] classpathEntries= fJavaProject.getRawClasspath();
 		assertNumberOfEntries(classpathEntries, 3);
 		IClasspathEntry entry= classpathEntries[1];
-		assertTrue(src1.getRawClasspathEntry() == entry);
+		assertSame(src1.getRawClasspathEntry(), entry);
 		IPath location= entry.getOutputLocation();
 		assertTrue("Output path is " + location + " expected was " + outputPath, outputPath.equals(location));
 
 		entry= classpathEntries[2];
-		assertTrue(src2.getRawClasspathEntry() == entry);
+		assertSame(src2.getRawClasspathEntry(), entry);
 		IPath[] exclusionPatterns= entry.getExclusionPatterns();
-		assertTrue(exclusionPatterns.length == 1);
-		assertTrue(exclusionPatterns[0].toString().equals("bin/"));
+		assertEquals(1, exclusionPatterns.length);
+		assertEquals("bin/", exclusionPatterns[0].toString());
 	}
 
+    @Test
 	public void testEditOutputFolder05CannotOutputToSource() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 		IPackageFragmentRoot src1= JavaProjectHelper.addSourceContainer(fJavaProject, "src1");
@@ -475,9 +476,10 @@ public class BuildpathModifierActionTest extends TestCase {
 		CPJavaProject cpProject= CPJavaProject.createFromExisting(fJavaProject);
 		CPListElement element= cpProject.getCPElement(CPListElement.createFromExisting(src1.getRawClasspathEntry(), fJavaProject));
 		IStatus status= ClasspathModifier.checkSetOutputLocationPrecondition(element, outputPath, false, cpProject);
-		assertTrue(status.getMessage(), status.getSeverity() == IStatus.ERROR);
+		assertEquals(status.getMessage(), IStatus.ERROR, status.getSeverity());
 	}
 
+    @Test
 	public void testEditOutputFolderBug153068() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 		IPackageFragmentRoot src= JavaProjectHelper.addSourceContainer(fJavaProject, "src");
@@ -488,9 +490,10 @@ public class BuildpathModifierActionTest extends TestCase {
 		CPJavaProject cpProject= CPJavaProject.createFromExisting(fJavaProject);
 		CPListElement element= cpProject.getCPElement(CPListElement.createFromExisting(src.getRawClasspathEntry(), fJavaProject));
 		IStatus status= ClasspathModifier.checkSetOutputLocationPrecondition(element, outputPath, false, cpProject);
-		assertTrue(status.getMessage(), status.getSeverity() == IStatus.ERROR);
+		assertEquals(status.getMessage(), IStatus.ERROR, status.getSeverity());
 	}
 
+    @Test
 	public void testEditOutputFolderBug154044() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 		IPackageFragmentRoot src1= JavaProjectHelper.addSourceContainer(fJavaProject, "src1");
@@ -521,14 +524,15 @@ public class BuildpathModifierActionTest extends TestCase {
 		IClasspathEntry[] classpathEntries= fJavaProject.getRawClasspath();
 		assertNumberOfEntries(classpathEntries, 2);
 		IClasspathEntry entry= classpathEntries[1];
-		assertTrue(src1.getRawClasspathEntry() == entry);
+		assertSame(src1.getRawClasspathEntry(), entry);
 		IPath location= entry.getOutputLocation();
 		assertTrue("Output path is " + location + " expected was " + outputPath, outputPath.equals(location));
 		IPath[] exclusionPatterns= entry.getExclusionPatterns();
-		assertTrue(exclusionPatterns.length == 1);
-		assertTrue(exclusionPatterns[0].toString(), exclusionPatterns[0].toString().equals("sub/newBin/"));
+		assertEquals(1, exclusionPatterns.length);
+		assertEquals(exclusionPatterns[0].toString(), "sub/newBin/", exclusionPatterns[0].toString());
 	}
 
+    @Test
 	public void testEditOutputFolderBug154044OldIsProject() throws Exception {
 		fJavaProject= createProject(null);
 		IPackageFragmentRoot p01= JavaProjectHelper.addSourceContainer(fJavaProject, null);
@@ -558,14 +562,15 @@ public class BuildpathModifierActionTest extends TestCase {
 		IClasspathEntry[] classpathEntries= fJavaProject.getRawClasspath();
 		assertNumberOfEntries(classpathEntries, 2);
 		IClasspathEntry entry= classpathEntries[1];
-		assertTrue(p01.getRawClasspathEntry() == entry);
+		assertSame(p01.getRawClasspathEntry(), entry);
 		IPath location= entry.getOutputLocation();
 		assertTrue("Output path is " + location + " expected was " + outputPath, outputPath.equals(location));
 		IPath[] exclusionPatterns= entry.getExclusionPatterns();
-		assertTrue(exclusionPatterns.length == 1);
-		assertTrue(exclusionPatterns[0].toString(), exclusionPatterns[0].toString().equals("bin/"));
+		assertEquals(1, exclusionPatterns.length);
+		assertEquals(exclusionPatterns[0].toString(), "bin/", exclusionPatterns[0].toString());
 	}
 
+    @Test
 	public void testEditOutputFolderBug154044DonotDeleteDefaultOutputFolder() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 		IPackageFragmentRoot src1= JavaProjectHelper.addSourceContainer(fJavaProject, "src1");
@@ -596,13 +601,14 @@ public class BuildpathModifierActionTest extends TestCase {
 		IClasspathEntry[] classpathEntries= fJavaProject.getRawClasspath();
 		assertNumberOfEntries(classpathEntries, 2);
 		IClasspathEntry entry= classpathEntries[1];
-		assertTrue(src1.getRawClasspathEntry() == entry);
+		assertSame(src1.getRawClasspathEntry(), entry);
 		IPath location= entry.getOutputLocation();
 		assertTrue("Output path is " + location + " expected was " + outputPath, outputPath.equals(location));
 		IPath[] exclusionPatterns= entry.getExclusionPatterns();
-		assertTrue(exclusionPatterns.length == 0);
+		assertEquals(0, exclusionPatterns.length);
 	}
 
+    @Test
 	public void testEditOutputFolderBug154196() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 		IPackageFragmentRoot src1= JavaProjectHelper.addSourceContainer(fJavaProject, "src1");
@@ -631,13 +637,14 @@ public class BuildpathModifierActionTest extends TestCase {
 		IClasspathEntry[] classpathEntries= fJavaProject.getRawClasspath();
 		assertNumberOfEntries(classpathEntries, 2);
 		IClasspathEntry entry= classpathEntries[1];
-		assertTrue(src1.getRawClasspathEntry() == entry);
+		assertSame(src1.getRawClasspathEntry(), entry);
 		IPath location= entry.getOutputLocation();
-		assertTrue(location == null);
+		assertNull(location);
 		IPath[] exclusionPatterns= entry.getExclusionPatterns();
-		assertTrue(exclusionPatterns.length == 0);
+		assertEquals(0, exclusionPatterns.length);
 	}
 
+    @Test
 	public void testRemoveFromBuildpath01() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 		IPackageFragmentRoot src1= JavaProjectHelper.addSourceContainer(fJavaProject, "src1");
@@ -660,6 +667,7 @@ public class BuildpathModifierActionTest extends TestCase {
 		assertNumberOfEntries(classpathEntries, 1);
 	}
 
+    @Test
 	public void testRemoveFromBuildpath01RemoveProject() throws Exception {
 		fJavaProject= createProject(null);
 		IPackageFragmentRoot p01= JavaProjectHelper.addSourceContainer(fJavaProject, null);
@@ -678,6 +686,7 @@ public class BuildpathModifierActionTest extends TestCase {
 		assertNumberOfEntries(classpathEntries, 1);
 	}
 
+    @Test
 	public void testRemoveFromBuildpath01RemoveLibs() throws Exception {
 		fJavaProject= createProject(DEFAULT_OUTPUT_FOLDER_NAME);
 
@@ -707,6 +716,7 @@ public class BuildpathModifierActionTest extends TestCase {
 		assertNumberOfEntries(classpathEntries, 1);
 	}
 
+    @Test
 	public void testRemoveFromBuildpathBug153299Src() throws Exception {
 		fJavaProject= createProject(null);
 
@@ -730,6 +740,7 @@ public class BuildpathModifierActionTest extends TestCase {
 		assertNumberOfEntries(classpathEntries, 2);
 	}
 
+    @Test
 	public void testRemoveFromBuildpathBug153299Lib() throws Exception {
 		fJavaProject= createProject(null);
 		IPackageFragmentRoot p01= JavaProjectHelper.addSourceContainer(fJavaProject, null, new IPath[] {new Path("src1/")});
