@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,35 +13,29 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.core;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+
+import org.junit.Test;
 
 import org.eclipse.jdt.core.formatter.IndentManipulation;
 
-public class IndentManipulationTest extends TestCase {
-	public IndentManipulationTest(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return new TestSuite(IndentManipulationTest.class);
-	}
-
-	public void testIsIndentChar() {
+public class IndentManipulationTest {
+	@Test
+	public void isIndentChar() {
 		assertTrue(IndentManipulation.isIndentChar(' '));
 		assertTrue(IndentManipulation.isIndentChar('\t'));
-		assertTrue(!IndentManipulation.isIndentChar('x'));
-		assertTrue(!IndentManipulation.isIndentChar('\n'));
-		assertTrue(!IndentManipulation.isIndentChar('\r'));
+		assertFalse(IndentManipulation.isIndentChar('x'));
+		assertFalse(IndentManipulation.isIndentChar('\n'));
+		assertFalse(IndentManipulation.isIndentChar('\r'));
 	}
 
-	public void testIsLineDelimiterChar() {
-		assertTrue(!IndentManipulation.isLineDelimiterChar(' '));
-		assertTrue(!IndentManipulation.isLineDelimiterChar('\t'));
-		assertTrue(!IndentManipulation.isLineDelimiterChar('x'));
+	@Test
+	public void isLineDelimiterChar() {
+		assertFalse(IndentManipulation.isLineDelimiterChar(' '));
+		assertFalse(IndentManipulation.isLineDelimiterChar('\t'));
+		assertFalse(IndentManipulation.isLineDelimiterChar('x'));
 		assertTrue(IndentManipulation.isLineDelimiterChar('\n'));
 		assertTrue(IndentManipulation.isLineDelimiterChar('\r'));
 	}
 }
-
