@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,19 +13,15 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.core;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+import static org.junit.Assert.assertEquals;
+
+import org.junit.Test;
 
 import org.eclipse.jdt.internal.core.manipulation.util.Strings;
 
-public class StringsTest extends TestCase {
-
-	public static Test suite() {
-		return new TestSuite(StringsTest.class);
-	}
-
-	public void testRemoveTrailingCharacters() {
+public class StringsTest {
+	@Test
+	public void removeTrailingCharacters() {
 		assertEquals("x", Strings.removeTrailingCharacters("x", ','));
 		assertEquals("x,y", Strings.removeTrailingCharacters("x,y", ','));
 		assertEquals("x", Strings.removeTrailingCharacters("x,", ','));
