@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,9 +13,17 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.core;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+
 import java.util.Hashtable;
 import java.util.List;
 
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
+
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.TestOptions;
 
@@ -33,34 +41,21 @@ import org.eclipse.jdt.core.dom.ITypeBinding;
 import org.eclipse.jdt.core.dom.TypeDeclaration;
 import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
 
+import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
 import org.eclipse.jdt.internal.corext.dom.TypeRules;
 
-import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
-
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
 
 public class TypeRulesTest extends CoreTests {
 
-	private static final Class<TypeRulesTest> THIS= TypeRulesTest.class;
+	@Rule
+	public ProjectTestSetup pts= new ProjectTestSetup();
 
 	private IJavaProject fJProject1;
 	private IPackageFragmentRoot fSourceFolder;
 
-	public TypeRulesTest(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return setUpTest(new TestSuite(THIS));
-	}
-
-	public static Test setUpTest(Test test) {
-		return new ProjectTestSetup(test);
-	}
-
-	@Override
-	protected void setUp() throws Exception {
+	@Before
+	public void setUp() throws Exception {
 		Hashtable<String, String> options= TestOptions.getDefaultOptions();
 		options.put(JavaCore.COMPILER_PB_NO_EFFECT_ASSIGNMENT, JavaCore.IGNORE);
 		options.put(JavaCore.COMPILER_PB_UNNECESSARY_TYPE_CHECK, JavaCore.IGNORE);
@@ -68,17 +63,15 @@ public class TypeRulesTest extends CoreTests {
 		options.put(JavaCore.COMPILER_PB_UNCHECKED_TYPE_OPERATION, JavaCore.IGNORE);
 		JavaCore.setOptions(options);
 
-		fJProject1= ProjectTestSetup.getProject();
+		fJProject1= pts.getProject();
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 	}
 
-
-	@Override
-	protected void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJProject1, ProjectTestSetup.getDefaultClasspath());
+	@After
+	public void tearDown() throws Exception {
+		JavaProjectHelper.clear(fJProject1, pts.getDefaultClasspath());
 	}
 
-
 	private VariableDeclarationFragment[] createVariables() throws JavaModelException {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 		StringBuilder buf= new StringBuilder();
@@ -168,6 +161,7 @@ public class TypeRulesTest extends CoreTests {
 	}
 
 	//TODO: only tests behavior for ITypeBindings from the same AST. See bug 80715.
+	@Test
 	public void testIsAssignmentCompatible() throws Exception {
 		VariableDeclarationFragment[] targets= createVariables();
 
@@ -203,9 +197,10 @@ public class TypeRulesTest extends CoreTests {
 				}
 			}
 		}
-		assertTrue(errors.toString(), errors.length() == 0);
+		assertEquals(errors.toString(), 0, errors.length());
 	}
 
+	@Test
 	public void testCanAssign() throws Exception {
 		VariableDeclarationFragment[] targets= createVariables();
 
@@ -243,9 +238,10 @@ public class TypeRulesTest extends CoreTests {
 				}
 			}
 		}
-		assertTrue(errors.toString(), errors.length() == 0);
+		assertEquals(errors.toString(), 0, errors.length());
 	}
 
+	@Test
 	public void testIsCastCompatible() throws Exception {
 		StringBuilder errors= new StringBuilder();
 		VariableDeclarationFragment[] targets= createVariables();
@@ -269,8 +265,7 @@ public class TypeRulesTest extends CoreTests {
 				parser.setProject(fJProject1);
 				parser.setUnitName("F.java");
 
-				CompilationUnit astRoot= null;
-				astRoot= (CompilationUnit) parser.createAST(null);
+				CompilationUnit astRoot= (CompilationUnit) parser.createAST(null);
 				IProblem[] problems= astRoot.getProblems();
 
 				ITypeBinding b1= f1.resolveBinding().getType();
@@ -283,9 +278,10 @@ public class TypeRulesTest extends CoreTests {
 				}
 			}
 		}
-		assertTrue(errors.toString(), errors.length() == 0);
+		assertEquals(errors.toString(), 0, errors.length());
 	}
 
+	@Test
 	public void testCanCast() throws Exception {
 		StringBuilder errors= new StringBuilder();
 		VariableDeclarationFragment[] targets= createVariables();
@@ -325,8 +321,7 @@ public class TypeRulesTest extends CoreTests {
 				if (b1.isPrimitive() != b2.isPrimitive())
 					continue;
 
-				CompilationUnit astRoot= null;
-				astRoot= (CompilationUnit) parser.createAST(null);
+				CompilationUnit astRoot= (CompilationUnit) parser.createAST(null);
 				IProblem[] problems= astRoot.getProblems();
 
 				boolean res= TypeRules.canCast(b2, b1);
@@ -335,8 +330,7 @@ public class TypeRulesTest extends CoreTests {
 				}
 			}
 		}
-		assertTrue(errors.toString(), errors.length() == 0);
+		assertEquals(errors.toString(), 0, errors.length());
 	}
 
-
 }
