@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2015 IBM Corporation and others.
+ * Copyright (c) 2008, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,6 +13,10 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.jarexport;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
 import java.io.File;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -23,6 +27,13 @@ import java.util.Map;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipFile;
 
+import org.junit.After;
+import org.junit.Before;
+import org.junit.BeforeClass;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TestName;
+
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.JavaTestPlugin;
 
@@ -45,35 +56,29 @@ import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 
 import org.eclipse.jdt.ui.jarpackager.IJarExportRunnable;
 import org.eclipse.jdt.ui.jarpackager.JarPackageData;
-import org.eclipse.jdt.ui.tests.core.ProjectTestSetup;
+import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
 
 import org.eclipse.jdt.internal.ui.jarpackager.JarPackagerUtil;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+public class PlainJarExportTests {
+	@Rule
+	public ProjectTestSetup pts= new ProjectTestSetup();
 
+	@Rule
+	public TestName tn= new TestName();
 
-public class PlainJarExportTests extends TestCase {
-
-	private static final Class<PlainJarExportTests> THIS= PlainJarExportTests.class;
-
-	public static Test suite() {
-		return setUpTest(new TestSuite(THIS));
-	}
-
-	public static Test setUpTest(Test test) {
+	@BeforeClass
+	public static void setUpTest() {
 		System.setProperty("jdt.bug.367669", "non-null");
-		return new ProjectTestSetup(test);
 	}
 
 	private IJavaProject fProject;
 	private IPackageFragmentRoot fMainRoot;
 	private ICompilationUnit fCU;
 
-	@Override
-	protected void setUp() throws Exception {
-		fProject= ProjectTestSetup.getProject();
+	@Before
+	public void setUp() throws Exception {
+		fProject= pts.getProject();
 
 		Map<String, String> options= fProject.getOptions(false);
 		String compliance= JavaCore.VERSION_1_4;
@@ -97,13 +102,13 @@ public class PlainJarExportTests extends TestCase {
 		fCU= fragment.createCompilationUnit("Main.java", buf.toString(), true, null);
 	}
 
-	@Override
-	protected void tearDown() throws Exception {
-		JavaProjectHelper.clear(fProject, ProjectTestSetup.getDefaultClasspath());
+	@After
+	public void tearDown() throws Exception {
+		JavaProjectHelper.clear(fProject, pts.getDefaultClasspath());
 	}
 
-
-	public void testExportCu() throws Exception {
+	@Test
+	public void exportCu() throws Exception {
 		JarPackageData data= createJarPackageData();
 
 		data.setElements(new Object[] { fCU });
@@ -113,16 +118,12 @@ public class PlainJarExportTests extends TestCase {
 		try (ZipFile jar= createArchive(data)) {
 			entries= getSortedEntries(jar);
 		}
-		List<String> expected= Arrays.asList(new String[] {
-				"META-INF/MANIFEST.MF\n",
-				"org/eclipse/jdt/ui/test/Main$1.class\n",
-				"org/eclipse/jdt/ui/test/Main$MainInner.class\n",
-				"org/eclipse/jdt/ui/test/Main.class\n",
-		});
+		List<String> expected= Arrays.asList("META-INF/MANIFEST.MF\n", "org/eclipse/jdt/ui/test/Main$1.class\n", "org/eclipse/jdt/ui/test/Main$MainInner.class\n", "org/eclipse/jdt/ui/test/Main.class\n");
 		assertEquals(expected.toString(), entries.toString());
 	}
 
-	public void testExportFile() throws Exception {
+	@Test
+	public void exportFile() throws Exception {
 		JarPackageData data= createJarPackageData();
 
 		data.setElements(new Object[] { fCU.getResource() });
@@ -132,19 +133,19 @@ public class PlainJarExportTests extends TestCase {
 		try (ZipFile jar= createArchive(data)) {
 			entries= getSortedEntries(jar);
 		}
-		List<String> expected= Arrays.asList(new String[] { "META-INF/MANIFEST.MF\n", "org/eclipse/jdt/ui/test/Main$1.class\n",
-				"org/eclipse/jdt/ui/test/Main$MainInner.class\n",
-				"org/eclipse/jdt/ui/test/Main.class\n", });
+		List<String> expected= Arrays.asList("META-INF/MANIFEST.MF\n", "org/eclipse/jdt/ui/test/Main$1.class\n", "org/eclipse/jdt/ui/test/Main$MainInner.class\n", "org/eclipse/jdt/ui/test/Main.class\n");
 
 		assertEquals(expected.toString(), entries.toString());
 	}
 
 	//https://bugs.eclipse.org/bugs/show_bug.cgi?id=229052
-	public void testExternalClassFolder() throws Exception {
+	@Test
+	public void externalClassFolder() throws Exception {
 		JarPackageData data= createJarPackageData();
 
 		File classFolder= JavaTestPlugin.getDefault().getFileInPlugin(new Path("testresources/externalClassFolder/"));//$NON-NLS-1$
-		assertTrue("class folder not found", classFolder != null && classFolder.exists());//$NON-NLS-1$
+		assertNotNull("class folder not found", classFolder);//$NON-NLS-1$
+		assertTrue("class folder not found", classFolder.exists());//$NON-NLS-1$
 
 		IPackageFragmentRoot externalRoot= JavaProjectHelper.addLibrary(fProject, Path.fromOSString(classFolder.getPath()), null, null);
 
@@ -155,11 +156,7 @@ public class PlainJarExportTests extends TestCase {
 		try (ZipFile jar= createArchive(data)) {
 			entries= getSortedEntries(jar);
 		}
-		List<String> expected= Arrays.asList(new String[] {
-				"META-INF/MANIFEST.MF\n",
-				"org/eclipse/jdt/ui/test/Main$1.class\n",
-				"org/eclipse/jdt/ui/test/Main$MainInner.class\n",
-				"org/eclipse/jdt/ui/test/Main.class\n", });
+		List<String> expected= Arrays.asList("META-INF/MANIFEST.MF\n", "org/eclipse/jdt/ui/test/Main$1.class\n", "org/eclipse/jdt/ui/test/Main$MainInner.class\n", "org/eclipse/jdt/ui/test/Main.class\n");
 		assertEquals(expected.toString(), entries.toString());
 	}
 
@@ -171,6 +168,10 @@ public class PlainJarExportTests extends TestCase {
 		return data;
 	}
 
+	private String getName() {
+		return tn.getMethodName();
+	}
+
 	private static ZipFile createArchive(JarPackageData data) throws Exception, CoreException {
 		IWorkbenchWindow window= PlatformUI.getWorkbench().getActiveWorkbenchWindow();
 
