@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2015 IBM Corporation and others.
+ * Copyright (c) 2008, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,6 +13,10 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.preferences;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
 import java.lang.reflect.Field;
 import java.lang.reflect.Method;
 import java.util.Arrays;
@@ -20,6 +24,8 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 
+import org.junit.Test;
+
 import org.eclipse.jdt.core.JavaCore;
 
 import org.eclipse.jdt.internal.ui.preferences.ComplianceConfigurationBlock;
@@ -30,25 +36,14 @@ import org.eclipse.jdt.internal.ui.preferences.OptionsConfigurationBlock.Key;
 import org.eclipse.jdt.internal.ui.preferences.ProblemSeveritiesConfigurationBlock;
 import org.eclipse.jdt.internal.ui.preferences.TodoTaskConfigurationBlock;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
-public class OptionsConfigurationBlockTest extends TestCase {
-
-	/*
-	 * NOTE: This test is not contained in the build test suite, since missing
-	 * UI should not make the build go red.
-	 */
-	public static Test suite() {
-		return new TestSuite(OptionsConfigurationBlockTest.class);
-	}
+public class OptionsConfigurationBlockTest {
 
 	/**
 	 * Reflective test that ensures that all options from {@link JavaCore} are used in the UI.
 	 *
 	 * @throws Exception should not
 	 */
+	@Test
 	public void testKeysForOptions() throws Exception {
 		HashMap<String, String> coreFieldLookup= new HashMap<>();
 		for (Field field : JavaCore.class.getDeclaredFields()) {
@@ -91,7 +86,7 @@ public class OptionsConfigurationBlockTest extends TestCase {
 	 */
 	@Deprecated
 	private void removeUnusedOptions(HashMap<String, String> coreFieldLookup) {
-		coreFieldLookup.keySet().removeAll(Arrays.asList(new String[] {
+		coreFieldLookup.keySet().removeAll(Arrays.asList(
 				JavaCore.COMPILER_PB_INCONSISTENT_NULL_CHECK,
 				JavaCore.COMPILER_PB_INVALID_IMPORT,
 				JavaCore.COMPILER_PB_UNREACHABLE_CODE,
@@ -111,8 +106,7 @@ public class OptionsConfigurationBlockTest extends TestCase {
 				JavaCore.COMPILER_PB_DEAD_CODE_IN_TRIVIAL_IF_STATEMENT, // default is good (don't flag trivial 'if (DEBUG)')
 
 				JavaCore.CODEASSIST_DISCOURAGED_REFERENCE_CHECK, // is on the Type Filters page now, see https://bugs.eclipse.org/218487
-				JavaCore.CODEASSIST_FORBIDDEN_REFERENCE_CHECK,   // is on the Type Filters page now, see https://bugs.eclipse.org/218487
-		}));
+				JavaCore.CODEASSIST_FORBIDDEN_REFERENCE_CHECK));   // is on the Type Filters page now, see https://bugs.eclipse.org/218487
 	}
 
 	private void checkConfigurationBlock(Class<?> configurationBlock, HashMap<String, String> coreFieldLookup) throws Exception {
@@ -137,9 +131,7 @@ public class OptionsConfigurationBlockTest extends TestCase {
 				boolean keyWasInKeySet= keySet.remove(key);
 				if (JavaCore.PLUGIN_ID.equals(key.getQualifier())) {
 					Object fieldName= coreFieldLookup.remove(key.getName());
-					assertTrue(
-						"No core constant for key " + key.getName() + " in class " + configurationBlock.getName(),
-						fieldName != null);
+					assertNotNull("No core constant for key " + key.getName() + " in class " + configurationBlock.getName(), fieldName);
 					assertTrue(configurationBlock.getName() + "#getKeys() is missing key '" + key.getName() + "'", keyWasInKeySet);
 				}
 			}
