@@ -20,8 +20,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.TestOptions;
@@ -56,11 +54,10 @@ import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.fix.CodeStyleCleanUp;
 
-@RunWith(JUnit4.class)
 public class ChangeNonStaticToStaticTest extends QuickFixTest {
 
 	@Rule
-    public ProjectTestSetup projectsetup = new ProjectTestSetup();
+    public ProjectTestSetup projectSetup = new ProjectTestSetup();
 
 	private IJavaProject fJProject1;
 	private IPackageFragmentRoot fSourceFolder;
@@ -86,14 +83,14 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		corePrefs.setValue(JavaCore.CODEASSIST_FIELD_SUFFIXES, "");
 		corePrefs.setValue(JavaCore.CODEASSIST_STATIC_FIELD_SUFFIXES, "");
 
-		fJProject1= ProjectTestSetup.getProject();
+		fJProject1= projectSetup.getProject();
 
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 	}
 
 	@After
 	public void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJProject1, ProjectTestSetup.getDefaultClasspath());
+		JavaProjectHelper.clear(fJProject1, projectSetup.getDefaultClasspath());
 	}
 
 	private void assertRefactoringResultAsExpected(CleanUpRefactoring refactoring, String[] expected) throws CoreException {
@@ -118,7 +115,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 	@Test
 	public void testNonStaticAccessTest01() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    public static int I;\n");
@@ -134,7 +131,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		ICleanUp cleanUp= createCleanUp();
 		refactoring.addCleanUp(cleanUp);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    public static int I;\n");
@@ -150,7 +147,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 	@Test
 	public void testNonStaticAccessTest02() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1<T> {\n");
 		buf.append("    public static int I;\n");
@@ -166,7 +163,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		ICleanUp cleanUp= createCleanUp();
 		refactoring.addCleanUp(cleanUp);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1<T> {\n");
 		buf.append("    public static int I;\n");
@@ -182,7 +179,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 	@Test
 	public void testNonStaticAccessTest03() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1<T extends String> {\n");
 		buf.append("    public static int I;\n");
@@ -198,7 +195,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		ICleanUp cleanUp= createCleanUp();
 		refactoring.addCleanUp(cleanUp);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1<T extends String> {\n");
 		buf.append("    public static int I;\n");
@@ -214,14 +211,14 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 	@Test
 	public void testNonStaticAccessTest04() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    public static int I;\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("E1.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E2 {\n");
 		buf.append("    private static class E1 {\n");
@@ -243,7 +240,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		ICleanUp cleanUp= createCleanUp();
 		refactoring.addCleanUp(cleanUp);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E2 {\n");
 		buf.append("    private static class E1 {\n");
@@ -265,20 +262,20 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 	@Test
 	public void testNonStaticAccessTest05() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    public static int I;\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("E1.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E2 extends E1 {}\n");
 		pack1.createCompilationUnit("E2.java", buf.toString(), false, null);
 
 		IPackageFragment pack2= fSourceFolder.createPackageFragment("test2", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("import test1.E2;\n");
 		buf.append("public class E3  {\n");
@@ -295,7 +292,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		ICleanUp cleanUp= createCleanUp();
 		refactoring.addCleanUp(cleanUp);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("import test1.E1;\n");
 		buf.append("import test1.E2;\n");
@@ -313,20 +310,20 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 	@Test
 	public void testNonStaticAccessTest06() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1<T> {\n");
 		buf.append("    public static int I;\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("E1.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E2<T, G> extends E1<T> {}\n");
 		pack1.createCompilationUnit("E2.java", buf.toString(), false, null);
 
 		IPackageFragment pack2= fSourceFolder.createPackageFragment("test2", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("import test1.E2;\n");
 		buf.append("public class E3<G>  {\n");
@@ -343,7 +340,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		ICleanUp cleanUp= createCleanUp();
 		refactoring.addCleanUp(cleanUp);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("import test1.E1;\n");
 		buf.append("import test1.E2;\n");
@@ -361,20 +358,20 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 	@Test
 	public void testNonStaticAccessTest07() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1<T> {\n");
 		buf.append("    public static int I;\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("E1.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E2<T, G> extends E1<T> {}\n");
 		pack1.createCompilationUnit("E2.java", buf.toString(), false, null);
 
 		IPackageFragment pack2= fSourceFolder.createPackageFragment("test2", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("import test1.E2;\n");
 		buf.append("public class E3<G>  {\n");
@@ -392,7 +389,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		ICleanUp cleanUp= createCleanUp();
 		refactoring.addCleanUp(cleanUp);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("import test1.E2;\n");
 		buf.append("public class E3<G>  {\n");
@@ -410,20 +407,20 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 	@Test
 	public void testNonStaticAccessTest08() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1<T> {\n");
 		buf.append("    public static int I;\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("E1.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E2<T, G> extends E1<T> {}\n");
 		pack1.createCompilationUnit("E2.java", buf.toString(), false, null);
 
 		IPackageFragment pack2= fSourceFolder.createPackageFragment("test2", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("import test1.E2;\n");
 		buf.append("public class E3<G>  {\n");
@@ -444,7 +441,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		ICleanUp cleanUp= createCleanUp();
 		refactoring.addCleanUp(cleanUp);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("import test1.E2;\n");
 		buf.append("public class E3<G>  {\n");
@@ -465,20 +462,20 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 	@Test
 	public void testNonStaticAccessTest09() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1<T> {\n");
 		buf.append("    public static int I;\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("E1.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E2<T, G> extends E1<T> {}\n");
 		pack1.createCompilationUnit("E2.java", buf.toString(), false, null);
 
 		IPackageFragment pack2= fSourceFolder.createPackageFragment("test2", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("import test1.E2;\n");
 		buf.append("public class E3<G>  {\n");
@@ -499,7 +496,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		ICleanUp cleanUp= createCleanUp();
 		refactoring.addCleanUp(cleanUp);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("import test1.E1;\n");
 		buf.append("import test1.E2;\n");
@@ -521,14 +518,14 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 	@Test
 	public void testNonStaticAccessTest10() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1 {\n");
 		buf.append("    public static void foo() {};\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("E1.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E2 {\n");
 		buf.append("    private static String E1= \"\";\n");
@@ -545,7 +542,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		ICleanUp cleanUp= createCleanUp();
 		refactoring.addCleanUp(cleanUp);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E2 {\n");
 		buf.append("    private static String E1= \"\";\n");
@@ -562,14 +559,14 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 	@Test
 	public void testNonStaticAccessTest11() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1<T> {\n");
 		buf.append("    public static void foo() {};\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("E1.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E2 {\n");
 		buf.append("    private static String E1= \"\";\n");
@@ -586,7 +583,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		ICleanUp cleanUp= createCleanUp();
 		refactoring.addCleanUp(cleanUp);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E2 {\n");
 		buf.append("    private static String E1= \"\";\n");
@@ -603,14 +600,14 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 	@Test
 	public void testNonStaticAccessTest12() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E1<G> {\n");
 		buf.append("    public static int I;\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("E1.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import test2.E1;\n");
 		buf.append("public class E2 {\n");
@@ -623,7 +620,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		ICompilationUnit cu= pack1.createCompilationUnit("E2.java", buf.toString(), false, null);
 
 		IPackageFragment pack2= fSourceFolder.createPackageFragment("test2", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("public class E1<G>  {}\n");
 		pack2.createCompilationUnit("E1.java", buf.toString(), false, null);
@@ -634,7 +631,7 @@ public class ChangeNonStaticToStaticTest extends QuickFixTest {
 		ICleanUp cleanUp= createCleanUp();
 		refactoring.addCleanUp(cleanUp);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import test2.E1;\n");
 		buf.append("public class E2 {\n");
