@@ -22,8 +22,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.TestOptions;
@@ -52,11 +50,10 @@ import org.eclipse.jdt.internal.ui.JavaPlugin;
 /**
  *
  */
-@RunWith(JUnit4.class)
 public class SerialVersionQuickFixTest extends QuickFixTest {
 
 	@Rule
-    public ProjectTestSetup projectsetup = new ProjectTestSetup();
+    public ProjectTestSetup projectSetup = new ProjectTestSetup();
 
 	private static final String DEFAULT_VALUE= "1L";
 
@@ -81,7 +78,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 	@Before
 	public void setUp() throws Exception {
 		JavaRuntime.getDefaultVMInstall();
-		fProject= ProjectTestSetup.getProject();
+		fProject= projectSetup.getProject();
 
 		Hashtable<String, String> options= TestOptions.getDefaultOptions();
 
@@ -107,13 +104,13 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 
 	@After
 	public void tearDown() throws Exception {
-		JavaProjectHelper.clear(fProject, ProjectTestSetup.getDefaultClasspath());
+		JavaProjectHelper.clear(fProject, projectSetup.getDefaultClasspath());
 	}
 
 	@Test
 	public void testLocalClass() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test3", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test3;\n");
 		buf.append("import java.io.Serializable;\n");
 		buf.append("public class Test5 {\n");
@@ -137,7 +134,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 		assertCorrectLabels(proposals);
 
 		String[] expected= new String[2];
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test3;\n");
 		buf.append("import java.io.Serializable;\n");
 		buf.append("public class Test5 {\n");
@@ -157,7 +154,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 		buf.append("}\n");
 		expected[0]= buf.toString();
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test3;\n");
 		buf.append("import java.io.Serializable;\n");
 		buf.append("public class Test5 {\n");
@@ -184,7 +181,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 	@Test
 	public void testAnonymousClass() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test3", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test3;\n");
 		buf.append("import java.io.Serializable;\n");
 		buf.append("public class Test3 {\n");
@@ -204,7 +201,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 		assertCorrectLabels(proposals);
 
 		String[] expected= new String[2];
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test3;\n");
 		buf.append("import java.io.Serializable;\n");
 		buf.append("public class Test3 {\n");
@@ -220,7 +217,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 		buf.append("}\n");
 		expected[0]= buf.toString();
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test3;\n");
 		buf.append("import java.io.Serializable;\n");
 		buf.append("public class Test3 {\n");
@@ -242,7 +239,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 	@Test
 	public void testInnerClass() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test2", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("\n");
 		buf.append("import java.io.Serializable;\n");
@@ -262,7 +259,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 		assertCorrectLabels(proposals);
 
 		String[] expected= new String[2];
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("\n");
 		buf.append("import java.io.Serializable;\n");
@@ -278,7 +275,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 		buf.append("}\n");
 		expected[0]= buf.toString();
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("\n");
 		buf.append("import java.io.Serializable;\n");
@@ -301,7 +298,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 	@Test
 	public void testOuterClass() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.io.Serializable;\n");
 		buf.append("public class Test1 implements Serializable {\n");
@@ -316,7 +313,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 		assertCorrectLabels(proposals);
 
 		String[] expected= new String[2];
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.io.Serializable;\n");
 		buf.append("public class Test1 implements Serializable {\n");
@@ -327,7 +324,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 		buf.append("}\n");
 		expected[0]= buf.toString();
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.io.Serializable;\n");
 		buf.append("public class Test1 implements Serializable {\n");
@@ -344,7 +341,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 	@Test
 	public void testOuterClass2() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test3", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test3;\n");
 		buf.append("import java.util.EventObject;\n");
 		buf.append("public class Test4 extends EventObject {\n");
@@ -370,7 +367,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 		assertCorrectLabels(proposals);
 
 		String[] expected= new String[2];
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test3;\n");
 		buf.append("import java.util.EventObject;\n");
 		buf.append("public class Test4 extends EventObject {\n");
@@ -392,7 +389,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 		buf.append("}\n");
 		expected[0]= buf.toString();
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test3;\n");
 		buf.append("import java.util.EventObject;\n");
 		buf.append("public class Test4 extends EventObject {\n");
@@ -422,7 +419,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 		// longer package
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("a.b.c", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package a.b.c;\n");
 		buf.append("import java.io.Serializable;\n");
 		buf.append("public class Test1 implements Serializable {\n");
@@ -437,7 +434,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 		assertCorrectLabels(proposals);
 
 		String[] expected= new String[2];
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package a.b.c;\n");
 		buf.append("import java.io.Serializable;\n");
 		buf.append("public class Test1 implements Serializable {\n");
@@ -448,7 +445,7 @@ public class SerialVersionQuickFixTest extends QuickFixTest {
 		buf.append("}\n");
 		expected[0]= buf.toString();
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package a.b.c;\n");
 		buf.append("import java.io.Serializable;\n");
 		buf.append("public class Test1 implements Serializable {\n");
