@@ -22,8 +22,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.TestOptions;
@@ -55,11 +53,10 @@ import org.eclipse.jdt.internal.ui.JavaPlugin;
 /**
  *
  */
-@RunWith(JUnit4.class)
 public class UtilitiesTest extends QuickFixTest {
 
 	@Rule
-    public ProjectTestSetup projectsetup = new ProjectTestSetup();
+    public ProjectTestSetup projectSetup = new ProjectTestSetup();
 
 	private IJavaProject fJProject1;
 	private IPackageFragmentRoot fSourceFolder;
@@ -75,14 +72,14 @@ public class UtilitiesTest extends QuickFixTest {
 		IPreferenceStore store= JavaPlugin.getDefault().getPreferenceStore();
 		store.setValue(PreferenceConstants.CODEGEN_ADD_COMMENTS, false);
 
-		fJProject1= ProjectTestSetup.getProject();
+		fJProject1= projectSetup.getProject();
 
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 	}
 
 	@After
 	public void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJProject1, ProjectTestSetup.getDefaultClasspath());
+		JavaProjectHelper.clear(fJProject1, projectSetup.getDefaultClasspath());
 	}
 
 	@Test
@@ -221,4 +218,30 @@ public class UtilitiesTest extends QuickFixTest {
 			}
 		}
 	}
+
+	@Test
+	public void testGetPossibleTypeKindsForTypes() throws Exception {
+		JavaProjectHelper.set16CompilerOptions(fJProject1, true);
+
+		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
+		StringBuilder buf= new StringBuilder();
+		buf.append("package test1;\n");
+		buf.append("public sealed interface E permits X {}\n");
+		buf.append("public sealed class F permits X {}\n");
+		buf.append("}\n");
+		ICompilationUnit cu= pack1.createCompilationUnit("E.java", buf.toString(), false, null);
+
+		int[] expected= {
+				TypeKinds.CLASSES | TypeKinds.INTERFACES,
+				TypeKinds.CLASSES
+		};
+
+		CompilationUnit astRoot= getASTRoot(cu);
+		for (int i = 0; i < astRoot.types().size(); i++) {
+			TypeDeclaration typeDecl = (TypeDeclaration) astRoot.types().get(i);
+			ASTNode node= NodeFinder.perform(astRoot, buf.indexOf("X", typeDecl.getStartPosition()), 1);
+			int kinds= ASTResolving.getPossibleTypeKinds(node, true);
+			assertEquals("Guessing failed for " + node.toString(), expected[i], kinds);
+		}
+	}
 }
