@@ -22,8 +22,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 
@@ -48,19 +46,17 @@ import org.eclipse.jdt.core.IPackageFragmentRoot;
 
 import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
 
-
-@RunWith(JUnit4.class)
 public class NLSSearchTest {
 
 	@Rule
-	public ProjectTestSetup projectsetup = new ProjectTestSetup();
+	public ProjectTestSetup projectSetup = new ProjectTestSetup();
 
 	private IJavaProject fJProject1;
 	private IPackageFragmentRoot fSourceFolder;
 
 	@Before
 	public void setUp() throws CoreException {
-		fJProject1= ProjectTestSetup.getProject();
+		fJProject1= projectSetup.getProject();
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		IPackageFragment pack= fSourceFolder.createPackageFragment("org.eclipse.osgi.util", false, null);
@@ -73,7 +69,7 @@ public class NLSSearchTest {
 
 	@After
 	public void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJProject1, ProjectTestSetup.getDefaultClasspath());
+		JavaProjectHelper.clear(fJProject1, projectSetup.getDefaultClasspath());
 		ISearchResultViewPart searchResultView= NewSearchUI.getSearchResultView();
 		if (searchResultView != null) {
 			searchResultView.getSite().getPage().hideView(searchResultView);
@@ -114,7 +110,7 @@ public class NLSSearchTest {
 	@Test
 	public void test02() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -127,14 +123,14 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("    public String s1= Accessor.Client_s1;\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Client_s1=s1\n");
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
 
@@ -144,7 +140,7 @@ public class NLSSearchTest {
 	@Test
 	public void test03() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -157,14 +153,14 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("    public String s1= Accessor.Client_s1;\n");
 		buf.append("}\n");
 		ICompilationUnit client= pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
 
 		NLSSearchTestHelper.assertNumberOfProblems(accessor, propertiesFile, 2);
@@ -176,7 +172,7 @@ public class NLSSearchTest {
 	@Test
 	public void test04() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -189,13 +185,13 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Client_s1=foo\n");
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
 
@@ -208,7 +204,7 @@ public class NLSSearchTest {
 	@Test
 	public void test05() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -221,13 +217,13 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
 
 		NLSSearchTestHelper.assertNumberOfProblems(accessor, propertiesFile, 2);
@@ -239,7 +235,7 @@ public class NLSSearchTest {
 	@Test
 	public void test06() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -252,14 +248,14 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("    public String s1= Accessor.Client_s1;\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Client_s1=s1\n");
 		buf.append("Client_s1=s1\n");
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
@@ -272,7 +268,7 @@ public class NLSSearchTest {
 	@Test
 	public void testBug152604() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -285,14 +281,14 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("    public int length= Accessor.Client_s1.length();\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Client_s1=s1\n");
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
 
@@ -302,7 +298,7 @@ public class NLSSearchTest {
 	@Test
 	public void testBug133810() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -315,14 +311,14 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("    public String s1= Accessor.Client_s1;\n");
 		buf.append("}\n");
 		pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Client_s2=s1\n");
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
 
@@ -341,7 +337,7 @@ public class NLSSearchTest {
 	@Test
 	public void testBug185178() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import java.util.MissingResourceException;\n");
 		buf.append("import java.util.ResourceBundle;\n");
@@ -359,7 +355,7 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("    public String s1= Accessor\n");
@@ -367,7 +363,7 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Client.0=s1\n");
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
 
@@ -377,7 +373,7 @@ public class NLSSearchTest {
 	@Test
 	public void testBug247012_1() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import java.util.MissingResourceException;\n");
 		buf.append("import java.util.ResourceBundle;\n");
@@ -395,7 +391,7 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("	private static final String X =\"Main.indirect\";//$NON-NLS-1$ \n");
@@ -407,7 +403,7 @@ public class NLSSearchTest {
 
 		pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Main.direct=Main.direct\n");
 		buf.append("Main.indirect=Main.indirect\n");
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
@@ -418,7 +414,7 @@ public class NLSSearchTest {
 	@Test
 	public void testBug247012_2() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import java.util.MissingResourceException;\n");
 		buf.append("import java.util.ResourceBundle;\n");
@@ -436,7 +432,7 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("	private static final String X = Accessor.getString(\"Main.indirect\");//$NON-NLS-1$ \n");
@@ -448,7 +444,7 @@ public class NLSSearchTest {
 
 		pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Main.direct=Main.direct\n");
 		buf.append("Main.indirect=Main.indirect\n");
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
@@ -459,7 +455,7 @@ public class NLSSearchTest {
 	@Test
 	public void testBug247012_3() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import java.util.MissingResourceException;\n");
 		buf.append("import java.util.ResourceBundle;\n");
@@ -473,7 +469,7 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("	private static final int i = 10; \n");
@@ -484,7 +480,7 @@ public class NLSSearchTest {
 
 		pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
 
 		NLSSearchTestHelper.assertNumberOfProblems(accessor, propertiesFile, 0);
@@ -493,7 +489,7 @@ public class NLSSearchTest {
 	@Test
 	public void testBug247012_4() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import java.util.MissingResourceException;\n");
 		buf.append("import java.util.ResourceBundle;\n");
@@ -511,7 +507,7 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("	public static void main(String[] args) { \n");
@@ -521,7 +517,7 @@ public class NLSSearchTest {
 
 		ICompilationUnit client= pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
 
 		NLSSearchTestHelper.assertNumberOfProblems(accessor, propertiesFile, 1);
@@ -531,7 +527,7 @@ public class NLSSearchTest {
 	@Test
 	public void testBug295040() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import java.util.MissingResourceException;\n");
 		buf.append("import java.util.ResourceBundle;\n");
@@ -552,7 +548,7 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("	public static void main(String[] args) { \n");
@@ -563,7 +559,7 @@ public class NLSSearchTest {
 
 		pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Client_s1=s1\n");
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
 
@@ -573,7 +569,7 @@ public class NLSSearchTest {
 	@Test
 	public void testBug306168_1() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import java.util.MissingResourceException;\n");
 		buf.append("import java.util.ResourceBundle;\n");
@@ -591,7 +587,7 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("	private static final String X =\"Main.indirect\";//$NON-NLS-1$ \n");
@@ -602,7 +598,7 @@ public class NLSSearchTest {
 
 		pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Main.indirect=Main.indirect\n");
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
 
@@ -612,7 +608,7 @@ public class NLSSearchTest {
 	@Test
 	public void testBug306168_2() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import java.util.MissingResourceException;\n");
 		buf.append("import java.util.ResourceBundle;\n");
@@ -630,7 +626,7 @@ public class NLSSearchTest {
 		buf.append("}\n");
 		ICompilationUnit accessor= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Client {\n");
 		buf.append("	private static final String X =\"Main.undefined\";//$NON-NLS-1$ \n");
@@ -641,7 +637,7 @@ public class NLSSearchTest {
 
 		pack1.createCompilationUnit("Client.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		IFile propertiesFile= write((IFolder)pack1.getCorrespondingResource(), buf.toString(), "Accessor.properties");
 
 		NLSSearchTestHelper.assertNumberOfProblems(accessor, propertiesFile, 1);
