@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2013 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,18 +14,16 @@
 
 package org.eclipse.jdt.ui.tests.search;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+	WorkspaceReferenceTest.class,
+	TreeContentProviderTestWrapper.class,
+	ParticipantTest.class,
+	FileAdapterTest.class,
+	NLSSearchTest.class
+})
 public class SearchTest {
-	public static Test suite() {
-		TestSuite suite= new TestSuite(SearchTest.class.getName());
-		//suite.addTestSuite(WorkspaceScopeTest.class);
-		suite.addTest(WorkspaceReferenceTest.suite());
-		suite.addTest(TreeContentProviderTestWrapper.suite());
-		suite.addTest(ParticipantTest.suite());
-		suite.addTest(FileAdapterTest.suite());
-		suite.addTest(NLSSearchTest.suite());
-		return suite;
-	}
 }
