@@ -18,8 +18,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.ui.tests.core.rules.JUnitSourceSetup;
 
@@ -30,13 +28,12 @@ import org.eclipse.jdt.ui.tests.core.rules.JUnitSourceSetup;
  *
  * @since 3.1
  */
-@RunWith(JUnit4.class)
 public class TreeContentProviderTestWrapper {
 
 	TreeContentProviderTest fTest;
 
 	@Rule
-	public JUnitSourceSetup projectsetup = new JUnitSourceSetup();
+	public JUnitSourceSetup projectSetup = new JUnitSourceSetup();
 
 	@Before
 	public void setUp() throws Exception {
@@ -44,10 +41,6 @@ public class TreeContentProviderTestWrapper {
 		fTest.setUp();
 	}
 
-	/*
-	 * @see junit.framework.TestCase#tearDown()
-	 * @since 3.1
-	 */
 	@After
 	public void tearDown() throws Exception {
 		fTest.tearDown();
