@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -60,6 +60,10 @@ import org.eclipse.jdt.core.Signature;
 import org.eclipse.jdt.internal.corext.CorextMessages;
 import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 
+import org.eclipse.jdt.launching.AbstractVMInstall;
+import org.eclipse.jdt.launching.IVMInstall;
+import org.eclipse.jdt.launching.JavaRuntime;
+
 import org.eclipse.jdt.ui.JavaUI;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
@@ -77,9 +81,6 @@ public class JavaDocLocations {
 	private static IClasspathEntry getConvertedEntry(IClasspathEntry entry, IJavaProject project, Map<IPath, String> oldLocationMap) {
 		IPath path= null;
 		switch (entry.getEntryKind()) {
-			case IClasspathEntry.CPE_SOURCE:
-			case IClasspathEntry.CPE_PROJECT:
-				return null;
 			case IClasspathEntry.CPE_CONTAINER:
 				convertContainer(entry, project, oldLocationMap);
 				return null;
@@ -89,6 +90,8 @@ public class JavaDocLocations {
 			case IClasspathEntry.CPE_VARIABLE:
 				path= JavaCore.getResolvedVariablePath(entry.getPath());
 				break;
+			case IClasspathEntry.CPE_SOURCE:
+			case IClasspathEntry.CPE_PROJECT:
 			default:
 				return null;
 		}
@@ -379,10 +382,10 @@ public class JavaDocLocations {
 		IModuleDescription moduleDescription= null;
 		/*
 		 * The Javadoc tool for Java SE 11 uses module name in the created URL.
-		 * We can't know what format is required, so we just guess by the project's compiler compliance.
+		 * We can't know what format is required, so we just guess by the project's execution environment or compiler compliance.
 		 */
 		IJavaProject javaProject= pack.getJavaProject();
-		if (javaProject != null && JavaModelUtil.is11OrHigher(javaProject)) {
+		if (javaProject != null && is11OrHigher(javaProject)) {
 			if (pack.isReadOnly()) {
 				IPackageFragmentRoot root= (IPackageFragmentRoot) pack.getAncestor(IJavaElement.PACKAGE_FRAGMENT_ROOT);
 				if (root != null) {
@@ -399,6 +402,79 @@ public class JavaDocLocations {
 		return moduleDescription;
 	}
 
+	/**
+	 * This function finds out which jvm/source compliance is being used to see if its version 11 or higher.
+	 * @param javaProject the java project for which the version number is to be verified.
+	 * @return <i>true</i> if the jvm used is version 11 or higher (If no jvm is found then the source compliance is used)
+	 * else returns <i>false</i>
+	 */
+	private static boolean is11OrHigher(IJavaProject javaProject) {
+		boolean is11orHigher= false;
+		if (javaProject != null) {
+			try {
+				IVMInstall install= JavaRuntime.getVMInstall(javaProject);
+				if (install instanceof AbstractVMInstall) {
+					String vmver = ((AbstractVMInstall)install).getJavaVersion();
+					is11orHigher= JavaModelUtil.is11OrHigher(vmver);
+				} else {
+					is11orHigher= JavaModelUtil.is11OrHigher(javaProject);
+				}
+			} catch (CoreException e) {
+				is11orHigher= JavaModelUtil.is11OrHigher(javaProject);
+			}
+		}
+		return is11orHigher;
+	}
+
+	/**
+	 * This function finds out which jvm/source compliance is being used to see if its version 10 or higher.
+	 * @param javaProject the java project for which the version number is to be verified.
+	 * @return <i>true</i> if the jvm used is version 10 or higher (If no jvm is found then the source compliance is used)
+	 * else returns <i>false</i>
+	 */
+	private static boolean is10OrHigher(IJavaProject javaProject) {
+		boolean is10orHigher= false;
+		if (javaProject != null) {
+			try {
+				IVMInstall install= JavaRuntime.getVMInstall(javaProject);
+				if (install instanceof AbstractVMInstall) {
+					String vmver = ((AbstractVMInstall)install).getJavaVersion();
+					is10orHigher= JavaModelUtil.is10OrHigher(vmver);
+				} else {
+					is10orHigher= JavaModelUtil.is10OrHigher(javaProject);
+				}
+			} catch (CoreException e) {
+				is10orHigher= JavaModelUtil.is10OrHigher(javaProject);
+			}
+		}
+		return is10orHigher;
+	}
+
+	/**
+	 * This function finds out which jvm/source compliance is being used to see if its version 1.8 or 9.
+	 * @param javaProject the java project for which the version number is to be verified.
+	 * @return <i>true</i> if the jvm used is 1.8 or 9 (If no jvm is found then the source compliance is used)
+	 * else returns <i>false</i>
+	 */
+	private static boolean is1d8Or9(IJavaProject javaProject) {
+		boolean is1d8Or9= false;
+		String compliance= JavaModelUtil.getSourceCompliance(javaProject);
+		if (javaProject != null) {
+			try {
+				IVMInstall install= JavaRuntime.getVMInstall(javaProject);
+				if (install instanceof AbstractVMInstall) {
+					String vmver = ((AbstractVMInstall)install).getJavaVersion();
+					is1d8Or9 = JavaModelUtil.is1d8OrHigher(vmver) && !JavaModelUtil.is10OrHigher(vmver);
+				} else {
+					is1d8Or9= JavaCore.compareJavaVersions(compliance, JavaCore.VERSION_1_8) == 0 || JavaCore.compareJavaVersions(compliance, JavaCore.VERSION_9) == 0;
+				}
+			} catch (CoreException e) {
+				is1d8Or9= JavaCore.compareJavaVersions(compliance, JavaCore.VERSION_1_8) == 0 || JavaCore.compareJavaVersions(compliance, JavaCore.VERSION_9) == 0;
+			}
+		}
+		return is1d8Or9;
+	}
+
 	private static void appendFieldReference(IField field, StringBuffer buf) {
 		buf.append(field.getElementName());
 	}
@@ -411,15 +487,25 @@ public class JavaDocLocations {
 		 * This breaks all clients that directly create such URLs.
 		 * We can't know what format is required, so we just guess by the project's compiler compliance.
 		 */
-		boolean is18OrHigher= JavaModelUtil.is18OrHigher(meth.getJavaProject());
-		buf.append(is18OrHigher ? '-' : '(');
+		IJavaProject javaProject= meth.getJavaProject();
+		boolean is1d8Or9= is1d8Or9(javaProject);
+		boolean is10OrHigher= is10OrHigher(javaProject);
+		buf.append(is1d8Or9 ? '-' : '(');
 		String[] params= meth.getParameterTypes();
 		IType declaringType= meth.getDeclaringType();
 		boolean isVararg= Flags.isVarargs(meth.getFlags());
 		int lastParam= params.length - 1;
 		for (int i= 0; i <= lastParam; i++) {
 			if (i != 0) {
-				buf.append(is18OrHigher ? "-" : ", "); //$NON-NLS-1$ //$NON-NLS-2$
+				String paramDelim;
+				if (is1d8Or9) {
+					paramDelim= "-"; //$NON-NLS-1$
+				} else if (is10OrHigher) {
+					paramDelim= ","; //$NON-NLS-1$
+				} else {
+					paramDelim= ", "; //$NON-NLS-1$
+				}
+				buf.append(paramDelim);
 			}
 			String curr= Signature.getTypeErasure(params[i]);
 			String fullName= JavaModelUtil.getResolvedTypeName(curr, declaringType);
@@ -433,7 +519,7 @@ public class JavaDocLocations {
 					dim--;
 				}
 				while (dim > 0) {
-					buf.append(is18OrHigher ? ":A" : "[]"); //$NON-NLS-1$ //$NON-NLS-2$
+					buf.append(is1d8Or9 ? ":A" : "[]"); //$NON-NLS-1$ //$NON-NLS-2$
 					dim--;
 				}
 				if (i == lastParam && isVararg) {
@@ -441,7 +527,7 @@ public class JavaDocLocations {
 				}
 			}
 		}
-		buf.append(is18OrHigher ? '-' : ')');
+		buf.append(is1d8Or9 ? '-' : ')');
 	}
 
 	/**
@@ -459,7 +545,7 @@ public class JavaDocLocations {
 			// => Always use the Javadoc location as base:
 			URL baseURL= JavaUI.getJavadocLocation(element, false);
 			if (baseURL != null) {
-				if (baseURL.getProtocol().equals(JAR_PROTOCOL)) {
+				if (JAR_PROTOCOL.equals(baseURL.getProtocol())) {
 					// It's a JarURLConnection, which is not known to the browser widget.
 					// Let's start the help web server:
 					URL baseURL2= PlatformUI.getWorkbench().getHelpSystem().resolve(baseURL.toExternalForm(), true);
@@ -597,4 +683,7 @@ public class JavaDocLocations {
 			return new File(url.getFile());
 		}
 	}
+
+	private JavaDocLocations() {
+	}
 }
