@@ -20,7 +20,6 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import javax.xml.parsers.DocumentBuilder;
@@ -237,9 +236,7 @@ public class TemplateSet {
 			Node root= document.createElement("templates"); //$NON-NLS-1$
 			document.appendChild(root);
 
-			for (int i= 0; i != fTemplates.size(); i++) {
-				Template template= fTemplates.get(i);
-
+			for (Template template : fTemplates) {
 				Node node= document.createElement(getTemplateTag());
 				root.appendChild(node);
 
@@ -306,14 +303,7 @@ public class TemplateSet {
 	}
 
 	private boolean exists(Template template) {
-		for (Iterator<Template> iterator = fTemplates.iterator(); iterator.hasNext();) {
-			Template anotherTemplate = iterator.next();
-
-			if (template.equals(anotherTemplate))
-				return true;
-		}
-
-		return false;
+		return fTemplates.contains(template);
 	}
 
 	/**
@@ -349,8 +339,7 @@ public class TemplateSet {
 	 */
 	public Template[] getTemplates(String name) {
 		ArrayList<Template> res= new ArrayList<>();
-		for (Iterator<Template> iterator= fTemplates.iterator(); iterator.hasNext();) {
-			Template curr= iterator.next();
+		for (Template curr : fTemplates) {
 			if (curr.getName().equals(name)) {
 				res.add(curr);
 			}
@@ -365,8 +354,7 @@ public class TemplateSet {
 	 * @return the first template with the given name
 	 */
 	public Template getFirstTemplate(String name) {
-		for (Iterator<Template> iterator= fTemplates.iterator(); iterator.hasNext();) {
-			Template curr= iterator.next();
+		for (Template curr : fTemplates) {
 			if (curr.getName().equals(name)) {
 				return curr;
 			}
