@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -66,6 +66,7 @@ import org.eclipse.jdt.core.dom.Modifier;
 import org.eclipse.jdt.core.dom.Name;
 import org.eclipse.jdt.core.dom.NodeFinder;
 import org.eclipse.jdt.core.dom.ParameterizedType;
+import org.eclipse.jdt.core.dom.RecordDeclaration;
 import org.eclipse.jdt.core.dom.ReturnStatement;
 import org.eclipse.jdt.core.dom.SimpleName;
 import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
@@ -297,9 +298,8 @@ public class IntroduceFactoryRefactoring extends Refactoring {
 		// we have some sub node. Make sure its the right child of the parent
 		StructuralPropertyDescriptor location= node.getLocationInParent();
 		ASTNode parent= node.getParent();
-		if (location == ClassInstanceCreation.TYPE_PROPERTY) {
-			return parent;
-		} else if (location == MethodDeclaration.NAME_PROPERTY && ((MethodDeclaration)parent).isConstructor()) {
+		if (location == ClassInstanceCreation.TYPE_PROPERTY
+				|| (location == MethodDeclaration.NAME_PROPERTY && ((MethodDeclaration)parent).isConstructor())) {
 			return parent;
 		}
 		return null;
@@ -483,7 +483,11 @@ public class IntroduceFactoryRefactoring extends Refactoring {
 	 */
 	private SearchResultGroup[] searchForCallsTo(IMethodBinding methodBinding, IProgressMonitor pm, RefactoringStatus status) throws JavaModelException {
 		IMethod method= (IMethod) methodBinding.getJavaElement();
-		final RefactoringSearchEngine2 engine= new RefactoringSearchEngine2(createSearchPattern(method, methodBinding));
+		SearchPattern searchPattern= createSearchPattern(method, methodBinding);
+		if (searchPattern == null) {
+			return new SearchResultGroup[0];
+		}
+		final RefactoringSearchEngine2 engine= new RefactoringSearchEngine2(searchPattern);
 		engine.setFiltering(true, true);
 		engine.setScope(createSearchScope(method, methodBinding));
 		engine.setStatus(status);
@@ -512,6 +516,9 @@ public class IntroduceFactoryRefactoring extends Refactoring {
 
 	private IType findNonPrimaryType(String fullyQualifiedName, IProgressMonitor pm, RefactoringStatus status) throws JavaModelException {
 		SearchPattern p= SearchPattern.createPattern(fullyQualifiedName, IJavaSearchConstants.TYPE, IJavaSearchConstants.DECLARATIONS, SearchUtils.GENERICS_AGNOSTIC_MATCH_RULE);
+		if (p == null) {
+			return null;
+		}
 		final RefactoringSearchEngine2 engine= new RefactoringSearchEngine2(p);
 
 		engine.setFiltering(true, true);
@@ -521,12 +528,10 @@ public class IntroduceFactoryRefactoring extends Refactoring {
 
 		SearchResultGroup[] groups= (SearchResultGroup[]) engine.getResults();
 
-		if (groups.length != 0) {
-			for (SearchResultGroup rg : groups) {
-				for (SearchMatch match : rg.getSearchResults()) {
-					if (match.getAccuracy() == SearchMatch.A_ACCURATE) {
-						return (IType) match.getElement();
-					}
+		for (SearchResultGroup rg : groups) {
+			for (SearchMatch match : rg.getSearchResults()) {
+				if (match.getAccuracy() == SearchMatch.A_ACCURATE) {
+					return (IType) match.getElement();
 				}
 			}
 		}
@@ -552,7 +557,7 @@ public class IntroduceFactoryRefactoring extends Refactoring {
 			fFormalArgNames= findCtorArgNames();
 
 			ICompilationUnit[]	affectedFiles= collectAffectedUnits(fAllCallsTo);
-			result.merge(Checks.validateModifiesFiles(ResourceUtil.getFiles(affectedFiles), getValidationContext()));
+			result.merge(Checks.validateModifiesFiles(ResourceUtil.getFiles(affectedFiles), getValidationContext(), pm));
 
 			if (fCallSitesInBinaryUnits)
 				result.merge(RefactoringStatus.createWarningStatus(RefactoringCoreMessages.IntroduceFactory_callSitesInBinaryClass));
@@ -582,7 +587,13 @@ public class IntroduceFactoryRefactoring extends Refactoring {
 		if (ctorDecl != null) {
 			List<SingleVariableDeclaration>	formalArgs= ctorDecl.parameters();
 			int i= 0;
-
+			if (formalArgs.size() == 0 && numArgs > 0 && fCtorBinding.isCompactConstructor()) {
+				ASTNode parent= ctorDecl.getParent();
+				if (parent instanceof RecordDeclaration) {
+					RecordDeclaration recDecl= (RecordDeclaration) parent;
+					formalArgs= recDecl.recordComponents();
+				}
+			}
 			for(Iterator<SingleVariableDeclaration> iter= formalArgs.iterator(); iter.hasNext(); i++) {
 				SingleVariableDeclaration svd= iter.next();
 
@@ -652,7 +663,7 @@ public class IntroduceFactoryRefactoring extends Refactoring {
 	}
 
 	private IMethodBinding[] getUnimplementedMethods(ITypeBinding binding) {
-		IMethodBinding[] unimplementedMethods= StubUtility2Core.getUnimplementedMethods(binding, true);
+		IMethodBinding[] unimplementedMethods= StubUtility2Core.getUnimplementedMethods(binding, null);
 		Arrays.sort(unimplementedMethods, new MethodsSourcePositionComparator(binding));
 		return unimplementedMethods;
 	}
@@ -861,14 +872,12 @@ public class IntroduceFactoryRefactoring extends Refactoring {
 		factoryMethodCall.setName(ast.newSimpleName(fNewMethodName));
 
 		List<Expression> actualCtorArgsList= actualCtorArgs.getRewrittenList();
-		for (int i=0; i < actualCtorArgsList.size(); i++) {
-			Expression actualCtorArg= actualCtorArgsList.get(i);
-
+		for (Expression actualCtorArg : actualCtorArgsList) {
 			ASTNode movedArg;
 			if (ASTNodes.isExistingNode(actualCtorArg)) {
 				movedArg= unitRewriter.createMoveTarget(actualCtorArg);
 			} else {
-				unitRewriter.remove(actualCtorArg, null);
+				unitRewriter.remove(actualCtorArg, gd);
 				movedArg= actualCtorArg;
 			}
 
@@ -1166,8 +1175,8 @@ public class IntroduceFactoryRefactoring extends Refactoring {
 			arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_INPUT, JavaRefactoringDescriptorUtil.elementToHandle(project, fCUHandle));
 			arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_NAME, fNewMethodName);
 			arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_ELEMENT + 1, JavaRefactoringDescriptorUtil.elementToHandle(project, binding.getJavaElement()));
-			arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_SELECTION, Integer.valueOf(fSelectionStart).toString() + " " + Integer.valueOf(fSelectionLength).toString()); //$NON-NLS-1$
-			arguments.put(ATTRIBUTE_PROTECT, Boolean.valueOf(fProtectConstructor).toString());
+			arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_SELECTION, Integer.toString(fSelectionStart) + " " + Integer.toString(fSelectionLength)); //$NON-NLS-1$
+			arguments.put(ATTRIBUTE_PROTECT, Boolean.toString(fProtectConstructor));
 			final DynamicValidationStateChange result= new DynamicValidationRefactoringChange(descriptor, RefactoringCoreMessages.IntroduceFactory_name);
 			boolean hitInFactoryClass= false;
 			boolean hitInCtorClass= false;
@@ -1256,7 +1265,9 @@ public class IntroduceFactoryRefactoring extends Refactoring {
 	 * @return return <code>true</code> if the constructor can be made protected
 	 */
 	public boolean canProtectConstructor() {
-		return !fCtorBinding.isSynthetic() && fFactoryCU.findDeclaringNode(fCtorBinding.getKey()) != null;
+		return !fCtorBinding.isSynthetic()
+				&& fFactoryCU.findDeclaringNode(fCtorBinding.getKey()) != null
+				&& !fCtorBinding.isCanonicalConstructor();
 	}
 
 	/**
@@ -1357,9 +1368,9 @@ public class IntroduceFactoryRefactoring extends Refactoring {
 			int length= -1;
 			final StringTokenizer tokenizer= new StringTokenizer(selection);
 			if (tokenizer.hasMoreTokens())
-				offset= Integer.valueOf(tokenizer.nextToken()).intValue();
+				offset= Integer.parseInt(tokenizer.nextToken());
 			if (tokenizer.hasMoreTokens())
-				length= Integer.valueOf(tokenizer.nextToken()).intValue();
+				length= Integer.parseInt(tokenizer.nextToken());
 			if (offset >= 0 && length >= 0) {
 				fSelectionStart= offset;
 				fSelectionLength= length;
@@ -1396,7 +1407,7 @@ public class IntroduceFactoryRefactoring extends Refactoring {
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, JavaRefactoringDescriptorUtil.ATTRIBUTE_NAME));
 		final String protect= arguments.getAttribute(ATTRIBUTE_PROTECT);
 		if (protect != null) {
-			fProtectConstructor= Boolean.valueOf(protect).booleanValue();
+			fProtectConstructor= Boolean.parseBoolean(protect);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_PROTECT));
 		return new RefactoringStatus();
