@@ -366,7 +366,7 @@ public final class RenameCompilationUnitProcessor extends JavaRenameProcessor im
 	}
 
 	private void computeRenameTypeRefactoring() throws CoreException{
-		if (getSimpleCUName().indexOf(".") != -1) { //$NON-NLS-1$
+		if (getSimpleCUName().indexOf('.') != -1) {
 			fRenameTypeProcessor= null;
 			fWillRenameType= false;
 			return;
@@ -382,11 +382,11 @@ public final class RenameCompilationUnitProcessor extends JavaRenameProcessor im
 
 	private IType getTypeWithTheSameName() {
 		try {
-			IType[] topLevelTypes= fCu.getTypes();
 			String name= getSimpleCUName();
-			for (int i = 0; i < topLevelTypes.length; i++) {
-				if (name.equals(topLevelTypes[i].getElementName()))
-					return topLevelTypes[i];
+			for (IType topLevelType : fCu.getTypes()) {
+				if (name.equals(topLevelType.getElementName())) {
+					return topLevelType;
+				}
 			}
 			return null;
 		} catch (CoreException e) {
@@ -400,7 +400,7 @@ public final class RenameCompilationUnitProcessor extends JavaRenameProcessor im
 
 	/**
 	 * Removes the extension (whatever comes after the last '.') from the given file name.
-	 * 
+	 *
 	 * @param fileName the file name
 	 * @return main type name
 	 */
