@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -47,6 +47,7 @@ import org.eclipse.jdt.core.dom.Initializer;
 import org.eclipse.jdt.core.dom.LambdaExpression;
 import org.eclipse.jdt.core.dom.MethodDeclaration;
 import org.eclipse.jdt.core.dom.NodeFinder;
+import org.eclipse.jdt.core.dom.RecordDeclaration;
 import org.eclipse.jdt.core.dom.VariableDeclaration;
 import org.eclipse.jdt.core.refactoring.CompilationUnitChange;
 import org.eclipse.jdt.core.refactoring.IJavaRefactorings;
@@ -230,8 +231,9 @@ public class RenameLocalVariableProcessor extends JavaRenameProcessor implements
 
 		if (!Checks.isDeclaredIn(fTempDeclarationNode, MethodDeclaration.class)
 				&& !Checks.isDeclaredIn(fTempDeclarationNode, Initializer.class)
-				&& !Checks.isDeclaredIn(fTempDeclarationNode, LambdaExpression.class)) {
-			if (JavaModelUtil.is18OrHigher(fCu.getJavaProject()))
+				&& !Checks.isDeclaredIn(fTempDeclarationNode, LambdaExpression.class)
+				&& !Checks.isDeclaredIn(fTempDeclarationNode, RecordDeclaration.class)) {
+			if (JavaModelUtil.is1d8OrHigher(fCu.getJavaProject()))
 				return RefactoringStatus.createFatalErrorStatus(RefactoringCoreMessages.RenameTempRefactoring_only_in_methods_initializers_and_lambda);
 
 			return RefactoringStatus.createFatalErrorStatus(RefactoringCoreMessages.RenameTempRefactoring_only_in_methods_and_initializers);
@@ -431,9 +433,9 @@ public class RenameLocalVariableProcessor extends JavaRenameProcessor implements
 				int length= -1;
 				final StringTokenizer tokenizer= new StringTokenizer(selection);
 				if (tokenizer.hasMoreTokens())
-					offset= Integer.valueOf(tokenizer.nextToken()).intValue();
+					offset= Integer.parseInt(tokenizer.nextToken());
 				if (tokenizer.hasMoreTokens())
-					length= Integer.valueOf(tokenizer.nextToken()).intValue();
+					length= Integer.parseInt(tokenizer.nextToken());
 				if (offset >= 0 && length >= 0) {
 					try {
 						final IJavaElement[] elements= fCu.codeSelect(offset, length);
@@ -457,7 +459,7 @@ public class RenameLocalVariableProcessor extends JavaRenameProcessor implements
 		}
 		final String references= extended.getAttribute(JavaRefactoringDescriptorUtil.ATTRIBUTE_REFERENCES);
 		if (references != null) {
-			fUpdateReferences= Boolean.valueOf(references).booleanValue();
+			fUpdateReferences= Boolean.parseBoolean(references);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, JavaRefactoringDescriptorUtil.ATTRIBUTE_REFERENCES));
 		return new RefactoringStatus();
