@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Microsoft Corporation - read formatting options from the compilation unit
  *******************************************************************************/
 package org.eclipse.jdt.internal.corext.refactoring.reorg;
 
@@ -133,7 +134,7 @@ class DeleteChangeCreator {
 	private static TextChange addTextEditFromRewrite(TextChangeManager manager, ICompilationUnit cu, ASTRewrite rewrite) throws CoreException {
 		try {
 			ITextFileBuffer buffer= RefactoringFileBuffers.acquire(cu);
-			TextEdit resultingEdits= rewrite.rewriteAST(buffer.getDocument(), cu.getJavaProject().getOptions(true));
+			TextEdit resultingEdits= rewrite.rewriteAST(buffer.getDocument(), cu.getOptions(true));
 			TextChange textChange= manager.get(cu);
 			if (textChange instanceof TextFileChange) {
 				TextFileChange tfc= (TextFileChange) textChange;
@@ -176,9 +177,6 @@ class DeleteChangeCreator {
 				return createDeleteChange(((IClassFile)javaElement).getResource());
 
 			case IJavaElement.JAVA_MODEL: //cannot be done
-				Assert.isTrue(false);
-				return null;
-
 			case IJavaElement.JAVA_PROJECT: //handled differently
 				Assert.isTrue(false);
 				return null;
@@ -190,11 +188,9 @@ class DeleteChangeCreator {
 			case IJavaElement.PACKAGE_DECLARATION:
 			case IJavaElement.IMPORT_CONTAINER:
 			case IJavaElement.IMPORT_DECLARATION:
+			default://there's no more kinds
 				Assert.isTrue(false);//not done here
 				return new NullChange();
-			default:
-				Assert.isTrue(false);//there's no more kinds
-				return new NullChange();
 		}
 	}
 
