@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2006, 2018 IBM Corporation and others.
+ * Copyright (c) 2006, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Microsoft Corporation - read formatting options from the compilation unit
  *******************************************************************************/
 package org.eclipse.jdt.internal.corext.refactoring.structure;
 
@@ -18,7 +19,6 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -55,21 +55,33 @@ import org.eclipse.jdt.core.ITypeHierarchy;
 import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.ASTNode;
+import org.eclipse.jdt.core.dom.ASTParser;
 import org.eclipse.jdt.core.dom.ASTRequestor;
+import org.eclipse.jdt.core.dom.ASTVisitor;
 import org.eclipse.jdt.core.dom.AbstractTypeDeclaration;
+import org.eclipse.jdt.core.dom.Annotation;
 import org.eclipse.jdt.core.dom.Block;
+import org.eclipse.jdt.core.dom.ClassInstanceCreation;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.dom.Expression;
 import org.eclipse.jdt.core.dom.FieldDeclaration;
+import org.eclipse.jdt.core.dom.IExtendedModifier;
 import org.eclipse.jdt.core.dom.MarkerAnnotation;
 import org.eclipse.jdt.core.dom.MethodDeclaration;
+import org.eclipse.jdt.core.dom.MethodInvocation;
 import org.eclipse.jdt.core.dom.Modifier;
 import org.eclipse.jdt.core.dom.Name;
+import org.eclipse.jdt.core.dom.NodeFinder;
+import org.eclipse.jdt.core.dom.SimpleName;
+import org.eclipse.jdt.core.dom.SimpleType;
+import org.eclipse.jdt.core.dom.ThisExpression;
 import org.eclipse.jdt.core.dom.Type;
+import org.eclipse.jdt.core.dom.TypeDeclaration;
 import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
 import org.eclipse.jdt.core.dom.rewrite.ASTRewrite;
 import org.eclipse.jdt.core.dom.rewrite.ITrackedNodePosition;
 import org.eclipse.jdt.core.dom.rewrite.ImportRewrite.ImportRewriteContext;
+import org.eclipse.jdt.core.dom.rewrite.ListRewrite;
 import org.eclipse.jdt.core.refactoring.IJavaRefactorings;
 import org.eclipse.jdt.core.refactoring.descriptors.JavaRefactoringDescriptor;
 import org.eclipse.jdt.core.refactoring.descriptors.PushDownDescriptor;
@@ -78,10 +90,15 @@ import org.eclipse.jdt.core.search.SearchEngine;
 import org.eclipse.jdt.core.search.SearchMatch;
 import org.eclipse.jdt.core.search.SearchPattern;
 
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
+import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
+import org.eclipse.jdt.internal.core.manipulation.util.Strings;
 import org.eclipse.jdt.internal.core.refactoring.descriptors.RefactoringSignatureDescriptorFactory;
 import org.eclipse.jdt.internal.corext.codemanipulation.ContextSensitiveImportRewriteContext;
 import org.eclipse.jdt.internal.corext.dom.ASTNodeFactory;
+import org.eclipse.jdt.internal.corext.dom.ASTNodes;
 import org.eclipse.jdt.internal.corext.dom.BodyDeclarationRewrite;
+import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
 import org.eclipse.jdt.internal.corext.dom.ModifierRewrite;
 import org.eclipse.jdt.internal.corext.refactoring.Checks;
 import org.eclipse.jdt.internal.corext.refactoring.JDTRefactoringDescriptorComment;
@@ -101,16 +118,12 @@ import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.internal.corext.util.JdtFlags;
 import org.eclipse.jdt.internal.corext.util.Messages;
 import org.eclipse.jdt.internal.corext.util.SearchUtils;
-import org.eclipse.jdt.internal.core.manipulation.util.Strings;
 
 import org.eclipse.jdt.ui.JavaElementLabels;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.preferences.JavaPreferencesSettings;
 
-import org.eclipse.jdt.internal.core.manipulation.StubUtility;
-import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
-
 
 /**
  * Refactoring processor for the push down refactoring.
@@ -288,20 +301,85 @@ public final class PushDownRefactoringProcessor extends HierarchyProcessor {
 
 	private static IJavaElement[] getReferencingElementsFromSameClass(IMember member, IProgressMonitor pm, RefactoringStatus status) throws JavaModelException {
 		Assert.isNotNull(member);
-		final RefactoringSearchEngine2 engine= new RefactoringSearchEngine2(SearchPattern.createPattern(member, IJavaSearchConstants.REFERENCES, SearchUtils.GENERICS_AGNOSTIC_MATCH_RULE));
+		SearchPattern pattern= SearchPattern.createPattern(member,
+				IJavaSearchConstants.REFERENCES, SearchUtils.GENERICS_AGNOSTIC_MATCH_RULE);
+		if (pattern == null) {
+			return new IJavaElement[0];
+		}
+		final RefactoringSearchEngine2 engine= new RefactoringSearchEngine2(pattern);
 		engine.setFiltering(true, true);
-		engine.setScope(SearchEngine.createJavaSearchScope(new IJavaElement[] { member.getDeclaringType() }));
+		IType declaringType= member.getDeclaringType();
+		engine.setScope(SearchEngine.createJavaSearchScope(new IJavaElement[] { declaringType }));
 		engine.setStatus(status);
 		engine.searchPattern(new SubProgressMonitor(pm, 1));
 		Set<IJavaElement> result= new HashSet<>(3);
+		ICompilationUnit cu= member.getCompilationUnit();
+		String source= cu.getSource();
+		CompilationUnit cuRoot= null;
 		for (SearchResultGroup group : (SearchResultGroup[]) engine.getResults()) {
+			outer:
 			for (SearchMatch searchResult : group.getSearchResults()) {
+				if (source.charAt(searchResult.getOffset() - 1) == '.') {
+					if (cuRoot == null) {
+						cuRoot= getCompilationUnitRoot(cu, source);
+					}
+					if (cuRoot != null) {
+						ASTNode node= NodeFinder.perform(cuRoot, searchResult.getOffset(), searchResult.getLength());
+						if (node != null && node instanceof MethodInvocation) {
+							MethodInvocation methodInvocation= (MethodInvocation)node;
+							Expression expression= methodInvocation.getExpression();
+							if (expression != null && !(expression instanceof ThisExpression)) {
+								if (expression instanceof ClassInstanceCreation) {
+									ClassInstanceCreation cic= (ClassInstanceCreation)expression;
+									Type t= cic.getType();
+									if (t.isSimpleType() && !((SimpleType)t).getName().getFullyQualifiedName().equals(declaringType.getElementName())) {
+										continue;
+									}
+								} else if (expression instanceof SimpleName) {
+									String referenceName= ((SimpleName)expression).getFullyQualifiedName();
+									final TypeDeclaration thisType= ASTNodes.getFirstAncestorOrNull(methodInvocation, TypeDeclaration.class);
+									if (thisType != null) {
+										final String thisTypeName= thisType.getName().getFullyQualifiedName();
+										for (FieldDeclaration fieldDeclaration : thisType.getFields()) {
+											List<VariableDeclarationFragment> fragments= fieldDeclaration.fragments();
+											for (VariableDeclarationFragment fragment : fragments) {
+												SimpleName name= fragment.getName();
+												if (name.getFullyQualifiedName().equals(referenceName)) {
+													Type fieldType= fieldDeclaration.getType();
+													if (!fieldType.isSimpleType()) {
+														continue outer;
+													}
+													SimpleType simpleType= (SimpleType)fieldType;
+													if (!simpleType.getName().getFullyQualifiedName().equals(thisTypeName)) {
+														continue outer;
+													}
+												}
+											}
+										}
+									}
+								}
+							}
+						}
+					}
+				}
 				result.add(SearchUtils.getEnclosingJavaElement(searchResult));
 			}
 		}
 		return result.toArray(new IJavaElement[result.size()]);
 	}
 
+	private static CompilationUnit getCompilationUnitRoot(ICompilationUnit cu, String source) {
+		Map<String, String> options = cu.getJavaProject().getOptions(true);
+		ASTParser parser= ASTParser.newParser(IASTSharedValues.SHARED_AST_LEVEL);
+		parser.setKind(ASTParser.K_COMPILATION_UNIT);
+		parser.setResolveBindings(false);
+		parser.setSource(source.toCharArray());
+		parser.setCompilerOptions(options);
+		parser.setProject(cu.getJavaProject());
+		CompilationUnit selectionCURoot= (CompilationUnit) parser.createAST(null);
+		return selectionCURoot;
+	}
+
 	private ITypeHierarchy fCachedClassHierarchy;
 
 	private MemberActionInfo[] fMemberInfos;
@@ -515,8 +593,7 @@ public final class PushDownRefactoringProcessor extends HierarchyProcessor {
 
 	private RefactoringStatus checkNonAbstractMembersInDestinationClasses(IMember[] membersToPushDown, IType[] destinationClassesForNonAbstract) throws JavaModelException {
 		RefactoringStatus result= new RefactoringStatus();
-		List<IMember> list= new ArrayList<>(); // Arrays.asList does not support removing
-		list.addAll(Arrays.asList(membersToPushDown));
+		List<IMember> list= new ArrayList<>(Arrays.asList(membersToPushDown)); // Arrays.asList does not support removing
 		list.removeAll(Arrays.asList(getAbstractMembers(membersToPushDown)));
 		IMember[] nonAbstractMembersToPushDown= list.toArray(new IMember[list.size()]);
 		for (IType type : destinationClassesForNonAbstract) {
@@ -569,6 +646,35 @@ public final class PushDownRefactoringProcessor extends HierarchyProcessor {
 		}
 	}
 
+	/**
+	 * AST node visitor which performs This check and removes qualifier if needed
+	 */
+	public static class ThisVisitor extends ASTVisitor {
+
+		private final IType fDeclaringType;
+		private final ASTRewrite fRewrite;
+
+		public ThisVisitor(final ASTRewrite rewrite, final IType declaringType) {
+			Assert.isNotNull(rewrite);
+			Assert.isNotNull(declaringType);
+			fRewrite= rewrite;
+			fDeclaringType= declaringType;
+		}
+
+		@Override
+		public final boolean visit(ThisExpression node) {
+			Name q= node.getQualifier();
+			if (q == null) {
+				return false;
+			}
+			String qName= q.getFullyQualifiedName();
+			if (qName.equals(fDeclaringType.getElementName()) || qName.equals(fDeclaringType.getFullyQualifiedName())) {
+				fRewrite.set(node, ThisExpression.QUALIFIER_PROPERTY, null, null);
+			}
+			return false;
+		}
+	}
+
 	private void copyBodyOfPushedDownMethod(ASTRewrite targetRewrite, IMethod method, MethodDeclaration oldMethod, MethodDeclaration newMethod, TypeVariableMaplet[] mapping) throws JavaModelException {
 		Block body= oldMethod.getBody();
 		if (body == null) {
@@ -580,15 +686,14 @@ public final class PushDownRefactoringProcessor extends HierarchyProcessor {
 			final ASTRewrite rewriter= ASTRewrite.create(body.getAST());
 			final ITrackedNodePosition position= rewriter.track(body);
 			body.accept(new TypeVariableMapper(rewriter, mapping));
-			rewriter.rewriteAST(document, getDeclaringType().getCompilationUnit().getJavaProject().getOptions(true)).apply(document, TextEdit.NONE);
+			body.accept(new ThisVisitor(rewriter, fCachedDeclaringType));
+			rewriter.rewriteAST(document, getDeclaringType().getCompilationUnit().getOptions(true)).apply(document, TextEdit.NONE);
 			String content= document.get(position.getStartPosition(), position.getLength());
 			String[] lines= Strings.convertIntoLines(content);
-			Strings.trimIndentation(lines, method.getJavaProject(), false);
+			Strings.trimIndentation(lines, method.getCompilationUnit(), false);
 			content= Strings.concatenate(lines, StubUtility.getLineDelimiterUsed(method));
 			newMethod.setBody((Block) targetRewrite.createStringPlaceholder(content, ASTNode.BLOCK));
-		} catch (MalformedTreeException exception) {
-			JavaPlugin.log(exception);
-		} catch (BadLocationException exception) {
+		} catch (MalformedTreeException | BadLocationException exception) {
 			JavaPlugin.log(exception);
 		}
 	}
@@ -732,13 +837,17 @@ public final class PushDownRefactoringProcessor extends HierarchyProcessor {
 					}
 					final IMember[] members= getAbstractMembers(getAbstractDestinations(new SubProgressMonitor(monitor, 1)));
 					final IType[] classes= new IType[members.length];
-					for (int offset= 0; offset < members.length; offset++)
+					for (int offset= 0; offset < members.length; offset++) {
 						classes[offset]= (IType) members[offset];
+					}
 					copyMembers(adjustors, adjustments, rewrites, status, getAbstractMemberInfos(), classes, sourceRewriter, rewrite, sub);
 					copyMembers(adjustors, adjustments, rewrites, status, getAffectedMemberInfos(), getAbstractDestinations(new SubProgressMonitor(monitor, 1)), sourceRewriter, rewrite, sub);
-					if (monitor.isCanceled())
+					if (monitor.isCanceled()) {
 						throw new OperationCanceledException();
+					}
 				}
+				removeOverrideAnnotation(rewrites);
+
 			} finally {
 				sub.done();
 			}
@@ -747,9 +856,9 @@ public final class PushDownRefactoringProcessor extends HierarchyProcessor {
 				adjustor.rewriteVisibility(new SubProgressMonitor(monitor, 1));
 			}
 			final TextEditBasedChangeManager manager= new TextEditBasedChangeManager();
-			for (final Iterator<ICompilationUnit> iterator= rewrites.keySet().iterator(); iterator.hasNext();) {
-				ICompilationUnit unit= iterator.next();
-				rewrite= rewrites.get(unit);
+			for (Map.Entry<ICompilationUnit, CompilationUnitRewrite> entry : rewrites.entrySet()) {
+				ICompilationUnit unit= entry.getKey();
+				rewrite= entry.getValue();
 				if (rewrite != null)
 					manager.manage(unit, rewrite.createChange(true));
 			}
@@ -759,6 +868,39 @@ public final class PushDownRefactoringProcessor extends HierarchyProcessor {
 		}
 	}
 
+	/*
+	 * Check if target method in subclass has '@Override' annotation, and if so removes it.
+	 */
+	private void removeOverrideAnnotation(Map<ICompilationUnit, CompilationUnitRewrite> rewrites) throws JavaModelException {
+		IType[] subclasses= fCachedClassHierarchy.getSubclasses(fCachedDeclaringType);
+
+		for (IMember memberActionInfo : fMembersToMove) {
+			if (memberActionInfo.getElementType() != IJavaElement.METHOD) {
+				continue;
+			}
+			IMethod method= (IMethod) memberActionInfo;
+			nextClass: for (IType iType : subclasses) {
+				for (IMethod iMethod : iType.getMethods()) {
+					if (iMethod.isSimilar(method)) {
+						CompilationUnitRewrite rewrite= getCompilationUnitRewrite(rewrites, iType.getCompilationUnit());
+						MethodDeclaration methodDeclarationNode= ASTNodeSearchUtil.getMethodDeclarationNode(iMethod, rewrite.getRoot());
+						if (methodDeclarationNode == null) {
+							continue;
+						}
+						ListRewrite listRewrite= rewrite.getASTRewrite().getListRewrite(methodDeclarationNode, MethodDeclaration.MODIFIERS2_PROPERTY);
+						for (IExtendedModifier iExtendedModifier : (List<IExtendedModifier>) methodDeclarationNode.modifiers()) {
+							if (iExtendedModifier.isAnnotation() &&
+									"Override".equals(((Annotation) iExtendedModifier).getTypeName().getFullyQualifiedName())) { //$NON-NLS-1$
+								listRewrite.remove((Annotation) iExtendedModifier, null);
+								continue nextClass; // resume checking with next target class
+							}
+						}
+					}
+				}
+			}
+		}
+	}
+
 	private FieldDeclaration createNewFieldDeclarationNode(MemberActionInfo info, CompilationUnit declaringCuNode, TypeVariableMaplet[] mapping, ASTRewrite rewrite, VariableDeclarationFragment oldFieldFragment) throws JavaModelException {
 		Assert.isTrue(info.isFieldInfo());
 		IField field= (IField) info.getMember();
@@ -804,7 +946,7 @@ public final class PushDownRefactoringProcessor extends HierarchyProcessor {
 		if (info.copyJavadocToCopiesInSubclasses())
 			copyJavadocNode(rewrite, oldMethod, newMethod);
 		final IJavaProject project= rewriter.getCu().getJavaProject();
-		if (info.isNewMethodToBeDeclaredAbstract() && JavaModelUtil.is50OrHigher(project) && JavaPreferencesSettings.getCodeGenerationSettings(project).overrideAnnotation) {
+		if (info.isNewMethodToBeDeclaredAbstract() && JavaModelUtil.is50OrHigher(project) && JavaPreferencesSettings.getCodeGenerationSettings(rewriter.getCu()).overrideAnnotation) {
 			final MarkerAnnotation annotation= ast.newMarkerAnnotation();
 			annotation.setTypeName(ast.newSimpleName("Override")); //$NON-NLS-1$
 			newMethod.modifiers().add(annotation);
