@@ -71,6 +71,7 @@ import org.eclipse.jdt.core.dom.ITypeBinding;
 import org.eclipse.jdt.core.dom.IVariableBinding;
 import org.eclipse.jdt.core.dom.MethodDeclaration;
 import org.eclipse.jdt.core.dom.NodeFinder;
+import org.eclipse.jdt.core.dom.ParameterizedType;
 import org.eclipse.jdt.core.dom.QualifiedName;
 import org.eclipse.jdt.core.dom.SimpleName;
 import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
@@ -297,9 +298,7 @@ public abstract class SuperTypeRefactoringProcessor extends RefactoringProcessor
 			final TextEdit edit= targetRewrite.rewriteAST(document, subType.getJavaProject().getOptions(true));
 			try {
 				edit.apply(document, TextEdit.UPDATE_REGIONS);
-			} catch (MalformedTreeException exception) {
-				JavaPlugin.log(exception);
-			} catch (BadLocationException exception) {
+			} catch (MalformedTreeException | BadLocationException exception) {
 				JavaPlugin.log(exception);
 			}
 			buffer.setLength(0);
@@ -327,9 +326,7 @@ public abstract class SuperTypeRefactoringProcessor extends RefactoringProcessor
 			monitor.beginTask("", 100); //$NON-NLS-1$
 			monitor.setTaskName(RefactoringCoreMessages.ExtractInterfaceProcessor_creating);
 			final ImportRewrite rewrite= StubUtility.createImportRewrite(unit, true);
-			ITypeBinding type= null;
-			for (final Iterator<ITypeBinding> iterator= fTypeBindings.iterator(); iterator.hasNext();) {
-				type= iterator.next();
+			for (ITypeBinding type : fTypeBindings) {
 				if (type.isTypeVariable()) {
 					for (ITypeBinding bound : type.getTypeBounds()) {
 						rewrite.addImport(bound);
@@ -337,19 +334,13 @@ public abstract class SuperTypeRefactoringProcessor extends RefactoringProcessor
 				}
 				rewrite.addImport(type);
 			}
-			IBinding binding= null;
-			for (final Iterator<IBinding> iterator= fStaticBindings.iterator(); iterator.hasNext();) {
-				binding= iterator.next();
+			for (IBinding binding : fStaticBindings) {
 				rewrite.addStaticImport(binding);
 			}
 			final IDocument document= new Document();
 			try {
 				rewrite.rewriteImports(new SubProgressMonitor(monitor, 100)).apply(document);
-			} catch (MalformedTreeException exception) {
-				JavaPlugin.log(exception);
-			} catch (BadLocationException exception) {
-				JavaPlugin.log(exception);
-			} catch (CoreException exception) {
+			} catch (MalformedTreeException | BadLocationException | CoreException exception) {
 				JavaPlugin.log(exception);
 			}
 			fTypeBindings.clear();
@@ -377,11 +368,9 @@ public abstract class SuperTypeRefactoringProcessor extends RefactoringProcessor
 		Assert.isNotNull(sourceDeclaration);
 		Assert.isNotNull(targetDeclaration);
 		if (sourceDeclaration instanceof TypeDeclaration) {
-			TypeParameter parameter= null;
 			final ListRewrite rewrite= targetRewrite.getListRewrite(targetDeclaration, TypeDeclaration.TYPE_PARAMETERS_PROPERTY);
-			for (final Iterator<TypeParameter> iterator= ((TypeDeclaration) sourceDeclaration).typeParameters().iterator(); iterator.hasNext();) {
-				parameter= iterator.next();
-				rewrite.insertLast(ASTNode.copySubtree(targetRewrite.getAST(), parameter), null);
+			for (Object parameter : ((TypeDeclaration) sourceDeclaration).typeParameters()) {
+				rewrite.insertLast(ASTNode.copySubtree(targetRewrite.getAST(), (TypeParameter) parameter), null);
 				ImportRewriteUtil.collectImports(subType.getJavaProject(), sourceDeclaration, fTypeBindings, fStaticBindings, false);
 			}
 		}
@@ -448,10 +437,7 @@ public abstract class SuperTypeRefactoringProcessor extends RefactoringProcessor
 			if (edit != null) {
 				try {
 					edit.apply(document, TextEdit.UPDATE_REGIONS);
-				} catch (MalformedTreeException exception) {
-					JavaPlugin.log(exception);
-					status.merge(RefactoringStatus.createFatalErrorStatus(RefactoringCoreMessages.ExtractInterfaceProcessor_internal_error));
-				} catch (BadLocationException exception) {
+				} catch (MalformedTreeException | BadLocationException exception) {
 					JavaPlugin.log(exception);
 					status.merge(RefactoringStatus.createFatalErrorStatus(RefactoringCoreMessages.ExtractInterfaceProcessor_internal_error));
 				}
@@ -543,9 +529,7 @@ public abstract class SuperTypeRefactoringProcessor extends RefactoringProcessor
 		for (ASTNode node : nodes) {
 			IJavaProject project= RefactoringASTParser.getCompilationUnit(node).getJavaProject();
 			if (project != null) {
-				final List<IField> fields= getReferencingFields(node, project);
-				for (int offset= 0; offset < fields.size(); offset++) {
-					IField field= fields.get(offset);
+				for (IField field : getReferencingFields(node, project)) {
 					Set<ICompilationUnit> set= units.get(project);
 					if (set == null) {
 						set= new HashSet<>();
@@ -613,7 +597,11 @@ public abstract class SuperTypeRefactoringProcessor extends RefactoringProcessor
 			engine.setFiltering(true, true);
 			engine.setStatus(status);
 			engine.setScope(RefactoringScopeFactory.create(type));
-			engine.setPattern(SearchPattern.createPattern(type, IJavaSearchConstants.REFERENCES, SearchUtils.GENERICS_AGNOSTIC_MATCH_RULE));
+			SearchPattern pattern= SearchPattern.createPattern(type, IJavaSearchConstants.REFERENCES, SearchUtils.GENERICS_AGNOSTIC_MATCH_RULE);
+			if (pattern == null) {
+				return Map.of();
+			}
+			engine.setPattern(pattern);
 			engine.searchPattern(new SubProgressMonitor(monitor, 100));
 			@SuppressWarnings("unchecked")
 			Map<IJavaProject, Set<SearchResultGroup>> result= (Map<IJavaProject, Set<SearchResultGroup>>) engine.getAffectedProjects();
@@ -641,9 +629,7 @@ public abstract class SuperTypeRefactoringProcessor extends RefactoringProcessor
 			if (parent instanceof FieldDeclaration) {
 				final List<VariableDeclarationFragment> fragments= ((FieldDeclaration) parent).fragments();
 				result= new ArrayList<>(fragments.size());
-				VariableDeclarationFragment fragment= null;
-				for (final Iterator<VariableDeclarationFragment> iterator= fragments.iterator(); iterator.hasNext();) {
-					fragment= iterator.next();
+				for (VariableDeclarationFragment fragment : fragments) {
 					final IField field= getCorrespondingField(fragment);
 					if (field != null)
 						result.add(field);
@@ -832,10 +818,9 @@ public abstract class SuperTypeRefactoringProcessor extends RefactoringProcessor
 	 *            the text edit group to use
 	 */
 	protected final void rewriteTypeOccurrence(final CompilationUnitRange range, final TType estimate, final ASTRequestor requestor, final CompilationUnitRewrite rewrite, final CompilationUnit copy, final Set<String> replacements, final TextEditGroup group) {
-		ASTNode node= null;
 		IBinding binding= null;
 		final CompilationUnit target= rewrite.getRoot();
-		node= NodeFinder.perform(copy, range.getSourceRange());
+		ASTNode node= NodeFinder.perform(copy, range.getSourceRange());
 		if (node != null) {
 			node= ASTNodes.getNormalizedNode(node).getParent();
 			if (node instanceof VariableDeclaration) {
@@ -869,8 +854,22 @@ public abstract class SuperTypeRefactoringProcessor extends RefactoringProcessor
 				}
 			} else if (node instanceof ArrayType) {
 				final ASTNode type= node;
-				while (node != null && !(node instanceof MethodDeclaration) && !(node instanceof VariableDeclarationFragment))
+				FieldDeclaration fieldDeclaration= ASTNodes.getParent(node, FieldDeclaration.class);
+				if (fieldDeclaration != null) {
+					binding= ((VariableDeclaration) fieldDeclaration.fragments().get(0)).resolveBinding();
+					node= target.findDeclaringNode(binding.getKey());
+					fieldDeclaration= ASTNodes.getParent(node, FieldDeclaration.class);
+					Type elementType= ((ArrayType) fieldDeclaration.getType()).getElementType();
+					ASTNode changeNode= NodeFinder.perform(target, elementType.getStartPosition(), elementType.getLength());
+					if (changeNode instanceof SimpleName || changeNode instanceof ParameterizedType) {
+						rewriteTypeOccurrence(estimate, rewrite, changeNode, group);
+					}
+					return;
+				}
+
+				while (node != null && !(node instanceof MethodDeclaration) && !(node instanceof VariableDeclarationFragment)) {
 					node= node.getParent();
+				}
 				if (node != null) {
 					final int delta= node.getStartPosition() + node.getLength() - type.getStartPosition();
 					if (node instanceof MethodDeclaration)
@@ -1000,9 +999,7 @@ public abstract class SuperTypeRefactoringProcessor extends RefactoringProcessor
 				final Map<IJavaProject, Collection<ICompilationUnit>> projects= new HashMap<>();
 				Collection<ICompilationUnit> collection= null;
 				IJavaProject project= null;
-				ICompilationUnit current= null;
-				for (final Iterator<ICompilationUnit> iterator= units.iterator(); iterator.hasNext();) {
-					current= iterator.next();
+				for (ICompilationUnit current : units) {
 					project= current.getJavaProject();
 					collection= projects.get(project);
 					if (collection == null) {
@@ -1231,8 +1228,7 @@ public abstract class SuperTypeRefactoringProcessor extends RefactoringProcessor
 					for (IJavaProject project : keySet) {
 						if (level == 3 && !JavaModelUtil.is50OrHigher(project))
 							level= 2;
-						Collection<ICompilationUnit> cuCollection= null;
-						cuCollection= secondPass.get(project);
+						Collection<ICompilationUnit> cuCollection= secondPass.get(project);
 						if (cuCollection != null) {
 							parser.setWorkingCopyOwner(fOwner);
 							parser.setResolveBindings(true);
