@@ -18,8 +18,6 @@ import java.util.Map;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.StyledText;
-import org.eclipse.swt.events.DisposeEvent;
-import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.RGB;
@@ -76,12 +74,7 @@ public final class CreateTextFileChangePreviewViewer implements IChangePreviewVi
 
 		public CreateTextFilePreviewer(Composite parent, int style) {
 			super(parent, style);
-			addDisposeListener(new DisposeListener() {
-				@Override
-				public void widgetDisposed(DisposeEvent e) {
-					disposeImage();
-				}
-			});
+			addDisposeListener(e -> disposeImage());
 		}
 
 		/*package*/ void disposeImage() {
@@ -127,11 +120,6 @@ public final class CreateTextFileChangePreviewViewer implements IChangePreviewVi
 
 		@Override
 		protected void handleDispose() {
-			for (Color color : customColors.values()) {
-				if (color != null) {
-					color.dispose();
-				}
-			}
 			customColors.clear();
 			super.handleDispose();
 		}
@@ -178,10 +166,7 @@ public final class CreateTextFileChangePreviewViewer implements IChangePreviewVi
 				default:
 					return;
 			}
-			Color oldColor= customColors.remove(key);
-			if (oldColor != null) {
-				oldColor.dispose();
-			}
+			customColors.remove(key);
 			customColors.put(key, newColor);
 		}
 
@@ -256,15 +241,23 @@ public final class CreateTextFileChangePreviewViewer implements IChangePreviewVi
 		String textType= textFileChange.getTextType();
 		JavaTextTools textTools= JavaPlugin.getDefault().getJavaTextTools();
 		IPreferenceStore store= JavaPlugin.getDefault().getCombinedPreferenceStore();
-		if ("java".equals(textType)) { //$NON-NLS-1$
+		boolean nomatch= false;
+		if (textType != null) switch (textType) {
+		case "java": //$NON-NLS-1$
 			textTools.setupJavaDocumentPartitioner(document);
 			fSourceViewer.configure(new JavaSourceViewerConfiguration(textTools.getColorManager(), store, null, null));
 			fSourceViewer.getTextWidget().setOrientation(SWT.LEFT_TO_RIGHT);
-		} else if ("properties".equals(textType)) { //$NON-NLS-1$
+			break;
+		case "properties": //$NON-NLS-1$
 			PropertiesFileDocumentSetupParticipant.setupDocument(document);
 			fSourceViewer.configure(new PropertiesFileSourceViewerConfiguration(textTools.getColorManager(), store, null, IPropertiesFilePartitions.PROPERTIES_FILE_PARTITIONING));
 			fSourceViewer.getTextWidget().setOrientation(SWT.LEFT_TO_RIGHT);
-		} else {
+			break;
+		default:
+			nomatch= true;
+			break;
+		}
+		if (nomatch) {
 			fSourceViewer.configure(new SourceViewerConfiguration());
 			fSourceViewer.getTextWidget().setOrientation(fSourceViewer.getTextWidget().getParent().getOrientation());
 		}
