@@ -17,7 +17,6 @@ import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 
@@ -45,21 +44,15 @@ import org.eclipse.jface.layout.PixelConverter;
 import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.jface.viewers.ArrayContentProvider;
 import org.eclipse.jface.viewers.CellEditor;
-import org.eclipse.jface.viewers.CheckStateChangedEvent;
 import org.eclipse.jface.viewers.CheckboxTableViewer;
 import org.eclipse.jface.viewers.ColumnWeightData;
 import org.eclipse.jface.viewers.ComboBoxCellEditor;
-import org.eclipse.jface.viewers.DoubleClickEvent;
 import org.eclipse.jface.viewers.ICellModifier;
-import org.eclipse.jface.viewers.ICheckStateListener;
-import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.ILabelProvider;
 import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.ITableLabelProvider;
 import org.eclipse.jface.viewers.LabelProvider;
-import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.jface.viewers.TableLayout;
 import org.eclipse.jface.window.Window;
@@ -119,7 +112,7 @@ public class PullUpMemberPage extends UserInputWizardPage {
 		public void modify(final Object element, final String property, final Object value) {
 			if (!ACTION_PROPERTY.equals(property))
 				return;
-			final int action= ((Integer) value).intValue();
+			final int action= ((Integer) value);
 			MemberActionInfo info;
 			if (element instanceof Item) {
 				info= (MemberActionInfo) ((Item) element).getData();
@@ -298,7 +291,7 @@ public class PullUpMemberPage extends UserInputWizardPage {
 	}
 
 	private static void putToStringMapping(final Map<String, Integer> result, final String[] actionLabels, final int actionIndex) {
-		result.put(actionLabels[actionIndex], Integer.valueOf(actionIndex));
+		result.put(actionLabels[actionIndex], actionIndex);
 	}
 
 	private static void setActionForInfos(final MemberActionInfo[] infos, final int action) {
@@ -571,33 +564,17 @@ public class PullUpMemberPage extends UserInputWizardPage {
 		fTableViewer.setUseHashlookup(true);
 		fTableViewer.setContentProvider(ArrayContentProvider.getInstance());
 		fTableViewer.setLabelProvider(new MemberActionInfoLabelProvider());
-		fTableViewer.addSelectionChangedListener(new ISelectionChangedListener() {
-
-			@Override
-			public void selectionChanged(final SelectionChangedEvent event) {
-				updateButtonEnablement(event.getSelection());
-			}
-		});
-		fTableViewer.addCheckStateListener(new ICheckStateListener() {
-
-			@Override
-			public void checkStateChanged(final CheckStateChangedEvent event) {
-				final boolean checked= event.getChecked();
-				final MemberActionInfo info= (MemberActionInfo) event.getElement();
-				if (checked)
-					info.setAction(PULL_UP_ACTION);
-				else
-					info.setAction(MemberActionInfo.NO_ACTION);
-				updateWizardPage(null, true);
-			}
-		});
-		fTableViewer.addDoubleClickListener(new IDoubleClickListener() {
-
-			@Override
-			public void doubleClick(final DoubleClickEvent event) {
-				editSelectedMembers();
-			}
+		fTableViewer.addSelectionChangedListener(event -> updateButtonEnablement(event.getSelection()));
+		fTableViewer.addCheckStateListener(event -> {
+			final boolean checked= event.getChecked();
+			final MemberActionInfo info= (MemberActionInfo) event.getElement();
+			if (checked)
+				info.setAction(PULL_UP_ACTION);
+			else
+				info.setAction(MemberActionInfo.NO_ACTION);
+			updateWizardPage(null, true);
 		});
+		fTableViewer.addDoubleClickListener(event -> editSelectedMembers());
 
 		setTableInput();
 		checkPullUp(fProcessor.getMembersToMove(), false);
@@ -690,16 +667,13 @@ public class PullUpMemberPage extends UserInputWizardPage {
 
 	protected void createSuperTypeControl(final Composite parent) {
 		try {
-			PlatformUI.getWorkbench().getActiveWorkbenchWindow().run(true, false, new IRunnableWithProgress() {
-				@Override
-				public void run(final IProgressMonitor monitor) throws InvocationTargetException {
-					try {
-						fCandidateTypes= fProcessor.getCandidateTypes(new RefactoringStatus(), monitor);
-					} catch (JavaModelException exception) {
-						throw new InvocationTargetException(exception);
-					} finally {
-						monitor.done();
-					}
+			PlatformUI.getWorkbench().getActiveWorkbenchWindow().run(true, false, monitor -> {
+				try {
+					fCandidateTypes= fProcessor.getCandidateTypes(new RefactoringStatus(), monitor);
+				} catch (JavaModelException exception) {
+					throw new InvocationTargetException(exception);
+				} finally {
+					monitor.done();
 				}
 			});
 			createSuperTypeCombo(parent);
@@ -731,14 +705,14 @@ public class PullUpMemberPage extends UserInputWizardPage {
 							JavaElementLabels.M_PARAMETER_TYPES))
 					: Messages.format(RefactoringMessages.PullUpInputPage1_Mark_selected_members_plural, String.valueOf(selectedMembers.length));
 			final Map<String, Integer> stringMapping= createStringMappingForSelectedMembers();
-			final String[] keys= stringMapping.keySet().toArray(new String[stringMapping.keySet().size()]);
+			final String[] keys= stringMapping.keySet().toArray(new String[stringMapping.size()]);
 			Arrays.sort(keys);
 			final int initialSelectionIndex= getInitialSelectionIndexForEditDialog(stringMapping, keys);
 			final ComboSelectionDialog dialog= new ComboSelectionDialog(getShell(), shellTitle, labelText, keys, initialSelectionIndex);
 			dialog.setBlockOnOpen(true);
 			if (dialog.open() == Window.CANCEL)
 				return;
-			final int action= stringMapping.get(dialog.getSelectedString()).intValue();
+			final int action= stringMapping.get(dialog.getSelectedString());
 			setActionForInfos(selectedMembers, action);
 		} finally {
 			updateWizardPage(preserved, true);
@@ -794,9 +768,9 @@ public class PullUpMemberPage extends UserInputWizardPage {
 		final int commonActionCode= getCommonActionCodeForSelectedInfos();
 		if (commonActionCode == -1)
 			return 0;
-		for (final Iterator<String> iter= stringMapping.keySet().iterator(); iter.hasNext();) {
-			final String key= iter.next();
-			final int action= stringMapping.get(key).intValue();
+		for (Map.Entry<String, Integer> entry : stringMapping.entrySet()) {
+			String key = entry.getKey();
+			final int action= entry.getValue();
 			if (commonActionCode == action) {
 				for (int i= 0; i < keys.length; i++) {
 					if (key.equals(keys[i]))
@@ -961,22 +935,18 @@ public class PullUpMemberPage extends UserInputWizardPage {
 		final ComboBoxCellEditor editor= new ComboBoxCellEditor();
 		editor.setStyle(SWT.READ_ONLY);
 		fTableViewer.setCellEditors(new CellEditor[] { null, editor});
-		fTableViewer.addSelectionChangedListener(new ISelectionChangedListener() {
-
-			@Override
-			public void selectionChanged(final SelectionChangedEvent event) {
-				if (editor.getControl() == null && !table.isDisposed())
-					editor.create(table);
-				final ISelection sel= event.getSelection();
-				if (!(sel instanceof IStructuredSelection))
-					return;
-				final IStructuredSelection structured= (IStructuredSelection) sel;
-				if (structured.size() != 1)
-					return;
-				final MemberActionInfo info= (MemberActionInfo) structured.getFirstElement();
-				editor.setItems(info.getAllowedLabels());
-				editor.setValue(Integer.valueOf(info.getAction()));
-			}
+		fTableViewer.addSelectionChangedListener(event -> {
+			if (editor.getControl() == null && !table.isDisposed())
+				editor.create(table);
+			final ISelection sel= event.getSelection();
+			if (!(sel instanceof IStructuredSelection))
+				return;
+			final IStructuredSelection structured= (IStructuredSelection) sel;
+			if (structured.size() != 1)
+				return;
+			final MemberActionInfo info= (MemberActionInfo) structured.getFirstElement();
+			editor.setItems(info.getAllowedLabels());
+			editor.setValue(Integer.valueOf(info.getAction()));
 		});
 
 		final ICellModifier cellModifier= new MemberActionCellModifier();
