@@ -16,7 +16,6 @@ package org.eclipse.jdt.internal.ui.refactoring;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 
@@ -34,10 +33,8 @@ import org.eclipse.swt.widgets.TreeItem;
 import org.eclipse.jface.dialogs.Dialog;
 import org.eclipse.jface.dialogs.IDialogSettings;
 import org.eclipse.jface.dialogs.IMessageProvider;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.ITreeContentProvider;
-import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.jface.viewers.TreeViewer;
 import org.eclipse.jface.viewers.Viewer;
 import org.eclipse.jface.viewers.ViewerComparator;
@@ -81,7 +78,7 @@ public class UseSupertypeWizard extends RefactoringWizard{
 
 	private static class UseSupertypeInputPage extends UserInputWizardPage{
 
-		private class UseSupertypeContentProvider implements ITreeContentProvider {
+		private static class UseSupertypeContentProvider implements ITreeContentProvider {
 
 			private ITypeHierarchy fHierarchy;
 
@@ -238,19 +235,16 @@ public class UseSupertypeWizard extends RefactoringWizard{
 					return getComparator().compare(type1.getElementName(), type2.getElementName());
 				}
 			});
-			fTreeViewer.addSelectionChangedListener(new ISelectionChangedListener(){
-				@Override
-				public void selectionChanged(SelectionChangedEvent event) {
-					IStructuredSelection ss= (IStructuredSelection)event.getSelection();
-					if (Integer.valueOf(0).equals(fFileCount.get(ss.getFirstElement()))){
-						setMessage(RefactoringMessages.UseSupertypeInputPage_No_updates, IMessageProvider.INFORMATION);
-						setPageComplete(false);
-					} else {
-						setMessage(MESSAGE);
-						setPageComplete(true);
-					}
-					fTreeViewer.refresh();
+			fTreeViewer.addSelectionChangedListener(event -> {
+				IStructuredSelection ss= (IStructuredSelection)event.getSelection();
+				if (Integer.valueOf(0).equals(fFileCount.get(ss.getFirstElement()))){
+					setMessage(RefactoringMessages.UseSupertypeInputPage_No_updates, IMessageProvider.INFORMATION);
+					setPageComplete(false);
+				} else {
+					setMessage(MESSAGE);
+					setPageComplete(true);
 				}
+				fTreeViewer.refresh();
 			});
 			try {
 				fTreeViewer.setInput(SuperTypeHierarchyCache.getTypeHierarchy(getUseSupertypeProcessor().getSubType()));
@@ -274,7 +268,7 @@ public class UseSupertypeWizard extends RefactoringWizard{
 		private void updateUpdateLabels() {
 			IType selectedType= getSelectedSupertype();
 			final int count= getUseSupertypeProcessor().getChanges();
-			fFileCount.put(selectedType, Integer.valueOf(count));
+			fFileCount.put(selectedType, count);
 			if (count == 0) {
 				setMessage(RefactoringMessages.UseSupertypeInputPage_No_updates, IMessageProvider.INFORMATION);
 				setPageComplete(false);
@@ -292,8 +286,8 @@ public class UseSupertypeWizard extends RefactoringWizard{
 
 		private int countFilesWithValue(int i) {
 			int count= 0;
-			for (Iterator<IType> iter= fFileCount.keySet().iterator(); iter.hasNext();) {
-				if (fFileCount.get(iter.next()).intValue() == i)
+			for (Map.Entry<IType, Integer> entry : fFileCount.entrySet()) {
+				if (entry.getValue().intValue() == i)
 					count++;
 			}
 			return count;
@@ -341,7 +335,7 @@ public class UseSupertypeWizard extends RefactoringWizard{
 				String superText= super.getText(element);
 				if  (! fFileCount.containsKey(element))
 					return superText;
-				int count= fFileCount.get(element).intValue();
+				int count= fFileCount.get(element);
 				switch (count) {
 				case 0:
 				{
