@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2021 IBM Corporation and others.
+ * Copyright (c) 2005, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,12 +10,16 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Nikolay Metchev <nikolaymetchev@gmail.com> - [rename] https://bugs.eclipse.org/99622
  *******************************************************************************/
 package org.eclipse.jdt.internal.ui.refactoring.reorg;
 
 import java.lang.reflect.InvocationTargetException;
-import java.util.Arrays;
+import java.util.ArrayList;
 import java.util.Comparator;
+import java.util.List;
+import java.util.Set;
+import java.util.TreeSet;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.StyledText;
@@ -37,6 +41,7 @@ import org.eclipse.core.commands.operations.OperationHistoryFactory;
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.core.runtime.Status;
 
 import org.eclipse.jface.dialogs.IDialogSettings;
@@ -71,6 +76,9 @@ import org.eclipse.jdt.core.IMethod;
 import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.dom.ASTNode;
 import org.eclipse.jdt.core.dom.CompilationUnit;
+import org.eclipse.jdt.core.dom.IBinding;
+import org.eclipse.jdt.core.dom.IMethodBinding;
+import org.eclipse.jdt.core.dom.Name;
 import org.eclipse.jdt.core.dom.NodeFinder;
 import org.eclipse.jdt.core.dom.SimpleName;
 import org.eclipse.jdt.core.manipulation.SharedASTProviderCore;
@@ -79,6 +87,7 @@ import org.eclipse.jdt.core.refactoring.descriptors.RenameJavaElementDescriptor;
 
 import org.eclipse.jdt.internal.corext.dom.LinkedNodeFinder;
 import org.eclipse.jdt.internal.corext.refactoring.rename.RenamingNameSuggestor;
+import org.eclipse.jdt.internal.corext.refactoring.rename.RippleMethodFinder2;
 import org.eclipse.jdt.internal.corext.util.JavaConventionsUtil;
 import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 
@@ -212,10 +221,28 @@ public class RenameLinkedMode {
 
 			fLinkedPositionGroup= new LinkedPositionGroup();
 			ASTNode selectedNode= NodeFinder.perform(root, fOriginalSelection.x, fOriginalSelection.y);
-			if (! (selectedNode instanceof SimpleName)) {
+
+			final int pos;
+			Name nameNode= null;
+			if (! (selectedNode instanceof Name)) {
 				return; // TODO: show dialog
+			} else if (this.fJavaElement != null &&
+					this.fJavaElement.getElementType() ==  IJavaElement.JAVA_MODULE) {
+				nameNode = (Name) selectedNode;
+				ASTNode parent = nameNode.getParent();
+				while(parent instanceof Name) {
+					nameNode = (Name) parent;
+					parent = nameNode.getParent();
+				}
+				fOriginalName= nameNode.getFullyQualifiedName();
+				pos= nameNode.getStartPosition();
+			} else if (! (selectedNode instanceof SimpleName)) {
+				return; // TODO: show dialog
+			} else {
+				nameNode = (SimpleName)selectedNode;
+				fOriginalName = ((SimpleName)nameNode).getIdentifier();
+				pos = nameNode.getStartPosition();
 			}
-			SimpleName nameNode= (SimpleName) selectedNode;
 
 			if (viewer instanceof ITextViewerExtension6) {
 				IUndoManager undoManager= ((ITextViewerExtension6)viewer).getUndoManager();
@@ -227,13 +254,7 @@ public class RenameLinkedMode {
 				}
 			}
 
-			fOriginalName= nameNode.getIdentifier();
-			final int pos= nameNode.getStartPosition();
-			ASTNode[] sameNodes= LinkedNodeFinder.findByNode(root, nameNode);
-
-			//TODO: copied from LinkedNamesAssistProposal#apply(..):
-			// sort for iteration order, starting with the node @ offset
-			Arrays.sort(sameNodes, new Comparator<ASTNode>() {
+			Set<ASTNode> sameNodes= new TreeSet<>(new Comparator<ASTNode>() {
 				@Override
 				public int compare(ASTNode o1, ASTNode o2) {
 					return rank(o1) - rank(o2);
@@ -253,12 +274,37 @@ public class RenameLinkedMode {
 						return relativeRank;
 				}
 			});
-			for (int i= 0; i < sameNodes.length; i++) {
-				ASTNode elem= sameNodes[i];
+			List<ASTNode> nodes= new ArrayList<>();
+			nodes.add(nameNode);
+			IBinding resolvedNameNode= nameNode.resolveBinding();
+			if (resolvedNameNode != null && resolvedNameNode instanceof IMethodBinding) {
+				IJavaElement javaElement= resolvedNameNode.getJavaElement();
+				if (javaElement instanceof IMethod) {
+					IMethod[] relatedMethods= RippleMethodFinder2.getRelatedMethodsInCompilationUnit((IMethod) javaElement, new NullProgressMonitor(), null);
+					for (IMethod iMethod : relatedMethods) {
+						ASTNode n= NodeFinder.perform(root, iMethod.getNameRange());
+						if (n != null) {
+							nodes.add(n);
+						}
+					}
+				}
+			}
+			for (ASTNode astNode : nodes) {
+				if (astNode instanceof SimpleName) {
+					for (SimpleName sameNode : LinkedNodeFinder.findByNode(root, (SimpleName) astNode)) {
+						sameNodes.add(sameNode);
+					}
+				}
+			}
+			//TODO: copied from LinkedNamesAssistProposal#apply(..):
+			// sort for iteration order, starting with the node @ offset
+			int i=0;
+			for (ASTNode elem : sameNodes) {
 				LinkedPosition linkedPosition= new LinkedPosition(document, elem.getStartPosition(), elem.getLength(), i);
 				if (i == 0)
 					fNamePosition= linkedPosition;
 				fLinkedPositionGroup.addPosition(linkedPosition);
+				i++;
 			}
 
 			fLinkedModeModel= new LinkedModeModel();
@@ -283,7 +329,7 @@ public class RenameLinkedMode {
 //			startAnimation();
 			fgActiveLinkedMode= this;
 
-		} catch (BadLocationException e) {
+		} catch (BadLocationException | CoreException e) {
 			JavaPlugin.log(e);
 		}
 	}
