@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,12 +14,15 @@
 package org.eclipse.jdt.internal.ui;
 
 import java.io.IOException;
+import java.util.Arrays;
 import java.util.HashSet;
 import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.LinkedHashMap;
+import java.util.LinkedHashSet;
 import java.util.Set;
 import java.util.StringTokenizer;
+import java.util.stream.Collectors;
 
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
@@ -57,7 +60,6 @@ import org.eclipse.jface.dialogs.IDialogSettings;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.resource.ImageRegistry;
 import org.eclipse.jface.util.IPropertyChangeListener;
-import org.eclipse.jface.util.PropertyChangeEvent;
 
 import org.eclipse.jface.text.templates.ContextTypeRegistry;
 import org.eclipse.jface.text.templates.TemplateContextType;
@@ -139,7 +141,6 @@ import org.eclipse.jdt.internal.ui.workingsets.WorkingSetMessages;
  */
 public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener {
 
-
 	/**
 	 * The view id for the workbench's Resource Navigator standard component.
 	 * @since 3.6
@@ -162,8 +163,6 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 
 	public static boolean DEBUG_BREADCRUMB_ITEM_DROP_DOWN;
 
-	public static boolean DEBUG_TYPE_CONSTRAINTS;
-
 	public static boolean DEBUG_RESULT_COLLECTOR;
 
 	private static JavaPlugin fgJavaPlugin;
@@ -180,7 +179,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * The template context type registry for the java editor.
 	 * @since 3.0
 	 */
-	private ContextTypeRegistry fContextTypeRegistry;
+	private volatile ContextTypeRegistry fContextTypeRegistry;
 	/**
 	 * The code template context type registry for the java editor.
 	 * @since 3.0
@@ -191,7 +190,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * The template store for the java editor.
 	 * @since 3.0
 	 */
-	private TemplateStore fTemplateStore;
+	private volatile TemplateStore fTemplateStore;
 	/**
 	 * The coded template store for the java editor.
 	 * @since 3.0
@@ -202,33 +201,35 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * Default instance of the appearance type filters.
 	 * @since 3.0
 	 */
-	private TypeFilter fTypeFilter;
+	private volatile TypeFilter fTypeFilter;
 
 
-	private WorkingCopyManager fWorkingCopyManager;
+	private volatile WorkingCopyManager fWorkingCopyManager;
 
 	private static final String CODE_ASSIST_MIGRATED= "code_assist_migrated"; //$NON-NLS-1$
 
+	private static final String TYPEFILTER_MIGRATED= "typefilter_migrated_2"; //$NON-NLS-1$
+
 	/**
 	 * @deprecated to avoid deprecation warning
 	 */
 	@Deprecated
 	private org.eclipse.jdt.core.IBufferFactory fBufferFactory;
-	private ICompilationUnitDocumentProvider fCompilationUnitDocumentProvider;
-	private ClassFileDocumentProvider fClassFileDocumentProvider;
-	private JavaTextTools fJavaTextTools;
-	private ProblemMarkerManager fProblemMarkerManager;
-	private ImageDescriptorRegistry fImageDescriptorRegistry;
+	private volatile ICompilationUnitDocumentProvider fCompilationUnitDocumentProvider;
+	private volatile ClassFileDocumentProvider fClassFileDocumentProvider;
+	private volatile JavaTextTools fJavaTextTools;
+	private volatile ProblemMarkerManager fProblemMarkerManager;
+	private volatile ImageDescriptorRegistry fImageDescriptorRegistry;
 
-	private MembersOrderPreferenceCache fMembersOrderPreferenceCache;
+	private volatile MembersOrderPreferenceCache fMembersOrderPreferenceCache;
 
-	private JavaEditorTextHoverDescriptor[] fJavaEditorTextHoverDescriptors;
+	private volatile JavaEditorTextHoverDescriptor[] fJavaEditorTextHoverDescriptors;
 
 	/**
 	 * The AST provider.
 	 * @since 3.0
 	 */
-	private ASTProvider fASTProvider;
+	private volatile ASTProvider fASTProvider;
 
 	/**
 	 * The combined preference store.
@@ -242,13 +243,13 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 *
 	 * @since 3.0
 	 */
-	private JavaFoldingStructureProviderRegistry fFoldingStructureProviderRegistry;
+	private volatile JavaFoldingStructureProviderRegistry fFoldingStructureProviderRegistry;
 
 	/**
 	 * The shared Java properties file document provider.
 	 * @since 3.1
 	 */
-	private IDocumentProvider fPropertiesFileDocumentProvider;
+	private volatile IDocumentProvider fPropertiesFileDocumentProvider;
 
 	/**
 	 * Content assist history.
@@ -260,23 +261,23 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * The save participant registry.
 	 * @since 3.3
 	 */
-	private SaveParticipantRegistry fSaveParticipantRegistry;
+	private volatile SaveParticipantRegistry fSaveParticipantRegistry;
 
 	/**
 	 * The clean up registry
 	 * @since 3.4
 	 */
-	private CleanUpRegistry fCleanUpRegistry;
+	private volatile CleanUpRegistry fCleanUpRegistry;
 
 	/**
 	 * The descriptors from the 'classpathAttributeConfiguration' extension point.
 	 * @since 3.3
 	 */
-	private ClasspathAttributeConfigurationDescriptors fClasspathAttributeConfigurationDescriptors;
+	private volatile ClasspathAttributeConfigurationDescriptors fClasspathAttributeConfigurationDescriptors;
 
 	private FormToolkit fDialogsFormToolkit;
 
-	private ImagesOnFileSystemRegistry fImagesOnFSRegistry;
+	private volatile ImagesOnFileSystemRegistry fImagesOnFSRegistry;
 
 	/**
 	 * Theme listener.
@@ -352,10 +353,10 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 		long now= System.currentTimeMillis();
 		boolean writeToLog= true;
 		if (fgRepeatedMessages.containsKey(message)) {
-			long last= fgRepeatedMessages.get(message).longValue();
+			long last= fgRepeatedMessages.get(message);
 			writeToLog= now - last > 5000;
 		}
-		fgRepeatedMessages.put(message, Long.valueOf(now));
+		fgRepeatedMessages.put(message, now);
 		if (writeToLog)
 			log(new Exception(message + detail).fillInStackTrace());
 	}
@@ -420,12 +421,9 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 			// Initialize AST provider
 			getASTProvider();
 
-			fThemeListener= new IPropertyChangeListener() {
-				@Override
-				public void propertyChange(PropertyChangeEvent event) {
-					if (IThemeManager.CHANGE_CURRENT_THEME.equals(event.getProperty()))
-						JavaUIPreferenceInitializer.setThemeBasedPreferences(PreferenceConstants.getPreferenceStore(), true);
-				}
+			fThemeListener= event -> {
+				if (IThemeManager.CHANGE_CURRENT_THEME.equals(event.getProperty()))
+					JavaUIPreferenceInitializer.setThemeBasedPreferences(PreferenceConstants.getPreferenceStore(), true);
 			};
 			PlatformUI.getWorkbench().getThemeManager().addPropertyChangeListener(fThemeListener);
 
@@ -438,6 +436,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 		JavaManipulation.setCodeTemplateStore(getCodeTemplateStore());
 		JavaManipulation.setCodeTemplateContextRegistry(getCodeTemplateContextRegistry());
 		disableNewCodeAssistCategoryPreferences();
+		setTypeFilterPreferences();
 	}
 
 	private void createOrUpdateWorkingSet(String name, String oldname, String label, final String id) {
@@ -586,10 +585,17 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 		return fBufferFactory;
 	}
 
-	public synchronized ICompilationUnitDocumentProvider getCompilationUnitDocumentProvider() {
-		if (fCompilationUnitDocumentProvider == null)
-			fCompilationUnitDocumentProvider= new CompilationUnitDocumentProvider();
-		return fCompilationUnitDocumentProvider;
+	public ICompilationUnitDocumentProvider getCompilationUnitDocumentProvider() {
+		ICompilationUnitDocumentProvider result= fCompilationUnitDocumentProvider;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fCompilationUnitDocumentProvider == null) { // Second check (with locking)
+				fCompilationUnitDocumentProvider= new CompilationUnitDocumentProvider();
+			}
+			return fCompilationUnitDocumentProvider;
+		}
 	}
 
 	/**
@@ -599,36 +605,70 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * @return the shared document provider for Java properties files
 	 * @since 3.1
 	 */
-	public synchronized IDocumentProvider getPropertiesFileDocumentProvider() {
-		if (fPropertiesFileDocumentProvider == null)
-			fPropertiesFileDocumentProvider= new PropertiesFileDocumentProvider();
-		return fPropertiesFileDocumentProvider;
-	}
-
-	public synchronized ClassFileDocumentProvider getClassFileDocumentProvider() {
-		if (fClassFileDocumentProvider == null)
-			fClassFileDocumentProvider= new ClassFileDocumentProvider();
-		return fClassFileDocumentProvider;
-	}
-
-	public synchronized WorkingCopyManager getWorkingCopyManager() {
-		if (fWorkingCopyManager == null) {
-			ICompilationUnitDocumentProvider provider= getCompilationUnitDocumentProvider();
-			fWorkingCopyManager= new WorkingCopyManager(provider);
+	public IDocumentProvider getPropertiesFileDocumentProvider() {
+		IDocumentProvider result= fPropertiesFileDocumentProvider;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fPropertiesFileDocumentProvider == null) { // Second check (with locking)
+				fPropertiesFileDocumentProvider= new PropertiesFileDocumentProvider();
+			}
+			return fPropertiesFileDocumentProvider;
 		}
-		return fWorkingCopyManager;
 	}
 
-	public synchronized ProblemMarkerManager getProblemMarkerManager() {
-		if (fProblemMarkerManager == null)
-			fProblemMarkerManager= new ProblemMarkerManager();
-		return fProblemMarkerManager;
+	public ClassFileDocumentProvider getClassFileDocumentProvider() {
+		ClassFileDocumentProvider result= fClassFileDocumentProvider;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fClassFileDocumentProvider == null) { // Second check (with locking)
+				fClassFileDocumentProvider= new ClassFileDocumentProvider();
+			}
+			return fClassFileDocumentProvider;
+		}
 	}
 
-	public synchronized JavaTextTools getJavaTextTools() {
-		if (fJavaTextTools == null)
-			fJavaTextTools= new JavaTextTools(getPreferenceStore(), getJavaCorePluginPreferences());
-		return fJavaTextTools;
+	public WorkingCopyManager getWorkingCopyManager() {
+		WorkingCopyManager result= fWorkingCopyManager;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fWorkingCopyManager == null) { // Second check (with locking)
+				ICompilationUnitDocumentProvider provider= getCompilationUnitDocumentProvider();
+				fWorkingCopyManager= new WorkingCopyManager(provider);
+			}
+			return fWorkingCopyManager;
+		}
+	}
+
+	public ProblemMarkerManager getProblemMarkerManager() {
+		ProblemMarkerManager result= fProblemMarkerManager;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fProblemMarkerManager == null) { // Second check (with locking)
+				fProblemMarkerManager= new ProblemMarkerManager();
+			}
+			return fProblemMarkerManager;
+		}
+	}
+
+	public JavaTextTools getJavaTextTools() {
+		JavaTextTools result= fJavaTextTools;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fJavaTextTools == null) { // Second check (with locking)
+				fJavaTextTools= new JavaTextTools(getPreferenceStore(), getJavaCorePluginPreferences());
+			}
+			return fJavaTextTools;
+		}
 	}
 
 	/**
@@ -647,23 +687,36 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * @return the AST provider
 	 * @since 3.0
 	 */
-	public synchronized ASTProvider getASTProvider() {
-		if (fASTProvider == null)
-			fASTProvider= new ASTProvider();
-
-		return fASTProvider;
+	public ASTProvider getASTProvider() {
+		ASTProvider result= fASTProvider;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fASTProvider == null) { // Second check (with locking)
+				fASTProvider= new ASTProvider();
+			}
+			return fASTProvider;
+		}
 	}
 
-	public synchronized MembersOrderPreferenceCache getMemberOrderPreferenceCache() {
+	public MembersOrderPreferenceCache getMemberOrderPreferenceCache() {
 		// initialized on startup
 		return fMembersOrderPreferenceCache;
 	}
 
 
-	public synchronized TypeFilter getTypeFilter() {
-		if (fTypeFilter == null)
-			fTypeFilter= new TypeFilter();
-		return fTypeFilter;
+	public TypeFilter getTypeFilter() {
+		TypeFilter result= fTypeFilter;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fTypeFilter == null) { // Second check (with locking)
+				fTypeFilter= new TypeFilter();
+			}
+			return fTypeFilter;
+		}
 	}
 
 	public FormToolkit getDialogsFormToolkit() {
@@ -682,34 +735,40 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * @return an array of JavaEditorTextHoverDescriptor
 	 * @since 2.1
 	 */
-	public synchronized JavaEditorTextHoverDescriptor[] getJavaEditorTextHoverDescriptors() {
-		if (fJavaEditorTextHoverDescriptors == null) {
-			fJavaEditorTextHoverDescriptors= JavaEditorTextHoverDescriptor.getContributedHovers();
-			ConfigurationElementSorter sorter= new ConfigurationElementSorter() {
-				/*
-				 * @see org.eclipse.ui.texteditor.ConfigurationElementSorter#getConfigurationElement(java.lang.Object)
-				 */
-				@Override
-				public IConfigurationElement getConfigurationElement(Object object) {
-					return ((JavaEditorTextHoverDescriptor)object).getConfigurationElement();
-				}
-			};
-			sorter.sort(fJavaEditorTextHoverDescriptors);
-
-			// Move Best Match hover to front
-			for (int i= 0; i < fJavaEditorTextHoverDescriptors.length - 1; i++) {
-				if (PreferenceConstants.ID_BESTMATCH_HOVER.equals(fJavaEditorTextHoverDescriptors[i].getId())) {
-					JavaEditorTextHoverDescriptor hoverDescriptor= fJavaEditorTextHoverDescriptors[i];
-					for (int j= i; j > 0; j--)
-						fJavaEditorTextHoverDescriptors[j]= fJavaEditorTextHoverDescriptors[j-1];
-					fJavaEditorTextHoverDescriptors[0]= hoverDescriptor;
-					break;
-				}
-
-			}
+	public JavaEditorTextHoverDescriptor[] getJavaEditorTextHoverDescriptors() {
+		JavaEditorTextHoverDescriptor[] result= fJavaEditorTextHoverDescriptors;
+		if (result != null) { // First check (no locking)
+			return result;
 		}
+		synchronized(this) {
+			if (fJavaEditorTextHoverDescriptors == null) { // Second check (with locking)
+				JavaEditorTextHoverDescriptor[] tmp= JavaEditorTextHoverDescriptor.getContributedHovers();
+				ConfigurationElementSorter sorter= new ConfigurationElementSorter() {
+					/*
+					 * @see org.eclipse.ui.texteditor.ConfigurationElementSorter#getConfigurationElement(java.lang.Object)
+					 */
+					@Override
+					public IConfigurationElement getConfigurationElement(Object object) {
+						return ((JavaEditorTextHoverDescriptor)object).getConfigurationElement();
+					}
+				};
+				sorter.sort(tmp);
 
-		return fJavaEditorTextHoverDescriptors;
+				// Move Best Match hover to front
+				for (int i= 0; i < tmp.length - 1; i++) {
+					if (PreferenceConstants.ID_BESTMATCH_HOVER.equals(tmp[i].getId())) {
+						JavaEditorTextHoverDescriptor hoverDescriptor= tmp[i];
+						for (int j= i; j > 0; j--)
+							tmp[j]= tmp[j-1];
+						tmp[0]= hoverDescriptor;
+						break;
+					}
+
+				}
+				fJavaEditorTextHoverDescriptors= tmp;
+			}
+			return fJavaEditorTextHoverDescriptors;
+		}
 	}
 
 	/**
@@ -754,31 +813,35 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * @return the template context type registry for the java plug-in
 	 * @since 3.0
 	 */
-	public synchronized ContextTypeRegistry getTemplateContextRegistry() {
-		if (fContextTypeRegistry == null) {
-			ContributionContextTypeRegistry registry= new ContributionContextTypeRegistry(JavaUI.ID_CU_EDITOR);
-
-			TemplateContextType all_contextType= registry.getContextType(JavaContextType.ID_ALL);
-			((AbstractJavaContextType) all_contextType).initializeContextTypeResolvers();
-
-			registerJavaContext(registry, JavaContextType.ID_MEMBERS, all_contextType);
-			registerJavaContext(registry, JavaContextType.ID_STATEMENTS, all_contextType);
-			registerJavaContext(registry, JavaContextType.ID_MODULE, all_contextType);
-			registerJavaContext(registry, JavaContextType.ID_EMPTY, all_contextType);
-
-			registerJavaContext(registry, SWTContextType.ID_ALL, all_contextType);
-			all_contextType= registry.getContextType(SWTContextType.ID_ALL);
-
-			registerJavaContext(registry, SWTContextType.ID_MEMBERS, all_contextType);
-			registerJavaContext(registry, SWTContextType.ID_STATEMENTS, all_contextType);
-
-			registerJavaContext(registry, JavaPostfixContextType.ID_ALL, all_contextType);
-			all_contextType= registry.getContextType(JavaPostfixContextType.ID_ALL);
-
-			fContextTypeRegistry= registry;
+	public ContextTypeRegistry getTemplateContextRegistry() {
+		ContextTypeRegistry result= fContextTypeRegistry;
+		if (result != null) { // First check (no locking)
+			return result;
 		}
+		synchronized(this) {
+			if (fContextTypeRegistry == null) { // Second check (with locking)
+				ContributionContextTypeRegistry registry= new ContributionContextTypeRegistry(JavaUI.ID_CU_EDITOR);
 
-		return fContextTypeRegistry;
+				TemplateContextType all_contextType= registry.getContextType(JavaContextType.ID_ALL);
+				((AbstractJavaContextType) all_contextType).initializeContextTypeResolvers();
+
+				registerJavaContext(registry, JavaContextType.ID_MEMBERS, all_contextType);
+				registerJavaContext(registry, JavaContextType.ID_STATEMENTS, all_contextType);
+				registerJavaContext(registry, JavaContextType.ID_MODULE, all_contextType);
+				registerJavaContext(registry, JavaContextType.ID_EMPTY, all_contextType);
+
+				registerJavaContext(registry, SWTContextType.ID_ALL, all_contextType);
+				all_contextType= registry.getContextType(SWTContextType.ID_ALL);
+
+				registerJavaContext(registry, SWTContextType.ID_MEMBERS, all_contextType);
+				registerJavaContext(registry, SWTContextType.ID_STATEMENTS, all_contextType);
+
+				registerJavaContext(registry, JavaPostfixContextType.ID_ALL, all_contextType);
+				all_contextType= registry.getContextType(JavaPostfixContextType.ID_ALL);
+				fContextTypeRegistry= registry;
+			}
+			return fContextTypeRegistry;
+		}
 	}
 
 	/**
@@ -805,7 +868,7 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	public TemplateStore getTemplateStore() {
 		if (fTemplateStore == null) {
 			final IPreferenceStore store= getPreferenceStore();
-				fTemplateStore= new ContributionTemplateStore(getTemplateContextRegistry(), store, TEMPLATES_KEY);
+			fTemplateStore= new ContributionTemplateStore(getTemplateContextRegistry(), store, TEMPLATES_KEY);
 			try {
 				fTemplateStore.load();
 			} catch (IOException e) {
@@ -813,7 +876,6 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 			}
 			fTemplateStore.startListeningForPreferenceChanges();
 		}
-
 		return fTemplateStore;
 	}
 
@@ -859,10 +921,17 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 		return fCodeTemplateStore;
 	}
 
-	private synchronized ImageDescriptorRegistry internalGetImageDescriptorRegistry() {
-		if (fImageDescriptorRegistry == null)
-			fImageDescriptorRegistry= new ImageDescriptorRegistry();
-		return fImageDescriptorRegistry;
+	ImageDescriptorRegistry internalGetImageDescriptorRegistry() {
+		ImageDescriptorRegistry result= fImageDescriptorRegistry;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fImageDescriptorRegistry == null) { // Second check (with locking)
+				fImageDescriptorRegistry= new ImageDescriptorRegistry();
+			}
+			return fImageDescriptorRegistry;
+		}
 	}
 
 	/**
@@ -900,10 +969,17 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * @return the registry of contributed <code>IJavaFoldingStructureProvider</code>
 	 * @since 3.0
 	 */
-	public synchronized JavaFoldingStructureProviderRegistry getFoldingStructureProviderRegistry() {
-		if (fFoldingStructureProviderRegistry == null)
-			fFoldingStructureProviderRegistry= new JavaFoldingStructureProviderRegistry();
-		return fFoldingStructureProviderRegistry;
+	public JavaFoldingStructureProviderRegistry getFoldingStructureProviderRegistry() {
+		JavaFoldingStructureProviderRegistry result= fFoldingStructureProviderRegistry;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fFoldingStructureProviderRegistry == null) { // Second check (with locking)
+				fFoldingStructureProviderRegistry= new JavaFoldingStructureProviderRegistry();
+			}
+			return fFoldingStructureProviderRegistry;
+		}
 	}
 
 	/**
@@ -912,17 +988,30 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * @return the save participant registry, not null
 	 * @since 3.3
 	 */
-	public synchronized SaveParticipantRegistry getSaveParticipantRegistry() {
-		if (fSaveParticipantRegistry == null)
-			fSaveParticipantRegistry= new SaveParticipantRegistry();
-		return fSaveParticipantRegistry;
+	public SaveParticipantRegistry getSaveParticipantRegistry() {
+		SaveParticipantRegistry result= fSaveParticipantRegistry;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fSaveParticipantRegistry == null) { // Second check (with locking)
+				fSaveParticipantRegistry= new SaveParticipantRegistry();
+			}
+			return fSaveParticipantRegistry;
+		}
 	}
 
-	public synchronized CleanUpRegistry getCleanUpRegistry() {
-		if (fCleanUpRegistry == null)
-			fCleanUpRegistry= new CleanUpRegistry();
-
-		return fCleanUpRegistry;
+	public CleanUpRegistry getCleanUpRegistry() {
+		CleanUpRegistry result= fCleanUpRegistry;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fCleanUpRegistry == null) { // Second check (with locking)
+				fCleanUpRegistry= new CleanUpRegistry();
+			}
+			return fCleanUpRegistry;
+		}
 	}
 
 	/**
@@ -968,10 +1057,16 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * @since 3.3
 	 */
 	public ClasspathAttributeConfigurationDescriptors getClasspathAttributeConfigurationDescriptors() {
-		if (fClasspathAttributeConfigurationDescriptors == null) {
-			fClasspathAttributeConfigurationDescriptors= new ClasspathAttributeConfigurationDescriptors();
+		ClasspathAttributeConfigurationDescriptors result= fClasspathAttributeConfigurationDescriptors;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fClasspathAttributeConfigurationDescriptors == null) { // Second check (with locking)
+				fClasspathAttributeConfigurationDescriptors= new ClasspathAttributeConfigurationDescriptors();
+			}
+			return fClasspathAttributeConfigurationDescriptors;
 		}
-		return fClasspathAttributeConfigurationDescriptors;
 	}
 
 	/**
@@ -981,10 +1076,16 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	 * @since 3.4
 	 */
 	public ImagesOnFileSystemRegistry getImagesOnFSRegistry() {
-		if (fImagesOnFSRegistry == null) {
-			fImagesOnFSRegistry= new ImagesOnFileSystemRegistry();
+		ImagesOnFileSystemRegistry result= fImagesOnFSRegistry;
+		if (result != null) { // First check (no locking)
+			return result;
+		}
+		synchronized(this) {
+			if (fImagesOnFSRegistry == null) { // Second check (with locking)
+				fImagesOnFSRegistry= new ImagesOnFileSystemRegistry();
+			}
+			return fImagesOnFSRegistry;
 		}
-		return fImagesOnFSRegistry;
 	}
 
 	/**
@@ -1030,7 +1131,6 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 	public void optionsChanged(DebugOptions options) {
 		DEBUG_AST_PROVIDER= options.getBooleanOption("org.eclipse.jdt.ui/debug/ASTProvider", false); //$NON-NLS-1$
 		DEBUG_BREADCRUMB_ITEM_DROP_DOWN= options.getBooleanOption("org.eclipse.jdt.ui/debug/BreadcrumbItemDropDown", false); //$NON-NLS-1$
-		DEBUG_TYPE_CONSTRAINTS= options.getBooleanOption("org.eclipse.jdt.ui/debug/TypeConstraints", false); //$NON-NLS-1$
 		DEBUG_RESULT_COLLECTOR= options.getBooleanOption("org.eclipse.jdt.ui/debug/ResultCollector", false); //$NON-NLS-1$
 	}
 
@@ -1109,4 +1209,89 @@ public class JavaPlugin extends AbstractUIPlugin implements DebugOptionsListener
 			JavaPlugin.log(e);
 		}
 	}
+
+	/**
+	 * Add the new default type filters in old workspaces that already have non-default type
+	 * filters. Only do this once, so that users have a way to opt-out if they don't want the new
+	 * filters.
+	 */
+	private void setTypeFilterPreferences() {
+		Set<String> enabledFiltersToAdd= new LinkedHashSet<>();
+		enabledFiltersToAdd.add("com.sun.*"); //$NON-NLS-1$
+		enabledFiltersToAdd.add("sun.*"); //$NON-NLS-1$
+		enabledFiltersToAdd.add("jdk.*"); //$NON-NLS-1$
+		enabledFiltersToAdd.add("io.micrometer.shaded.*"); //$NON-NLS-1$
+		enabledFiltersToAdd.add("java.awt.List"); //$NON-NLS-1$
+
+		Set<String> disabledFiltersToAdd= new LinkedHashSet<>();
+		disabledFiltersToAdd.add("java.rmi.*"); //$NON-NLS-1$
+		disabledFiltersToAdd.add("org.graalvm.*"); //$NON-NLS-1$
+		disabledFiltersToAdd.add("java.awt.*"); //$NON-NLS-1$
+
+		// default value - enabled
+		Set<String> defaultEnabled= new LinkedHashSet<>();
+		String defaultEnabledString= PreferenceConstants.getPreferenceStore().getDefaultString(PreferenceConstants.TYPEFILTER_ENABLED);
+		defaultEnabled.addAll(Arrays.asList(defaultEnabledString.split(";"))); //$NON-NLS-1$
+		defaultEnabled.addAll(enabledFiltersToAdd);
+		String newDefaultEnabledString= defaultEnabled.stream().collect(Collectors.joining(";")); //$NON-NLS-1$
+		PreferenceConstants.getPreferenceStore().setDefault(PreferenceConstants.TYPEFILTER_ENABLED, newDefaultEnabledString);
+
+		// default value - disabled
+		Set<String> defaultDisabled= new LinkedHashSet<>();
+		String defaultDisabledString= PreferenceConstants.getPreferenceStore().getDefaultString(PreferenceConstants.TYPEFILTER_DISABLED);
+		defaultDisabled.addAll(Arrays.asList(defaultDisabledString.split(";"))); //$NON-NLS-1$
+		defaultDisabled.addAll(disabledFiltersToAdd);
+		String newDefaultDisabledString= defaultDisabled.stream().collect(Collectors.joining(";")); //$NON-NLS-1$
+		PreferenceConstants.getPreferenceStore().setDefault(PreferenceConstants.TYPEFILTER_DISABLED, newDefaultDisabledString);
+
+		if (isTypeFilterMigrated()) {
+			return;
+		}
+
+		// current values
+		Set<String> currentEnabled= new LinkedHashSet<>();
+		String currentEnabledString= PreferenceConstants.getPreferenceStore().getString(PreferenceConstants.TYPEFILTER_ENABLED);
+		currentEnabled.addAll(Arrays.asList(currentEnabledString.split(";"))); //$NON-NLS-1$
+		currentEnabled.remove("org.graalvm.*"); //$NON-NLS-1$
+		currentEnabled.remove("java.awt.*"); //$NON-NLS-1$
+
+		Set<String> currentDisabled= new LinkedHashSet<>();
+		String currentDisabledString= PreferenceConstants.getPreferenceStore().getString(PreferenceConstants.TYPEFILTER_DISABLED);
+		currentDisabled.addAll(Arrays.asList(currentDisabledString.split(";"))); //$NON-NLS-1$
+
+		enabledFiltersToAdd.removeAll(currentEnabled);
+		enabledFiltersToAdd.removeAll(currentDisabled);
+
+		disabledFiltersToAdd.removeAll(currentEnabled);
+		disabledFiltersToAdd.removeAll(currentDisabled);
+
+		if (!enabledFiltersToAdd.isEmpty()) {
+			currentEnabledString = currentEnabled.stream().collect(Collectors.joining(";")); //$NON-NLS-1$
+			String newEnabledString= currentEnabledString + ";" + enabledFiltersToAdd.stream().collect(Collectors.joining(";")); //$NON-NLS-1$ //$NON-NLS-2$
+			PreferenceConstants.getPreferenceStore().setValue(PreferenceConstants.TYPEFILTER_ENABLED, newEnabledString);
+		}
+
+		if (!disabledFiltersToAdd.isEmpty()) {
+			currentDisabledString = currentDisabled.stream().collect(Collectors.joining(";")); //$NON-NLS-1$
+			String newDisabledString= currentDisabledString + ";" + disabledFiltersToAdd.stream().collect(Collectors.joining(";")); //$NON-NLS-1$ //$NON-NLS-2$
+			PreferenceConstants.getPreferenceStore().setValue(PreferenceConstants.TYPEFILTER_DISABLED, newDisabledString);
+		}
+
+		// set as migrated
+		setTypeFilterMigrated();
+	}
+
+	private boolean isTypeFilterMigrated() {
+		return Platform.getPreferencesService().getBoolean(JavaPlugin.getPluginId(), TYPEFILTER_MIGRATED, false, null);
+	}
+
+	private void setTypeFilterMigrated() {
+		IEclipsePreferences preferences= InstanceScope.INSTANCE.getNode(JavaPlugin.getPluginId());
+		preferences.putBoolean(TYPEFILTER_MIGRATED, true);
+		try {
+			preferences.flush();
+		} catch (BackingStoreException e) {
+			JavaPlugin.log(e);
+		}
+	}
 }
