@@ -98,7 +98,7 @@ public class CategoryFilterActionGroup extends ActionGroup {
 
 	}
 
-	private class CategoryFilterSelectionDialog extends SelectionStatusDialog implements IListAdapter<String> {
+	private static class CategoryFilterSelectionDialog extends SelectionStatusDialog implements IListAdapter<String> {
 
 		private static final int SELECT_ALL= 0;
 		private static final int DESELECT_ALL= 1;
@@ -241,7 +241,7 @@ public class CategoryFilterActionGroup extends ActionGroup {
 	}
 
 	private interface IResultCollector {
-		public boolean accept(String[] category);
+		boolean accept(String[] category);
 	}
 
 	private static int COUNTER= 0;//WORKAROUND for Bug 132669 https://bugs.eclipse.org/bugs/show_bug.cgi?id=132669
@@ -342,14 +342,11 @@ public class CategoryFilterActionGroup extends ActionGroup {
 	public void contributeToViewMenu(IMenuManager menuManager) {
 		menuManager.add(new Separator(CATEGORY_MENU_GROUP_NAME));
 		menuManager.appendToGroup(CATEGORY_MENU_GROUP_NAME, fMenuAction);
-		fMenuListener= new IMenuListener() {
-					@Override
-					public void menuAboutToShow(IMenuManager manager) {
-						if (!manager.isVisible())
-							return;
-						updateMenu(manager);
-					}
-				};
+		fMenuListener= manager -> {
+			if (!manager.isVisible())
+				return;
+			updateMenu(manager);
+		};
 		menuManager.addMenuListener(fMenuListener);
 		fMenuManager= menuManager;
 	}
@@ -368,7 +365,7 @@ public class CategoryFilterActionGroup extends ActionGroup {
 		IContributionItem[] items= manager.getItems();
 		if (items != null) {
 			for (IContributionItem item : items) {
-				if (item != null && item.getId() != null && item.getId().equals(FILTER_CATEGORY_ACTION_ID)) {
+				if (item != null && item.getId() != null && FILTER_CATEGORY_ACTION_ID.equals(item.getId())) {
 					IContributionItem removed= manager.remove(item);
 					if (removed != null) {
 						item.dispose();
@@ -394,22 +391,19 @@ public class CategoryFilterActionGroup extends ActionGroup {
 		final HashSet<String> categories= new HashSet<>();
 		final HashSet<String> foundLRUCategories= new HashSet<>();
 		final boolean hasUncategorizedMember[]= new boolean[] {false};
-		for (int i= 0; i < fInputElement.length && !(hasUncategorizedMember[0] && foundLRUCategories.size() >= MAX_NUMBER_OF_CATEGORIES_IN_MENU); i++) {
-			collectCategories(fInputElement[i], new IResultCollector() {
-				@Override
-				public boolean accept(String[] cats) {
-					if (cats.length > 0) {
-						for (String category : cats) {
-							categories.add(category);
-							if (fLRUList.containsKey(category)) {
-								foundLRUCategories.add(category);
-							}
+		for (int i= 0; i < fInputElement.length && (!hasUncategorizedMember[0] || (foundLRUCategories.size() < MAX_NUMBER_OF_CATEGORIES_IN_MENU)); i++) {
+			collectCategories(fInputElement[i], cats -> {
+				if (cats.length > 0) {
+					for (String category : cats) {
+						categories.add(category);
+						if (fLRUList.containsKey(category)) {
+							foundLRUCategories.add(category);
 						}
-					} else {
-						hasUncategorizedMember[0]= true;
 					}
-					return hasUncategorizedMember[0] && foundLRUCategories.size() >= MAX_NUMBER_OF_CATEGORIES_IN_MENU;
+				} else {
+					hasUncategorizedMember[0]= true;
 				}
+				return hasUncategorizedMember[0] && foundLRUCategories.size() >= MAX_NUMBER_OF_CATEGORIES_IN_MENU;
 			});
 		}
 		int count= 0;
@@ -468,12 +462,7 @@ public class CategoryFilterActionGroup extends ActionGroup {
 
 	private void fireSelectionChange() {
 		fViewer.getControl().setRedraw(false);
-		BusyIndicator.showWhile(fViewer.getControl().getDisplay(), new Runnable() {
-			@Override
-			public void run() {
-				fViewer.refresh();
-			}
-		});
+		BusyIndicator.showWhile(fViewer.getControl().getDisplay(), () -> fViewer.refresh());
 		fViewer.getControl().setRedraw(true);
 	}
 
@@ -484,12 +473,9 @@ public class CategoryFilterActionGroup extends ActionGroup {
 	private void showCategorySelectionDialog(IJavaElement[] input) {
 		final HashSet<String> categories= new HashSet<>();
 		for (IJavaElement i : input) {
-			collectCategories(i, new IResultCollector() {
-				@Override
-				public boolean accept(String[] cats) {
-					categories.addAll(Arrays.asList(cats));
-					return false;
-				}
+			collectCategories(i, cats -> {
+				categories.addAll(Arrays.asList(cats));
+				return false;
 			});
 		}
 		CategoryFilterSelectionDialog dialog= new CategoryFilterSelectionDialog(fViewer.getControl().getShell(), new ArrayList<>(categories), new ArrayList<>(fFilteredCategories));
