@@ -410,14 +410,9 @@ abstract class JavaBrowsingPart extends ViewPart implements IMenuListener, IView
 	 * @return returns the <code>IShowInSource</code>
 	 */
 	protected IShowInSource getShowInSource() {
-		return new IShowInSource() {
-			@Override
-			public ShowInContext getShowInContext() {
-				return new ShowInContext(
-					null,
-				getSite().getSelectionProvider().getSelection());
-			}
-		};
+		return () -> new ShowInContext(
+			null,
+		getSite().getSelectionProvider().getSelection());
 	}
 
 	protected DecoratingJavaLabelProvider createDecoratingLabelProvider(JavaUILabelProvider provider) {
@@ -579,12 +574,7 @@ abstract class JavaBrowsingPart extends ViewPart implements IMenuListener, IView
 		if (fHasWorkingSetFilter) {
 			String viewId= getConfigurationElement().getAttribute("id"); //$NON-NLS-1$
 			Assert.isNotNull(viewId);
-			IPropertyChangeListener workingSetListener= new IPropertyChangeListener() {
-				@Override
-				public void propertyChange(PropertyChangeEvent event) {
-					doWorkingSetChanged(event);
-				}
-			};
+			IPropertyChangeListener workingSetListener= this::doWorkingSetChanged;
 			fWorkingSetFilterActionGroup= new WorkingSetFilterActionGroup(getSite(), workingSetListener);
 			fViewer.addFilter(fWorkingSetFilterActionGroup.getWorkingSetFilter());
 		}
@@ -906,7 +896,7 @@ abstract class JavaBrowsingPart extends ViewPart implements IMenuListener, IView
 		if (!(input instanceof IJavaElement)) {
 			// Use the input of the page
 			input= getSite().getPage().getInput();
-			if (!(input instanceof IJavaElement) && input instanceof IAdaptable)
+			if (input != null && !(input instanceof IJavaElement))
 				input= ((IAdaptable)input).getAdapter(IJavaElement.class);
 		}
 		setInput(findInputForJavaElement((IJavaElement)input));
@@ -914,7 +904,6 @@ abstract class JavaBrowsingPart extends ViewPart implements IMenuListener, IView
 
 	protected void setInitialSelection() {
 		// Use the selection, if any
-		Object input;
 		IWorkbenchPage page= getSite().getPage();
 		ISelection selection= null;
 		if (page != null)
@@ -934,13 +923,16 @@ abstract class JavaBrowsingPart extends ViewPart implements IMenuListener, IView
 
 		if (selection == null || selection.isEmpty()) {
 			// Use the input of the page
-			input= getSite().getPage().getInput();
-			if (!(input instanceof IJavaElement)) {
-				if (input instanceof IAdaptable)
-					input= ((IAdaptable)input).getAdapter(IJavaElement.class);
-				else
-					return;
+			IAdaptable input= getSite().getPage().getInput();
+
+			if (input == null) {
+				return;
 			}
+
+			if (!(input instanceof IJavaElement)) {
+				input= input.getAdapter(IJavaElement.class);
+			}
+
 			selection= new StructuredSelection(input);
 		}
 		selectionChanged(null, selection);
@@ -1060,9 +1052,9 @@ abstract class JavaBrowsingPart extends ViewPart implements IMenuListener, IView
 		return (newInput == null || !newInput.equals(oldInput))
 			&& (elementToSelect == null
 				|| oldInput == null
-				|| (!((elementToSelect instanceof IPackageDeclaration)
-					&& (elementToSelect.getParent().equals(oldInput.getParent()))
-					&& (!isAncestorOf(getViewPartInput(), elementToSelect)))));
+				|| !(elementToSelect instanceof IPackageDeclaration)
+				|| !(elementToSelect.getParent().equals(oldInput.getParent()))
+				|| isAncestorOf(getViewPartInput(), elementToSelect));
 	}
 
 	/**
