@@ -159,25 +159,27 @@ public class PackagesViewFlatContentProvider extends LogicalPackagesProvider imp
 		if (element instanceof IPackageFragment) {
 			final IPackageFragment frag= (IPackageFragment) element;
 
-			if (kind == IJavaElementDelta.REMOVED) {
-				removeElement(frag);
-
-			} else if (kind == IJavaElementDelta.ADDED) {
-				addElement(frag);
-
-			} else if (kind == IJavaElementDelta.CHANGED) {
-				//just refresh
-				Object toBeRefreshed= element;
-
-				IPackageFragment pkgFragment= (IPackageFragment) element;
-				LogicalPackage logicalPkg= findLogicalPackage(pkgFragment);
-				//deal with packages that have been filtered and are now visible
-				if (logicalPkg != null)
-					toBeRefreshed= findElementToRefresh(logicalPkg);
-				else
-					toBeRefreshed= findElementToRefresh(pkgFragment);
-
-				postRefresh(toBeRefreshed);
+			switch (kind) {
+				case IJavaElementDelta.REMOVED:
+					removeElement(frag);
+					break;
+				case IJavaElementDelta.ADDED:
+					addElement(frag);
+					break;
+				case IJavaElementDelta.CHANGED:
+					//just refresh
+					Object toBeRefreshed= element;
+					IPackageFragment pkgFragment= (IPackageFragment) element;
+					LogicalPackage logicalPkg= findLogicalPackage(pkgFragment);
+					//deal with packages that have been filtered and are now visible
+					if (logicalPkg != null)
+						toBeRefreshed= findElementToRefresh(logicalPkg);
+					else
+						toBeRefreshed= findElementToRefresh(pkgFragment);
+					postRefresh(toBeRefreshed);
+					break;
+				default:
+					break;
 			}
 			//in this view there will be no children of PackageFragment to refresh
 			return;
@@ -214,26 +216,20 @@ public class PackagesViewFlatContentProvider extends LogicalPackagesProvider imp
 	}
 
 	private void postAdd(final Object child) {
-		postRunnable(new Runnable() {
-			@Override
-			public void run() {
-				Control ctrl = fViewer.getControl();
-				if (ctrl != null && !ctrl.isDisposed()) {
-					((TableViewer)fViewer).add(child);
-				}
+		postRunnable(() -> {
+			Control ctrl = fViewer.getControl();
+			if (ctrl != null && !ctrl.isDisposed()) {
+				((TableViewer)fViewer).add(child);
 			}
 		});
 	}
 
 
 	private void postRemove(final Object object) {
-		postRunnable(new Runnable() {
-			@Override
-			public void run() {
-				Control ctrl = fViewer.getControl();
-				if (ctrl != null && !ctrl.isDisposed()) {
-					((TableViewer)fViewer).remove(object);
-				}
+		postRunnable(() -> {
+			Control ctrl = fViewer.getControl();
+			if (ctrl != null && !ctrl.isDisposed()) {
+				((TableViewer)fViewer).remove(object);
 			}
 		});
 	}
@@ -282,13 +278,10 @@ public class PackagesViewFlatContentProvider extends LogicalPackagesProvider imp
 			new Exception("postRefresh: " + element).printStackTrace(System.out); //$NON-NLS-1$
 		}
 
-		postRunnable(new Runnable() {
-			@Override
-			public void run() {
-				Control ctrl= fViewer.getControl();
-				if (ctrl != null && !ctrl.isDisposed()) {
-					fViewer.refresh(element);
-				}
+		postRunnable(() -> {
+			Control ctrl= fViewer.getControl();
+			if (ctrl != null && !ctrl.isDisposed()) {
+				fViewer.refresh(element);
 			}
 		});
 	}
