@@ -226,9 +226,9 @@ public class JavaMergeViewer extends TextMergeViewer {
 	protected void setEditable(ISourceViewer sourceViewer, boolean state) {
 		super.setEditable(sourceViewer, state);
 		if (fEditor != null) {
-			Object editor= fEditor.get(sourceViewer);
-			if (editor instanceof CompilationUnitEditorAdapter)
-				((CompilationUnitEditorAdapter)editor).setEditable(state);
+			CompilationUnitEditorAdapter editor= fEditor.get(sourceViewer);
+			if (editor != null)
+				editor.setEditable(state);
 		}
 	}
 
@@ -369,17 +369,15 @@ public class JavaMergeViewer extends TextMergeViewer {
 				case JavaNode.CLASS:
 					// append after last class
 					children= javaContainer.getChildren();
-					if (children.length > 0) {
-						for (int i= children.length-1; i >= 0; i--) {
-							JavaNode child= (JavaNode) children[i];
-							switch (child.getTypeCode()) {
-							case JavaNode.CLASS:
-							case JavaNode.IMPORT_CONTAINER:
-							case JavaNode.PACKAGE:
-							case JavaNode.FIELD:
-								p= child.getRange();
-								return p.getOffset() + p.getLength();
-							}
+					for (int i= children.length-1; i >= 0; i--) {
+						JavaNode child= (JavaNode) children[i];
+						switch (child.getTypeCode()) {
+						case JavaNode.CLASS:
+						case JavaNode.IMPORT_CONTAINER:
+						case JavaNode.PACKAGE:
+						case JavaNode.FIELD:
+							p= child.getRange();
+							return p.getOffset() + p.getLength();
 						}
 					}
 					return javaContainer.getAppendPosition().getOffset();
@@ -459,12 +457,7 @@ public class JavaMergeViewer extends TextMergeViewer {
 		}
 		fPreferenceStore= ps;
 		if (fPreferenceStore != null) {
-			fPreferenceChangeListener= new IPropertyChangeListener() {
-				@Override
-				public void propertyChange(PropertyChangeEvent event) {
-					handlePropertyChange(event);
-				}
-			};
+			fPreferenceChangeListener= this::handlePropertyChange;
 			fPreferenceStore.addPropertyChangeListener(fPreferenceChangeListener);
 		}
 	}
@@ -499,12 +492,11 @@ public class JavaMergeViewer extends TextMergeViewer {
 	@Override
 	protected void setActionsActivated(SourceViewer sourceViewer, boolean state) {
 		if (fEditor != null) {
-			Object editor= fEditor.get(sourceViewer);
-			if (editor instanceof CompilationUnitEditorAdapter) {
-				CompilationUnitEditorAdapter cuea= (CompilationUnitEditorAdapter)editor;
-				cuea.setActionsActivated(state);
+			CompilationUnitEditorAdapter editor= fEditor.get(sourceViewer);
+			if (editor != null) {
+				editor.setActionsActivated(state);
 
-				IAction saveAction= cuea.getAction(ITextEditorActionConstants.SAVE);
+				IAction saveAction= editor.getAction(ITextEditorActionConstants.SAVE);
 				if (saveAction instanceof IPageListener) {
 					PartEventAction partEventAction= (PartEventAction) saveAction;
 					IWorkbenchPart compareEditorPart= getCompareConfiguration().getContainer().getWorkbenchPart();
