@@ -53,8 +53,6 @@ import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.resource.JFaceResources;
 import org.eclipse.jface.resource.LocalResourceManager;
-import org.eclipse.jface.util.IPropertyChangeListener;
-import org.eclipse.jface.util.PropertyChangeEvent;
 import org.eclipse.jface.viewers.DelegatingStyledCellLabelProvider.IStyledLabelProvider;
 import org.eclipse.jface.viewers.ILabelDecorator;
 import org.eclipse.jface.viewers.ISelection;
@@ -90,6 +88,7 @@ import org.eclipse.jdt.core.search.TypeNameMatch;
 import org.eclipse.jdt.core.search.TypeNameMatchRequestor;
 import org.eclipse.jdt.core.search.TypeNameRequestor;
 
+import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.corext.util.CollectionsUtil;
 import org.eclipse.jdt.internal.corext.util.Messages;
 import org.eclipse.jdt.internal.corext.util.OpenTypeHistory;
@@ -117,7 +116,6 @@ import org.eclipse.jdt.internal.ui.preferences.TypeFilterPreferencePage;
 import org.eclipse.jdt.internal.ui.search.JavaSearchScopeFactory;
 import org.eclipse.jdt.internal.ui.util.ExceptionHandler;
 import org.eclipse.jdt.internal.ui.util.TypeNameMatchLabelProvider;
-import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.ui.workingsets.WorkingSetFilterActionGroup;
 
 
@@ -345,20 +343,17 @@ public class FilteredTypesSelectionDialog extends FilteredItemsSelectionDialog i
 		super.fillViewMenu(menuManager);
 
 		if (fAllowScopeSwitching) {
-			fFilterActionGroup= new WorkingSetFilterActionGroup(getShell(), JavaPlugin.getActivePage(), new IPropertyChangeListener() {
-				@Override
-				public void propertyChange(PropertyChangeEvent event) {
-					IWorkingSet ws= (IWorkingSet) event.getNewValue();
-					if (ws == null || (ws.isAggregateWorkingSet() && ws.isEmpty())) {
-						setSearchScope(SearchEngine.createWorkspaceScope());
-						setSubtitle(null);
-					} else {
-						setSearchScope(JavaSearchScopeFactory.getInstance().createJavaSearchScope(ws, true));
-						setSubtitle(ws.getLabel());
-					}
-
-					applyFilter();
+			fFilterActionGroup= new WorkingSetFilterActionGroup(getShell(), JavaPlugin.getActivePage(), event -> {
+				IWorkingSet ws= (IWorkingSet) event.getNewValue();
+				if (ws == null || (ws.isAggregateWorkingSet() && ws.isEmpty())) {
+					setSearchScope(SearchEngine.createWorkspaceScope());
+					setSubtitle(null);
+				} else {
+					setSearchScope(JavaSearchScopeFactory.getInstance().createJavaSearchScope(ws, true));
+					setSubtitle(ws.getLabel());
 				}
+
+				applyFilter();
 			});
 			fFilterActionGroup.fillViewMenu(menuManager);
 		}
@@ -392,16 +387,16 @@ public class FilteredTypesSelectionDialog extends FilteredItemsSelectionDialog i
 
 		List<IType> resultToReturn= new ArrayList<>();
 
-		for (int i= 0; i < newResult.size(); i++) {
-			if (newResult.get(i) instanceof TypeNameMatch) {
-				IType type= ((TypeNameMatch) newResult.get(i)).getType();
+		for (Object element : newResult) {
+			if (element instanceof TypeNameMatch) {
+				IType type= ((TypeNameMatch) element).getType();
 				if (type.exists()) {
 					// items are added to history in the
 					// org.eclipse.ui.dialogs.FilteredItemsSelectionDialog#computeResult()
 					// method
 					resultToReturn.add(type);
 				} else {
-					TypeNameMatch typeInfo= (TypeNameMatch) newResult.get(i);
+					TypeNameMatch typeInfo= (TypeNameMatch) element;
 					IPackageFragmentRoot root= typeInfo.getPackageFragmentRoot();
 					String containerName= JavaElementLabels.getElementLabel(root, JavaElementLabels.ROOT_QUALIFIED);
 					String message= Messages.format(JavaUIMessages.FilteredTypesSelectionDialog_dialogMessage, new String[] { TypeNameMatchLabelProvider.getText(typeInfo, TypeNameMatchLabelProvider.SHOW_FULLYQUALIFIED), containerName });
@@ -436,7 +431,7 @@ public class FilteredTypesSelectionDialog extends FilteredItemsSelectionDialog i
 					String text= ((ITextSelection) selection).getText();
 					if (text != null) {
 						text= text.trim();
-						if (text.length() > 0 && JavaConventions.validateJavaTypeName(text, JavaCore.VERSION_1_3, JavaCore.VERSION_1_3).isOK()) {
+						if (text.length() > 0 && JavaConventions.validateJavaTypeName(text, JavaCore.VERSION_1_3, JavaCore.VERSION_1_3, null).isOK()) {
 							setInitialPattern(text, FULL_SELECTION);
 						}
 					}
@@ -1148,7 +1143,7 @@ public class FilteredTypesSelectionDialog extends FilteredItemsSelectionDialog i
 		}
 
 		private String getFormattedLabel(String name) {
-			return MessageFormat.format(JavaUIMessages.FilteredTypesSelectionDialog_library_name_format, new Object[] { name });
+			return MessageFormat.format(JavaUIMessages.FilteredTypesSelectionDialog_library_name_format, name);
 		}
 
 		@Override
@@ -1161,16 +1156,17 @@ public class FilteredTypesSelectionDialog extends FilteredItemsSelectionDialog i
 			if (result != 0)
 				return result;
 
-			result= compareTypeContainerName(leftInfo.getTypeContainerName(), rightInfo.getTypeContainerName());
-			if (result != 0)
-				return result;
-
 			int leftCategory= getElementTypeCategory(leftInfo);
 			int rightCategory= getElementTypeCategory(rightInfo);
 			if (leftCategory < rightCategory)
 				return -1;
 			if (leftCategory > rightCategory)
 				return +1;
+
+			result= compareTypeContainerName(leftInfo.getTypeContainerName(), rightInfo.getTypeContainerName());
+			if (result != 0)
+				return result;
+
 			return compareContainerName(leftInfo, rightInfo);
 		}
 
