@@ -75,6 +75,7 @@ import org.eclipse.jdt.core.ToolFactory;
 import org.eclipse.jdt.core.util.IClassFileReader;
 import org.eclipse.jdt.core.util.ISourceAttribute;
 
+import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.internal.corext.util.Messages;
 import org.eclipse.jdt.internal.corext.util.Resources;
@@ -91,7 +92,6 @@ import org.eclipse.jdt.ui.refactoring.RefactoringSaveHelper;
 import org.eclipse.jdt.internal.ui.IJavaStatusConstants;
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.util.BusyIndicatorRunnableContext;
-import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 
 /**
  * Operation for exporting a resource and its children to a new  JAR file.
@@ -377,7 +377,7 @@ public class JarFileExportOperation extends WorkspaceModifyOperation implements
 				leadSegmentsToRemove= pkgRoot.getPath().segmentCount();
 				boolean isOnBuildPath;
 				isOnBuildPath= jProject.isOnClasspath(resource);
-				if (!isOnBuildPath || (mustUseSourceFolderHierarchy() && !pkgRoot.getElementName().equals(IPackageFragmentRoot.DEFAULT_PACKAGEROOT_PATH)))
+				if (!isOnBuildPath || (mustUseSourceFolderHierarchy() && !IPackageFragmentRoot.DEFAULT_PACKAGEROOT_PATH.equals(pkgRoot.getElementName())))
 					leadSegmentsToRemove--;
 			}
 
@@ -545,7 +545,7 @@ public class JarFileExportOperation extends WorkspaceModifyOperation implements
 	private void exportResource(IProgressMonitor progressMonitor, IPackageFragmentRoot pkgRoot, boolean isInJavaProject, IResource resource, IPath destinationPath) {
 
 		// Handle case where META-INF/MANIFEST.MF is part of the exported files
-		if (fJarPackage.areClassFilesExported() && destinationPath.toString().equals("META-INF/MANIFEST.MF")) {//$NON-NLS-1$
+		if (fJarPackage.areClassFilesExported() && "META-INF/MANIFEST.MF".equals(destinationPath.toString())) {//$NON-NLS-1$
 			if (fJarPackage.isManifestGenerated())
 				addWarning(Messages.format(JarPackagerMessages.JarFileExportOperation_didNotAddManifestToJar, BasicElementLabels.getPathLabel(resource.getFullPath(), false)), null);
 			return;
@@ -832,7 +832,7 @@ public class JarFileExportOperation extends WorkspaceModifyOperation implements
 		return file != null
 			&& file.getType() == IResource.FILE
 			&& file.getFileExtension() != null
-			&& file.getFileExtension().equalsIgnoreCase("class"); //$NON-NLS-1$
+			&& "class".equalsIgnoreCase(file.getFileExtension()); //$NON-NLS-1$
 	}
 
 	/*
@@ -934,6 +934,8 @@ public class JarFileExportOperation extends WorkspaceModifyOperation implements
 		String message= null;
 		switch (fStatus.getSeverity()) {
 			case IStatus.OK:
+			default:
+				// defensive code in case new severity is defined
 				message= ""; //$NON-NLS-1$
 				break;
 			case IStatus.INFO:
@@ -948,10 +950,6 @@ public class JarFileExportOperation extends WorkspaceModifyOperation implements
 				else
 					message= JarPackagerMessages.JarFileExportOperation_jarCreationFailed;
 				break;
-			default:
-				// defensive code in case new severity is defined
-				message= ""; //$NON-NLS-1$
-				break;
 		}
 		fStatus.setMessage(message);
 		return fStatus;
@@ -1068,13 +1066,10 @@ public class JarFileExportOperation extends WorkspaceModifyOperation implements
 
 		if (fParentShell != null) {
 			final boolean[] res= { false };
-			fParentShell.getDisplay().syncExec(new Runnable() {
-				@Override
-				public void run() {
-					RefactoringSaveHelper refactoringSaveHelper= new RefactoringSaveHelper(RefactoringSaveHelper.SAVE_ALL_ALWAYS_ASK);
-					res[0]= refactoringSaveHelper.saveEditors(fParentShell);
-					fFilesSaved= refactoringSaveHelper.didSaveFiles();
-				}
+			fParentShell.getDisplay().syncExec(() -> {
+				RefactoringSaveHelper refactoringSaveHelper= new RefactoringSaveHelper(RefactoringSaveHelper.SAVE_ALL_ALWAYS_ASK);
+				res[0]= refactoringSaveHelper.saveEditors(fParentShell);
+				fFilesSaved= refactoringSaveHelper.didSaveFiles();
 			});
 			if (!res[0]) {
 				addError(JarPackagerMessages.JarFileExportOperation_fileUnsaved, null);
@@ -1090,9 +1085,7 @@ public class JarFileExportOperation extends WorkspaceModifyOperation implements
 		if (fJarPackage.areGeneratedFilesExported() && fJarPackage.isManifestGenerated() && fJarPackage.isManifestSaved()) {
 			try {
 				saveManifest();
-			} catch (CoreException ex) {
-				addError(JarPackagerMessages.JarFileExportOperation_errorSavingManifest, ex);
-			} catch (IOException ex) {
+			} catch (CoreException | IOException ex) {
 				addError(JarPackagerMessages.JarFileExportOperation_errorSavingManifest, ex);
 			}
 		}
@@ -1101,9 +1094,7 @@ public class JarFileExportOperation extends WorkspaceModifyOperation implements
 		if (fJarPackage.isDescriptionSaved()) {
 			try {
 				saveDescription();
-			} catch (CoreException ex) {
-				addError(JarPackagerMessages.JarFileExportOperation_errorSavingDescription, ex);
-			} catch (IOException ex) {
+			} catch (CoreException | IOException ex) {
 				addError(JarPackagerMessages.JarFileExportOperation_errorSavingDescription, ex);
 			}
 		}
