@@ -140,6 +140,7 @@ import org.eclipse.jdt.internal.ui.preferences.SaveParticipantPreferencePage;
 import org.eclipse.jdt.internal.ui.preferences.formatter.FormatterProfileManager;
 import org.eclipse.jdt.internal.ui.text.ContentAssistPreference;
 import org.eclipse.jdt.internal.ui.text.JavaHeuristicScanner;
+import org.eclipse.jdt.internal.ui.text.JavaReconciler;
 import org.eclipse.jdt.internal.ui.text.SmartBackspaceManager;
 import org.eclipse.jdt.internal.ui.text.Symbols;
 import org.eclipse.jdt.internal.ui.text.correction.CorrectionCommandInstaller;
@@ -1648,16 +1649,18 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 	 */
 	@Override
 	public void aboutToBeReconciled() {
-
-		// Notify AST provider
-		CoreASTProvider.getInstance().aboutToBeReconciled(getInputJavaElement());
-
 		// Notify listeners
 		for (IJavaReconcilingListener listener : fReconcilingListeners) {
 			listener.aboutToBeReconciled();
 		}
 	}
 
+	@Override
+	public void aboutToWork(JavaReconciler javaReconciler) {
+		// Notify AST provider
+		CoreASTProvider.getInstance().aboutToBeReconciled(getInputJavaElement(), javaReconciler::signalWaitForFinish);
+	}
+
 	/*
 	 * @see org.eclipse.jdt.internal.ui.text.java.IJavaReconcilingListener#reconciled(CompilationUnit, boolean, IProgressMonitor)
 	 * @since 3.0
