@@ -32,11 +32,9 @@ import org.eclipse.core.resources.IResource;
 import org.eclipse.jface.viewers.IBaseLabelProvider;
 import org.eclipse.jface.viewers.ILabelProvider;
 import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.ISelectionProvider;
 import org.eclipse.jface.viewers.ITreeContentProvider;
 import org.eclipse.jface.viewers.LabelProviderChangedEvent;
-import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.jface.viewers.StyledString;
 import org.eclipse.jface.viewers.TreeViewer;
 import org.eclipse.jface.viewers.Viewer;
@@ -470,19 +468,16 @@ public class JavaEditorBreadcrumb extends EditorBreadcrumb {
 			if (changedElement == null)
 				return;
 
-			fRunnable= new Runnable() {
-				@Override
-				public void run() {
-					if (fViewer == null)
-						return;
+			fRunnable= () -> {
+				if (fViewer == null)
+					return;
 
-					Object newInput= getCurrentInput();
-					if (newInput instanceof IJavaElement)
-						newInput= getInput((IJavaElement) newInput);
+				Object newInput= getCurrentInput();
+				if (newInput instanceof IJavaElement)
+					newInput= getInput((IJavaElement) newInput);
 
-					fViewer.setInput(newInput);
-					fRunnable= null;
-				}
+				fViewer.setInput(newInput);
+				fRunnable= null;
 			};
 			fViewer.getControl().getDisplay().asyncExec(fRunnable);
 		}
@@ -541,7 +536,7 @@ public class JavaEditorBreadcrumb extends EditorBreadcrumb {
 			if (delta.getKind() != IJavaElementDelta.CHANGED)
 				return true;
 
-			return (delta.getFlags() & IJavaElementDelta.F_CONTENT | IJavaElementDelta.F_FINE_GRAINED) == IJavaElementDelta.F_CONTENT;
+			return (delta.getFlags() & (IJavaElementDelta.F_CONTENT | IJavaElementDelta.F_FINE_GRAINED)) == IJavaElementDelta.F_CONTENT;
 		}
 
 		private boolean onlyChildrenChanged(IJavaElementDelta delta) {
@@ -599,12 +594,7 @@ public class JavaEditorBreadcrumb extends EditorBreadcrumb {
 		fViewer.setToolTipLabelProvider(createToolTipLabelProvider());
 
 		fViewer.setContentProvider(createContentProvider());
-		fViewer.addSelectionChangedListener(new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				fBreadcrumbActionGroup.setContext(new ActionContext(fViewer.getSelection()));
-			}
-		});
+		fViewer.addSelectionChangedListener(event -> fBreadcrumbActionGroup.setContext(new ActionContext(fViewer.getSelection())));
 
 		fBreadcrumbActionGroup= new JavaEditorBreadcrumbActionGroup(getJavaEditor(), fViewer);
 
@@ -651,11 +641,8 @@ public class JavaEditorBreadcrumb extends EditorBreadcrumb {
 				for (IPackageFragmentRoot root : project.getPackageFragmentRoots()) {
 					IClasspathEntry classpathEntry= JavaModelUtil.getClasspathEntry(root);
 					int entryKind= classpathEntry.getEntryKind();
-					if (entryKind == IClasspathEntry.CPE_CONTAINER) {
-						// all ClassPathContainers are added later
-					} else if (SHOW_LIBRARIES_NODE && (entryKind == IClasspathEntry.CPE_LIBRARY || entryKind == IClasspathEntry.CPE_VARIABLE)) {
-						// skip: will add the referenced library node later
-					} else {
+					if (entryKind != IClasspathEntry.CPE_CONTAINER // all ClassPathContainers are added later
+							&& (!SHOW_LIBRARIES_NODE || (entryKind != IClasspathEntry.CPE_LIBRARY && entryKind != IClasspathEntry.CPE_VARIABLE))) { // skip: will add the referenced library node later
 						if (isProjectPackageFragmentRoot(root)) {
 							// filter out package fragments that correspond to projects and
 							// replace them with the package fragments directly
