@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -39,19 +39,25 @@ import org.eclipse.jdt.core.dom.ASTNode;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.dom.ConstructorInvocation;
 import org.eclipse.jdt.core.dom.Expression;
+import org.eclipse.jdt.core.dom.GuardedPattern;
 import org.eclipse.jdt.core.dom.IMethodBinding;
+import org.eclipse.jdt.core.dom.Modifier;
+import org.eclipse.jdt.core.dom.Modifier.ModifierKeyword;
+import org.eclipse.jdt.core.dom.RecordDeclaration;
 import org.eclipse.jdt.core.dom.SimpleName;
 import org.eclipse.jdt.core.dom.SimpleType;
 import org.eclipse.jdt.core.dom.SuperConstructorInvocation;
+import org.eclipse.jdt.core.dom.TypeDeclaration;
+import org.eclipse.jdt.core.dom.YieldStatement;
 import org.eclipse.jdt.core.manipulation.SharedASTProviderCore;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.javaeditor.SemanticHighlightingManager.HighlightedPosition;
 import org.eclipse.jdt.internal.ui.javaeditor.SemanticHighlightingManager.Highlighting;
 import org.eclipse.jdt.internal.ui.javaeditor.SemanticHighlightings.DeprecatedMemberHighlighting;
-import org.eclipse.jdt.internal.ui.javaeditor.SemanticHighlightings.VarKeywordHighlighting;
+import org.eclipse.jdt.internal.ui.javaeditor.SemanticHighlightings.RestrictedIdentifiersHighlighting;
 import org.eclipse.jdt.internal.ui.text.java.IJavaReconcilingListener;
-
+import org.eclipse.jdt.internal.ui.util.ASTHelper;
 
 /**
  * Semantic highlighting reconciler - Background thread implementation.
@@ -126,13 +132,100 @@ public class SemanticHighlightingReconciler implements IJavaReconcilingListener,
 
 		@Override
 		public boolean visit(SimpleType node) {
-			if (node.getAST().apiLevel() >= AST.JLS10 && node.isVar()) {
+			if (node.getAST().apiLevel() >= ASTHelper.JLS10 && node.isVar()) {
 				int offset= node.getStartPosition();
 				int length= node.getLength();
 				if (offset > -1 && length > 0) {
 					for (int i= 0; i < fJobSemanticHighlightings.length; i++) {
 						SemanticHighlighting semanticHighlighting= fJobSemanticHighlightings[i];
-						if (semanticHighlighting instanceof VarKeywordHighlighting) {
+						if (semanticHighlighting instanceof RestrictedIdentifiersHighlighting) {
+							addPosition(offset, length, fJobHighlightings[i]);
+							return false;
+						}
+					}
+				}
+			}
+			return true;
+		}
+
+		@Override
+		public boolean visit(YieldStatement node) {
+			AST ast= node.getAST();
+			if (ASTHelper.isYieldNodeSupportedInAST(ast) && !node.isImplicit()) {
+				int offset= node.getStartPosition();
+				int length= 5; // length of 'yield'
+				if (offset > -1 && length > 0) {
+					for (int i= 0; i < fJobSemanticHighlightings.length; i++) {
+						SemanticHighlighting semanticHighlighting= fJobSemanticHighlightings[i];
+						if (semanticHighlighting instanceof RestrictedIdentifiersHighlighting) {
+							addPosition(offset, length, fJobHighlightings[i]);
+							return true;
+						}
+					}
+				}
+			}
+			return true;
+		}
+
+		@Override
+		public boolean visit(RecordDeclaration node) {
+			AST ast= node.getAST();
+			if (ASTHelper.isRecordDeclarationNodeSupportedInAST(ast)) {
+				int offset= node.getRestrictedIdentifierStartPosition();
+				int length= 6; // length of 'record'
+				if (offset > -1 && length > 0) {
+					for (int i= 0; i < fJobSemanticHighlightings.length; i++) {
+						SemanticHighlighting semanticHighlighting= fJobSemanticHighlightings[i];
+						if (semanticHighlighting instanceof RestrictedIdentifiersHighlighting) {
+							addPosition(offset, length, fJobHighlightings[i]);
+							return true;
+						}
+					}
+				}
+			}
+			return true;
+		}
+
+		@Override
+		public boolean visit(TypeDeclaration node) {
+			try {
+				if (node.permittedTypes().size() > 0) {
+					int offset= node.getRestrictedIdentifierStartPosition();
+					int length= 7; // length of 'permits'
+					if (offset > -1) {
+						for (int i= 0; i < fJobSemanticHighlightings.length; i++) {
+							SemanticHighlighting semanticHighlighting= fJobSemanticHighlightings[i];
+							if (semanticHighlighting instanceof RestrictedIdentifiersHighlighting) {
+								addPosition(offset, length, fJobHighlightings[i]);
+								return true;
+							}
+						}
+					}
+				}
+			} catch (UnsupportedOperationException e) {
+				// do nothing
+			}
+			return true;
+		}
+
+		@Override
+		public boolean visit(Modifier node) {
+			AST ast= node.getAST();
+			if (ASTHelper.isSealedTypeSupportedInAST(ast)) {
+				ModifierKeyword keyword= node.getKeyword();
+				int offset= node.getStartPosition();
+				int length;
+				if (keyword == ModifierKeyword.SEALED_KEYWORD) {
+					length= 6;
+				} else if (keyword == ModifierKeyword.NON_SEALED_KEYWORD) {
+					length= 10;
+				} else {
+					return true;
+				}
+				if (offset > -1 && length > 0) {
+					for (int i= 0; i < fJobSemanticHighlightings.length; i++) {
+						SemanticHighlighting semanticHighlighting= fJobSemanticHighlightings[i];
+						if (semanticHighlighting instanceof RestrictedIdentifiersHighlighting) {
 							addPosition(offset, length, fJobHighlightings[i]);
 							return false;
 						}
@@ -205,6 +298,28 @@ public class SemanticHighlightingReconciler implements IJavaReconcilingListener,
 				}
 			}
 		}
+
+		@Override
+		public boolean visit(GuardedPattern node) {
+			try {
+				if (node != null) {
+					int offset= node.getRestrictedIdentifierStartPosition();
+					int length= 4; // length of 'when'
+					if (offset > -1) {
+						for (int i= 0; i < fJobSemanticHighlightings.length; i++) {
+							SemanticHighlighting semanticHighlighting= fJobSemanticHighlightings[i];
+							if (semanticHighlighting instanceof RestrictedIdentifiersHighlighting) {
+								addPosition(offset, length, fJobHighlightings[i]);
+								return true;
+							}
+						}
+					}
+				}
+			} catch (UnsupportedOperationException e) {
+				// do nothing
+			}
+			return true;
+		}
 	}
 
 	/** Position collector */
@@ -354,12 +469,11 @@ public class SemanticHighlightingReconciler implements IJavaReconcilingListener,
 
 
 
-		for (int i= 0, n= subtrees.length; i < n; i++)
-			subtrees[i].accept(fCollector);
+		for (ASTNode subtree : subtrees)
+			subtree.accept(fCollector);
 		List<Position> oldPositions= fRemovedPositions;
 		List<Position> newPositions= new ArrayList<>(fNOfRemovedPositions);
-		for (int i= 0, n= oldPositions.size(); i < n; i ++) {
-			Position current= oldPositions.get(i);
+		for (Position current : oldPositions) {
 			if (current != null)
 				newPositions.add(current);
 		}
