@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2018, 2019 Angelo Zerr and others.
+ * Copyright (c) 2018, 2020 Angelo Zerr and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  * - Angelo Zerr: initial API and implementation
+ * - IBM Corporation
  *******************************************************************************/
 package org.eclipse.jdt.internal.ui.javaeditor.codemining;
 
@@ -35,6 +36,8 @@ import org.eclipse.ui.IEditorPart;
 
 import org.eclipse.ui.texteditor.ITextEditor;
 
+import org.eclipse.search.ui.NewSearchUI;
+
 import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.JavaCore;
@@ -84,7 +87,7 @@ public class JavaReferenceCodeMining extends AbstractJavaElementLineHeaderCodeMi
 				long refCount= countReferences(element, monitor);
 				monitor.isCanceled();
 				action= refCount > 0 ? e -> {
-					if (refCount == 1 && (e.stateMask & SWT.CTRL) == SWT.CTRL) {
+					if (refCount == 1 && ((e.stateMask & SWT.CTRL) == SWT.CTRL || (e.stateMask & SWT.COMMAND) == SWT.COMMAND)) {
 						// Ctrl + Click is done, open the referenced element in the Java Editor
 						try {
 							SearchMatch match= getReferenceMatch(element, monitor);
@@ -97,8 +100,6 @@ public class JavaReferenceCodeMining extends AbstractJavaElementLineHeaderCodeMi
 									textEditor.selectAndReveal(match.getOffset(), match.getLength());
 								}
 							}
-						} catch (JavaModelException e1) {
-							// Should never occur
 						} catch (CoreException e1) {
 							// Should never occur
 						}
@@ -112,8 +113,6 @@ public class JavaReferenceCodeMining extends AbstractJavaElementLineHeaderCodeMi
 				} else {
 					super.setLabel(MessageFormat.format(JavaCodeMiningMessages.JavaReferenceCodeMining_label, refCount));
 				}
-			} catch (JavaModelException e) {
-				// Should never occur
 			} catch (CoreException e) {
 				// Should never occur
 			}
@@ -141,12 +140,19 @@ public class JavaReferenceCodeMining extends AbstractJavaElementLineHeaderCodeMi
 		}
 		final AtomicLong count= new AtomicLong(0);
 		SearchPattern pattern= SearchPattern.createPattern(element, IJavaSearchConstants.REFERENCES);
+		if (pattern == null) {
+			return 0;
+		}
 		SearchEngine engine= new SearchEngine();
+		final boolean ignoreInaccurate= NewSearchUI.arePotentialMatchesIgnored();
 		engine.search(pattern, new SearchParticipant[] { SearchEngine.getDefaultSearchParticipant() },
 				createSearchScope(element), new SearchRequestor() {
 
 					@Override
 					public void acceptSearchMatch(SearchMatch match) throws CoreException {
+						if (match.getAccuracy() == SearchMatch.A_INACCURATE && ignoreInaccurate) {
+							return;
+						}
 						Object o= match.getElement();
 						if (o instanceof IJavaElement) {
 							IJavaElement e= (IJavaElement)o;
@@ -177,6 +183,9 @@ public class JavaReferenceCodeMining extends AbstractJavaElementLineHeaderCodeMi
 		}
 		final SearchMatch[] matches= new SearchMatch[1];
 		SearchPattern pattern= SearchPattern.createPattern(element, IJavaSearchConstants.REFERENCES);
+		if (pattern == null) {
+			return null;
+		}
 		SearchEngine engine= new SearchEngine();
 		engine.search(pattern, new SearchParticipant[] { SearchEngine.getDefaultSearchParticipant() },
 				createSourceSearchScope(), new SearchRequestor() {
