@@ -19,7 +19,6 @@ import java.io.StringReader;
 import java.io.StringWriter;
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.help.IContextProvider;
@@ -56,8 +55,6 @@ import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.util.IPropertyChangeListener;
 import org.eclipse.jface.util.PropertyChangeEvent;
 import org.eclipse.jface.viewers.AbstractTreeViewer;
-import org.eclipse.jface.viewers.DoubleClickEvent;
-import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.IElementComparer;
 import org.eclipse.jface.viewers.ILabelDecorator;
 import org.eclipse.jface.viewers.ISelection;
@@ -91,7 +88,6 @@ import org.eclipse.ui.internal.views.helpers.EmptyWorkspaceHelper;
 import org.eclipse.ui.part.ISetSelectionTarget;
 import org.eclipse.ui.part.IShowInSource;
 import org.eclipse.ui.part.IShowInTarget;
-import org.eclipse.ui.part.IShowInTargetList;
 import org.eclipse.ui.part.ShowInContext;
 import org.eclipse.ui.part.ViewPart;
 import org.eclipse.ui.views.framelist.Frame;
@@ -113,6 +109,7 @@ import org.eclipse.jdt.core.IType;
 import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
 
+import org.eclipse.jdt.internal.core.manipulation.MembersOrderPreferenceCacheCommon;
 import org.eclipse.jdt.internal.corext.util.Messages;
 
 import org.eclipse.jdt.ui.IPackagesViewPart;
@@ -129,8 +126,8 @@ import org.eclipse.jdt.internal.ui.dnd.JdtViewerDragSupport;
 import org.eclipse.jdt.internal.ui.dnd.JdtViewerDropSupport;
 import org.eclipse.jdt.internal.ui.filters.OutputFolderFilter;
 import org.eclipse.jdt.internal.ui.javaeditor.EditorUtility;
-import org.eclipse.jdt.internal.ui.preferences.MembersOrderPreferenceCache;
 import org.eclipse.jdt.internal.ui.util.JavaUIHelp;
+import org.eclipse.jdt.internal.ui.util.SWTUtil;
 import org.eclipse.jdt.internal.ui.util.SelectionUtil;
 import org.eclipse.jdt.internal.ui.viewsupport.AppearanceAwareLabelProvider;
 import org.eclipse.jdt.internal.ui.viewsupport.BasicElementLabels;
@@ -260,7 +257,7 @@ public class PackageExplorerPart extends ViewPart
 			fPendingRefreshes= Collections.synchronizedList(new ArrayList<>());
 		}
 		@Override
-		public void add(Object parentElement, Object[] childElements) {
+		public void add(Object parentElement, Object... childElements) {
 			if (fPendingRefreshes.contains(parentElement)) {
 				return;
 			}
@@ -326,8 +323,7 @@ public class PackageExplorerPart extends ViewPart
 				ns= new ArrayList<>();
 			}
 			boolean changed= false;
-			for (Iterator<?> iter= is.iterator(); iter.hasNext();) {
-				Object element= iter.next();
+			for (Object element : is) {
 				if (element instanceof IJavaProject) {
 					IProject project= ((IJavaProject)element).getProject();
 					if (!project.isOpen() && project.exists()) {
@@ -411,7 +407,7 @@ public class PackageExplorerPart extends ViewPart
 
 	private void restoreRootMode(IMemento memento) {
 		Integer value= memento.getInteger(TAG_ROOT_MODE);
-		fRootMode= value == null ? PROJECTS_AS_ROOTS : value.intValue();
+		fRootMode= value == null ? PROJECTS_AS_ROOTS : value;
 		if (fRootMode != PROJECTS_AS_ROOTS && fRootMode != WORKING_SETS_AS_ROOTS)
 			fRootMode= PROJECTS_AS_ROOTS;
 	}
@@ -525,12 +521,7 @@ public class PackageExplorerPart extends ViewPart
 		initFrameActions();
 		initKeyListener();
 
-		fViewer.addDoubleClickListener(new IDoubleClickListener() {
-			@Override
-			public void doubleClick(DoubleClickEvent event) {
-				fActionSet.handleDoubleClick(event);
-			}
-		});
+		fViewer.addDoubleClickListener(event -> fActionSet.handleDoubleClick(event));
 
 		fOpenAndLinkWithEditorHelper= new OpenAndLinkWithEditorHelper(fViewer) {
 			@Override
@@ -703,15 +694,6 @@ public class PackageExplorerPart extends ViewPart
 		if (key == IShowInSource.class) {
 			return (T) getShowInSource();
 		}
-		if (key == IShowInTargetList.class) {
-			return (T) new IShowInTargetList() {
-				@Override
-				public String[] getShowInTargetIds() {
-					return new String[] { JavaPlugin.ID_RES_NAV };
-				}
-
-			};
-		}
 		if (key == IContextProvider.class) {
 			return (T) JavaUIHelp.getHelpContextProvider(this, IJavaHelpContextIds.PACKAGES_VIEW);
 		}
@@ -837,9 +819,8 @@ public class PackageExplorerPart extends ViewPart
 
 	@Override
 	public void refresh(IStructuredSelection selection) {
-		Object[] selectedElements= selection.toArray();
-		for (int i= 0; i < selectedElements.length; i++) {
-			fViewer.refresh(selectedElements[i]);
+		for (Object selectedElement : selection.toArray()) {
+			fViewer.refresh(selectedElement);
 		}
 	}
 
@@ -1137,13 +1118,10 @@ public class PackageExplorerPart extends ViewPart
 				final IType type2= type;
 				Control ctrl= fViewer.getControl();
 				if (ctrl != null && !ctrl.isDisposed()) {
-					ctrl.getDisplay().asyncExec(new Runnable() {
-						@Override
-						public void run() {
-							Control ctrl2= fViewer.getControl();
-							if (ctrl2 != null && !ctrl2.isDisposed())
-								fViewer.expandToLevel(type2, 1);
-						}
+					ctrl.getDisplay().asyncExec(() -> {
+						Control ctrl2= fViewer.getControl();
+						if (ctrl2 != null && !ctrl2.isDisposed())
+							fViewer.expandToLevel(type2, 1);
 					});
 				}
 			}
@@ -1212,23 +1190,25 @@ public class PackageExplorerPart extends ViewPart
 		if (fViewer == null)
 			return;
 
-		boolean refreshViewer= false;
+		SWTUtil.execDirectOrAsyncIfNecessary(fViewer::getControl, ()-> {
+			boolean refreshViewer= false;
 
-		if (PreferenceConstants.SHOW_CU_CHILDREN.equals(event.getProperty())) {
-			boolean showCUChildren= PreferenceConstants.getPreferenceStore().getBoolean(PreferenceConstants.SHOW_CU_CHILDREN);
-			((StandardJavaElementContentProvider)fViewer.getContentProvider()).setProvideMembers(showCUChildren);
+			if (PreferenceConstants.SHOW_CU_CHILDREN.equals(event.getProperty())) {
+				boolean showCUChildren= PreferenceConstants.getPreferenceStore().getBoolean(PreferenceConstants.SHOW_CU_CHILDREN);
+				((StandardJavaElementContentProvider)fViewer.getContentProvider()).setProvideMembers(showCUChildren);
 
-			refreshViewer= true;
-		} else if (MembersOrderPreferenceCache.isMemberOrderProperty(event.getProperty())) {
-			refreshViewer= true;
-		} else if (PreferenceConstants.APPEARANCE_SORT_LIBRARY_ENTRIES_BY_NAME.equals(event.getProperty())) {
-			// set new comparator, since it might evaluate this property on construction
-			setComparator();
-			refreshViewer = true;
-		}
+				refreshViewer= true;
+			} else if (MembersOrderPreferenceCacheCommon.isMemberOrderProperty(event.getProperty())) {
+				refreshViewer= true;
+			} else if (PreferenceConstants.APPEARANCE_SORT_LIBRARY_ENTRIES_BY_NAME.equals(event.getProperty())) {
+				// set new comparator, since it might evaluate this property on construction
+				setComparator();
+				refreshViewer = true; // is this really necessary? setComparator() calls refresh if the comparator changes
+			}
 
-		if (refreshViewer)
-			fViewer.refresh();
+			if (refreshViewer)
+				fViewer.refresh();
+		});
 	}
 
 	@Override
@@ -1280,14 +1260,9 @@ public class PackageExplorerPart extends ViewPart
 	 * @return the <code>IShowInSource</code>
 	 */
 	protected IShowInSource getShowInSource() {
-		return new IShowInSource() {
-			@Override
-			public ShowInContext getShowInContext() {
-				return new ShowInContext(
-					getTreeViewer().getInput(),
-					getTreeViewer().getSelection());
-			}
-		};
+		return () -> new ShowInContext(
+			getTreeViewer().getInput(),
+			getTreeViewer().getSelection());
 	}
 
 	@Override
