@@ -25,11 +25,8 @@ import com.ibm.icu.text.Collator;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.StyledText;
-import org.eclipse.swt.events.DisposeEvent;
-import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.events.FocusEvent;
 import org.eclipse.swt.events.FocusListener;
-import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
@@ -51,7 +48,6 @@ import org.eclipse.core.expressions.Expression;
 import org.eclipse.jface.action.Action;
 import org.eclipse.jface.action.GroupMarker;
 import org.eclipse.jface.action.IAction;
-import org.eclipse.jface.action.IMenuListener;
 import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.action.Separator;
@@ -62,17 +58,13 @@ import org.eclipse.jface.dialogs.StatusDialog;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.resource.JFaceResources;
 import org.eclipse.jface.util.BidiUtils;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
-import org.eclipse.jface.viewers.SelectionChangedEvent;
 
 import org.eclipse.jface.text.BadLocationException;
 import org.eclipse.jface.text.Document;
 import org.eclipse.jface.text.IDocument;
 import org.eclipse.jface.text.IRegion;
-import org.eclipse.jface.text.ITextListener;
 import org.eclipse.jface.text.ITextOperationTarget;
 import org.eclipse.jface.text.ITextViewer;
-import org.eclipse.jface.text.TextEvent;
 import org.eclipse.jface.text.source.ISourceViewer;
 import org.eclipse.jface.text.source.SourceViewer;
 import org.eclipse.jface.text.templates.ContextTypeRegistry;
@@ -83,6 +75,7 @@ import org.eclipse.jface.text.templates.TemplateException;
 import org.eclipse.ui.ActiveShellExpression;
 import org.eclipse.ui.IWorkbenchCommandConstants;
 import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.actions.ActionFactory;
 import org.eclipse.ui.handlers.IHandlerActivation;
 import org.eclipse.ui.handlers.IHandlerService;
 
@@ -112,7 +105,7 @@ import org.eclipse.jdt.internal.ui.util.SWTUtil;
  */
 public class EditTemplateDialog extends StatusDialog {
 
-	private static class TextViewerAction extends Action implements IUpdate {
+	protected static class TextViewerAction extends Action implements IUpdate {
 
 		private int fOperationCode= -1;
 		private ITextOperationTarget fOperationTarget;
@@ -206,7 +199,7 @@ public class EditTemplateDialog extends StatusDialog {
 		List<String[]> contexts= new ArrayList<>();
 		for (Iterator<TemplateContextType> it= registry.contextTypes(); it.hasNext();) {
 			TemplateContextType type= it.next();
-			if (type.getId().equals("javadoc")) //$NON-NLS-1$
+			if ("javadoc".equals(type.getId())) //$NON-NLS-1$
 				contexts.add(new String[] { type.getId(), type.getName(), "/**" + delim }); //$NON-NLS-1$
 			else
 				contexts.add(0, new String[] { type.getId(), type.getName(), "" }); //$NON-NLS-1$
@@ -263,12 +256,7 @@ public class EditTemplateDialog extends StatusDialog {
 		parent.setLayout(layout);
 		parent.setLayoutData(new GridData(GridData.FILL_BOTH));
 
-		ModifyListener listener= new ModifyListener() {
-			@Override
-			public void modifyText(ModifyEvent e) {
-				doTextWidgetChanged(e.widget);
-			}
-		};
+		ModifyListener listener= e -> doTextWidgetChanged(e.widget);
 
 		if (fIsNameModifiable) {
 			createLabel(parent, PreferencesMessages.EditTemplateDialog_name);
@@ -466,20 +454,12 @@ public class EditTemplateDialog extends StatusDialog {
 		data.heightHint= convertHeightInCharsToPixels(nLines);
 		control.setLayoutData(data);
 
-		viewer.addTextListener(new ITextListener() {
-			@Override
-			public void textChanged(TextEvent event) {
-				if (event .getDocumentEvent() != null)
-					doSourceChanged(event.getDocumentEvent().getDocument());
-			}
+		viewer.addTextListener(event -> {
+			if (event .getDocumentEvent() != null)
+				doSourceChanged(event.getDocumentEvent().getDocument());
 		});
 
-		viewer.addSelectionChangedListener(new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				updateSelectionDependentActions();
-			}
-		});
+		viewer.addSelectionChangedListener(event -> updateSelectionDependentActions());
 
 		return viewer;
 	}
@@ -498,12 +478,7 @@ public class EditTemplateDialog extends StatusDialog {
 		final IHandlerService handlerService= PlatformUI.getWorkbench().getAdapter(IHandlerService.class);
 		final Expression expression= new ActiveShellExpression(fPatternEditor.getControl().getShell());
 
-		getShell().addDisposeListener(new DisposeListener() {
-			@Override
-			public void widgetDisposed(DisposeEvent e) {
-				handlerService.deactivateHandlers(handlerActivations);
-				}
-						});
+		getShell().addDisposeListener(e -> handlerService.deactivateHandlers(handlerActivations));
 
 		fPatternEditor.getTextWidget().addFocusListener(new FocusListener() {
 			@Override
@@ -523,26 +498,32 @@ public class EditTemplateDialog extends StatusDialog {
 
 
 		TextViewerAction action= new TextViewerAction(fPatternEditor, ITextOperationTarget.UNDO);
+		action.setActionDefinitionId(ActionFactory.UNDO.getCommandId());
 		action.setText(PreferencesMessages.EditTemplateDialog_undo);
 		fGlobalActions.put(ITextEditorActionConstants.UNDO, action);
 
 		action= new TextViewerAction(fPatternEditor, ITextOperationTarget.REDO);
+		action.setActionDefinitionId(ActionFactory.REDO.getCommandId());
 		action.setText(PreferencesMessages.EditTemplateDialog_redo);
 		fGlobalActions.put(ITextEditorActionConstants.REDO, action);
 
 		action= new TextViewerAction(fPatternEditor, ITextOperationTarget.CUT);
+		action.setActionDefinitionId(ActionFactory.CUT.getCommandId());
 		action.setText(PreferencesMessages.EditTemplateDialog_cut);
 		fGlobalActions.put(ITextEditorActionConstants.CUT, action);
 
 		action= new TextViewerAction(fPatternEditor, ITextOperationTarget.COPY);
+		action.setActionDefinitionId(ActionFactory.COPY.getCommandId());
 		action.setText(PreferencesMessages.EditTemplateDialog_copy);
 		fGlobalActions.put(ITextEditorActionConstants.COPY, action);
 
 		action= new TextViewerAction(fPatternEditor, ITextOperationTarget.PASTE);
+		action.setActionDefinitionId(ActionFactory.PASTE.getCommandId());
 		action.setText(PreferencesMessages.EditTemplateDialog_paste);
 		fGlobalActions.put(ITextEditorActionConstants.PASTE, action);
 
 		action= new TextViewerAction(fPatternEditor, ITextOperationTarget.SELECT_ALL);
+		action.setActionDefinitionId(ActionFactory.SELECT_ALL.getCommandId());
 		action.setText(PreferencesMessages.EditTemplateDialog_select_all);
 		fGlobalActions.put(ITextEditorActionConstants.SELECT_ALL, action);
 
@@ -557,12 +538,7 @@ public class EditTemplateDialog extends StatusDialog {
 		// create context menu
 		MenuManager manager= new MenuManager(null, null);
 		manager.setRemoveAllWhenShown(true);
-		manager.addMenuListener(new IMenuListener() {
-			@Override
-			public void menuAboutToShow(IMenuManager mgr) {
-				fillContextMenu(mgr);
-			}
-		});
+		manager.addMenuListener(this::fillContextMenu);
 
 		StyledText text= fPatternEditor.getTextWidget();
 		Menu menu= manager.createContextMenu(text);
@@ -647,7 +623,7 @@ public class EditTemplateDialog extends StatusDialog {
 	private boolean isValidPattern(String pattern) {
 		for (int i= 0; i < pattern.length(); i++) {
 			char ch= pattern.charAt(i);
-			if (!(ch == 9 || ch == 10 || ch == 13 || ch >= 32))
+			if ((ch != 9) && (ch != 10) && (ch != 13) && (ch < 32))
 				return false;
 		}
 		return true;
