@@ -183,8 +183,7 @@ public class NameConventionConfigurationBlock extends OptionsConfigurationBlock
 		}
 
 		private IStatus validateIdentifiers(String[] values, boolean prefix) {
-			for (int i= 0; i < values.length; i++) {
-				String val= values[i];
+			for (String val : values) {
 				if (val.length() == 0) {
 					if (prefix) {
 						return new StatusInfo(IStatus.ERROR, PreferencesMessages.NameConventionConfigurationBlock_error_emptyprefix);
@@ -243,7 +242,6 @@ public class NameConventionConfigurationBlock extends OptionsConfigurationBlock
 				case STATIC_FINAL:
 					return registry.get(new JavaElementImageDescriptor(JavaPluginImages.DESC_FIELD_PUBLIC, JavaElementImageDescriptor.STATIC | JavaElementImageDescriptor.FINAL, JavaElementImageProvider.SMALL_SIZE));
 				case ARGUMENT:
-					return registry.get(JavaPluginImages.DESC_OBJS_LOCAL_VARIABLE);
 				default:
 					return registry.get(JavaPluginImages.DESC_OBJS_LOCAL_VARIABLE);
 			}
@@ -251,22 +249,23 @@ public class NameConventionConfigurationBlock extends OptionsConfigurationBlock
 		@Override
 		public String getColumnText(Object element, int columnIndex) {
 			NameConventionEntry entry= (NameConventionEntry) element;
-			if (columnIndex == 0) {
+			switch (columnIndex) {
+			case 0:
 				switch (entry.kind) {
-					case FIELD:
-						return PreferencesMessages.NameConventionConfigurationBlock_field_label;
-					case STATIC:
-						return PreferencesMessages.NameConventionConfigurationBlock_static_label;
-					case STATIC_FINAL:
-						return PreferencesMessages.NameConventionConfigurationBlock_static_final_label;
-					case ARGUMENT:
-						return PreferencesMessages.NameConventionConfigurationBlock_arg_label;
-					default:
-						return PreferencesMessages.NameConventionConfigurationBlock_local_label;
+				case FIELD:
+					return PreferencesMessages.NameConventionConfigurationBlock_field_label;
+				case STATIC:
+					return PreferencesMessages.NameConventionConfigurationBlock_static_label;
+				case STATIC_FINAL:
+					return PreferencesMessages.NameConventionConfigurationBlock_static_final_label;
+				case ARGUMENT:
+					return PreferencesMessages.NameConventionConfigurationBlock_arg_label;
+				default:
+					return PreferencesMessages.NameConventionConfigurationBlock_local_label;
 				}
-			} else if (columnIndex == 1) {
+			case 1:
 				return entry.prefix;
-			} else {
+			default:
 				return entry.suffix;
 			}
 		}
@@ -402,7 +401,7 @@ public class NameConventionConfigurationBlock extends OptionsConfigurationBlock
 		fUseIsForBooleanGettersBox.doFillIntoGrid(composite, 3);
 
 		fUseOverrideAnnotation.doFillIntoGrid(composite, 3);
-		
+
 		Link seeProblemSeverity= new Link(composite, SWT.WRAP);
 		data= new GridData(SWT.BEGINNING, SWT.CENTER, true, false, 3, 1);
 		seeProblemSeverity.setLayoutData(data);
@@ -421,7 +420,7 @@ public class NameConventionConfigurationBlock extends OptionsConfigurationBlock
 				}
 			}
 		});
-		
+
 		DialogField.createEmptySpace(composite, 3);
 
 		fExceptionName.doFillIntoGrid(composite, 2);
