@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -104,8 +104,6 @@ import org.eclipse.jdt.internal.ui.preferences.formatter.ProfileManager.CustomPr
 import org.eclipse.jdt.internal.ui.preferences.formatter.ProfileManager.Profile;
 import org.eclipse.jdt.internal.ui.util.ExceptionHandler;
 import org.eclipse.jdt.internal.ui.util.SWTUtil;
-import org.eclipse.jdt.internal.ui.wizards.dialogfields.DialogField;
-import org.eclipse.jdt.internal.ui.wizards.dialogfields.IDialogFieldListener;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.LayoutUtil;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.StringDialogField;
 
@@ -902,7 +900,7 @@ public abstract class ModifyDialog extends StatusDialog implements IModification
 					doValidate();
 					return true;
 				};
-				((Preference<?>) node).init(fWorkingValues, validator , () -> valuesModified());
+				((Preference<?>) node).init(fWorkingValues, validator, ModifyDialog.this::valuesModified);
 			}
 
 			if (!(node instanceof Section)) {
@@ -1048,7 +1046,7 @@ public abstract class ModifyDialog extends StatusDialog implements IModification
 		}
 	}
 
-	public class Images {
+	public static class Images {
 		private Map<ImageDescriptor, Image> imagesMap= new HashMap<>();
 
 		protected Images(Composite rootComposite) {
@@ -1096,7 +1094,7 @@ public abstract class ModifyDialog extends StatusDialog implements IModification
 		private void add(Control control) {
 			control.addFocusListener(this);
 			fItemList.add(fIndex, control);
-			fItemMap.put(control, Integer.valueOf(fIndex++));
+			fItemMap.put(control, fIndex++);
 		}
 
 		@Override
@@ -1109,7 +1107,7 @@ public abstract class ModifyDialog extends StatusDialog implements IModification
 				updatePreviewCode();
 			}
 
-			fDialogSettings.put(fKeyLastFocusIndex, fItemMap.get(e.widget).intValue());
+			fDialogSettings.put(fKeyLastFocusIndex, fItemMap.get(e.widget));
 		}
 
 		private void highlightCurrent(boolean focus) {
@@ -1129,7 +1127,10 @@ public abstract class ModifyDialog extends StatusDialog implements IModification
 			Display.getCurrent().asyncExec(() -> {
 				FontData fd= control.getFont().getFontData()[0];
 				int style= italic ? (fd.getStyle() | SWT.ITALIC) : (fd.getStyle() & ~SWT.ITALIC);
-				control.setFont(new Font(control.getDisplay(), new FontData(fd.getName(), fd.getHeight(), style)));
+				FontData fontData= new FontData(fd.getName(), fd.getHeight(), style);
+				Font font= new Font(control.getDisplay(), fontData);
+				control.addDisposeListener(e -> font.dispose());
+				control.setFont(font);
 				if (control instanceof Composite)
 					((Composite) control).layout();
 			});
@@ -1301,12 +1302,7 @@ public abstract class ModifyDialog extends StatusDialog implements IModification
 		fProfileNameField.setText(fProfile.getName());
 		fProfileNameField.getLabelControl(nameComposite).setLayoutData(new GridData(SWT.LEFT, SWT.CENTER, false, false));
 		fProfileNameField.getTextControl(nameComposite).setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
-		fProfileNameField.setDialogFieldListener(new IDialogFieldListener() {
-			@Override
-			public void dialogFieldChanged(DialogField field) {
-				doValidate();
-			}
-		});
+		fProfileNameField.setDialogFieldListener(field -> doValidate());
 
 		fSaveButton= createButton(nameComposite, SAVE_BUTTON_ID, FormatterMessages.ModifyDialog_Export_Button, false);
 	}
@@ -1362,7 +1358,7 @@ public abstract class ModifyDialog extends StatusDialog implements IModification
 		super.okPressed();
 	}
 
-    @Override
+	@Override
 	protected void buttonPressed(int buttonId) {
 		if (buttonId == APPLAY_BUTTON_ID) {
 			applyPressed();
@@ -1372,7 +1368,7 @@ public abstract class ModifyDialog extends StatusDialog implements IModification
 		} else {
 			super.buttonPressed(buttonId);
 		}
-    }
+	}
 
 	private void applyPressed() {
 		if (!fProfile.getName().equals(fProfileNameField.getText())) {
@@ -1419,9 +1415,9 @@ public abstract class ModifyDialog extends StatusDialog implements IModification
 		}
 	}
 
-    @Override
+	@Override
 	protected void createButtonsForButtonBar(Composite parent) {
-	    fApplyButton= createButton(parent, APPLAY_BUTTON_ID, FormatterMessages.ModifyDialog_apply_button, false);
+		fApplyButton= createButton(parent, APPLAY_BUTTON_ID, FormatterMessages.ModifyDialog_apply_button, false);
 		fApplyButton.setEnabled(false);
 
 		GridLayout layout= (GridLayout) parent.getLayout();
@@ -1443,27 +1439,27 @@ public abstract class ModifyDialog extends StatusDialog implements IModification
 
 	@Override
 	protected void updateButtonsEnableState(IStatus status) {
-	    super.updateButtonsEnableState(status);
-	    if (fApplyButton != null && !fApplyButton.isDisposed()) {
-	    	fApplyButton.setEnabled(hasChanges() && !status.matches(IStatus.ERROR));
+		super.updateButtonsEnableState(status);
+		if (fApplyButton != null && !fApplyButton.isDisposed()) {
+			fApplyButton.setEnabled(hasChanges() && !status.matches(IStatus.ERROR));
+		}
+		if (fSaveButton != null && !fSaveButton.isDisposed()) {
+			fSaveButton.setEnabled(!validateProfileName().matches(IStatus.ERROR));
 		}
-	    if (fSaveButton != null && !fSaveButton.isDisposed()) {
-	    	fSaveButton.setEnabled(!validateProfileName().matches(IStatus.ERROR));
-	    }
 	}
 
-    private void doValidate() {
-    	String name= fProfileNameField.getText().trim();
+	private void doValidate() {
+		String name= fProfileNameField.getText().trim();
 		if (name.equals(fProfile.getName()) && fProfile.hasEqualSettings(fWorkingValues, fWorkingValues.keySet())) {
 			updateStatus(StatusInfo.OK_STATUS);
 			return;
 		}
 
-    	IStatus status= validateProfileName();
-    	if (status.matches(IStatus.ERROR)) {
-    		updateStatus(status);
-    		return;
-    	}
+		IStatus status= validateProfileName();
+		if (status.matches(IStatus.ERROR)) {
+			updateStatus(status);
+			return;
+		}
 
 		if (!name.equals(fProfile.getName()) && fProfileManager.containsName(name)) {
 			updateStatus(new Status(IStatus.ERROR, JavaUI.ID_PLUGIN, FormatterMessages.ModifyDialog_Duplicate_Status));
@@ -1475,30 +1471,30 @@ public abstract class ModifyDialog extends StatusDialog implements IModification
 			return;
 		}
 
-	    updateStatus(StatusInfo.OK_STATUS);
-    }
+		updateStatus(StatusInfo.OK_STATUS);
+	}
 
-    private IStatus validateProfileName() {
-    	final String name= fProfileNameField.getText().trim();
+	private IStatus validateProfileName() {
+		final String name= fProfileNameField.getText().trim();
 
-	    if (fProfile.isBuiltInProfile()) {
+		if (fProfile.isBuiltInProfile()) {
 			if (fProfile.getName().equals(name)) {
 				return new Status(IStatus.ERROR, JavaUI.ID_PLUGIN, FormatterMessages.ModifyDialog_BuiltIn_Status);
 			}
-    	}
+		}
 
-    	if (fProfile.isSharedProfile()) {
+		if (fProfile.isSharedProfile()) {
 			if (fProfile.getName().equals(name)) {
 				return new Status(IStatus.ERROR, JavaUI.ID_PLUGIN, FormatterMessages.ModifyDialog_Shared_Status);
 			}
-    	}
+		}
 
 		if (name.length() == 0) {
 			return new Status(IStatus.ERROR, JavaUI.ID_PLUGIN, FormatterMessages.ModifyDialog_EmptyName_Status);
 		}
 
 		return StatusInfo.OK_STATUS;
-    }
+	}
 
 	private boolean hasChanges() {
 		if (!fProfileNameField.getText().trim().equals(fProfile.getName()))
@@ -1581,7 +1577,7 @@ public abstract class ModifyDialog extends StatusDialog implements IModification
 	}
 
 	private String doGetPreviewCode(PreferenceTreeNode<?> node) {
-		if (!(node instanceof Section || node instanceof Preference))
+		if (!(node instanceof Section) && !(node instanceof Preference))
 			return null;
 		String key= node instanceof Section ? ((Section) node).getKey() : ((Preference<?>) node).getKey();
 		final String START_PREFIX= "//--PREVIEW--START--"; //$NON-NLS-1$
