@@ -66,9 +66,7 @@ public final class PropertyValueScanner extends AbstractJavaScanner {
 				if (fDocument instanceof IDocumentExtension3)
 					partition= ((IDocumentExtension3)fDocument).getPartition(IPropertiesFilePartitions.PROPERTIES_FILE_PARTITIONING, i, false);
 				return partition != null && IDocument.DEFAULT_CONTENT_TYPE.equals(partition.getType());
-			} catch (BadLocationException ex) {
-				return false;
-			} catch (BadPartitioningException e) {
+			} catch (BadLocationException | BadPartitioningException e) {
 				return false;
 			}
 		}
