@@ -30,12 +30,7 @@ public class SortAction extends Action {
 
 	@Override
 	public void run() {
-		BusyIndicator.showWhile(fPage.getViewer().getControl().getDisplay(), new Runnable() {
-			@Override
-			public void run() {
-				fPage.setSortOrder(fSortOrder);
-			}
-		});
+		BusyIndicator.showWhile(fPage.getViewer().getControl().getDisplay(), () -> fPage.setSortOrder(fSortOrder));
 	}
 
 	public int getSortOrder() {
