@@ -31,6 +31,7 @@ import org.eclipse.jdt.core.dom.Assignment;
 import org.eclipse.jdt.core.dom.BodyDeclaration;
 import org.eclipse.jdt.core.dom.CastExpression;
 import org.eclipse.jdt.core.dom.CompilationUnit;
+import org.eclipse.jdt.core.dom.ConditionalExpression;
 import org.eclipse.jdt.core.dom.EnhancedForStatement;
 import org.eclipse.jdt.core.dom.Expression;
 import org.eclipse.jdt.core.dom.FieldAccess;
@@ -55,6 +56,9 @@ import org.eclipse.jdt.core.dom.rewrite.ImportRewrite;
 import org.eclipse.jdt.core.dom.rewrite.ImportRewrite.ImportRewriteContext;
 import org.eclipse.jdt.core.dom.rewrite.ImportRewrite.TypeLocation;
 
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
+import org.eclipse.jdt.internal.core.manipulation.dom.ASTResolving;
+import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.corext.codemanipulation.ContextSensitiveImportRewriteContext;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
 import org.eclipse.jdt.internal.corext.dom.Bindings;
@@ -76,12 +80,9 @@ import org.eclipse.jdt.internal.ui.text.correction.proposals.ChangeMethodSignatu
 import org.eclipse.jdt.internal.ui.text.correction.proposals.ImplementInterfaceProposal;
 import org.eclipse.jdt.internal.ui.text.correction.proposals.LinkedCorrectionProposal;
 import org.eclipse.jdt.internal.ui.text.correction.proposals.NewVariableCorrectionProposal;
-import org.eclipse.jdt.internal.ui.text.correction.proposals.TypeChangeCorrectionProposal;
 import org.eclipse.jdt.internal.ui.text.correction.proposals.OptionalCorrectionProposal;
-
-import org.eclipse.jdt.internal.core.manipulation.StubUtility;
-import org.eclipse.jdt.internal.core.manipulation.dom.ASTResolving;
-import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
+import org.eclipse.jdt.internal.ui.text.correction.proposals.TypeChangeCorrectionProposal;
+import org.eclipse.jdt.internal.ui.util.ASTHelper;
 import org.eclipse.jdt.internal.ui.viewsupport.BindingLabelProvider;
 
 
@@ -110,34 +111,40 @@ public class TypeMismatchSubProcessor {
 		ITypeBinding castTypeBinding= null;
 
 		int parentNodeType= selectedNode.getParent().getNodeType();
-		if (parentNodeType == ASTNode.ASSIGNMENT) {
-			Assignment assign= (Assignment) selectedNode.getParent();
-			Expression leftHandSide= assign.getLeftHandSide();
-			if (selectedNode.equals(leftHandSide)) {
-				nodeToCast= assign.getRightHandSide();
-			}
-			castTypeBinding= assign.getLeftHandSide().resolveTypeBinding();
-			if (leftHandSide instanceof Name) {
-				receiverNode= (Name) leftHandSide;
-			} else if (leftHandSide instanceof FieldAccess) {
-				receiverNode= ((FieldAccess) leftHandSide).getName();
-			}
-		} else if (parentNodeType == ASTNode.VARIABLE_DECLARATION_FRAGMENT) {
-			VariableDeclarationFragment frag= (VariableDeclarationFragment) selectedNode.getParent();
-			if (selectedNode.equals(frag.getName()) || selectedNode.equals(frag.getInitializer())) {
-				nodeToCast= frag.getInitializer();
-				castTypeBinding= ASTNodes.getType(frag).resolveBinding();
-				receiverNode= frag.getName();
-			}
-		} else if (parentNodeType == ASTNode.MEMBER_VALUE_PAIR) {
-			receiverNode= ((MemberValuePair) selectedNode.getParent()).getName();
-			castTypeBinding= ASTResolving.guessBindingForReference(nodeToCast);
-		} else if (parentNodeType == ASTNode.SINGLE_MEMBER_ANNOTATION) {
-			receiverNode= ((SingleMemberAnnotation) selectedNode.getParent()).getTypeName(); // use the type name
-			castTypeBinding= ASTResolving.guessBindingForReference(nodeToCast);
-		} else {
-			// try to find the binding corresponding to 'castTypeName'
-			castTypeBinding= ASTResolving.guessBindingForReference(nodeToCast);
+		switch (parentNodeType) {
+			case ASTNode.ASSIGNMENT:
+				Assignment assign= (Assignment) selectedNode.getParent();
+				Expression leftHandSide= assign.getLeftHandSide();
+				if (selectedNode.equals(leftHandSide)) {
+					nodeToCast= assign.getRightHandSide();
+				}
+				castTypeBinding= assign.getLeftHandSide().resolveTypeBinding();
+				if (leftHandSide instanceof Name) {
+					receiverNode= (Name) leftHandSide;
+				} else if (leftHandSide instanceof FieldAccess) {
+					receiverNode= ((FieldAccess) leftHandSide).getName();
+				}
+				break;
+			case ASTNode.VARIABLE_DECLARATION_FRAGMENT:
+				VariableDeclarationFragment frag= (VariableDeclarationFragment) selectedNode.getParent();
+				if (selectedNode.equals(frag.getName()) || selectedNode.equals(frag.getInitializer())) {
+					nodeToCast= frag.getInitializer();
+					castTypeBinding= ASTNodes.getType(frag).resolveBinding();
+					receiverNode= frag.getName();
+				}
+				break;
+			case ASTNode.MEMBER_VALUE_PAIR:
+				receiverNode= ((MemberValuePair) selectedNode.getParent()).getName();
+				castTypeBinding= ASTResolving.guessBindingForReference(nodeToCast);
+				break;
+			case ASTNode.SINGLE_MEMBER_ANNOTATION:
+				receiverNode= ((SingleMemberAnnotation) selectedNode.getParent()).getTypeName(); // use the type name
+				castTypeBinding= ASTResolving.guessBindingForReference(nodeToCast);
+				break;
+			default:
+				// try to find the binding corresponding to 'castTypeName'
+				castTypeBinding= ASTResolving.guessBindingForReference(nodeToCast);
+				break;
 		}
 		if (castTypeBinding == null) {
 			return;
@@ -153,7 +160,7 @@ public class TypeMismatchSubProcessor {
 
 		if (!(nodeToCast instanceof ArrayInitializer)) {
 			String castTypeName= castTypeBinding.getErasure().getQualifiedName();
-			if (castTypeName.equals("java.util.Optional") && ast.apiLevel() >= AST.JLS8) { //$NON-NLS-1$
+			if ("java.util.Optional".equals(castTypeName) && ast.apiLevel() >= ASTHelper.JLS8) { //$NON-NLS-1$
 				ITypeBinding nodeToCastTypeBinding= nodeToCast.resolveTypeBinding();
 				String label0= Messages.format(CorrectionMessages.TypeMismatchSubProcessor_changetooptionalempty_description, nodeToCast.toString());
 				proposals.add(new OptionalCorrectionProposal(label0, cu, nodeToCast, IProposalRelevance.CREATE_EMPTY_OPTIONAL, OptionalCorrectionProposal.OPTIONAL_EMPTY));
@@ -192,7 +199,7 @@ public class TypeMismatchSubProcessor {
 		boolean nullOrVoid= currBinding == null || "void".equals(currBinding.getName()); //$NON-NLS-1$
 
 		// change method return statement to actual type
-		if (!nullOrVoid && parentNodeType == ASTNode.RETURN_STATEMENT) {
+		if (!nullOrVoid && isTypeReturned(nodeToCast)) {
 			BodyDeclaration decl= ASTResolving.findParentBodyDeclaration(selectedNode);
 			if (decl instanceof MethodDeclaration) {
 				MethodDeclaration methodDeclaration= (MethodDeclaration) decl;
@@ -256,6 +263,21 @@ public class TypeMismatchSubProcessor {
 
 	}
 
+	private static boolean isTypeReturned(final Expression nodeToCast) {
+		int parentNodeType= nodeToCast.getParent().getNodeType();
+
+		if (parentNodeType == ASTNode.RETURN_STATEMENT) {
+			return true;
+		}
+
+		if (parentNodeType == ASTNode.PARENTHESIZED_EXPRESSION
+				|| parentNodeType == ASTNode.CONDITIONAL_EXPRESSION && (nodeToCast.getLocationInParent() == ConditionalExpression.THEN_EXPRESSION_PROPERTY || nodeToCast.getLocationInParent() == ConditionalExpression.ELSE_EXPRESSION_PROPERTY)) {
+			return isTypeReturned((Expression) nodeToCast.getParent());
+		}
+
+		return false;
+	}
+
 	public static ITypeBinding boxUnboxPrimitives(ITypeBinding castType, ITypeBinding toCast, AST ast) {
 		/*
 		 * e.g:
