@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -31,6 +31,7 @@ import org.eclipse.jdt.core.dom.MethodDeclaration;
 import org.eclipse.jdt.core.dom.Modifier;
 import org.eclipse.jdt.core.dom.ReturnStatement;
 import org.eclipse.jdt.core.dom.Type;
+import org.eclipse.jdt.core.dom.TypeDeclaration;
 import org.eclipse.jdt.core.dom.VariableDeclarationExpression;
 import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
 import org.eclipse.jdt.core.dom.VariableDeclarationStatement;
@@ -107,7 +108,7 @@ public class ModifierChangeCorrectionProposal extends LinkedCorrectionProposal {
 						ICompilationUnit unit= getCompilationUnit();
 						String delimiter= unit.findRecommendedLineSeparator();
 						String bodyStatement= ""; //$NON-NLS-1$
-						
+
 						Block body= ast.newBlock();
 						rewrite.set(methodDecl, MethodDeclaration.BODY_PROPERTY, body, null);
 						Type returnType= methodDecl.getReturnType2();
@@ -129,11 +130,22 @@ public class ModifierChangeCorrectionProposal extends LinkedCorrectionProposal {
 			}
 			ModifierRewrite listRewrite= ModifierRewrite.create(rewrite, declNode);
 			PositionInformation trackedDeclNode= listRewrite.setModifiers(fIncludedModifiers, fExcludedModifiers, null);
-			
+
 			LinkedProposalPositionGroup positionGroup= new LinkedProposalPositionGroup("group"); //$NON-NLS-1$
 			positionGroup.addPosition(trackedDeclNode);
+
+			// add abstract modifier to class if we added abstract modifier to method
+			if (declNode.getNodeType() == ASTNode.METHOD_DECLARATION && (fIncludedModifiers & Modifier.ABSTRACT) != 0) {
+				TypeDeclaration typeDecl= ASTNodes.getFirstAncestorOrNull(declNode, TypeDeclaration.class);
+				if (typeDecl != null && !typeDecl.isInterface() && !Modifier.isAbstract(typeDecl.getModifiers())) {
+					ModifierRewrite listRewrite2= ModifierRewrite.create(rewrite, typeDecl);
+					PositionInformation trackedDeclNode2= listRewrite2.setModifiers(typeDecl.getModifiers() | Modifier.ABSTRACT, null);
+					positionGroup.addPosition(trackedDeclNode2);
+				}
+			}
+
 			getLinkedProposalModel().addPositionGroup(positionGroup);
-			
+
 			if (boundNode != null) {
 				// only set end position if in same CU
 				setEndPosition(rewrite.track(fNode));
