@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -17,6 +17,7 @@ import java.util.ArrayList;
 import java.util.List;
 
 import org.eclipse.ui.ISharedImages;
+import org.eclipse.ui.PlatformUI;
 
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.dom.ASTNode;
@@ -55,7 +56,6 @@ import org.eclipse.jdt.internal.corext.util.Messages;
 
 import org.eclipse.jdt.ui.text.java.correction.ASTRewriteCorrectionProposal;
 
-import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.text.correction.CorrectionMessages;
 import org.eclipse.jdt.internal.ui.text.correction.JavadocTagsSubProcessor;
 
@@ -110,17 +110,17 @@ public class RemoveDeclarationCorrectionProposal extends ASTRewriteCorrectionPro
 	}
 
 
-	private SimpleName fName;
+	private SimpleName fSimpleName;
 
 	public RemoveDeclarationCorrectionProposal(ICompilationUnit cu, SimpleName name, int relevance) {
-		super("", cu, null, relevance, JavaPlugin.getDefault().getWorkbench().getSharedImages().getImage(ISharedImages.IMG_TOOL_DELETE)); //$NON-NLS-1$
-		fName= name;
+		super("", cu, null, relevance, PlatformUI.getWorkbench().getSharedImages().getImage(ISharedImages.IMG_TOOL_DELETE)); //$NON-NLS-1$
+		fSimpleName= name;
 	}
 
 	@Override
 	public String getName() {
-		IBinding binding= fName.resolveBinding();
-		String name= BasicElementLabels.getJavaElementName(fName.getIdentifier());
+		IBinding binding= fSimpleName.resolveBinding();
+		String name= BasicElementLabels.getJavaElementName(fSimpleName.getIdentifier());
 		switch (binding.getKind()) {
 			case IBinding.TYPE:
 				return Messages.format(CorrectionMessages.RemoveDeclarationCorrectionProposal_removeunusedtype_description, name);
@@ -143,8 +143,8 @@ public class RemoveDeclarationCorrectionProposal extends ASTRewriteCorrectionPro
 
 	@Override
 	protected ASTRewrite getRewrite() {
-		IBinding binding= fName.resolveBinding();
-		CompilationUnit root= (CompilationUnit) fName.getRoot();
+		IBinding binding= fSimpleName.resolveBinding();
+		CompilationUnit root= (CompilationUnit) fSimpleName.getRoot();
 		ASTRewrite rewrite;
 		if (binding.getKind() == IBinding.METHOD) {
 			IMethodBinding decl= ((IMethodBinding) binding).getMethodDeclaration();
@@ -160,12 +160,11 @@ public class RemoveDeclarationCorrectionProposal extends ASTRewriteCorrectionPro
 			// needs full AST
 			CompilationUnit completeRoot= SharedASTProviderCore.getAST(getCompilationUnit(), SharedASTProviderCore.WAIT_YES, null);
 
-			SimpleName nameNode= (SimpleName) NodeFinder.perform(completeRoot, fName.getStartPosition(), fName.getLength());
+			SimpleName nameNode= (SimpleName) NodeFinder.perform(completeRoot, fSimpleName.getStartPosition(), fSimpleName.getLength());
 
 			rewrite= ASTRewrite.create(completeRoot.getAST());
-			SimpleName[] references= LinkedNodeFinder.findByBinding(completeRoot, nameNode.resolveBinding());
-			for (int i= 0; i < references.length; i++) {
-				removeVariableReferences(rewrite, references[i]);
+			for (SimpleName reference : LinkedNodeFinder.findByBinding(completeRoot, nameNode.resolveBinding())) {
+				removeVariableReferences(rewrite, reference);
 			}
 
 			IVariableBinding bindingDecl= ((IVariableBinding) nameNode.resolveBinding()).getVariableDeclaration();
@@ -206,34 +205,39 @@ public class RemoveDeclarationCorrectionProposal extends ASTRewriteCorrectionPro
 		}
 
 		int nameParentType= parent.getNodeType();
-		if (nameParentType == ASTNode.ASSIGNMENT) {
-			Assignment assignment= (Assignment) parent;
-			Expression rightHand= assignment.getRightHandSide();
-
-			ASTNode assignParent= assignment.getParent();
-			if (assignParent.getNodeType() == ASTNode.EXPRESSION_STATEMENT && rightHand.getNodeType() != ASTNode.ASSIGNMENT) {
-				removeVariableWithInitializer(rewrite, rightHand, assignParent);
-			}	else {
-				rewrite.replace(assignment, rewrite.createCopyTarget(rightHand), null);
-			}
-		} else if (nameParentType == ASTNode.SINGLE_VARIABLE_DECLARATION) {
-			rewrite.remove(parent, null);
-		} else if (nameParentType == ASTNode.VARIABLE_DECLARATION_FRAGMENT) {
-			VariableDeclarationFragment frag= (VariableDeclarationFragment) parent;
-			ASTNode varDecl= frag.getParent();
-			List<VariableDeclarationFragment> fragments;
-			if (varDecl instanceof VariableDeclarationExpression) {
-				fragments= ((VariableDeclarationExpression) varDecl).fragments();
-			} else if (varDecl instanceof FieldDeclaration) {
-				fragments= ((FieldDeclaration) varDecl).fragments();
-			} else {
-				fragments= ((VariableDeclarationStatement) varDecl).fragments();
-			}
-			if (fragments.size() == 1) {
-				rewrite.remove(varDecl, null);
-			} else {
-				rewrite.remove(frag, null); // don't try to preserve
-			}
+		switch (nameParentType) {
+			case ASTNode.ASSIGNMENT:
+				Assignment assignment= (Assignment) parent;
+				Expression rightHand= assignment.getRightHandSide();
+				ASTNode assignParent= assignment.getParent();
+				if (assignParent.getNodeType() == ASTNode.EXPRESSION_STATEMENT && rightHand.getNodeType() != ASTNode.ASSIGNMENT) {
+					removeVariableWithInitializer(rewrite, rightHand, assignParent);
+				}	else {
+					rewrite.replace(assignment, rewrite.createCopyTarget(rightHand), null);
+				}
+				break;
+			case ASTNode.SINGLE_VARIABLE_DECLARATION:
+				rewrite.remove(parent, null);
+				break;
+			case ASTNode.VARIABLE_DECLARATION_FRAGMENT:
+				VariableDeclarationFragment frag= (VariableDeclarationFragment) parent;
+				ASTNode varDecl= frag.getParent();
+				List<VariableDeclarationFragment> fragments;
+				if (varDecl instanceof VariableDeclarationExpression) {
+					fragments= ((VariableDeclarationExpression) varDecl).fragments();
+				} else if (varDecl instanceof FieldDeclaration) {
+					fragments= ((FieldDeclaration) varDecl).fragments();
+				} else {
+					fragments= ((VariableDeclarationStatement) varDecl).fragments();
+				}
+				if (fragments.size() == 1) {
+					rewrite.remove(varDecl, null);
+				} else {
+					rewrite.remove(frag, null); // don't try to preserve
+				}
+				break;
+			default:
+				break;
 		}
 	}
 
