@@ -240,7 +240,7 @@ public class AnonymousTypeCompletionProposal extends JavaTypeCompletionProposal
 				methodsToOverride= result.toArray(new IMethodBinding[result.size()]);
 			}
 			ASTNode focusNode; // used to find @NonNullByDefault effective
-			if (fCompilationUnit.getJavaProject().getOption(JavaCore.COMPILER_ANNOTATION_NULL_ANALYSIS, true).equals(JavaCore.ENABLED)) {
+			if (JavaCore.ENABLED.equals(fCompilationUnit.getJavaProject().getOption(JavaCore.COMPILER_ANNOTATION_NULL_ANALYSIS, true))) {
 				focusNode= NodeFinder.perform(astRoot, getReplacementOffset()+dummyClassContent.length(), 0);
 			} else {
 				focusNode= null;
@@ -262,9 +262,7 @@ public class AnonymousTypeCompletionProposal extends JavaTypeCompletionProposal
 				int bodyStart= trackedDeclaration.getStartPosition() + dummyClassContent.indexOf('{');
 				int bodyEnd= trackedDeclaration.getStartPosition() + trackedDeclaration.getLength();
 				return document.get(bodyStart, bodyEnd - bodyStart);
-			} catch (MalformedTreeException exception) {
-				JavaPlugin.log(exception);
-			} catch (BadLocationException exception) {
+			} catch (MalformedTreeException | BadLocationException exception) {
 				JavaPlugin.log(exception);
 			}
 			return null;
