@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2010, 2020 Darmstadt University of Technology and others
+ * Copyright (c) 2010, 2022 Darmstadt University of Technology and others
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -45,9 +45,9 @@ import org.eclipse.jdt.ui.text.java.JavaContentAssistInvocationContext;
 
 import org.eclipse.jdt.internal.ui.text.Chain;
 import org.eclipse.jdt.internal.ui.text.ChainElement;
+import org.eclipse.jdt.internal.ui.text.ChainElementAnalyzer;
 import org.eclipse.jdt.internal.ui.text.ChainFinder;
 import org.eclipse.jdt.internal.ui.text.ChainType;
-import org.eclipse.jdt.internal.ui.text.ChainElementAnalyzer;
 import org.eclipse.jdt.internal.ui.text.template.contentassist.TemplateProposal;
 
 public class ChainCompletionProposalComputer implements IJavaCompletionProposalComputer {
@@ -83,6 +83,9 @@ public class ChainCompletionProposalComputer implements IJavaCompletionProposalC
 		}
 
 		ctx= (JavaContentAssistInvocationContext) context;
+		if (ctx.getCompilationUnit() == null) {
+			return false;
+		}
 		collector= new CompletionProposalCollector(ctx.getCompilationUnit());
 		collector.setInvocationContext(ctx);
 		ICompilationUnit cu= ctx.getCompilationUnit();
@@ -97,6 +100,10 @@ public class ChainCompletionProposalComputer implements IJavaCompletionProposalC
 	}
 
 	private boolean shouldPerformCompletionOnExpectedType() {
+		if (ctx.getCoreContext() == null) {
+			return false;
+		}
+
 		AST ast;
 		CompilationUnit cuNode= SharedASTProviderCore.getAST(ctx.getCompilationUnit(), SharedASTProviderCore.WAIT_NO, null);
 		if (cuNode != null) {
@@ -168,6 +175,7 @@ public class ChainCompletionProposalComputer implements IJavaCompletionProposalC
 			long timeout= Long.parseLong(JavaManipulation.getPreference(PreferenceConstants.PREF_CHAIN_TIMEOUT, ctx.getProject()));
 			future.get(timeout, TimeUnit.SECONDS);
 		} catch (final Exception e) {
+			finder.cancel();
 			executor.shutdownNow();
 			setError("Timeout during call chain computation."); //$NON-NLS-1$
 		}
