@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -21,17 +21,18 @@ import org.eclipse.swt.custom.StyledText;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.widgets.Display;
-import org.eclipse.swt.widgets.Shell;
 
 import org.eclipse.core.runtime.CoreException;
 
 import org.eclipse.jface.text.BadLocationException;
+import org.eclipse.jface.text.BadPartitioningException;
 import org.eclipse.jface.text.Document;
 import org.eclipse.jface.text.IDocument;
-import org.eclipse.jface.text.IInformationControl;
+import org.eclipse.jface.text.IDocumentExtension3;
 import org.eclipse.jface.text.IInformationControlCreator;
 import org.eclipse.jface.text.IRegion;
 import org.eclipse.jface.text.ITextViewer;
+import org.eclipse.jface.text.ITypedRegion;
 
 import org.eclipse.ui.IEditorPart;
 import org.eclipse.ui.part.IWorkbenchPartOrientation;
@@ -39,6 +40,7 @@ import org.eclipse.ui.part.IWorkbenchPartOrientation;
 import org.eclipse.ui.editors.text.EditorsUI;
 
 import org.eclipse.jdt.core.IJavaElement;
+import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.ILocalVariable;
 import org.eclipse.jdt.core.IMember;
 import org.eclipse.jdt.core.ISourceReference;
@@ -54,15 +56,20 @@ import org.eclipse.jdt.core.dom.Javadoc;
 import org.eclipse.jdt.core.dom.NodeFinder;
 import org.eclipse.jdt.core.dom.Statement;
 import org.eclipse.jdt.core.dom.SwitchStatement;
+import org.eclipse.jdt.core.dom.TextBlock;
 import org.eclipse.jdt.core.manipulation.SharedASTProviderCore;
 
 import org.eclipse.jdt.internal.core.manipulation.StubUtility;
 import org.eclipse.jdt.internal.core.manipulation.util.Strings;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
 import org.eclipse.jdt.internal.corext.dom.TokenScanner;
+import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.internal.corext.util.Messages;
 
+import org.eclipse.jdt.ui.text.IJavaPartitions;
+
 import org.eclipse.jdt.internal.ui.JavaPlugin;
+import org.eclipse.jdt.internal.ui.javaeditor.EditorUtility;
 import org.eclipse.jdt.internal.ui.javaeditor.JavaEditor;
 import org.eclipse.jdt.internal.ui.javaeditor.JavaSourceViewer;
 import org.eclipse.jdt.internal.ui.text.JavaCodeReader;
@@ -96,7 +103,7 @@ public class JavaSourceHover extends AbstractJavaEditorTextHover {
 	 */
 	private IJavaElement fJavaElement;
 
-	class JavaSourceInformationInput {
+	static class JavaSourceInformationInput {
 		private IJavaElement fElement;
 
 		private String fHoverInfo;
@@ -137,7 +144,11 @@ public class JavaSourceHover extends AbstractJavaEditorTextHover {
 		fBracketHoverStatus= null;
 
 		if (result == null || result.length == 0) {
-			return getBracketHoverInfo(textViewer, region);
+			String val = getBracketHoverInfo(textViewer, region);
+			if (val == null) {
+				return getTextBlockHoverInfo(textViewer, region);
+			}
+			return val;
 		}
 
 		if (result.length > 1)
@@ -249,12 +260,7 @@ public class JavaSourceHover extends AbstractJavaEditorTextHover {
 					throw ex;
 			}
 
-			display.syncExec(new Runnable() {
-				@Override
-				public void run() {
-					topIndex[0]= textViewer.getTopIndex();
-				}
-			});
+			display.syncExec(() -> topIndex[0]= textViewer.getTopIndex());
 
 			int topLine= topIndex[0];
 			if (topLine == -1)
@@ -284,9 +290,7 @@ public class JavaSourceHover extends AbstractJavaEditorTextHover {
 					fBracketHoverStatus= Messages.format(JavaHoverMessages.JavaSourceHover_skippedLines, Integer.valueOf(skippedLines));
 				}
 			} else {
-				noOfSourceLines= line2 - line1;
-				endLine= document.getLineInformation(line2);
-				fUpwardShiftInLines= line2 - line1;
+				return null;
 			}
 			if (fUpwardShiftInLines == 0)
 				return null;
@@ -410,6 +414,72 @@ public class JavaSourceHover extends AbstractJavaEditorTextHover {
 		return hoverText;
 	}
 
+	private String getTextBlockHoverInfo(final ITextViewer textViewer, IRegion region) {
+		String hoverText= null;
+		IEditorPart editor= getEditor();
+		ITypeRoot input= getEditorInputJavaElement();
+		if (!(editor instanceof JavaEditor) || input == null || region == null) {
+			return null;
+		}
+		IDocument document= textViewer.getDocument();
+		if (document == null)
+			return null;
+
+		IDocumentExtension3 docExtension= null;
+		if (document instanceof IDocumentExtension3)
+			docExtension= (IDocumentExtension3) document;
+		else
+			return null;
+		IJavaProject javaProject= getProject(editor);
+		if (javaProject == null) {
+			return null;
+		}
+
+		try {
+			int selectionOffset= region.getOffset();
+			//boolean setCaratPosition= selection.getLength() > 0 ? false : true;
+			ITypedRegion partition= docExtension.getPartition(IJavaPartitions.JAVA_PARTITIONING, selectionOffset, false);
+			if (partition == null || !isTextBlock( partition, javaProject)) {
+				return null;
+			}
+			CompilationUnit ast= SharedASTProviderCore.getAST(input, SharedASTProviderCore.WAIT_NO, null);
+			if (ast == null) {
+				return null;
+			}
+			ASTNode textBlockNode= NodeFinder.perform(ast, partition.getOffset(),
+					partition.getLength());
+			if (!(textBlockNode instanceof TextBlock)) {
+				return null;
+			}
+			TextBlock textBlock= (TextBlock) textBlockNode;
+			return textBlock.getLiteralValue();
+		} catch (BadLocationException | BadPartitioningException e) {
+			//do nothing
+		}
+		return hoverText;
+	}
+
+	private boolean isTextBlock(ITypedRegion partition, IJavaProject javaProject) {
+		if (!JavaModelUtil.is15OrHigher(javaProject)) {
+			return false;
+		}
+		boolean isTextBlock= true;
+		String partitionType= partition.getType();
+		if (IJavaPartitions.JAVA_MULTI_LINE_STRING.equals(partitionType)) {
+			isTextBlock= true;
+		}
+		return isTextBlock;
+	}
+
+	private IJavaProject getProject(IEditorPart editor) {
+		IJavaProject javaProject= null;
+		if (editor != null) {
+			ITypeRoot inputJavaElement= EditorUtility.getEditorInputJavaElement(editor, false);
+			javaProject= inputJavaElement.getJavaProject();
+		}
+		return javaProject;
+	}
+
 	private int getNextElseOffset(Statement then, ITypeRoot editorInput) {
 		int thenEnd= ASTNodes.getExclusiveEnd(then);
 		try {
@@ -499,68 +569,65 @@ public class JavaSourceHover extends AbstractJavaEditorTextHover {
 	 * @since 3.8
 	 */
 	private IInformationControlCreator createInformationControlCreator(final boolean isResizable, final String statusFieldText, final boolean doShiftUp) {
-		return new IInformationControlCreator() {
-			@Override
-			public IInformationControl createInformationControl(final Shell parent) {
-				final IEditorPart editor= getEditor();
-				int orientation= SWT.NONE;
-				if (editor instanceof IWorkbenchPartOrientation)
-					orientation= ((IWorkbenchPartOrientation) editor).getOrientation();
+		return parent -> {
+			final IEditorPart editor= getEditor();
+			int orientation= SWT.NONE;
+			if (editor instanceof IWorkbenchPartOrientation)
+				orientation= ((IWorkbenchPartOrientation) editor).getOrientation();
 
-				return new SourceViewerInformationControl(parent, isResizable, orientation, statusFieldText) {
-					@Override
-					public void setLocation(Point location) {
-						Point loc= location;
-						if (doShiftUp && fUpwardShiftInLines > 0) {
-							Point size= super.computeSizeConstraints(0, fUpwardShiftInLines + 1);
-							//bracket hover is rendered above '}'
-							int y= location.y - size.y - 5; //AbstractInformationControlManager.fMarginY = 5
-							Rectangle trim= computeTrim();
-							loc= new Point(location.x + trim.x - getViewer().getTextWidget().getLeftMargin(), y - trim.height - trim.y);
-						}
-						super.setLocation(loc);
+			return new SourceViewerInformationControl(parent, isResizable, orientation, statusFieldText) {
+				@Override
+				public void setLocation(Point location) {
+					Point loc= location;
+					if (doShiftUp && fUpwardShiftInLines > 0) {
+						Point size= super.computeSizeConstraints(0, fUpwardShiftInLines + 1);
+						//bracket hover is rendered above '}'
+						int y= location.y - size.y - 5; //AbstractInformationControlManager.fMarginY = 5
+						Rectangle trim= computeTrim();
+						loc= new Point(location.x + trim.x - getViewer().getTextWidget().getLeftMargin(), y - trim.height - trim.y);
 					}
+					super.setLocation(loc);
+				}
 
-					@Override
-					public Point computeSizeConstraints(int widthInChars, int heightInChars) {
-						if (doShiftUp && fUpwardShiftInLines > 0) {
-							Point sizeConstraints= super.computeSizeConstraints(widthInChars, heightInChars);
-							return new Point(sizeConstraints.x, 0); //set height as 0 to ensure selection of bottom anchor in AbstractInformationControlManager.computeInformationControlLocation(...)
-						} else {
-							return super.computeSizeConstraints(widthInChars, heightInChars);
-						}
+				@Override
+				public Point computeSizeConstraints(int widthInChars, int heightInChars) {
+					if (doShiftUp && fUpwardShiftInLines > 0) {
+						Point sizeConstraints= super.computeSizeConstraints(widthInChars, heightInChars);
+						return new Point(sizeConstraints.x, 0); //set height as 0 to ensure selection of bottom anchor in AbstractInformationControlManager.computeInformationControlLocation(...)
+					} else {
+						return super.computeSizeConstraints(widthInChars, heightInChars);
 					}
+				}
 
-					@Override
-					public void setSize(int width, int height) {
-						if (doShiftUp && fUpwardShiftInLines != 0) {
-							//compute the correct height of hover, this was set to 0 in computeSizeConstraints(..)
-							Point size= super.computeSizeConstraints(0, fUpwardShiftInLines);
-							Rectangle trim= computeTrim();
-							super.setSize(width, size.y + trim.height - trim.y);
-						} else {
-							super.setSize(width, height);
-						}
+				@Override
+				public void setSize(int width, int height) {
+					if (doShiftUp && fUpwardShiftInLines != 0) {
+						//compute the correct height of hover, this was set to 0 in computeSizeConstraints(..)
+						Point size= super.computeSizeConstraints(0, fUpwardShiftInLines);
+						Rectangle trim= computeTrim();
+						super.setSize(width, size.y + trim.height - trim.y);
+					} else {
+						super.setSize(width, height);
 					}
+				}
 
-					@Override
-					public IInformationControlCreator getInformationPresenterControlCreator() {
-						if (doShiftUp && fUpwardShiftInLines > 0) {
-							// Hack: We don't wan't to have auto-enrichment when the mouse moves into the hover,
-							// but we do want F2 to persist the hover. The framework has no way to distinguish the
-							// two requests, so we have to implement this aspect.
-							for (StackTraceElement element : Thread.currentThread().getStackTrace()) {
-								if ("canMoveIntoInformationControl".equals(element.getMethodName()) //$NON-NLS-1$
-										&& "org.eclipse.jface.text.AbstractHoverInformationControlManager".equals(element.getClassName())) //$NON-NLS-1$
-									return null; //do not enrich bracket hover
-							}
-							return JavaSourceHover.this.createInformationControlCreator(isResizable && !isResizable, statusFieldText, false);
-						} else {
-							return super.getInformationPresenterControlCreator();
+				@Override
+				public IInformationControlCreator getInformationPresenterControlCreator() {
+					if (doShiftUp && fUpwardShiftInLines > 0) {
+						// Hack: We don't wan't to have auto-enrichment when the mouse moves into the hover,
+						// but we do want F2 to persist the hover. The framework has no way to distinguish the
+						// two requests, so we have to implement this aspect.
+						for (StackTraceElement element : Thread.currentThread().getStackTrace()) {
+							if ("canMoveIntoInformationControl".equals(element.getMethodName()) //$NON-NLS-1$
+									&& "org.eclipse.jface.text.AbstractHoverInformationControlManager".equals(element.getClassName())) //$NON-NLS-1$
+								return null; //do not enrich bracket hover
 						}
+						return JavaSourceHover.this.createInformationControlCreator(isResizable && !isResizable, statusFieldText, false);
+					} else {
+						return super.getInformationPresenterControlCreator();
 					}
-				};
-			}
+				}
+			};
 		};
 	}
 }
