@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -47,6 +47,8 @@ import org.eclipse.jdt.core.Signature;
 import org.eclipse.jdt.core.dom.ASTNode;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.dom.IBinding;
+import org.eclipse.jdt.core.dom.ITypeBinding;
+import org.eclipse.jdt.core.dom.IVariableBinding;
 import org.eclipse.jdt.core.dom.NodeFinder;
 import org.eclipse.jdt.core.dom.QualifiedName;
 import org.eclipse.jdt.core.dom.SimpleName;
@@ -120,12 +122,12 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 
 	/**
 	 * Returns the hover input.
-	 * 
+	 *
 	 * @param textViewer the viewer on which the hover popup should be shown
 	 * @param hoverRegion the text range in the viewer which is used to determine the hover display
 	 *            information
 	 * @return the hover popup display input, or <code>null</code> if none available
-	 * 
+	 *
 	 * @see #getHoverInfo2(ITextViewer, IRegion)
 	 */
 	private NLSHoverControlInput internalGetHoverInfo(ITextViewer textViewer, IRegion hoverRegion) {
@@ -169,7 +171,23 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 			identifier= ((StringLiteral)node).getLiteralValue();
 		} else if (!usedFullyQualifiedName && node.getLocationInParent() == QualifiedName.NAME_PROPERTY) {
 			identifier= ((SimpleName)node).getIdentifier();
-		} else {
+			IBinding nodeBinding= ((SimpleName)node).resolveBinding();
+			if (nodeBinding != null) {
+				if (nodeBinding instanceof IVariableBinding && ((IVariableBinding)nodeBinding).isField()) {
+					ITypeBinding nodeDeclaringType= ((IVariableBinding)nodeBinding).getDeclaringClass();
+					if (nodeDeclaringType != null) {
+						ITypeBinding superClass= nodeDeclaringType.getSuperclass();
+						if (superClass != null) {
+							String superClassName= superClass.getQualifiedName();
+							if (!"org.eclipse.osgi.util.NLS".equals(superClassName)) { //$NON-NLS-1$
+								identifier= null;
+							}
+						}
+					}
+				}
+			}
+		}
+		if (identifier == null) {
 			try {
 				if (containingClassBinding == null)
 					return null;
@@ -178,7 +196,7 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 					return null;
 				String varName= ((SimpleName)node).getIdentifier();
 				IField field= parentType.getField(varName);
-				if (!Signature.getSignatureSimpleName(field.getTypeSignature()).equals("String")) //$NON-NLS-1$
+				if (!"String".equals(Signature.getSignatureSimpleName(field.getTypeSignature()))) //$NON-NLS-1$
 					return null;
 				Object obj= field.getConstant();
 				identifier= obj instanceof String ? ((String)obj).substring(1, ((String)obj).length() - 1) : null;
@@ -238,10 +256,10 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 		HTMLPrinter.addPageEpilog(buffer);
 		return buffer.toString();
 	}
-	
+
 	/**
 	 * The input for NLS hover.
-	 * 
+	 *
 	 * @since 3.5
 	 */
 	private static class NLSHoverControlInput {
@@ -253,7 +271,7 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 
 		/**
 		 * Creates the NLS hover input.
-		 * 
+		 *
 		 * @param information the hover info (string with simple HTML)
 		 * @param propertiesFile the properties file, or <code>null</code> if not found
 		 * @param key the NLS key
@@ -269,7 +287,7 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 
 	/**
 	 * The NLS hover control.
-	 * 
+	 *
 	 * @since 3.5
 	 */
 	static class NLSHoverControl extends DefaultInformationControl implements IInformationControlExtension2 {
@@ -281,7 +299,7 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 
 		/**
 		 * Creates a resizable NLS hover control with the given shell as parent.
-		 * 
+		 *
 		 * @param parent the parent shell
 		 * @param tbm the toolbar manager or <code>null</code> if toolbar is not desired
 		 */
@@ -292,7 +310,7 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 
 		/**
 		 * Creates an NLS hover control with the given shell as parent.
-		 * 
+		 *
 		 * @param parent the parent shell
 		 * @param tooltipAffordanceString the text to be used in the status field or
 		 *            <code>null</code> to hide the status field
@@ -307,7 +325,7 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 		@Override
 		public void setInput(Object input) {
 			Assert.isLegal(input instanceof NLSHoverControlInput);
-			
+
 			NLSHoverControlInput info= (NLSHoverControlInput)input;
 			setInformation(info.fInformation);
 			fInput= info;
@@ -315,7 +333,7 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 
 		/**
 		 * Returns the control input.
-		 * 
+		 *
 		 * @return the control input
 		 */
 		public NLSHoverControlInput getInput() {
@@ -325,7 +343,7 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 
 	/**
 	 * Presenter control creator.
-	 * 
+	 *
 	 * @since 3.5
 	 */
 	private static final class PresenterControlCreator extends AbstractReusableInformationControlCreator {
@@ -345,7 +363,7 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 
 	/**
 	 * Hover control creator.
-	 * 
+	 *
 	 * @since 3.5
 	 */
 	private static final class HoverControlCreator extends AbstractReusableInformationControlCreator {
@@ -357,7 +375,7 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 
 		/**
 		 * Creates the hover control creator.
-		 * 
+		 *
 		 * @param presenterControlCreator the presenter control creator
 		 */
 		public HoverControlCreator(IInformationControlCreator presenterControlCreator) {
@@ -383,14 +401,14 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 
 	/**
 	 * The hover control creator.
-	 * 
+	 *
 	 * @since 3.5
 	 */
 	private IInformationControlCreator fHoverControlCreator;
 
 	/**
 	 * The presentation control creator.
-	 * 
+	 *
 	 * @since 3.5
 	 */
 	private IInformationControlCreator fPresenterControlCreator;
@@ -420,11 +438,11 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 
 	/**
 	 * Action that opens the current hover NLS string in properties file.
-	 * 
+	 *
 	 * @since 3.5
 	 */
 	private static final class OpenPropertiesFileAction extends Action {
-		
+
 		/**
 		 * The NLS hover control.
 		 */
@@ -432,7 +450,7 @@ public class NLSStringHover extends AbstractJavaEditorTextHover {
 
 		/**
 		 * Creates the action for opening properties file.
-		 * 
+		 *
 		 * @param control the NLS hover control
 		 */
 		public OpenPropertiesFileAction(NLSHoverControl control) {
