@@ -108,12 +108,7 @@ public class SourceViewerInformationControl
 	 * @since 3.0
 	 */
 	private Font fStatusTextFont;
-	/**
-	 * The color of the optional status text label or <code>null</code> if none.
-	 * 
-	 * @since 3.6
-	 */
-	private Color fStatusTextForegroundColor;
+
 	/**
 	 * The width size constraint.
 	 * @since 3.2
@@ -131,7 +126,6 @@ public class SourceViewerInformationControl
 	private final int fOrientation;
 
 	private Color fBackgroundColor;
-	private boolean fIsSystemBackgroundColor= true;
 
 	private JavaSourceViewerConfiguration fViewerConfiguration;
 	private Map<String, JavaSourceViewerConfiguration> fKindToViewerConfiguration= new HashMap<>();
@@ -223,16 +217,17 @@ public class SourceViewerInformationControl
 			fStatusField.setText(statusFieldText);
 			Font font= fStatusField.getFont();
 			FontData[] fontDatas= font.getFontData();
-			for (int i= 0; i < fontDatas.length; i++)
-				fontDatas[i].setHeight(fontDatas[i].getHeight() * 9 / 10);
+			for (FontData fontData : fontDatas) {
+				fontData.setHeight(fontData.getHeight() * 9 / 10);
+			}
 			fStatusTextFont= new Font(fStatusField.getDisplay(), fontDatas);
 			fStatusField.setFont(fStatusTextFont);
 			GridData gd2= new GridData(GridData.FILL_HORIZONTAL | GridData.VERTICAL_ALIGN_BEGINNING);
 			fStatusField.setLayoutData(gd2);
-			
+
 			RGB javaDefaultColor= JavaUI.getColorManager().getColor(IJavaColorConstants.JAVA_DEFAULT).getRGB();
-			fStatusTextForegroundColor= new Color(fStatusField.getDisplay(), blend(fBackgroundColor.getRGB(), javaDefaultColor, 0.56f));
-			fStatusField.setForeground(fStatusTextForegroundColor);
+			Color statusTextForegroundColor= new Color(fStatusField.getDisplay(), blend(fBackgroundColor.getRGB(), javaDefaultColor, 0.56));
+			fStatusField.setForeground(statusTextForegroundColor);
 			fStatusField.setBackground(fBackgroundColor);
 		}
 
@@ -251,20 +246,21 @@ public class SourceViewerInformationControl
 	 * @return the interpolated color
 	 * @since 3.6
 	 */
-	private static RGB blend(RGB bg, RGB fg, float factor) {
+	private static RGB blend(RGB bg, RGB fg, double factor) {
 		// copy of org.eclipse.jface.internal.text.revisions.Colors#blend(..)
 		Assert.isLegal(bg != null);
 		Assert.isLegal(fg != null);
-		Assert.isLegal(factor >= 0f && factor <= 1f);
-		
-		float complement= 1f - factor;
+		Assert.isLegal(factor >= 0.0);
+		Assert.isLegal(factor <= 1.0);
+
+		double complement= 1.0 - factor;
 		return new RGB(
 				(int) (complement * bg.red + factor * fg.red),
 				(int) (complement * bg.green + factor * fg.green),
 				(int) (complement * bg.blue + factor * fg.blue)
 		);
 	}
-	
+
 	private void initializeColors() {
 		IPreferenceStore store= JavaPlugin.getDefault().getPreferenceStore();
 		RGB bgRGB;
@@ -275,28 +271,26 @@ public class SourceViewerInformationControl
 		}
 		if (bgRGB != null) {
 			fBackgroundColor= new Color(fShell.getDisplay(), bgRGB);
-			fIsSystemBackgroundColor= false;
 		} else {
 			fBackgroundColor= fShell.getDisplay().getSystemColor(SWT.COLOR_INFO_BACKGROUND);
-			fIsSystemBackgroundColor= true;
 		}
 	}
 
 	/**
 	 * Returns <code>null</code> if {@link SWT#COLOR_INFO_BACKGROUND} is visibly distinct from the
 	 * default Java source text color. Otherwise, returns the editor background color.
-	 * 
+	 *
 	 * @param display the display
 	 * @return an RGB or <code>null</code>
 	 * @since 3.6.1
 	 */
 	public static RGB getVisibleBackgroundColor(Display display) {
 		float[] infoBgHSB= display.getSystemColor(SWT.COLOR_INFO_BACKGROUND).getRGB().getHSB();
-		
+
 		Color javaDefaultColor= JavaUI.getColorManager().getColor(IJavaColorConstants.JAVA_DEFAULT);
 		RGB javaDefaultRGB= javaDefaultColor != null ? javaDefaultColor.getRGB() : new RGB(255, 255, 255);
 		float[] javaDefaultHSB= javaDefaultRGB.getHSB();
-		
+
 		if (Math.abs(infoBgHSB[2] - javaDefaultHSB[2]) < 0.5f) {
 			// workaround for dark tooltip background color, see https://bugs.eclipse.org/309334
 			IPreferenceStore preferenceStore= JavaPlugin.getDefault().getCombinedPreferenceStore();
@@ -332,15 +326,12 @@ public class SourceViewerInformationControl
 		if (fShell != null && !fShell.isDisposed()) {
 			Display display= fShell.getDisplay();
 			if (!display.isDisposed()) {
-				display.asyncExec(new Runnable() {
-					@Override
-					public void run() {
-						IJavaElement javaElement= null;
-						if (input instanceof JavaSourceInformationInput) {
-							javaElement= ((JavaSourceInformationInput) input).getJavaElement();
-						}
-						updateViewerConfiguration(javaElement);
+				display.asyncExec(() -> {
+					IJavaElement javaElement= null;
+					if (input instanceof JavaSourceInformationInput) {
+						javaElement= ((JavaSourceInformationInput) input).getJavaElement();
 					}
+					updateViewerConfiguration(javaElement);
 				});
 			}
 		}
@@ -396,10 +387,6 @@ public class SourceViewerInformationControl
 			fStatusTextFont.dispose();
 		fStatusTextFont= null;
 
-		if (fStatusTextForegroundColor != null && !fStatusTextForegroundColor.isDisposed())
-			fStatusTextForegroundColor.dispose();
-		fStatusTextForegroundColor= null;
-
 		fTextFont= null;
 		fShell= null;
 		fText= null;
@@ -407,8 +394,6 @@ public class SourceViewerInformationControl
 
 	@Override
 	public final void dispose() {
-		if (!fIsSystemBackgroundColor)
-			fBackgroundColor.dispose();
 		if (fShell != null && !fShell.isDisposed())
 			fShell.dispose();
 		else
@@ -603,12 +588,7 @@ public class SourceViewerInformationControl
 	 */
 	@Override
 	public IInformationControlCreator getInformationPresenterControlCreator() {
-		return new IInformationControlCreator() {
-			@Override
-			public IInformationControl createInformationControl(Shell parent) {
-				return new SourceViewerInformationControl(parent, true, fOrientation, null);
-			}
-		};
+		return parent -> new SourceViewerInformationControl(parent, true, fOrientation, null);
 	}
 
 	/*
