@@ -16,7 +16,6 @@ package org.eclipse.jdt.internal.ui.text.spelling;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
-import java.net.MalformedURLException;
 import java.net.URL;
 import java.util.Collections;
 import java.util.Enumeration;
@@ -370,22 +369,22 @@ public class SpellCheckEngine implements ISpellCheckEngine, IPropertyChangeListe
 	 */
 	@Override
 	public final void propertyChange(final PropertyChangeEvent event) {
-		if (event.getProperty().equals(PreferenceConstants.SPELLING_LOCALE)) {
+		if (PreferenceConstants.SPELLING_LOCALE.equals(event.getProperty())) {
 			resetSpellChecker();
 			return;
 		}
 
-		if (event.getProperty().equals(PreferenceConstants.SPELLING_USER_DICTIONARY)) {
+		if (PreferenceConstants.SPELLING_USER_DICTIONARY.equals(event.getProperty())) {
 			resetUserDictionary();
 			return;
 		}
 
-		if (event.getProperty().equals(PreferenceConstants.SPELLING_USER_DICTIONARY_ENCODING)) {
+		if (PreferenceConstants.SPELLING_USER_DICTIONARY_ENCODING.equals(event.getProperty())) {
 			resetUserDictionary();
 			return;
 		}
 
-		if (event.getProperty().equals(SpellingService.PREFERENCE_SPELLING_ENABLED) && !EditorsUI.getPreferenceStore().getBoolean(SpellingService.PREFERENCE_SPELLING_ENABLED)) {
+		if (SpellingService.PREFERENCE_SPELLING_ENABLED.equals(event.getProperty()) && !EditorsUI.getPreferenceStore().getBoolean(SpellingService.PREFERENCE_SPELLING_ENABLED)) {
 			if (this == fgEngine)
 				SpellCheckEngine.shutdownInstance();
 			else
@@ -437,8 +436,6 @@ public class SpellCheckEngine implements ISpellCheckEngine, IPropertyChangeListe
 						stream.close();
 					}
 				}
-			} catch (MalformedURLException exception) {
-				// Do nothing
 			} catch (IOException exception) {
 				// Do nothing
 			}
