@@ -113,14 +113,12 @@ public class SelectionUtil {
 			if (target != null) {
 				// select and reveal resource
 				final ISetSelectionTarget finalTarget= target;
-				window.getShell().getDisplay().asyncExec(new Runnable() {
-					@Override
-					public void run() {
-						finalTarget.selectReveal(selection);
-					}
-				});
+				window.getShell().getDisplay().asyncExec(() -> finalTarget.selectReveal(selection));
 			}
 		}
 	}
 
+	private SelectionUtil() {
+	}
+
 }
