@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -403,6 +403,14 @@ public class JavaElementImageProvider {
 					if (JdtFlags.isStatic(member))
 						flags|= JavaElementImageDescriptor.STATIC;
 
+					if (isInterfaceOrClassType(member)) {
+						if (Flags.isSealed(modifiers)) {
+							flags|= JavaElementImageDescriptor.SEALED;
+						}
+						if (Flags.isNonSealed(modifiers)) {
+							flags|= JavaElementImageDescriptor.NON_SEALED;
+						}
+					}
 					if (Flags.isDeprecated(modifiers))
 						flags|= JavaElementImageDescriptor.DEPRECATED;
 
@@ -451,6 +459,17 @@ public class JavaElementImageProvider {
 		return true;
 	}
 
+	private static boolean isInterfaceOrClassType(IMember element) throws JavaModelException {
+		//check if the type is interface or class
+		boolean val= false;
+		if (element instanceof IType) {
+			IType type= (IType) element;
+			if (type.isInterface() || type.isClass()) {
+				val= true;
+			}
+		}
+		return val;
+	}
 	private static boolean isInterfaceOrAnnotationField(IMember element) throws JavaModelException {
 		// always show the final symbol on interface fields
 		if (element.getElementType() == IJavaElement.FIELD) {
@@ -515,6 +534,14 @@ public class JavaElementImageProvider {
 				return getInnerInterfaceImageDescriptor(isInInterfaceOrAnnotation, flags);
 			}
 			return getInterfaceImageDescriptor(flags);
+		} else if (Flags.isRecord(flags)) {
+			if (useLightIcons) {
+				return JavaPluginImages.DESC_OBJS_RECORD_ALT;
+			}
+			if (isInner) {
+				return getInnerRecordImageDescriptor(isInInterfaceOrAnnotation, flags);
+			}
+			return getRecordImageDescriptor(flags);
 		} else {
 			if (useLightIcons) {
 				return JavaPluginImages.DESC_OBJS_CLASSALT;
@@ -575,6 +602,13 @@ public class JavaElementImageProvider {
 			return JavaPluginImages.DESC_OBJS_ANNOTATION_DEFAULT;
 	}
 
+	private static ImageDescriptor getRecordImageDescriptor(int flags) {
+		if (Flags.isPublic(flags) || Flags.isProtected(flags) || Flags.isPrivate(flags))
+			return JavaPluginImages.DESC_OBJS_RECORD;
+		else
+			return JavaPluginImages.DESC_OBJS_RECORD_DEFAULT;
+	}
+
 	private static ImageDescriptor getInnerAnnotationImageDescriptor(boolean isInInterfaceOrAnnotation, int flags) {
 		if (Flags.isPublic(flags) || isInInterfaceOrAnnotation)
 			return JavaPluginImages.DESC_OBJS_ANNOTATION;
@@ -586,6 +620,17 @@ public class JavaElementImageProvider {
 			return JavaPluginImages.DESC_OBJS_ANNOTATION_DEFAULT;
 	}
 
+	private static ImageDescriptor getInnerRecordImageDescriptor(boolean isInInterfaceOrAnnotation, int flags) {
+		if (Flags.isPublic(flags) || isInInterfaceOrAnnotation)
+			return JavaPluginImages.DESC_OBJS_RECORD;
+		else if (Flags.isPrivate(flags))
+			return JavaPluginImages.DESC_OBJS_RECORD_PRIVATE;
+		else if (Flags.isProtected(flags))
+			return JavaPluginImages.DESC_OBJS_RECORD_PROTECTED;
+		else
+			return JavaPluginImages.DESC_OBJS_RECORD_DEFAULT;
+	}
+
 	private static ImageDescriptor getInterfaceImageDescriptor(int flags) {
 		if (Flags.isPublic(flags) || Flags.isProtected(flags) || Flags.isPrivate(flags))
 			return JavaPluginImages.DESC_OBJS_INTERFACE;
