@@ -13,6 +13,8 @@
  *******************************************************************************/
 package org.eclipse.jdt.internal.ui.wizards.buildpaths;
 
+import java.util.Objects;
+
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.IStatus;
 
@@ -78,7 +80,7 @@ public class CPListElementAttribute {
 			return true;
 		}
 		if (fBuiltIn) {
-			if (this.fKey.equals(IClasspathAttribute.MODULE)) {
+			if (IClasspathAttribute.MODULE.equals(this.fKey)) {
 				IJavaProject javaProject= fParent.getJavaProject();
 				if (!JavaModelUtil.is9OrHigher(javaProject)) {
 					return true; // cannot set "module=true" in 1.8- project
@@ -134,7 +136,8 @@ public class CPListElementAttribute {
         if (!(obj instanceof CPListElementAttribute))
             return false;
         CPListElementAttribute attrib= (CPListElementAttribute)obj;
-        return attrib.fKey== this.fKey && attrib.getParent().getPath().equals(fParent.getPath());
+        return Objects.equals(attrib.fKey, this.fKey)
+        		&& Objects.equals(attrib.getParent().getPath(), fParent.getPath());
     }
 
     @Override
