@@ -16,13 +16,21 @@ package org.eclipse.jdt.internal.ui.wizards.buildpaths;
 
 import java.io.File;
 import java.lang.reflect.InvocationTargetException;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
+import java.util.Map.Entry;
+
+import com.ibm.icu.text.MessageFormat;
 
 import org.eclipse.equinox.bidi.StructuredTextTypeHandlerFactory;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
+import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.DirectoryDialog;
@@ -56,23 +64,31 @@ import org.eclipse.ui.model.WorkbenchContentProvider;
 import org.eclipse.ui.model.WorkbenchLabelProvider;
 
 import org.eclipse.jdt.core.IClasspathAttribute;
+import org.eclipse.jdt.core.IClasspathContainer;
 import org.eclipse.jdt.core.IClasspathEntry;
 import org.eclipse.jdt.core.IJavaProject;
+import org.eclipse.jdt.core.JavaCore;
+import org.eclipse.jdt.core.JavaModelException;
 
+import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.corext.util.Messages;
 
 import org.eclipse.jdt.internal.ui.IJavaHelpContextIds;
 import org.eclipse.jdt.internal.ui.JavaPlugin;
+import org.eclipse.jdt.internal.ui.JavaPluginImages;
 import org.eclipse.jdt.internal.ui.dialogs.StatusInfo;
-import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
+import org.eclipse.jdt.internal.ui.refactoring.contentassist.ControlContentAssistHelper;
+import org.eclipse.jdt.internal.ui.refactoring.contentassist.JavaPrecomputedNamesAssistProcessor;
 import org.eclipse.jdt.internal.ui.wizards.IStatusChangeListener;
 import org.eclipse.jdt.internal.ui.wizards.NewWizardMessages;
+import org.eclipse.jdt.internal.ui.wizards.dialogfields.ComboDialogField;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.DialogField;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.IDialogFieldListener;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.IStringButtonAdapter;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.LayoutUtil;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.SelectionButtonDialogField;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.StringButtonDialogField;
+import org.eclipse.jdt.internal.ui.wizards.dialogfields.StringDialogField;
 
 
 /**
@@ -86,10 +102,17 @@ public class ExternalAnnotationsAttachmentBlock {
 	private StringButtonDialogField fWorkspaceFileNameField;
 	private StringButtonDialogField fExternalFileNameField;
 	private SelectionButtonDialogField fExternalFolderButton;
-	private SelectionButtonDialogField fExternalRadio, fWorkspaceRadio;
+	private SelectionButtonDialogField fExternalRadio, fWorkspaceRadio, fContainerRelativeRadio;
+	private ComboDialogField fContainerSelection;
+	private StringDialogField fContainerRelative;
+
+	private Map<String,String> fContainerDesc2ID;
+	private Map<String,IClasspathContainer> fID2Container;
+	private JavaPrecomputedNamesAssistProcessor fArtifactAssistprocessor;
 
 	private IStatus fWorkspaceNameStatus;
 	private IStatus fExternalNameStatus;
+	private IStatus fContainerRelativeStatus;
 
 	private final IWorkspaceRoot fWorkspaceRoot;
 
@@ -100,8 +123,9 @@ public class ExternalAnnotationsAttachmentBlock {
 	/**
 	 * @param context listeners for status updates
 	 * @param entry The entry to edit
+	 * @param javaProject The enclosing java project
 	 */
-	public ExternalAnnotationsAttachmentBlock(IStatusChangeListener context, IPath entry) {
+	public ExternalAnnotationsAttachmentBlock(IStatusChangeListener context, IPath entry, IJavaProject javaProject) {
 		fContext= context;
 		fEntry= entry == null ? Path.EMPTY : entry;
 
@@ -135,9 +159,48 @@ public class ExternalAnnotationsAttachmentBlock {
 		fExternalFolderButton.setDialogFieldListener(adapter);
 		fExternalFolderButton.setLabelText(NewWizardMessages.AnnotationsAttachmentBlock_filename_externalfolder_button);
 
+		fContainerRelativeRadio= new SelectionButtonDialogField(SWT.RADIO);
+		fContainerRelativeRadio.setDialogFieldListener(adapter);
+		fContainerRelativeRadio.setLabelText(NewWizardMessages.AnnotationsAttachmentBlock_containerRelative_radio);
+
+		createContainerMaps(javaProject);
+		fContainerSelection= new ComboDialogField(SWT.READ_ONLY);
+		fContainerSelection.setDialogFieldListener(adapter);
+		fContainerSelection.setItems(fContainerDesc2ID.keySet().toArray(String[]::new));
+		fContainerSelection.setLabelText(NewWizardMessages.AnnotationsAttachmentBlock_container_label);
+
+		fContainerRelative= new StringDialogField();
+		fContainerRelative.setDialogFieldListener(adapter);
+		fContainerRelative.setLabelText(NewWizardMessages.AnnotationsAttachmentBlock_artifact_label);
+
 		setDefaults();
 	}
 
+	private void createContainerMaps(IJavaProject javaProject) {
+		fContainerDesc2ID= new HashMap<>();
+		fID2Container= new HashMap<>();
+		if (javaProject != null) {
+			try {
+				for (IClasspathEntry entry : javaProject.getRawClasspath()) {
+					if (entry.getEntryKind() == IClasspathEntry.CPE_CONTAINER) {
+						IPath path= entry.getPath();
+						IClasspathContainer container= JavaCore.getClasspathContainer(path, javaProject);
+						fContainerDesc2ID.put(container.getDescription(), path.toString());
+						fID2Container.put(path.toString(), container);
+					}
+				}
+			} catch (JavaModelException e) {
+				JavaPlugin.log(e.getStatus());
+			}
+		} else {
+			// workaround for missing java project:
+			// fetch all registered containers and use ID also instead of readable description
+			for (String containerId : IClasspathContainer.getRegisteredContainerIds()) {
+				fContainerDesc2ID.put(containerId, containerId);
+			}
+		}
+	}
+
 	public void setDefaults() {
 		IPath annotationsAttachmentPath= fEntry;
 		String path= annotationsAttachmentPath == null ? null : annotationsAttachmentPath.toPortableString();
@@ -146,14 +209,31 @@ public class ExternalAnnotationsAttachmentBlock {
 			fWorkspaceRadio.setSelection(true);
 			fWorkspaceFileNameField.setText(path);
 		} else if (path != null && path.length() != 0) {
-			fExternalRadio.setSelection(true);
-			fExternalFileNameField.setText(path);
+			Entry<String, String> container= getContainerPrefix(path);
+			if (container != null) {
+				fContainerRelativeRadio.setSelection(true);
+				fContainerSelection.selectItem(container.getKey());
+				fContainerRelative.setText(path.substring(container.getValue().length()+1));
+			} else {
+				fExternalRadio.setSelection(true);
+				fExternalFileNameField.setText(path);
+			}
 		} else {
 			fWorkspaceRadio.setSelection(true);
 			fExternalRadio.setSelection(false);
 		}
 	}
 
+	/* Answer description and ID of a container that is the prefix of path. */
+	private Entry<String,String> getContainerPrefix(String path) {
+		for (Entry<String, String> entry : fContainerDesc2ID.entrySet()) {
+			if (path.startsWith(entry.getValue()+'/')) {
+				return entry;
+			}
+		}
+		return null;
+	}
+
 	private boolean isWorkspacePath(IPath path) {
 		if (path == null || path.getDevice() != null)
 			return false;
@@ -223,11 +303,31 @@ public class ExternalAnnotationsAttachmentBlock {
 
 		fExternalFolderButton.doFillIntoGrid(composite, 1);
 
+		fContainerRelativeRadio.doFillIntoGrid(composite, 3);
+
+		fContainerSelection.doFillIntoGrid(composite, 3);
+		LayoutUtil.setHorizontalIndent(fContainerSelection.getLabelControl(null));
+		Combo containerSelection= fContainerSelection.getComboControl(null);
+		LayoutUtil.setWidthHint(containerSelection, widthHint);
+		LayoutUtil.setHorizontalGrabbing(containerSelection);
+
+		fContainerRelative.doFillIntoGrid(composite, 3);
+		LayoutUtil.setHorizontalIndent(fContainerRelative.getLabelControl(null));
+		Text containerRelative= fContainerRelative.getTextControl(null);
+		LayoutUtil.setWidthHint(containerRelative, widthHint);
+		LayoutUtil.setHorizontalGrabbing(containerRelative);
+
 		fWorkspaceRadio.attachDialogField(fWorkspaceFileNameField);
 		fExternalRadio.attachDialogFields(new DialogField[] { fExternalFileNameField, fExternalFolderButton });
+		fContainerRelativeRadio.attachDialogFields(new DialogField[] { fContainerSelection, fContainerRelative });
 
 		Dialog.applyDialogFont(composite);
 
+		if (fContainerRelativeRadio.isSelected()) {
+			// continue initialization that started during setDefaults, but didn't have a textControl at that time
+			configureArtifactAssist();
+		}
+
 		PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, IJavaHelpContextIds.EXTERNAL_ANNOTATIONS_ATTACHMENT_DIALOG);
 		return composite;
 	}
@@ -275,6 +375,37 @@ public class ExternalAnnotationsAttachmentBlock {
 				fExternalFileNameField.setText(folderPath.toString());
 			}
 			return;
+		} else if (field == fContainerRelative || field == fContainerRelativeRadio || field == fContainerSelection) {
+			if (field == fContainerSelection && fSWTWidget != null) {
+				configureArtifactAssist();
+			}
+			StatusInfo status= new StatusInfo();
+			if (fContainerSelection.getText().isEmpty()) {
+				status.setError(NewWizardMessages.AnnotationsAttachmentBlock_missingContainer_error);
+			} else if (fContainerRelative.getText().isEmpty()) {
+				status.setError(NewWizardMessages.AnnotationsAttachmentBlock_missingArtifact_error);
+			} else {
+				String containerID= fContainerDesc2ID.get(fContainerSelection.getText());
+				if (fID2Container.containsKey(containerID)) {
+					IClasspathContainer container= fID2Container.get(containerID);
+					boolean found= false;
+					String relative= fContainerRelative.getText();
+					for (IClasspathEntry classpathEntry : container.getClasspathEntries()) {
+						String entryPath= classpathEntry.getPath().lastSegment().toString();
+						// relative must be equal to entryPath (a) entirely, or (b) up-to a boundary char
+						if (entryPath.equals(relative) ||
+								(entryPath.startsWith(relative) && !Character.isLetterOrDigit(entryPath.charAt(relative.length())))) {
+							found= true;
+							break;
+						}
+					}
+					if (!found) {
+						status.setError(MessageFormat.format(NewWizardMessages.AnnotationsAttachmentBlock_artifactNotFound_error,
+								fContainerRelative.getText(), fContainerSelection.getText()));
+					}
+				}
+			}
+			fContainerRelativeStatus= status;
 		}
 		doStatusLineUpdate();
 	}
@@ -285,13 +416,56 @@ public class ExternalAnnotationsAttachmentBlock {
 		if (isWorkSpace) {
 			fWorkspaceFileNameField.enableButton(canBrowseFileName());
 			status= fWorkspaceNameStatus;
-		} else {
+		} else if (fExternalRadio.isSelected()) {
 			fExternalFileNameField.enableButton(canBrowseFileName());
 			status= fExternalNameStatus;
+		} else {
+			status= fContainerRelativeStatus;
 		}
 		fContext.statusChanged(status);
 	}
 
+	private void configureArtifactAssist() {
+		String id= fContainerDesc2ID.get(fContainerSelection.getText());
+		if (id == null) return;
+		IClasspathContainer container= fID2Container.get(id);
+		if (container == null) return;
+		List<String> names= new ArrayList<>();
+		for (IClasspathEntry entry : container.getClasspathEntries()) {
+			String path= guessArtifactName(entry.getPath().toString());
+			names.add(path);
+		}
+		Text textControl= fContainerRelative.getTextControl(null);
+		getArtifactAssistprocessor(textControl).setNames(names);
+		if (names.size() == 1) {
+			textControl.setText(names.iterator().next());
+		}
+	}
+
+	private JavaPrecomputedNamesAssistProcessor getArtifactAssistprocessor(Text textControl) {
+		if (fArtifactAssistprocessor == null) {
+			fArtifactAssistprocessor= new JavaPrecomputedNamesAssistProcessor(Collections.emptyList(),
+					JavaPlugin.getImageDescriptorRegistry().get(JavaPluginImages.DESC_OBJS_JAR));
+			ControlContentAssistHelper.createTextContentAssistant(textControl, fArtifactAssistprocessor);
+		}
+		return fArtifactAssistprocessor;
+	}
+
+	private String guessArtifactName(String path) {
+		int s= path.lastIndexOf('/')+1;
+		for (int i=s; i<path.length(); i++) {
+			if (!Character.isLetterOrDigit(path.charAt(i))) {
+				if (i+1 < path.length()) {
+					char next= path.charAt(i+1);
+					if (Character.isLetter(next))
+						continue;
+				}
+				return path.substring(s, i);
+			}
+		}
+		return path.substring(s);
+	}
+
 	private boolean canBrowseFileName() { // FIXME remove
 		return true;
 	}
@@ -342,6 +516,10 @@ public class ExternalAnnotationsAttachmentBlock {
 	}
 
 	private IPath getFilePath() {
+		if (fContainerRelativeRadio.isSelected()) {
+			String container= fContainerSelection.getText();
+			return new Path(fContainerDesc2ID.get(container)).append(fContainerRelative.getText());
+		}
 		String filePath= fWorkspaceRadio.isSelected() ? fWorkspaceFileNameField.getText() : fExternalFileNameField.getText();
 		return Path.fromOSString(filePath).makeAbsolute();
 	}
