@@ -17,6 +17,7 @@ package org.eclipse.jdt.internal.ui.wizards.buildpaths;
 import java.io.File;
 import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
@@ -33,11 +34,8 @@ import org.eclipse.swt.events.KeyEvent;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Display;
-import org.eclipse.swt.widgets.Shell;
 
-import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
-import org.eclipse.core.runtime.IProgressMonitor;
 
 import org.eclipse.core.resources.IContainer;
 import org.eclipse.core.resources.IFile;
@@ -47,7 +45,6 @@ import org.eclipse.core.resources.IResource;
 import org.eclipse.core.resources.IWorkspaceRoot;
 import org.eclipse.core.resources.IWorkspaceRunnable;
 
-import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.layout.PixelConverter;
 import org.eclipse.jface.viewers.IStructuredSelection;
@@ -158,12 +155,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 		if (Display.getCurrent() != null) {
 			updateLibrariesList();
 		} else {
-			Display.getDefault().asyncExec(new Runnable() {
-				@Override
-				public void run() {
-					updateLibrariesList();
-				}
-			});
+			Display.getDefault().asyncExec(this::updateLibrariesList);
 		}
 	}
 
@@ -175,9 +167,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 		List<CPListElement> cpelements= fClassPathList.getElements();
 		List<CPListElement> libelements= new ArrayList<>(cpelements.size());
 
-		int nElements= cpelements.size();
-		for (int i= 0; i < nElements; i++) {
-			CPListElement cpe= cpelements.get(i);
+		for (CPListElement cpe : cpelements) {
 			if (isEntryKind(cpe.getEntryKind())) {
 				libelements.add(cpe);
 			}
@@ -191,10 +181,8 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 		List<CPListElement> cpelements= fClassPathList.getElements();
 		List<CPListElement> libelements= new ArrayList<>(cpelements.size());
 
-		int nElements= cpelements.size();
 		int size= fLibrariesList.getElements().size();
-		for (int i= 0; i < nElements; i++) {
-			CPListElement cpe= cpelements.get(i);
+		for (CPListElement cpe : cpelements) {
 			if (isEntryKind(cpe.getEntryKind())) {
 				if (size > 0) {
 					// only for update
@@ -369,16 +357,11 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 
 	}
 
-	static boolean isJREContainer(IPath path) {
+	public static boolean isJREContainer(IPath path) {
 		if (path == null)
 			return false;
 		String[] segments= path.segments();
-		for (String seg : segments) {
-			if (seg.equals(JavaRuntime.JRE_CONTAINER)) {
-				return true;
-			}
-		}
-		return false;
+		return Arrays.asList(segments).contains(JavaRuntime.JRE_CONTAINER);
 	}
 
 	boolean hasRootNodes(){
@@ -412,14 +395,6 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 		return composite;
 	}
 
-	private Shell getShell() {
-		if (fSWTControl != null) {
-			return fSWTControl.getShell();
-		}
-		return JavaPlugin.getActiveWorkbenchShell();
-	}
-
-
 	private class LibrariesAdapter extends CPListAdapter {
 
 		// -------- IListAdapter --------
@@ -505,8 +480,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 			List<CPListElement> cplist= fLibrariesList.getElements();
 			List<CPListElement> elementsToAdd= new ArrayList<>(nElementsChosen);
 
-			for (int i= 0; i < nElementsChosen; i++) {
-				CPListElement curr= libentries[i];
+			for (CPListElement curr : libentries) {
 				boolean contains= cplist.contains(curr);
 				if(hasRootNodes()) {
 					contains= hasCurrentElement(cplist,curr);
@@ -665,7 +639,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 				String key= attrib.getKey();
 				if (attrib.isBuiltIn()) {
 					Object value= null;
-					if (key.equals(CPListElement.ACCESSRULES)) {
+					if (CPListElement.ACCESSRULES.equals(key)) {
 						value= new IAccessRule[0];
 					}
 					attrib.setValue(value);
@@ -717,8 +691,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 		if (selElements.isEmpty()) {
 			return false;
 		}
-		for (int i= 0; i < selElements.size(); i++) {
-			Object elem= selElements.get(i);
+		for (Object elem : selElements) {
 			if (elem instanceof CPListElementAttribute) {
 				CPListElementAttribute attrib= (CPListElementAttribute) elem;
 
@@ -733,7 +706,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 					if (attrib.getParent().isInContainer(JavaRuntime.JRE_CONTAINER) && CPListElement.ACCESSRULES.equals(attrib.getKey())) {
 						return false; // workaround for 166519 until we have full story
 					}
-					if (attrib.getKey().equals(CPListElement.ACCESSRULES)) {
+					if (CPListElement.ACCESSRULES.equals(attrib.getKey())) {
 						return ((IAccessRule[]) attrib.getValue()).length > 0;
 					}
 					if (attrib.getValue() == null) {
@@ -791,10 +764,10 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 		boolean canEditEncoding= false;
 		for (CPListElementAttribute attribute : selElement.getAllAttributes()) {
 			if (CPListElement.SOURCE_ATTACHMENT_ENCODING.equals(attribute.getKey())) {
-				canEditEncoding= !(attribute.isNonModifiable() || attribute.isNotSupported());
+				canEditEncoding= !attribute.isNonModifiable() && !attribute.isNotSupported();
 			}
 		}
-		if (key.equals(CPListElement.SOURCEATTACHMENT)) {
+		if (CPListElement.SOURCEATTACHMENT.equals(key)) {
 			IClasspathEntry result= BuildPathDialogAccess.configureSourceAttachment(getShell(), selElement.getClasspathEntry(), canEditEncoding);
 			if (result != null) {
 				selElement.setAttribute(CPListElement.SOURCEATTACHMENT, result.getSourceAttachmentPath());
@@ -806,7 +779,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 				fClassPathList.refresh(); // images
 				updateEnabledState();
 			}
-		} else if (key.equals(CPListElement.ACCESSRULES)) {
+		} else if (CPListElement.ACCESSRULES.equals(key)) {
 			AccessRulesDialog dialog= new AccessRulesDialog(getShell(), selElement, fCurrJProject, fPageContainer != null);
 			int res= dialog.open();
 			if (res == Window.OK || res == AccessRulesDialog.SWITCH_PAGE) {
@@ -822,7 +795,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 					dialog.performPageSwitch(fPageContainer);
 				}
 			}
-		} else if (key.equals(CPListElement.MODULE)) {
+		} else if (CPListElement.MODULE.equals(key)) {
 			boolean wasModular= selElement.getAttribute(CPListElement.MODULE) != null;
 			if (showModuleDialog(getShell(), elem)) {
 				String[] changedAttributes= { CPListElement.MODULE };
@@ -842,24 +815,14 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 			if (editCustomAttribute(getShell(), elem)) {
 				String[] changedAttributes= { key };
 				attributeUpdated(selElement, changedAttributes);
-				if(key.equals(CPListElement.TEST) || key.equals(CPListElement.WITHOUT_TEST_CODE)) {
+				if(CPListElement.TEST.equals(key) || CPListElement.WITHOUT_TEST_CODE.equals(key)) {
 					fLibrariesList.refresh(elem.getParent());
 				} else {
 					fLibrariesList.refresh(elem);
 				}
 				fClassPathList.dialogFieldChanged(); // validate
 				updateEnabledState();
-				if (key.equals(IClasspathAttribute.EXTERNAL_ANNOTATION_PATH)) {
-					if (fCurrJProject.getOption(JavaCore.COMPILER_ANNOTATION_NULL_ANALYSIS, true).equals(JavaCore.DISABLED)) {
-						MessageDialog messageDialog= new MessageDialog(getShell(),
-								NewWizardMessages.LibrariesWorkbookPage_externalAnnotationNeedsNullAnnotationEnabled_title,
-								null,
-								NewWizardMessages.LibrariesWorkbookPage_externalAnnotationNeedsNullAnnotationEnabled_message,
-								MessageDialog.INFORMATION, new String[] { IDialogConstants.OK_LABEL },
-								0);
-						messageDialog.open();
-					}
-				}
+				checkAttributeEffect(key, fCurrJProject);
 			}
 		}
 	}
@@ -874,12 +837,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 
 	private void updateContainerEntry(final IClasspathEntry newEntry, final String[] changedAttributes, final IJavaProject jproject, final IPath containerPath) {
 		try {
-			IWorkspaceRunnable runnable= new IWorkspaceRunnable() {
-				@Override
-				public void run(IProgressMonitor monitor) throws CoreException {
-					BuildPathSupport.modifyClasspathEntry(null, newEntry, changedAttributes, jproject, containerPath, false, monitor);
-				}
-			};
+			IWorkspaceRunnable runnable= monitor -> BuildPathSupport.modifyClasspathEntry(null, newEntry, changedAttributes, jproject, containerPath, false, monitor);
 			PlatformUI.getWorkbench().getProgressService().run(true, true, new WorkbenchRunnableAdapter(runnable));
 
 		} catch (InvocationTargetException e) {
@@ -1053,8 +1011,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 		if (selElements.isEmpty() || selElements.size() > 1) {
 			return false;
 		}
-		for (int i= 0; i < selElements.size(); i++) {
-			Object elem= selElements.get(i);
+		for (Object elem : selElements) {
 			if (elem instanceof CPListElement) {
 				if (!((CPListElement) elem).isRootNodeForPath()) {
 					return false;
@@ -1086,7 +1043,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 			if (!attrib.isBuiltIn()) {
 				return canEditCustomAttribute(attrib);
 			}
-			if (hasRootNodes() && attrib.getKey().equals(IClasspathAttribute.MODULE)) {
+			if (hasRootNodes() && IClasspathAttribute.MODULE.equals(attrib.getKey())) {
 				//module attribute should always be enabled
 				return true;
 			}
@@ -1109,8 +1066,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 	private void updateClasspathList() {
 		 List<CPListElement> projelements= fLibrariesList.getElements();
 		 List<CPListElement> flattenedProjElements= new ArrayList<>();
-		 for ( int i =0; i < projelements.size(); i++ ) {
-		 	CPListElement ele= projelements.get(i);
+		 for (CPListElement ele : projelements) {
 		 	// if root node, collect the CPList elements
 		 	if(ele.isRootNodeForPath()) {
 		 		for (Object object : ((RootCPListElement)ele).getChildren()) {
@@ -1164,7 +1120,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 
 	private CPListElement[] openClassFolderDialog(CPListElement existing) {
 		if (existing == null) {
-			IPath[] selected= BuildPathDialogAccess.chooseClassFolderEntries(getShell(), fCurrJProject.getPath(), getUsedContainers(existing));
+			IPath[] selected= BuildPathDialogAccess.chooseClassFolderEntries(getShell(), fCurrJProject.getPath(), getUsedContainers(null));
 			if (selected != null) {
 				IWorkspaceRoot root= fCurrJProject.getProject().getWorkspace().getRoot();
 				ArrayList<CPListElement> res= new ArrayList<>();
@@ -1188,7 +1144,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 		IWorkspaceRoot root= fCurrJProject.getProject().getWorkspace().getRoot();
 
 		if (existing == null) {
-			IPath[] selected= BuildPathDialogAccess.chooseJAREntries(getShell(), fCurrJProject.getPath(), getUsedJARFiles(existing));
+			IPath[] selected= BuildPathDialogAccess.chooseJAREntries(getShell(), fCurrJProject.getPath(), getUsedJARFiles(null));
 			if (selected != null) {
 				ArrayList<CPListElement> res= new ArrayList<>();
 
@@ -1229,8 +1185,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 		}
 
 		List<CPListElement> cplist= fLibrariesList.getElements();
-		for (int i= 0; i < cplist.size(); i++) {
-			CPListElement elem= cplist.get(i);
+		for (CPListElement elem : cplist) {
 			if (elem.getEntryKind() == IClasspathEntry.CPE_LIBRARY && (elem != existing)) {
 				IResource resource= elem.getResource();
 				if (resource instanceof IContainer) {
@@ -1244,8 +1199,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 	private IPath[] getUsedJARFiles(CPListElement existing) {
 		List<IPath> res= new ArrayList<>();
 		List<CPListElement> cplist= fLibrariesList.getElements();
-		for (int i= 0; i < cplist.size(); i++) {
-			CPListElement elem= cplist.get(i);
+		for (CPListElement elem : cplist) {
 			if (elem.getEntryKind() == IClasspathEntry.CPE_LIBRARY && (elem != existing)) {
 				IResource resource= elem.getResource();
 				if (resource instanceof IFile) {
@@ -1311,8 +1265,7 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 	private CPListElement[] openVariableSelectionDialog(CPListElement existing) {
 		List<CPListElement> existingElements= fLibrariesList.getElements();
 		ArrayList<IPath> existingPaths= new ArrayList<>(existingElements.size());
-		for (int i= 0; i < existingElements.size(); i++) {
-			CPListElement elem= existingElements.get(i);
+		for (CPListElement elem : existingElements) {
 			if (elem.getEntryKind() == IClasspathEntry.CPE_VARIABLE) {
 				existingPaths.add(elem.getPath());
 			}
@@ -1419,16 +1372,16 @@ public class LibrariesWorkbookPage extends BuildPathBasePage {
 	public void setSelection(List<?> selElements, boolean expand) {
 		fLibrariesList.selectElements(new StructuredSelection(selElements));
 		if (expand) {
-			for (int i= 0; i < selElements.size(); i++) {
-				fLibrariesList.expandElement(selElements.get(i), 1);
+			for (Object selElement : selElements) {
+				fLibrariesList.expandElement(selElement, 1);
 			}
 		}
 	}
 
-    @Override
+	@Override
 	public void setFocus() {
-    	fLibrariesList.setFocus();
-    }
+		fLibrariesList.setFocus();
+	}
 
 	public void selectRootNode(boolean modulePath) {
 		selectRootNode(fLibrariesList, modulePath);
