@@ -178,7 +178,7 @@ public class ClasspathModifierQueries {
      * Query to get information about the inclusion and exclusion filters of
      * an element.
      */
-    public static interface IInclusionExclusionQuery {
+    public interface IInclusionExclusionQuery {
         /**
          * Query to get information about the
          * inclusion and exclusion filters of
@@ -200,7 +200,7 @@ public class ClasspathModifierQueries {
          * or <code>getExclusionPattern</code> can
          * be called.
          */
-        public boolean doQuery(CPListElement element, boolean focusOnExcluded);
+        boolean doQuery(CPListElement element, boolean focusOnExcluded);
 
         /**
          * Can only be called after <code>
@@ -209,7 +209,7 @@ public class ClasspathModifierQueries {
          *
          * @return the new inclusion filters
          */
-        public IPath[] getInclusionPattern();
+        IPath[] getInclusionPattern();
 
         /**
          * Can only be called after <code>
@@ -218,14 +218,14 @@ public class ClasspathModifierQueries {
          *
          * @return the new exclusion filters
          */
-        public IPath[] getExclusionPattern();
+        IPath[] getExclusionPattern();
     }
 
     /**
      * Query to get information about the output location that should be used for a
      * given element.
      */
-    public static interface IOutputLocationQuery {
+    public interface IOutputLocationQuery {
         /**
          * Query to get information about the output
          * location that should be used for a
@@ -237,7 +237,7 @@ public class ClasspathModifierQueries {
          * location has changed, <code>false</code>
          * otherwise.
          */
-        public boolean doQuery(CPListElement element);
+        boolean doQuery(CPListElement element);
 
         /**
          * Gets the new output location.
@@ -248,7 +248,7 @@ public class ClasspathModifierQueries {
          *
          * @return the new output location, can be <code>null</code>
          */
-        public IPath getOutputLocation();
+        IPath getOutputLocation();
 
         /**
          * Get a query for information about whether the project should be removed as
@@ -260,22 +260,22 @@ public class ClasspathModifierQueries {
          * @throws JavaModelException
          *
          */
-        public OutputFolderQuery getOutputFolderQuery(IPath outputLocation) throws JavaModelException;
+        OutputFolderQuery getOutputFolderQuery(IPath outputLocation) throws JavaModelException;
     }
 
     /**
 	 * Query to determine whether a linked folder should be removed.
 	 */
-	public static interface IRemoveLinkedFolderQuery {
+	public interface IRemoveLinkedFolderQuery {
 
 		/** Remove status indicating that the removal should be cancelled */
-		public static final int REMOVE_CANCEL= 0;
+		int REMOVE_CANCEL= 0;
 
 		/** Remove status indicating that the folder should be removed from the build path only */
-		public static final int REMOVE_BUILD_PATH= 1;
+		int REMOVE_BUILD_PATH= 1;
 
 		/** Remove status indicating that the folder should be removed from the build path and deleted */
-		public static final int REMOVE_BUILD_PATH_AND_FOLDER= 2;
+		int REMOVE_BUILD_PATH_AND_FOLDER= 2;
 
 		/**
 		 * Query to determined whether the linked folder should be removed as well.
@@ -283,13 +283,13 @@ public class ClasspathModifierQueries {
 		 * @param folder the linked folder to remove
 		 * @return a status code corresponding to one of the IRemoveLinkedFolderQuery#REMOVE_XXX constants
 		 */
-		public int doQuery(IFolder folder);
+		int doQuery(IFolder folder);
 	}
 
     /**
 	 * Query to create a folder.
 	 */
-    public static interface ICreateFolderQuery {
+    public interface ICreateFolderQuery {
         /**
          * Query to create a folder.
          *
@@ -297,7 +297,7 @@ public class ClasspathModifierQueries {
          * was successful (e.g. no cancelled), <code>
          * false</code> otherwise
          */
-        public boolean doQuery();
+        boolean doQuery();
 
         /**
          * Find out whether a source folder is about
@@ -314,7 +314,7 @@ public class ClasspathModifierQueries {
          * folder should be created, <code>false
          * </code> otherwise
          */
-        public boolean isSourceFolder();
+        boolean isSourceFolder();
 
         /**
          * Get the newly created folder.
@@ -324,26 +324,26 @@ public class ClasspathModifierQueries {
          * @return the created folder of type
          * <code>IFolder</code>
          */
-        public IFolder getCreatedFolder();
+        IFolder getCreatedFolder();
     }
 
     /**
      * Query to add archives (.jar or .zip files) to the buildpath.
      */
-    public static interface IAddArchivesQuery {
+    public interface IAddArchivesQuery {
         /**
          * Get the paths to the new archive entries that should be added to the buildpath.
          *
          * @return Returns the new classpath container entry paths or an empty array if the query has
          * been cancelled by the user.
          */
-        public IPath[] doQuery();
+        IPath[] doQuery();
     }
 
     /**
      * Query to add libraries to the buildpath.
      */
-    public static interface IAddLibrariesQuery {
+    public interface IAddLibrariesQuery {
         /**
          * Get the new classpath entries for libraries to be added to the buildpath.
          *
@@ -352,7 +352,7 @@ public class ClasspathModifierQueries {
          * @return Returns the selected classpath container entries or an empty if the query has
          * been cancelled by the user.
          */
-        public IClasspathEntry[] doQuery(final IJavaProject project, final IClasspathEntry[] entries);
+        IClasspathEntry[] doQuery(final IJavaProject project, final IClasspathEntry[] entries);
     }
 
     /**
@@ -376,37 +376,34 @@ public class ClasspathModifierQueries {
                 final boolean[] result= { false };
                 fRemoveProject= false;
                 fOutputLocation= project.getOutputLocation();
-				Display.getDefault().syncExec(new Runnable() {
-					@Override
-					public void run() {
-						Shell sh= shell != null ? shell : JavaPlugin.getActiveWorkbenchShell();
+				Display.getDefault().syncExec(() -> {
+					Shell sh= shell != null ? shell : JavaPlugin.getActiveWorkbenchShell();
 
-						String title= NewWizardMessages.ClasspathModifier_ChangeOutputLocationDialog_title;
+					String title= NewWizardMessages.ClasspathModifier_ChangeOutputLocationDialog_title;
 
-						if (fDesiredOutputLocation.segmentCount() == 1) {
-							String outputFolderName= PreferenceConstants.getPreferenceStore().getString(PreferenceConstants.SRCBIN_BINNAME);
-							IPath newOutputFolder= fDesiredOutputLocation.append(outputFolderName);
-							newOutputFolder= getValidPath(newOutputFolder, validator);
-							String message= Messages.format(NewWizardMessages.ClasspathModifier_ChangeOutputLocationDialog_project_outputLocation, BasicElementLabels.getPathLabel(newOutputFolder, false));
-							fRemoveProject= true;
-							if (MessageDialog.openConfirm(sh, title, message)) {
-								fOutputLocation= newOutputFolder;
-								result[0]= true;
-							}
-						} else {
-							IPath newOutputFolder= fDesiredOutputLocation;
-							newOutputFolder= getValidPath(newOutputFolder, validator);
-							if (editingOutputFolder) {
-								fOutputLocation= newOutputFolder;
-								result[0]= true;
-								return; // show no dialog
-							}
-							String message= NewWizardMessages.ClasspathModifier_ChangeOutputLocationDialog_project_message;
-							fRemoveProject= true;
-							if (MessageDialog.openQuestion(sh, title, message)) {
-								fOutputLocation= newOutputFolder;
-								result[0]= true;
-							}
+					if (fDesiredOutputLocation.segmentCount() == 1) {
+						String outputFolderName= PreferenceConstants.getPreferenceStore().getString(PreferenceConstants.SRCBIN_BINNAME);
+						IPath newOutputFolder1= fDesiredOutputLocation.append(outputFolderName);
+						newOutputFolder1= getValidPath(newOutputFolder1, validator);
+						String message1= Messages.format(NewWizardMessages.ClasspathModifier_ChangeOutputLocationDialog_project_outputLocation, BasicElementLabels.getPathLabel(newOutputFolder1, false));
+						fRemoveProject= true;
+						if (MessageDialog.openConfirm(sh, title, message1)) {
+							fOutputLocation= newOutputFolder1;
+							result[0]= true;
+						}
+					} else {
+						IPath newOutputFolder2= fDesiredOutputLocation;
+						newOutputFolder2= getValidPath(newOutputFolder2, validator);
+						if (editingOutputFolder) {
+							fOutputLocation= newOutputFolder2;
+							result[0]= true;
+							return; // show no dialog
+						}
+						String message2= NewWizardMessages.ClasspathModifier_ChangeOutputLocationDialog_project_message;
+						fRemoveProject= true;
+						if (MessageDialog.openQuestion(sh, title, message2)) {
+							fOutputLocation= newOutputFolder2;
+							result[0]= true;
 						}
 					}
 				});
@@ -454,15 +451,12 @@ public class ClasspathModifierQueries {
 			@Override
 			public boolean doQuery(final CPListElement element, final boolean focusOnExcluded) {
 				final boolean[] result= { false };
-				Display.getDefault().syncExec(new Runnable() {
-					@Override
-					public void run() {
-						Shell sh= shell != null ? shell : JavaPlugin.getActiveWorkbenchShell();
-						ExclusionInclusionDialog dialog= new ExclusionInclusionDialog(sh, element, focusOnExcluded);
-						result[0]= dialog.open() == Window.OK;
-						fInclusionPattern= dialog.getInclusionPattern();
-						fExclusionPattern= dialog.getExclusionPattern();
-					}
+				Display.getDefault().syncExec(() -> {
+					Shell sh= shell != null ? shell : JavaPlugin.getActiveWorkbenchShell();
+					ExclusionInclusionDialog dialog= new ExclusionInclusionDialog(sh, element, focusOnExcluded);
+					result[0]= dialog.open() == Window.OK;
+					fInclusionPattern= dialog.getInclusionPattern();
+					fExclusionPattern= dialog.getExclusionPattern();
 				});
 				return result[0];
 			}
@@ -490,23 +484,16 @@ public class ClasspathModifierQueries {
      * @see IAddArchivesQuery
      */
     public static IAddArchivesQuery getDefaultArchivesQuery(final Shell shell) {
-        return new IAddArchivesQuery() {
-
-            @Override
-			public IPath[] doQuery() {
-                final IPath[][] selected= {null};
-                Display.getDefault().syncExec(new Runnable() {
-                    @Override
-					public void run() {
-                        Shell sh= shell != null ? shell : JavaPlugin.getActiveWorkbenchShell();
-                        selected[0]= BuildPathDialogAccess.chooseExternalJAREntries(sh);
-                    }
-                });
-                if(selected[0] == null)
-                    return new IPath[0];
-                return selected[0];
-            }
-        };
+        return () -> {
+		    final IPath[][] selected= {null};
+		    Display.getDefault().syncExec(() -> {
+			    Shell sh= shell != null ? shell : JavaPlugin.getActiveWorkbenchShell();
+			    selected[0]= BuildPathDialogAccess.chooseExternalJAREntries(sh);
+			});
+		    if(selected[0] == null)
+		        return new IPath[0];
+		    return selected[0];
+		};
     }
 
     /**
@@ -518,25 +505,17 @@ public class ClasspathModifierQueries {
 	 * @see IRemoveLinkedFolderQuery
 	 */
 	public static IRemoveLinkedFolderQuery getDefaultRemoveLinkedFolderQuery(final Shell shell) {
-		return new IRemoveLinkedFolderQuery() {
-
-			@Override
-			public final int doQuery(final IFolder folder) {
-				final int[] result= { IRemoveLinkedFolderQuery.REMOVE_BUILD_PATH};
-				Display.getDefault().syncExec(new Runnable() {
-
-					@Override
-					public final void run() {
-						final RemoveLinkedFolderDialog dialog= new RemoveLinkedFolderDialog((shell != null ? shell : JavaPlugin.getActiveWorkbenchShell()), folder);
-						final int status= dialog.open();
-						if (status == 0)
-							result[0]= dialog.getRemoveStatus();
-						else
-							result[0]= IRemoveLinkedFolderQuery.REMOVE_CANCEL;
-					}
-				});
-				return result[0];
-			}
+		return folder -> {
+			final int[] result= { IRemoveLinkedFolderQuery.REMOVE_BUILD_PATH};
+			Display.getDefault().syncExec(() -> {
+				final RemoveLinkedFolderDialog dialog= new RemoveLinkedFolderDialog((shell != null ? shell : JavaPlugin.getActiveWorkbenchShell()), folder);
+				final int status= dialog.open();
+				if (status == 0)
+					result[0]= dialog.getRemoveStatus();
+				else
+					result[0]= IRemoveLinkedFolderQuery.REMOVE_CANCEL;
+			});
+			return result[0];
 		};
 	}
 
@@ -551,23 +530,16 @@ public class ClasspathModifierQueries {
      * been cancelled by the user.
      */
     public static IAddLibrariesQuery getDefaultLibrariesQuery(final Shell shell) {
-        return new IAddLibrariesQuery() {
-
-            @Override
-			public IClasspathEntry[] doQuery(final IJavaProject project, final IClasspathEntry[] entries) {
-                final IClasspathEntry[][] selected= {null};
-                Display.getDefault().syncExec(new Runnable() {
-                    @Override
-					public void run() {
-                        Shell sh= shell != null ? shell : JavaPlugin.getActiveWorkbenchShell();
-                        selected[0]= BuildPathDialogAccess.chooseContainerEntries(sh, project, entries);
-                    }
-                });
-                if(selected[0] == null)
-                    return new IClasspathEntry[0];
-                return selected[0];
-            }
-        };
+        return (project, entries) -> {
+		    final IClasspathEntry[][] selected= {null};
+		    Display.getDefault().syncExec(() -> {
+			    Shell sh= shell != null ? shell : JavaPlugin.getActiveWorkbenchShell();
+			    selected[0]= BuildPathDialogAccess.chooseContainerEntries(sh, project, entries);
+			});
+		    if(selected[0] == null)
+		        return new IClasspathEntry[0];
+		    return selected[0];
+		};
     }
 
     /**
@@ -585,23 +557,20 @@ public class ClasspathModifierQueries {
 			@Override
 			public boolean doQuery() {
 				final boolean[] isOK= {false};
-                Display.getDefault().syncExec(new Runnable() {
-                    @Override
-					public void run() {
-                        Shell sh= shell != null ? shell : JavaPlugin.getActiveWorkbenchShell();
+                Display.getDefault().syncExec(() -> {
+				    Shell sh= shell != null ? shell : JavaPlugin.getActiveWorkbenchShell();
 
-                        NewFolderDialog dialog= new NewFolderDialog(sh, project.getProject());
-                        isOK[0]= dialog.open() == Window.OK;
-                        if (isOK[0]) {
-                        	IResource sourceContainer= (IResource) dialog.getResult()[0];
-                        	if (sourceContainer instanceof IFolder) {
-                        		fNewFolder= (IFolder)sourceContainer;
-                        	} else {
-                        		fNewFolder= null;
-                        	}
-                        }
-                    }
-                });
+				    NewFolderDialog dialog= new NewFolderDialog(sh, project.getProject());
+				    isOK[0]= dialog.open() == Window.OK;
+				    if (isOK[0]) {
+				    	IResource sourceContainer= (IResource) dialog.getResult()[0];
+				    	if (sourceContainer instanceof IFolder) {
+				    		fNewFolder= (IFolder)sourceContainer;
+				    	} else {
+				    		fNewFolder= null;
+				    	}
+				    }
+				});
                 return isOK[0];
 			}
 
@@ -618,4 +587,7 @@ public class ClasspathModifierQueries {
 
 		};
 	}
+
+	private ClasspathModifierQueries() {
+	}
 }
