@@ -16,7 +16,6 @@ package org.eclipse.jdt.ui.actions;
 import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.swt.SWT;
@@ -41,10 +40,8 @@ import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.jface.viewers.ArrayContentProvider;
 import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.LabelProvider;
-import org.eclipse.jface.viewers.SelectionChangedEvent;
 
 import org.eclipse.jface.text.BadLocationException;
 
@@ -124,8 +121,7 @@ public class FindStringsToExternalizeAction extends SelectionDispatchAction {
 	private boolean computeEnablementState(IStructuredSelection selection) throws JavaModelException {
 		if (selection.isEmpty())
 			return false;
-		for (Iterator<?> iter= selection.iterator(); iter.hasNext();) {
-			Object element= iter.next();
+		for (Object element : selection) {
 			if (!(element instanceof IJavaElement))
 				return false;
 			IJavaElement javaElement= (IJavaElement)element;
@@ -162,14 +158,11 @@ public class FindStringsToExternalizeAction extends SelectionDispatchAction {
 	}
 
 	private IRunnableWithProgress createRunnable(final IStructuredSelection selection) {
-		return new IRunnableWithProgress() {
-			@Override
-			public void run(IProgressMonitor pm) throws InvocationTargetException {
-				try {
-					fElements= doRun(selection, pm);
-				} catch (CoreException e) {
-					throw new InvocationTargetException(e);
-				}
+		return pm -> {
+			try {
+				fElements= doRun(selection, pm);
+			} catch (CoreException e) {
+				throw new InvocationTargetException(e);
 			}
 		};
 	}
@@ -183,8 +176,8 @@ public class FindStringsToExternalizeAction extends SelectionDispatchAction {
 
 		try{
 			List<NonNLSElement> l= new ArrayList<>();
-			for (Iterator<?> iter= elements.iterator(); iter.hasNext();) {
-				IJavaElement element= (IJavaElement) iter.next();
+			for (Object e : (List<?>)elements) {
+				IJavaElement element=(IJavaElement) e;
 				if (element.getElementType() == IJavaElement.PACKAGE_FRAGMENT)
 					l.addAll(analyze((IPackageFragment) element, new SubProgressMonitor(pm, 1)));
 				else if (element.getElementType() == IJavaElement.PACKAGE_FRAGMENT_ROOT)
@@ -207,9 +200,10 @@ public class FindStringsToExternalizeAction extends SelectionDispatchAction {
 
 	private boolean noStrings() {
 		if (fElements != null) {
-			for (int i= 0; i < fElements.length; i++) {
-				if (fElements[i].count != 0)
+			for (NonNLSElement fElement : fElements) {
+				if (fElement.count != 0) {
 					return false;
+				}
 			}
 		}
 		return true;
@@ -229,9 +223,9 @@ public class FindStringsToExternalizeAction extends SelectionDispatchAction {
 			pm.setTaskName(pack.getElementName());
 
 			List<NonNLSElement> l= new ArrayList<>(cus.length);
-			for (int i= 0; i < cus.length; i++){
-				pm.subTask(BasicElementLabels.getFileName(cus[i]));
-				NonNLSElement element= analyze(cus[i]);
+			for (ICompilationUnit cu : cus) {
+				pm.subTask(BasicElementLabels.getFileName(cu));
+				NonNLSElement element= analyze(cu);
 				if (element != null)
 					l.add(element);
 				pm.worked(1);
@@ -253,8 +247,7 @@ public class FindStringsToExternalizeAction extends SelectionDispatchAction {
 			pm.beginTask("", children.length); //$NON-NLS-1$
 			pm.setTaskName(JavaElementLabels.getElementLabel(sourceFolder, JavaElementLabels.ALL_DEFAULT));
 			List<NonNLSElement> result= new ArrayList<>();
-			for (int i= 0; i < children.length; i++) {
-				IJavaElement iJavaElement= children[i];
+			for (IJavaElement iJavaElement : children) {
 				if (iJavaElement.getElementType() == IJavaElement.PACKAGE_FRAGMENT){
 					IPackageFragment pack= (IPackageFragment)iJavaElement;
 					if (! pack.isReadOnly())
@@ -278,11 +271,12 @@ public class FindStringsToExternalizeAction extends SelectionDispatchAction {
 			IPackageFragment[] packs= project.getPackageFragments();
 			pm.beginTask("", packs.length); //$NON-NLS-1$
 			List<NonNLSElement> result= new ArrayList<>();
-			for (int i= 0; i < packs.length; i++) {
-				if (! packs[i].isReadOnly())
-					result.addAll(analyze(packs[i], new SubProgressMonitor(pm, 1)));
-				else
+			for (IPackageFragment pack : packs) {
+				if (!pack.isReadOnly()) {
+					result.addAll(analyze(pack, new SubProgressMonitor(pm, 1)));
+				} else {
 					pm.worked(1);
+				}
 			}
 			return result;
 		} finally{
@@ -293,8 +287,9 @@ public class FindStringsToExternalizeAction extends SelectionDispatchAction {
 	private int countStrings() {
 		int found= 0;
 		if (fElements != null) {
-			for (int i= 0; i < fElements.length; i++)
-				found+= fElements[i].count;
+			for (NonNLSElement fElement : fElements) {
+				found+= fElement.count;
+			}
 		}
 		return found;
 	}
@@ -309,17 +304,12 @@ public class FindStringsToExternalizeAction extends SelectionDispatchAction {
 
 	private int countNonExternalizedStrings(ICompilationUnit cu) throws CoreException {
 		try{
-			NLSLine[] lines= NLSScanner.scan(cu);
 			int result= 0;
-			for (int i= 0; i < lines.length; i++) {
-				result += countNonExternalizedStrings(lines[i]);
+			for (NLSLine line : NLSScanner.scan(cu)) {
+				result += countNonExternalizedStrings(line);
 			}
 			return result;
-		} catch (InvalidInputException e) {
-			throw new CoreException(new Status(IStatus.ERROR, JavaPlugin.getPluginId(), IStatus.ERROR,
-				Messages.format(ActionMessages.FindStringsToExternalizeAction_error_cannotBeParsed, BasicElementLabels.getFileName(cu)),
-				e));
-		} catch (BadLocationException e) {
+		} catch (InvalidInputException | BadLocationException e) {
 			throw new CoreException(new Status(IStatus.ERROR, JavaPlugin.getPluginId(), IStatus.ERROR, Messages.format(ActionMessages.FindStringsToExternalizeAction_error_cannotBeParsed,
 					BasicElementLabels.getFileName(cu)), e));
 		}
@@ -327,10 +317,10 @@ public class FindStringsToExternalizeAction extends SelectionDispatchAction {
 
 	private int countNonExternalizedStrings(NLSLine line){
 		int result= 0;
-		NLSElement[] elements= line.getElements();
-		for (int i= 0; i < elements.length; i++){
-			if (! elements[i].hasTag())
+		for (NLSElement element : line.getElements()) {
+			if (!element.hasTag()) {
 				result++;
+			}
 		}
 		return result;
 	}
@@ -375,12 +365,9 @@ public class FindStringsToExternalizeAction extends SelectionDispatchAction {
 		@Override
 		protected Control createDialogArea(Composite parent) {
 			Composite result= (Composite)super.createDialogArea(parent);
-			getTableViewer().addSelectionChangedListener(new ISelectionChangedListener(){
-				@Override
-				public void selectionChanged(SelectionChangedEvent event){
-					if (fOpenButton != null){
-						fOpenButton.setEnabled(! getTableViewer().getSelection().isEmpty());
-					}
+			getTableViewer().addSelectionChangedListener(event -> {
+				if (fOpenButton != null){
+					fOpenButton.setEnabled(! getTableViewer().getSelection().isEmpty());
 				}
 			});
 			getTableViewer().getTable().addSelectionListener(new SelectionAdapter(){
