@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -111,7 +111,7 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 
 	private static final String PAGE_NAME= "NewPackageWizardPage"; //$NON-NLS-1$
 
-	private static final String PACKAGE= "NewPackageWizardPage.package"; //$NON-NLS-1$
+	private static final String PACKAGE_NAME= "NewPackageWizardPage.package"; //$NON-NLS-1$
 
 	private final static String SETTINGS_CREATEPACKAGE_INFO_JAVA= "create_package_info_java"; //$NON-NLS-1$
 
@@ -124,7 +124,7 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 	/*
 	 * Status of last validation of the package field
 	 */
-	private IStatus fPackageStatus;
+	private IStatus fPackageNameStatus;
 
 	private IPackageFragment fCreatedPackageFragment;
 
@@ -143,7 +143,7 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 
 		PackageFieldAdapter adapter= new PackageFieldAdapter();
 
-		fPackageDialogField= new StringDialogField(); 
+		fPackageDialogField= new StringDialogField();
 		fPackageDialogField.setDialogFieldListener(adapter);
 		fPackageDialogField.setLabelText(NewWizardMessages.NewPackageWizardPage_package_label);
 
@@ -151,7 +151,7 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 		fCreatePackageInfoJavaDialogField.setDialogFieldListener(adapter);
 		fCreatePackageInfoJavaDialogField.setLabelText(NewWizardMessages.NewPackageWizardPage_package_CreatePackageInfoJava);
 
-		fPackageStatus= new StatusInfo();
+		fPackageNameStatus= new StatusInfo();
 	}
 
 	// -------- Initialization ---------
@@ -203,7 +203,7 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 			}
 		}
 
-		updateStatus(new IStatus[] { fContainerStatus, fPackageStatus });
+		updateStatus(new IStatus[] { fContainerStatus, fPackageNameStatus });
 		setAddComments(StubUtility.doAddComments(getJavaProject()), true); // from project or workspace
 	}
 
@@ -303,9 +303,9 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 
 		@Override
 		public void dialogFieldChanged(DialogField field) {
-			fPackageStatus= getPackageStatus(getPackageText());
+			fPackageNameStatus= getPackageStatus(getPackageText());
 			// tell all others
-			handleFieldChanged(PACKAGE);
+			handleFieldChanged(PACKAGE_NAME);
 		}
 	}
 
@@ -317,11 +317,11 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 	@Override
 	protected void handleFieldChanged(String fieldName) {
 		super.handleFieldChanged(fieldName);
-		if (fieldName == CONTAINER) {
-			fPackageStatus= getPackageStatus(getPackageText());
+		if (CONTAINER.equals(fieldName)) {
+			fPackageNameStatus= getPackageStatus(getPackageText());
 		}
 		// do status line update
-		updateStatus(new IStatus[] { fContainerStatus, fPackageStatus });
+		updateStatus(new IStatus[] { fContainerStatus, fPackageNameStatus });
 	}
 
 	// ----------- validation ----------
@@ -336,9 +336,9 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 
 	/**
 	 * Validates the package name and returns the status of the validation.
-	 * 
+	 *
 	 * @param packName the package name
-	 * 
+	 *
 	 * @return the status of the validation
 	 */
 	private IStatus getPackageStatus(String packName) {
@@ -401,15 +401,13 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 		}
 		return status;
 	}
-	
+
 	private boolean packageDocumentationAlreadyExists(IPackageFragment pack) throws JavaModelException {
 		ICompilationUnit packageInfoJava= pack.getCompilationUnit(PACKAGE_INFO_JAVA_FILENAME);
 		if (packageInfoJava.exists()) {
 			return true;
 		}
-		Object[] nonJavaResources= pack.getNonJavaResources();
-		for (int i= 0; i < nonJavaResources.length; i++) {
-			Object resource= nonJavaResources[i];
+		for (Object resource : pack.getNonJavaResources()) {
 			if (resource instanceof IFile) {
 				IFile file= (IFile) resource;
 				String fileName= file.getName();
@@ -426,6 +424,7 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 	 *
 	 * @return the content of the package input field
 	 */
+	@Override
 	public String getPackageText() {
 		return fPackageDialogField.getText();
 	}
@@ -459,6 +458,7 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 	 * @return A resource or null if the page contains illegal values.
 	 * @since 3.0
 	 */
+	@Override
 	public IResource getModifiedResource() {
 		IPackageFragmentRoot root= getPackageFragmentRoot();
 		if (root != null) {
@@ -485,15 +485,13 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 	 *
 	 * @return the runnable that creates the new package
 	 */
+	@Override
 	public IRunnableWithProgress getRunnable() {
-		return new IRunnableWithProgress() {
-			@Override
-			public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
-				try {
-					createPackage(monitor);
-				} catch (CoreException e) {
-					throw new InvocationTargetException(e);
-				}
+		return monitor -> {
+			try {
+				createPackage(monitor);
+			} catch (CoreException e) {
+				throw new InvocationTargetException(e);
 			}
 		};
 	}
@@ -525,7 +523,7 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 
 		IPackageFragmentRoot root= getPackageFragmentRoot();
 		IPackageFragment pack= root.getPackageFragment(getPackageText());
-		
+
 		if (pack.exists()) {
 			fCreatedPackageFragment= pack;
 		} else {
@@ -645,5 +643,5 @@ public class NewPackageWizardPage extends NewTypeWizardPage {
 		}
 		return buf.toString();
 	}
-	
+
 }
