@@ -14,7 +14,6 @@
 package org.eclipse.ltk.core.refactoring;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.core.runtime.Assert;
@@ -142,9 +141,7 @@ public class RefactoringStatus {
 	 */
 	public RefactoringStatusEntry[] getEntries(IRefactoringStatusEntryComparator comparator, RefactoringStatusEntry entry) {
 		final List<RefactoringStatusEntry> matches= new ArrayList<>(fEntries.size());
-		RefactoringStatusEntry current= null;
-		for (Iterator<RefactoringStatusEntry> iterator= fEntries.iterator(); iterator.hasNext();) {
-			current= iterator.next();
+		for (RefactoringStatusEntry current : fEntries) {
 			if (comparator.compare(current, entry) == 0)
 				matches.add(current);
 		}
@@ -208,9 +205,7 @@ public class RefactoringStatus {
 		Assert.isTrue(severity >= OK && severity <= FATAL);
 		if (severity > fSeverity)
 			return null;
-		Iterator<RefactoringStatusEntry> iter= fEntries.iterator();
-		while (iter.hasNext()) {
-			RefactoringStatusEntry entry= iter.next();
+		for (RefactoringStatusEntry entry : fEntries) {
 			if (entry.getSeverity() >= severity)
 				return entry;
 		}
@@ -675,9 +670,9 @@ public class RefactoringStatus {
 		buff.append("<") //$NON-NLS-1$
 			.append(getSeverityString(fSeverity)).append("\n"); //$NON-NLS-1$
 		if (!isOK()) {
-			for (Iterator<RefactoringStatusEntry> iter= fEntries.iterator(); iter.hasNext(); ) {
+			for (RefactoringStatusEntry refactoringStatusEntry : fEntries) {
 				buff.append("\t") //$NON-NLS-1$
-					.append(iter.next()).append("\n"); //$NON-NLS-1$
+					.append(refactoringStatusEntry).append("\n"); //$NON-NLS-1$
 			}
 		}
 		buff.append(">"); //$NON-NLS-1$
