@@ -13,7 +13,7 @@ public class TestCaseClassLoaderTest extends TestCase {
 
 	public void testClassLoading() throws Exception {
 		TestCaseClassLoader loader= new TestCaseClassLoader();
-		Class loadedClass= loader.loadClass("junit.tests.runner.ClassLoaderTest", true);
+		Class<?> loadedClass= loader.loadClass("junit.tests.runner.ClassLoaderTest", true);
 		Object o= loadedClass.newInstance();
 		//
 		// Invoke the assertClassLoaders method via reflection.
@@ -30,7 +30,7 @@ public class TestCaseClassLoaderTest extends TestCase {
 		assertNotNull("Cannot find test.jar", url);
 		String path= url.getFile();
 		TestCaseClassLoader loader= new TestCaseClassLoader(path);
-		Class loadedClass= loader.loadClass("junit.tests.runner.LoadedFromJar", true);
+		Class<?> loadedClass= loader.loadClass("junit.tests.runner.LoadedFromJar", true);
 		Object o= loadedClass.newInstance();
 		//
 		// Invoke the assertClassLoaders method via reflection.
